function(){return function(){var h,l=this;function m(a){return void 0!==a}function aa(a,b){var c=a.split("."),d=l;c[0]in d||!d.execScript||d.execScript("var "+c[0]);for(var e;c.length&&(e=c.shift());)!c.length&&m(b)?d[e]=b:d[e]?d=d[e]:d=d[e]={}}
function ba(a){var b=typeof a;if("object"==b)if(a){if(a instanceof Array)return"array";if(a instanceof Object)return b;var c=Object.prototype.toString.call(a);if("[object Window]"==c)return"object";if("[object Array]"==c||"number"==typeof a.length&&"undefined"!=typeof a.splice&&"undefined"!=typeof a.propertyIsEnumerable&&!a.propertyIsEnumerable("splice"))return"array";if("[object Function]"==c||"undefined"!=typeof a.call&&"undefined"!=typeof a.propertyIsEnumerable&&!a.propertyIsEnumerable("call"))return"function"}else return"null";
else if("function"==b&&"undefined"==typeof a.call)return"object";return b}function ca(a){var b=ba(a);return"array"==b||"object"==b&&"number"==typeof a.length}function p(a){return"string"==typeof a}function ea(a){return"number"==typeof a}function fa(a){var b=typeof a;return"object"==b&&null!=a||"function"==b}function ga(a,b,c){return a.call.apply(a.bind,arguments)}
function ha(a,b,c){if(!a)throw Error();if(2<arguments.length){var d=Array.prototype.slice.call(arguments,2);return function(){var c=Array.prototype.slice.call(arguments);Array.prototype.unshift.apply(c,d);return a.apply(b,c)}}return function(){return a.apply(b,arguments)}}function ia(a,b,c){ia=Function.prototype.bind&&-1!=Function.prototype.bind.toString().indexOf("native code")?ga:ha;return ia.apply(null,arguments)}
function ja(a,b){var c=Array.prototype.slice.call(arguments,1);return function(){var b=c.slice();b.push.apply(b,arguments);return a.apply(this,b)}}var ka=Date.now||function(){return+new Date};function q(a,b){function c(){}c.prototype=b.prototype;a.R=b.prototype;a.prototype=new c;a.prototype.constructor=a;a.O=function(a,c,f){for(var g=Array(arguments.length-2),k=2;k<arguments.length;k++)g[k-2]=arguments[k];return b.prototype[c].apply(a,g)}};function la(a){var b=a.length-1;return 0<=b&&a.indexOf(" ",b)==b}var ma=String.prototype.trim?function(a){return a.trim()}:function(a){return a.replace(/^[\s\xa0]+|[\s\xa0]+$/g,"")};
function na(a,b){for(var c=0,d=ma(String(a)).split("."),e=ma(String(b)).split("."),f=Math.max(d.length,e.length),g=0;0==c&&g<f;g++){var k=d[g]||"",r=e[g]||"",t=RegExp("(\\d*)(\\D*)","g"),n=RegExp("(\\d*)(\\D*)","g");do{var x=t.exec(k)||["","",""],G=n.exec(r)||["","",""];if(0==x[0].length&&0==G[0].length)break;c=oa(0==x[1].length?0:parseInt(x[1],10),0==G[1].length?0:parseInt(G[1],10))||oa(0==x[2].length,0==G[2].length)||oa(x[2],G[2])}while(0==c)}return c}function oa(a,b){return a<b?-1:a>b?1:0}
function pa(a){return String(a).replace(/\-([a-z])/g,function(a,c){return c.toUpperCase()})};function qa(a,b){if(p(a))return p(b)&&1==b.length?a.indexOf(b,0):-1;for(var c=0;c<a.length;c++)if(c in a&&a[c]===b)return c;return-1}function u(a,b){for(var c=a.length,d=p(a)?a.split(""):a,e=0;e<c;e++)e in d&&b.call(void 0,d[e],e,a)}function ra(a,b){for(var c=a.length,d=[],e=0,f=p(a)?a.split(""):a,g=0;g<c;g++)if(g in f){var k=f[g];b.call(void 0,k,g,a)&&(d[e++]=k)}return d}
function sa(a,b){for(var c=a.length,d=Array(c),e=p(a)?a.split(""):a,f=0;f<c;f++)f in e&&(d[f]=b.call(void 0,e[f],f,a));return d}function ta(a,b,c){var d=c;u(a,function(c,f){d=b.call(void 0,d,c,f,a)});return d}function ua(a,b){for(var c=a.length,d=p(a)?a.split(""):a,e=0;e<c;e++)if(e in d&&b.call(void 0,d[e],e,a))return!0;return!1}function va(a,b){for(var c=a.length,d=p(a)?a.split(""):a,e=0;e<c;e++)if(e in d&&!b.call(void 0,d[e],e,a))return!1;return!0}
function wa(a,b){var c;a:{c=a.length;for(var d=p(a)?a.split(""):a,e=0;e<c;e++)if(e in d&&b.call(void 0,d[e],e,a)){c=e;break a}c=-1}return 0>c?null:p(a)?a.charAt(c):a[c]}function xa(a){return Array.prototype.concat.apply(Array.prototype,arguments)}function za(a,b,c){return 2>=arguments.length?Array.prototype.slice.call(a,b):Array.prototype.slice.call(a,b,c)};var Aa={aliceblue:"#f0f8ff",antiquewhite:"#faebd7",aqua:"#00ffff",aquamarine:"#7fffd4",azure:"#f0ffff",beige:"#f5f5dc",bisque:"#ffe4c4",black:"#000000",blanchedalmond:"#ffebcd",blue:"#0000ff",blueviolet:"#8a2be2",brown:"#a52a2a",burlywood:"#deb887",cadetblue:"#5f9ea0",chartreuse:"#7fff00",chocolate:"#d2691e",coral:"#ff7f50",cornflowerblue:"#6495ed",cornsilk:"#fff8dc",crimson:"#dc143c",cyan:"#00ffff",darkblue:"#00008b",darkcyan:"#008b8b",darkgoldenrod:"#b8860b",darkgray:"#a9a9a9",darkgreen:"#006400",
darkgrey:"#a9a9a9",darkkhaki:"#bdb76b",darkmagenta:"#8b008b",darkolivegreen:"#556b2f",darkorange:"#ff8c00",darkorchid:"#9932cc",darkred:"#8b0000",darksalmon:"#e9967a",darkseagreen:"#8fbc8f",darkslateblue:"#483d8b",darkslategray:"#2f4f4f",darkslategrey:"#2f4f4f",darkturquoise:"#00ced1",darkviolet:"#9400d3",deeppink:"#ff1493",deepskyblue:"#00bfff",dimgray:"#696969",dimgrey:"#696969",dodgerblue:"#1e90ff",firebrick:"#b22222",floralwhite:"#fffaf0",forestgreen:"#228b22",fuchsia:"#ff00ff",gainsboro:"#dcdcdc",
ghostwhite:"#f8f8ff",gold:"#ffd700",goldenrod:"#daa520",gray:"#808080",green:"#008000",greenyellow:"#adff2f",grey:"#808080",honeydew:"#f0fff0",hotpink:"#ff69b4",indianred:"#cd5c5c",indigo:"#4b0082",ivory:"#fffff0",khaki:"#f0e68c",lavender:"#e6e6fa",lavenderblush:"#fff0f5",lawngreen:"#7cfc00",lemonchiffon:"#fffacd",lightblue:"#add8e6",lightcoral:"#f08080",lightcyan:"#e0ffff",lightgoldenrodyellow:"#fafad2",lightgray:"#d3d3d3",lightgreen:"#90ee90",lightgrey:"#d3d3d3",lightpink:"#ffb6c1",lightsalmon:"#ffa07a",
lightseagreen:"#20b2aa",lightskyblue:"#87cefa",lightslategray:"#778899",lightslategrey:"#778899",lightsteelblue:"#b0c4de",lightyellow:"#ffffe0",lime:"#00ff00",limegreen:"#32cd32",linen:"#faf0e6",magenta:"#ff00ff",maroon:"#800000",mediumaquamarine:"#66cdaa",mediumblue:"#0000cd",mediumorchid:"#ba55d3",mediumpurple:"#9370db",mediumseagreen:"#3cb371",mediumslateblue:"#7b68ee",mediumspringgreen:"#00fa9a",mediumturquoise:"#48d1cc",mediumvioletred:"#c71585",midnightblue:"#191970",mintcream:"#f5fffa",mistyrose:"#ffe4e1",
moccasin:"#ffe4b5",navajowhite:"#ffdead",navy:"#000080",oldlace:"#fdf5e6",olive:"#808000",olivedrab:"#6b8e23",orange:"#ffa500",orangered:"#ff4500",orchid:"#da70d6",palegoldenrod:"#eee8aa",palegreen:"#98fb98",paleturquoise:"#afeeee",palevioletred:"#db7093",papayawhip:"#ffefd5",peachpuff:"#ffdab9",peru:"#cd853f",pink:"#ffc0cb",plum:"#dda0dd",powderblue:"#b0e0e6",purple:"#800080",red:"#ff0000",rosybrown:"#bc8f8f",royalblue:"#4169e1",saddlebrown:"#8b4513",salmon:"#fa8072",sandybrown:"#f4a460",seagreen:"#2e8b57",
seashell:"#fff5ee",sienna:"#a0522d",silver:"#c0c0c0",skyblue:"#87ceeb",slateblue:"#6a5acd",slategray:"#708090",slategrey:"#708090",snow:"#fffafa",springgreen:"#00ff7f",steelblue:"#4682b4",tan:"#d2b48c",teal:"#008080",thistle:"#d8bfd8",tomato:"#ff6347",turquoise:"#40e0d0",violet:"#ee82ee",wheat:"#f5deb3",white:"#ffffff",whitesmoke:"#f5f5f5",yellow:"#ffff00",yellowgreen:"#9acd32"};var Ba="backgroundColor borderTopColor borderRightColor borderBottomColor borderLeftColor color outlineColor".split(" "),Ca=/#([0-9a-fA-F])([0-9a-fA-F])([0-9a-fA-F])/,Da=/^#(?:[0-9a-f]{3}){1,2}$/i,Ea=/^(?:rgba)?\((\d{1,3}),\s?(\d{1,3}),\s?(\d{1,3}),\s?(0|1|0\.\d*)\)$/i,Fa=/^(?:rgb)?\((0|[1-9]\d{0,2}),\s?(0|[1-9]\d{0,2}),\s?(0|[1-9]\d{0,2})\)$/i;function Ga(a,b){this.code=a;this.a=v[a]||Ha;this.message=b||"";var c=this.a.replace(/((?:^|\s+)[a-z])/g,function(a){return a.toUpperCase().replace(/^[\s\xa0]+/g,"")}),d=c.length-5;if(0>d||c.indexOf("Error",d)!=d)c+="Error";this.name=c;c=Error(this.message);c.name=this.name;this.stack=c.stack||""}q(Ga,Error);var Ha="unknown error",v={15:"element not selectable",11:"element not visible"};v[31]=Ha;v[30]=Ha;v[24]="invalid cookie domain";v[29]="invalid element coordinates";v[12]="invalid element state";
v[32]="invalid selector";v[51]="invalid selector";v[52]="invalid selector";v[17]="javascript error";v[405]="unsupported operation";v[34]="move target out of bounds";v[27]="no such alert";v[7]="no such element";v[8]="no such frame";v[23]="no such window";v[28]="script timeout";v[33]="session not created";v[10]="stale element reference";v[21]="timeout";v[25]="unable to set cookie";v[26]="unexpected alert open";v[13]=Ha;v[9]="unknown command";Ga.prototype.toString=function(){return this.name+": "+this.message};var w;a:{var Ia=l.navigator;if(Ia){var Ja=Ia.userAgent;if(Ja){w=Ja;break a}}w=""}function y(a){return-1!=w.indexOf(a)};function Ka(a,b){var c={},d;for(d in a)b.call(void 0,a[d],d,a)&&(c[d]=a[d]);return c}function La(a,b){var c={},d;for(d in a)c[d]=b.call(void 0,a[d],d,a);return c}function Ma(a,b){return null!==a&&b in a}function Na(a,b){for(var c in a)if(b.call(void 0,a[c],c,a))return c};function Oa(){return y("Opera")||y("OPR")}function Pa(){return(y("Chrome")||y("CriOS"))&&!Oa()&&!y("Edge")};function Qa(){return y("iPhone")&&!y("iPod")&&!y("iPad")};var Ra=Oa(),z=y("Trident")||y("MSIE"),Sa=y("Edge"),A=y("Gecko")&&!(-1!=w.toLowerCase().indexOf("webkit")&&!y("Edge"))&&!(y("Trident")||y("MSIE"))&&!y("Edge"),Ta=-1!=w.toLowerCase().indexOf("webkit")&&!y("Edge"),Ua=y("Macintosh"),Va=y("Windows");function Wa(){var a=w;if(A)return/rv\:([^\);]+)(\)|;)/.exec(a);if(Sa)return/Edge\/([\d\.]+)/.exec(a);if(z)return/\b(?:MSIE|rv)[: ]([^\);]+)(\)|;)/.exec(a);if(Ta)return/WebKit\/(\S+)/.exec(a)}function Xa(){var a=l.document;return a?a.documentMode:void 0}
var Ya=function(){if(Ra&&l.opera){var a;var b=l.opera.version;try{a=b()}catch(c){a=b}return a}a="";(b=Wa())&&(a=b?b[1]:"");return z&&(b=Xa(),null!=b&&b>parseFloat(a))?String(b):a}(),Za={};function $a(a){return Za[a]||(Za[a]=0<=na(Ya,a))}var ab=l.document,bb=ab&&z?Xa()||("CSS1Compat"==ab.compatMode?parseInt(Ya,10):5):void 0;!A&&!z||z&&9<=Number(bb)||A&&$a("1.9.1");z&&$a("9");function cb(a,b){this.x=m(a)?a:0;this.y=m(b)?b:0}h=cb.prototype;h.clone=function(){return new cb(this.x,this.y)};h.toString=function(){return"("+this.x+", "+this.y+")"};h.ceil=function(){this.x=Math.ceil(this.x);this.y=Math.ceil(this.y);return this};h.floor=function(){this.x=Math.floor(this.x);this.y=Math.floor(this.y);return this};h.round=function(){this.x=Math.round(this.x);this.y=Math.round(this.y);return this};h.scale=function(a,b){var c=ea(b)?b:a;this.x*=a;this.y*=c;return this};function db(a,b){this.width=a;this.height=b}h=db.prototype;h.clone=function(){return new db(this.width,this.height)};h.toString=function(){return"("+this.width+" x "+this.height+")"};h.ceil=function(){this.width=Math.ceil(this.width);this.height=Math.ceil(this.height);return this};h.floor=function(){this.width=Math.floor(this.width);this.height=Math.floor(this.height);return this};h.round=function(){this.width=Math.round(this.width);this.height=Math.round(this.height);return this};
h.scale=function(a,b){var c=ea(b)?b:a;this.width*=a;this.height*=c;return this};function eb(a){for(;a&&1!=a.nodeType;)a=a.previousSibling;return a}function fb(a,b){if(!a||!b)return!1;if(a.contains&&1==b.nodeType)return a==b||a.contains(b);if("undefined"!=typeof a.compareDocumentPosition)return a==b||!!(a.compareDocumentPosition(b)&16);for(;b&&a!=b;)b=b.parentNode;return b==a}
function gb(a,b){if(a==b)return 0;if(a.compareDocumentPosition)return a.compareDocumentPosition(b)&2?1:-1;if(z&&!(9<=Number(bb))){if(9==a.nodeType)return-1;if(9==b.nodeType)return 1}if("sourceIndex"in a||a.parentNode&&"sourceIndex"in a.parentNode){var c=1==a.nodeType,d=1==b.nodeType;if(c&&d)return a.sourceIndex-b.sourceIndex;var e=a.parentNode,f=b.parentNode;return e==f?hb(a,b):!c&&fb(e,b)?-1*ib(a,b):!d&&fb(f,a)?ib(b,a):(c?a.sourceIndex:e.sourceIndex)-(d?b.sourceIndex:f.sourceIndex)}d=B(a);c=d.createRange();
c.selectNode(a);c.collapse(!0);d=d.createRange();d.selectNode(b);d.collapse(!0);return c.compareBoundaryPoints(l.Range.START_TO_END,d)}function ib(a,b){var c=a.parentNode;if(c==b)return-1;for(var d=b;d.parentNode!=c;)d=d.parentNode;return hb(d,a)}function hb(a,b){for(var c=b;c=c.previousSibling;)if(c==a)return-1;return 1}function B(a){return 9==a.nodeType?a:a.ownerDocument||a.document}function jb(a,b){a=a.parentNode;for(var c=0;a;){if(b(a))return a;a=a.parentNode;c++}return null}
function kb(a){this.a=a||l.document||document}kb.prototype.contains=fb;var lb=y("Firefox"),mb=Qa()||y("iPod"),nb=y("iPad"),ob=y("Android")&&!(Pa()||y("Firefox")||Oa()||y("Silk")),pb=Pa(),qb=y("Safari")&&!(Pa()||y("Coast")||Oa()||y("Edge")||y("Silk")||y("Android"))&&!(Qa()||y("iPad")||y("iPod"));/*

 The MIT License

 Copyright (c) 2007 Cybozu Labs, Inc.
 Copyright (c) 2012 Google Inc.

 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to
 deal in the Software without restriction, including without limitation the
 rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
 sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in
 all copies or substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 IN THE SOFTWARE.
*/
function rb(a,b,c){this.a=a;this.b=b||1;this.h=c||1};var C=z&&!(9<=Number(bb)),sb=z&&!(8<=Number(bb));function tb(a,b,c,d){this.a=a;this.nodeName=c;this.nodeValue=d;this.nodeType=2;this.parentNode=this.ownerElement=b}function ub(a,b){var c=sb&&"href"==b.nodeName?a.getAttribute(b.nodeName,2):b.nodeValue;return new tb(b,a,b.nodeName,c)};function vb(a){this.b=a;this.a=0}function wb(a){a=a.match(xb);for(var b=0;b<a.length;b++)yb.test(a[b])&&a.splice(b,1);return new vb(a)}var xb=RegExp("\\$?(?:(?![0-9-\\.])(?:\\*|[\\w-\\.]+):)?(?![0-9-\\.])(?:\\*|[\\w-\\.]+)|\\/\\/|\\.\\.|::|\\d+(?:\\.\\d*)?|\\.\\d+|\"[^\"]*\"|'[^']*'|[!<>]=|\\s+|.","g"),yb=/^\s/;function D(a,b){return a.b[a.a+(b||0)]}function E(a){return a.b[a.a++]}function zb(a){return a.b.length<=a.a};function F(a){var b=null,c=a.nodeType;1==c&&(b=a.textContent,b=void 0==b||null==b?a.innerText:b,b=void 0==b||null==b?"":b);if("string"!=typeof b)if(C&&"title"==a.nodeName.toLowerCase()&&1==c)b=a.text;else if(9==c||1==c){a=9==c?a.documentElement:a.firstChild;for(var c=0,d=[],b="";a;){do 1!=a.nodeType&&(b+=a.nodeValue),C&&"title"==a.nodeName.toLowerCase()&&(b+=a.text),d[c++]=a;while(a=a.firstChild);for(;c&&!(a=d[--c].nextSibling););}}else b=a.nodeValue;return""+b}
function Ab(a,b,c){if(null===b)return!0;try{if(!a.getAttribute)return!1}catch(d){return!1}sb&&"class"==b&&(b="className");return null==c?!!a.getAttribute(b):a.getAttribute(b,2)==c}function Bb(a,b,c,d,e){return(C?Cb:Db).call(null,a,b,p(c)?c:null,p(d)?d:null,e||new H)}
function Cb(a,b,c,d,e){if(a instanceof Eb||8==a.b||c&&null===a.b){var f=b.all;if(!f)return e;a=Fb(a);if("*"!=a&&(f=b.getElementsByTagName(a),!f))return e;if(c){for(var g=[],k=0;b=f[k++];)Ab(b,c,d)&&g.push(b);f=g}for(k=0;b=f[k++];)"*"==a&&"!"==b.tagName||I(e,b);return e}Gb(a,b,c,d,e);return e}
function Db(a,b,c,d,e){b.getElementsByName&&d&&"name"==c&&!z?(b=b.getElementsByName(d),u(b,function(b){a.a(b)&&I(e,b)})):b.getElementsByClassName&&d&&"class"==c?(b=b.getElementsByClassName(d),u(b,function(b){b.className==d&&a.a(b)&&I(e,b)})):a instanceof J?Gb(a,b,c,d,e):b.getElementsByTagName&&(b=b.getElementsByTagName(a.h()),u(b,function(a){Ab(a,c,d)&&I(e,a)}));return e}
function Hb(a,b,c,d,e){var f;if((a instanceof Eb||8==a.b||c&&null===a.b)&&(f=b.childNodes)){var g=Fb(a);if("*"!=g&&(f=ra(f,function(a){return a.tagName&&a.tagName.toLowerCase()==g}),!f))return e;c&&(f=ra(f,function(a){return Ab(a,c,d)}));u(f,function(a){"*"==g&&("!"==a.tagName||"*"==g&&1!=a.nodeType)||I(e,a)});return e}return Ib(a,b,c,d,e)}function Ib(a,b,c,d,e){for(b=b.firstChild;b;b=b.nextSibling)Ab(b,c,d)&&a.a(b)&&I(e,b);return e}
function Gb(a,b,c,d,e){for(b=b.firstChild;b;b=b.nextSibling)Ab(b,c,d)&&a.a(b)&&I(e,b),Gb(a,b,c,d,e)}function Fb(a){if(a instanceof J){if(8==a.b)return"!";if(null===a.b)return"*"}return a.h()};function H(){this.b=this.a=null;this.s=0}function Jb(a){this.node=a;this.a=this.b=null}function Kb(a,b){if(!a.a)return b;if(!b.a)return a;for(var c=a.a,d=b.a,e=null,f=null,g=0;c&&d;){var f=c.node,k=d.node;f==k||f instanceof tb&&k instanceof tb&&f.a==k.a?(f=c,c=c.a,d=d.a):0<gb(c.node,d.node)?(f=d,d=d.a):(f=c,c=c.a);(f.b=e)?e.a=f:a.a=f;e=f;g++}for(f=c||d;f;)f.b=e,e=e.a=f,g++,f=f.a;a.b=e;a.s=g;return a}
H.prototype.unshift=function(a){a=new Jb(a);a.a=this.a;this.b?this.a.b=a:this.a=this.b=a;this.a=a;this.s++};function I(a,b){var c=new Jb(b);c.b=a.b;a.a?a.b.a=c:a.a=a.b=c;a.b=c;a.s++}function Lb(a){return(a=a.a)?a.node:null}function Mb(a){return(a=Lb(a))?F(a):""}function Nb(a,b){return new Ob(a,!!b)}function Ob(a,b){this.h=a;this.b=(this.c=b)?a.b:a.a;this.a=null}function K(a){var b=a.b;if(null==b)return null;var c=a.a=b;a.b=a.c?b.b:b.a;return c.node};function L(a){this.m=a;this.b=this.i=!1;this.h=null}function M(a){return"\n  "+a.toString().split("\n").join("\n  ")}function Pb(a,b){a.i=b}function Qb(a,b){a.b=b}function N(a,b){var c=a.a(b);return c instanceof H?+Mb(c):+c}function O(a,b){var c=a.a(b);return c instanceof H?Mb(c):""+c}function Rb(a,b){var c=a.a(b);return c instanceof H?!!c.s:!!c};function Sb(a,b,c){L.call(this,a.m);this.c=a;this.j=b;this.w=c;this.i=b.i||c.i;this.b=b.b||c.b;this.c==Tb&&(c.b||c.i||4==c.m||0==c.m||!b.h?b.b||b.i||4==b.m||0==b.m||!c.h||(this.h={name:c.h.name,A:b}):this.h={name:b.h.name,A:c})}q(Sb,L);
function Ub(a,b,c,d,e){b=b.a(d);c=c.a(d);var f;if(b instanceof H&&c instanceof H){b=Nb(b);for(d=K(b);d;d=K(b))for(e=Nb(c),f=K(e);f;f=K(e))if(a(F(d),F(f)))return!0;return!1}if(b instanceof H||c instanceof H){b instanceof H?(e=b,d=c):(e=c,d=b);f=Nb(e);for(var g=typeof d,k=K(f);k;k=K(f)){switch(g){case "number":k=+F(k);break;case "boolean":k=!!F(k);break;case "string":k=F(k);break;default:throw Error("Illegal primitive type for comparison.");}if(e==b&&a(k,d)||e==c&&a(d,k))return!0}return!1}return e?
"boolean"==typeof b||"boolean"==typeof c?a(!!b,!!c):"number"==typeof b||"number"==typeof c?a(+b,+c):a(b,c):a(+b,+c)}Sb.prototype.a=function(a){return this.c.u(this.j,this.w,a)};Sb.prototype.toString=function(){var a="Binary Expression: "+this.c,a=a+M(this.j);return a+=M(this.w)};function Vb(a,b,c,d){this.a=a;this.I=b;this.m=c;this.u=d}Vb.prototype.toString=function(){return this.a};var Wb={};
function P(a,b,c,d){if(Wb.hasOwnProperty(a))throw Error("Binary operator already created: "+a);a=new Vb(a,b,c,d);return Wb[a.toString()]=a}P("div",6,1,function(a,b,c){return N(a,c)/N(b,c)});P("mod",6,1,function(a,b,c){return N(a,c)%N(b,c)});P("*",6,1,function(a,b,c){return N(a,c)*N(b,c)});P("+",5,1,function(a,b,c){return N(a,c)+N(b,c)});P("-",5,1,function(a,b,c){return N(a,c)-N(b,c)});P("<",4,2,function(a,b,c){return Ub(function(a,b){return a<b},a,b,c)});
P(">",4,2,function(a,b,c){return Ub(function(a,b){return a>b},a,b,c)});P("<=",4,2,function(a,b,c){return Ub(function(a,b){return a<=b},a,b,c)});P(">=",4,2,function(a,b,c){return Ub(function(a,b){return a>=b},a,b,c)});var Tb=P("=",3,2,function(a,b,c){return Ub(function(a,b){return a==b},a,b,c,!0)});P("!=",3,2,function(a,b,c){return Ub(function(a,b){return a!=b},a,b,c,!0)});P("and",2,2,function(a,b,c){return Rb(a,c)&&Rb(b,c)});P("or",1,2,function(a,b,c){return Rb(a,c)||Rb(b,c)});function Xb(a,b){if(b.a.length&&4!=a.m)throw Error("Primary expression must evaluate to nodeset if filter has predicate(s).");L.call(this,a.m);this.c=a;this.j=b;this.i=a.i;this.b=a.b}q(Xb,L);Xb.prototype.a=function(a){a=this.c.a(a);return Yb(this.j,a)};Xb.prototype.toString=function(){var a;a="Filter:"+M(this.c);return a+=M(this.j)};function Zb(a,b){if(b.length<a.J)throw Error("Function "+a.o+" expects at least"+a.J+" arguments, "+b.length+" given");if(null!==a.D&&b.length>a.D)throw Error("Function "+a.o+" expects at most "+a.D+" arguments, "+b.length+" given");a.N&&u(b,function(b,d){if(4!=b.m)throw Error("Argument "+d+" to function "+a.o+" is not of type Nodeset: "+b);});L.call(this,a.m);this.j=a;this.c=b;Pb(this,a.i||ua(b,function(a){return a.i}));Qb(this,a.M&&!b.length||a.L&&!!b.length||ua(b,function(a){return a.b}))}
q(Zb,L);Zb.prototype.a=function(a){return this.j.u.apply(null,xa(a,this.c))};Zb.prototype.toString=function(){var a="Function: "+this.j;if(this.c.length)var b=ta(this.c,function(a,b){return a+M(b)},"Arguments:"),a=a+M(b);return a};function $b(a,b,c,d,e,f,g,k,r){this.o=a;this.m=b;this.i=c;this.M=d;this.L=e;this.u=f;this.J=g;this.D=m(k)?k:g;this.N=!!r}$b.prototype.toString=function(){return this.o};var ac={};
function Q(a,b,c,d,e,f,g,k){if(ac.hasOwnProperty(a))throw Error("Function already created: "+a+".");ac[a]=new $b(a,b,c,d,!1,e,f,g,k)}Q("boolean",2,!1,!1,function(a,b){return Rb(b,a)},1);Q("ceiling",1,!1,!1,function(a,b){return Math.ceil(N(b,a))},1);Q("concat",3,!1,!1,function(a,b){return ta(za(arguments,1),function(b,d){return b+O(d,a)},"")},2,null);Q("contains",2,!1,!1,function(a,b,c){b=O(b,a);a=O(c,a);return-1!=b.indexOf(a)},2);Q("count",1,!1,!1,function(a,b){return b.a(a).s},1,1,!0);
Q("false",2,!1,!1,function(){return!1},0);Q("floor",1,!1,!1,function(a,b){return Math.floor(N(b,a))},1);Q("id",4,!1,!1,function(a,b){function c(a){if(C){var b=e.all[a];if(b){if(b.nodeType&&a==b.id)return b;if(b.length)return wa(b,function(b){return a==b.id})}return null}return e.getElementById(a)}var d=a.a,e=9==d.nodeType?d:d.ownerDocument,d=O(b,a).split(/\s+/),f=[];u(d,function(a){a=c(a);!a||0<=qa(f,a)||f.push(a)});f.sort(gb);var g=new H;u(f,function(a){I(g,a)});return g},1);
Q("lang",2,!1,!1,function(){return!1},1);Q("last",1,!0,!1,function(a){if(1!=arguments.length)throw Error("Function last expects ()");return a.h},0);Q("local-name",3,!1,!0,function(a,b){var c=b?Lb(b.a(a)):a.a;return c?c.localName||c.nodeName.toLowerCase():""},0,1,!0);Q("name",3,!1,!0,function(a,b){var c=b?Lb(b.a(a)):a.a;return c?c.nodeName.toLowerCase():""},0,1,!0);Q("namespace-uri",3,!0,!1,function(){return""},0,1,!0);
Q("normalize-space",3,!1,!0,function(a,b){return(b?O(b,a):F(a.a)).replace(/[\s\xa0]+/g," ").replace(/^\s+|\s+$/g,"")},0,1);Q("not",2,!1,!1,function(a,b){return!Rb(b,a)},1);Q("number",1,!1,!0,function(a,b){return b?N(b,a):+F(a.a)},0,1);Q("position",1,!0,!1,function(a){return a.b},0);Q("round",1,!1,!1,function(a,b){return Math.round(N(b,a))},1);Q("starts-with",2,!1,!1,function(a,b,c){b=O(b,a);a=O(c,a);return 0==b.lastIndexOf(a,0)},2);Q("string",3,!1,!0,function(a,b){return b?O(b,a):F(a.a)},0,1);
Q("string-length",1,!1,!0,function(a,b){return(b?O(b,a):F(a.a)).length},0,1);Q("substring",3,!1,!1,function(a,b,c,d){c=N(c,a);if(isNaN(c)||Infinity==c||-Infinity==c)return"";d=d?N(d,a):Infinity;if(isNaN(d)||-Infinity===d)return"";c=Math.round(c)-1;var e=Math.max(c,0);a=O(b,a);return Infinity==d?a.substring(e):a.substring(e,c+Math.round(d))},2,3);Q("substring-after",3,!1,!1,function(a,b,c){b=O(b,a);a=O(c,a);c=b.indexOf(a);return-1==c?"":b.substring(c+a.length)},2);
Q("substring-before",3,!1,!1,function(a,b,c){b=O(b,a);a=O(c,a);a=b.indexOf(a);return-1==a?"":b.substring(0,a)},2);Q("sum",1,!1,!1,function(a,b){for(var c=Nb(b.a(a)),d=0,e=K(c);e;e=K(c))d+=+F(e);return d},1,1,!0);Q("translate",3,!1,!1,function(a,b,c,d){b=O(b,a);c=O(c,a);var e=O(d,a);a={};for(d=0;d<c.length;d++){var f=c.charAt(d);f in a||(a[f]=e.charAt(d))}c="";for(d=0;d<b.length;d++)f=b.charAt(d),c+=f in a?a[f]:f;return c},3);Q("true",2,!1,!1,function(){return!0},0);function J(a,b){this.j=a;this.c=m(b)?b:null;this.b=null;switch(a){case "comment":this.b=8;break;case "text":this.b=3;break;case "processing-instruction":this.b=7;break;case "node":break;default:throw Error("Unexpected argument");}}function bc(a){return"comment"==a||"text"==a||"processing-instruction"==a||"node"==a}J.prototype.a=function(a){return null===this.b||this.b==a.nodeType};J.prototype.h=function(){return this.j};
J.prototype.toString=function(){var a="Kind Test: "+this.j;null===this.c||(a+=M(this.c));return a};function cc(a){L.call(this,3);this.c=a.substring(1,a.length-1)}q(cc,L);cc.prototype.a=function(){return this.c};cc.prototype.toString=function(){return"Literal: "+this.c};function Eb(a,b){this.o=a.toLowerCase();var c;c="*"==this.o?"*":"http://www.w3.org/1999/xhtml";this.c=b?b.toLowerCase():c}Eb.prototype.a=function(a){var b=a.nodeType;return 1!=b&&2!=b?!1:"*"!=this.o&&this.o!=a.localName.toLowerCase()?!1:"*"==this.c?!0:this.c==(a.namespaceURI?a.namespaceURI.toLowerCase():"http://www.w3.org/1999/xhtml")};Eb.prototype.h=function(){return this.o};Eb.prototype.toString=function(){return"Name Test: "+("http://www.w3.org/1999/xhtml"==this.c?"":this.c+":")+this.o};function dc(a){L.call(this,1);this.c=a}q(dc,L);dc.prototype.a=function(){return this.c};dc.prototype.toString=function(){return"Number: "+this.c};function ec(a,b){L.call(this,a.m);this.j=a;this.c=b;this.i=a.i;this.b=a.b;if(1==this.c.length){var c=this.c[0];c.B||c.c!=fc||(c=c.w,"*"!=c.h()&&(this.h={name:c.h(),A:null}))}}q(ec,L);function gc(){L.call(this,4)}q(gc,L);gc.prototype.a=function(a){var b=new H;a=a.a;9==a.nodeType?I(b,a):I(b,a.ownerDocument);return b};gc.prototype.toString=function(){return"Root Helper Expression"};function hc(){L.call(this,4)}q(hc,L);hc.prototype.a=function(a){var b=new H;I(b,a.a);return b};hc.prototype.toString=function(){return"Context Helper Expression"};
function ic(a){return"/"==a||"//"==a}ec.prototype.a=function(a){var b=this.j.a(a);if(!(b instanceof H))throw Error("Filter expression must evaluate to nodeset.");a=this.c;for(var c=0,d=a.length;c<d&&b.s;c++){var e=a[c],f=Nb(b,e.c.a),g;if(e.i||e.c!=jc)if(e.i||e.c!=kc)for(g=K(f),b=e.a(new rb(g));null!=(g=K(f));)g=e.a(new rb(g)),b=Kb(b,g);else g=K(f),b=e.a(new rb(g));else{for(g=K(f);(b=K(f))&&(!g.contains||g.contains(b))&&b.compareDocumentPosition(g)&8;g=b);b=e.a(new rb(g))}}return b};
ec.prototype.toString=function(){var a;a="Path Expression:"+M(this.j);if(this.c.length){var b=ta(this.c,function(a,b){return a+M(b)},"Steps:");a+=M(b)}return a};function lc(a,b){this.a=a;this.b=!!b}
function Yb(a,b,c){for(c=c||0;c<a.a.length;c++)for(var d=a.a[c],e=Nb(b),f=b.s,g,k=0;g=K(e);k++){var r=a.b?f-k:k+1;g=d.a(new rb(g,r,f));if("number"==typeof g)r=r==g;else if("string"==typeof g||"boolean"==typeof g)r=!!g;else if(g instanceof H)r=0<g.s;else throw Error("Predicate.evaluate returned an unexpected type.");if(!r){r=e;g=r.h;var t=r.a;if(!t)throw Error("Next must be called at least once before remove.");var n=t.b,t=t.a;n?n.a=t:g.a=t;t?t.b=n:g.b=n;g.s--;r.a=null}}return b}
lc.prototype.toString=function(){return ta(this.a,function(a,b){return a+M(b)},"Predicates:")};function mc(a,b,c,d){L.call(this,4);this.c=a;this.w=b;this.j=c||new lc([]);this.B=!!d;b=this.j;b=0<b.a.length?b.a[0].h:null;a.b&&b&&(a=b.name,a=C?a.toLowerCase():a,this.h={name:a,A:b.A});a:{a=this.j;for(b=0;b<a.a.length;b++)if(c=a.a[b],c.i||1==c.m||0==c.m){a=!0;break a}a=!1}this.i=a}q(mc,L);
mc.prototype.a=function(a){var b=a.a,c=null,c=this.h,d=null,e=null,f=0;c&&(d=c.name,e=c.A?O(c.A,a):null,f=1);if(this.B)if(this.i||this.c!=nc)if(a=Nb((new mc(oc,new J("node"))).a(a)),b=K(a))for(c=this.u(b,d,e,f);null!=(b=K(a));)c=Kb(c,this.u(b,d,e,f));else c=new H;else c=Bb(this.w,b,d,e),c=Yb(this.j,c,f);else c=this.u(a.a,d,e,f);return c};mc.prototype.u=function(a,b,c,d){a=this.c.h(this.w,a,b,c);return a=Yb(this.j,a,d)};
mc.prototype.toString=function(){var a;a="Step:"+M("Operator: "+(this.B?"//":"/"));this.c.o&&(a+=M("Axis: "+this.c));a+=M(this.w);if(this.j.a.length){var b=ta(this.j.a,function(a,b){return a+M(b)},"Predicates:");a+=M(b)}return a};function pc(a,b,c,d){this.o=a;this.h=b;this.a=c;this.b=d}pc.prototype.toString=function(){return this.o};var qc={};function R(a,b,c,d){if(qc.hasOwnProperty(a))throw Error("Axis already created: "+a);b=new pc(a,b,c,!!d);return qc[a]=b}
R("ancestor",function(a,b){for(var c=new H,d=b;d=d.parentNode;)a.a(d)&&c.unshift(d);return c},!0);R("ancestor-or-self",function(a,b){var c=new H,d=b;do a.a(d)&&c.unshift(d);while(d=d.parentNode);return c},!0);
var fc=R("attribute",function(a,b){var c=new H,d=a.h();if("style"==d&&b.style&&C)return I(c,new tb(b.style,b,"style",b.style.cssText)),c;var e=b.attributes;if(e)if(a instanceof J&&null===a.b||"*"==d)for(var d=0,f;f=e[d];d++)C?f.nodeValue&&I(c,ub(b,f)):I(c,f);else(f=e.getNamedItem(d))&&(C?f.nodeValue&&I(c,ub(b,f)):I(c,f));return c},!1),nc=R("child",function(a,b,c,d,e){return(C?Hb:Ib).call(null,a,b,p(c)?c:null,p(d)?d:null,e||new H)},!1,!0);R("descendant",Bb,!1,!0);
var oc=R("descendant-or-self",function(a,b,c,d){var e=new H;Ab(b,c,d)&&a.a(b)&&I(e,b);return Bb(a,b,c,d,e)},!1,!0),jc=R("following",function(a,b,c,d){var e=new H;do for(var f=b;f=f.nextSibling;)Ab(f,c,d)&&a.a(f)&&I(e,f),e=Bb(a,f,c,d,e);while(b=b.parentNode);return e},!1,!0);R("following-sibling",function(a,b){for(var c=new H,d=b;d=d.nextSibling;)a.a(d)&&I(c,d);return c},!1);R("namespace",function(){return new H},!1);
var rc=R("parent",function(a,b){var c=new H;if(9==b.nodeType)return c;if(2==b.nodeType)return I(c,b.ownerElement),c;var d=b.parentNode;a.a(d)&&I(c,d);return c},!1),kc=R("preceding",function(a,b,c,d){var e=new H,f=[];do f.unshift(b);while(b=b.parentNode);for(var g=1,k=f.length;g<k;g++){var r=[];for(b=f[g];b=b.previousSibling;)r.unshift(b);for(var t=0,n=r.length;t<n;t++)b=r[t],Ab(b,c,d)&&a.a(b)&&I(e,b),e=Bb(a,b,c,d,e)}return e},!0,!0);
R("preceding-sibling",function(a,b){for(var c=new H,d=b;d=d.previousSibling;)a.a(d)&&c.unshift(d);return c},!0);var sc=R("self",function(a,b){var c=new H;a.a(b)&&I(c,b);return c},!1);function tc(a){L.call(this,1);this.c=a;this.i=a.i;this.b=a.b}q(tc,L);tc.prototype.a=function(a){return-N(this.c,a)};tc.prototype.toString=function(){return"Unary Expression: -"+M(this.c)};function uc(a){L.call(this,4);this.c=a;Pb(this,ua(this.c,function(a){return a.i}));Qb(this,ua(this.c,function(a){return a.b}))}q(uc,L);uc.prototype.a=function(a){var b=new H;u(this.c,function(c){c=c.a(a);if(!(c instanceof H))throw Error("Path expression must evaluate to NodeSet.");b=Kb(b,c)});return b};uc.prototype.toString=function(){return ta(this.c,function(a,b){return a+M(b)},"Union Expression:")};function vc(a,b){this.a=a;this.b=b}function wc(a){for(var b,c=[];;){S(a,"Missing right hand side of binary expression.");b=xc(a);var d=E(a.a);if(!d)break;var e=(d=Wb[d]||null)&&d.I;if(!e){a.a.a--;break}for(;c.length&&e<=c[c.length-1].I;)b=new Sb(c.pop(),c.pop(),b);c.push(b,d)}for(;c.length;)b=new Sb(c.pop(),c.pop(),b);return b}function S(a,b){if(zb(a.a))throw Error(b);}function yc(a,b){var c=E(a.a);if(c!=b)throw Error("Bad token, expected: "+b+" got: "+c);}
function zc(a){a=E(a.a);if(")"!=a)throw Error("Bad token: "+a);}function Ac(a){a=E(a.a);if(2>a.length)throw Error("Unclosed literal string");return new cc(a)}
function Bc(a){var b,c=[],d;if(ic(D(a.a))){b=E(a.a);d=D(a.a);if("/"==b&&(zb(a.a)||"."!=d&&".."!=d&&"@"!=d&&"*"!=d&&!/(?![0-9])[\w]/.test(d)))return new gc;d=new gc;S(a,"Missing next location step.");b=Cc(a,b);c.push(b)}else{a:{b=D(a.a);d=b.charAt(0);switch(d){case "$":throw Error("Variable reference not allowed in HTML XPath");case "(":E(a.a);b=wc(a);S(a,'unclosed "("');yc(a,")");break;case '"':case "'":b=Ac(a);break;default:if(isNaN(+b))if(!bc(b)&&/(?![0-9])[\w]/.test(d)&&"("==D(a.a,1)){b=E(a.a);
b=ac[b]||null;E(a.a);for(d=[];")"!=D(a.a);){S(a,"Missing function argument list.");d.push(wc(a));if(","!=D(a.a))break;E(a.a)}S(a,"Unclosed function argument list.");zc(a);b=new Zb(b,d)}else{b=null;break a}else b=new dc(+E(a.a))}"["==D(a.a)&&(d=new lc(Dc(a)),b=new Xb(b,d))}if(b)if(ic(D(a.a)))d=b;else return b;else b=Cc(a,"/"),d=new hc,c.push(b)}for(;ic(D(a.a));)b=E(a.a),S(a,"Missing next location step."),b=Cc(a,b),c.push(b);return new ec(d,c)}
function Cc(a,b){var c,d,e;if("/"!=b&&"//"!=b)throw Error('Step op should be "/" or "//"');if("."==D(a.a))return d=new mc(sc,new J("node")),E(a.a),d;if(".."==D(a.a))return d=new mc(rc,new J("node")),E(a.a),d;var f;if("@"==D(a.a))f=fc,E(a.a),S(a,"Missing attribute name");else if("::"==D(a.a,1)){if(!/(?![0-9])[\w]/.test(D(a.a).charAt(0)))throw Error("Bad token: "+E(a.a));c=E(a.a);f=qc[c]||null;if(!f)throw Error("No axis with name: "+c);E(a.a);S(a,"Missing node name")}else f=nc;c=D(a.a);if(/(?![0-9])[\w\*]/.test(c.charAt(0)))if("("==
D(a.a,1)){if(!bc(c))throw Error("Invalid node type: "+c);c=E(a.a);if(!bc(c))throw Error("Invalid type name: "+c);yc(a,"(");S(a,"Bad nodetype");e=D(a.a).charAt(0);var g=null;if('"'==e||"'"==e)g=Ac(a);S(a,"Bad nodetype");zc(a);c=new J(c,g)}else if(c=E(a.a),e=c.indexOf(":"),-1==e)c=new Eb(c);else{var g=c.substring(0,e),k;if("*"==g)k="*";else if(k=a.b(g),!k)throw Error("Namespace prefix not declared: "+g);c=c.substr(e+1);c=new Eb(c,k)}else throw Error("Bad token: "+E(a.a));e=new lc(Dc(a),f.a);return d||
new mc(f,c,e,"//"==b)}function Dc(a){for(var b=[];"["==D(a.a);){E(a.a);S(a,"Missing predicate expression.");var c=wc(a);b.push(c);S(a,"Unclosed predicate expression.");yc(a,"]")}return b}function xc(a){if("-"==D(a.a))return E(a.a),new tc(xc(a));var b=Bc(a);if("|"!=D(a.a))a=b;else{for(b=[b];"|"==E(a.a);)S(a,"Missing next union location path."),b.push(Bc(a));a.a.a--;a=new uc(b)}return a};function Ec(a){switch(a.nodeType){case 1:return ja(Fc,a);case 9:return Ec(a.documentElement);case 11:case 10:case 6:case 12:return Gc;default:return a.parentNode?Ec(a.parentNode):Gc}}function Gc(){return null}function Fc(a,b){if(a.prefix==b)return a.namespaceURI||"http://www.w3.org/1999/xhtml";var c=a.getAttributeNode("xmlns:"+b);return c&&c.specified?c.value||null:a.parentNode&&9!=a.parentNode.nodeType?Fc(a.parentNode,b):null};function Hc(a,b){if(!a.length)throw Error("Empty XPath expression.");var c=wb(a);if(zb(c))throw Error("Invalid XPath expression.");b?"function"==ba(b)||(b=ia(b.lookupNamespaceURI,b)):b=function(){return null};var d=wc(new vc(c,b));if(!zb(c))throw Error("Bad token: "+E(c));this.evaluate=function(a,b){var c=d.a(new rb(a));return new T(c,b)}}
function T(a,b){if(0==b)if(a instanceof H)b=4;else if("string"==typeof a)b=2;else if("number"==typeof a)b=1;else if("boolean"==typeof a)b=3;else throw Error("Unexpected evaluation result.");if(2!=b&&1!=b&&3!=b&&!(a instanceof H))throw Error("value could not be converted to the specified type");this.resultType=b;var c;switch(b){case 2:this.stringValue=a instanceof H?Mb(a):""+a;break;case 1:this.numberValue=a instanceof H?+Mb(a):+a;break;case 3:this.booleanValue=a instanceof H?0<a.s:!!a;break;case 4:case 5:case 6:case 7:var d=
Nb(a);c=[];for(var e=K(d);e;e=K(d))c.push(e instanceof tb?e.a:e);this.snapshotLength=a.s;this.invalidIteratorState=!1;break;case 8:case 9:d=Lb(a);this.singleNodeValue=d instanceof tb?d.a:d;break;default:throw Error("Unknown XPathResult type.");}var f=0;this.iterateNext=function(){if(4!=b&&5!=b)throw Error("iterateNext called with wrong result type");return f>=c.length?null:c[f++]};this.snapshotItem=function(a){if(6!=b&&7!=b)throw Error("snapshotItem called with wrong result type");return a>=c.length||
0>a?null:c[a]}}T.ANY_TYPE=0;T.NUMBER_TYPE=1;T.STRING_TYPE=2;T.BOOLEAN_TYPE=3;T.UNORDERED_NODE_ITERATOR_TYPE=4;T.ORDERED_NODE_ITERATOR_TYPE=5;T.UNORDERED_NODE_SNAPSHOT_TYPE=6;T.ORDERED_NODE_SNAPSHOT_TYPE=7;T.ANY_UNORDERED_NODE_TYPE=8;T.FIRST_ORDERED_NODE_TYPE=9;function Ic(a){this.lookupNamespaceURI=Ec(a)}
function Jc(a,b){var c=a||l,d=c.document;if(!d.evaluate||b)c.XPathResult=T,d.evaluate=function(a,b,c,d){return(new Hc(a,c)).evaluate(b,d)},d.createExpression=function(a,b){return new Hc(a,b)},d.createNSResolver=function(a){return new Ic(a)}}aa("wgxpath.install",Jc);var U={};U.F=function(){var a={S:"http://www.w3.org/2000/svg"};return function(b){return a[b]||null}}();
U.u=function(a,b,c){var d=B(a);if(!d.documentElement)return null;(z||ob)&&Jc(d?d.parentWindow||d.defaultView:window);try{var e=d.createNSResolver?d.createNSResolver(d.documentElement):U.F;if(z&&!$a(7))return d.evaluate.call(d,b,a,e,c,null);if(!z||9<=Number(bb)){for(var f={},g=d.getElementsByTagName("*"),k=0;k<g.length;++k){var r=g[k],t=r.namespaceURI;if(t&&!f[t]){var n=r.lookupPrefix(t);if(!n)var x=t.match(".*/(\\w+)/?$"),n=x?x[1]:"xhtml";f[t]=n}}var G={},da;for(da in f)G[f[da]]=da;e=function(a){return G[a]||
null}}try{return d.evaluate(b,a,e,c,null)}catch(ya){if("TypeError"===ya.name)return e=d.createNSResolver?d.createNSResolver(d.documentElement):U.F,d.evaluate(b,a,e,c,null);throw ya;}}catch(ya){if(!A||"NS_ERROR_ILLEGAL_VALUE"!=ya.name)throw new Ga(32,"Unable to locate an element with the xpath expression "+b+" because of the following error:\n"+ya);}};U.G=function(a,b){if(!a||1!=a.nodeType)throw new Ga(32,'The result of the xpath expression "'+b+'" is: '+a+". It should be an element.");};
U.K=function(a,b){var c=function(){var c=U.u(b,a,9);return c?c.singleNodeValue||null:b.selectSingleNode?(c=B(b),c.setProperty&&c.setProperty("SelectionLanguage","XPath"),b.selectSingleNode(a)):null}();null===c||U.G(c,a);return c};
U.P=function(a,b){var c=function(){var c=U.u(b,a,7);if(c){for(var e=c.snapshotLength,f=[],g=0;g<e;++g)f.push(c.snapshotItem(g));return f}return b.selectNodes?(c=B(b),c.setProperty&&c.setProperty("SelectionLanguage","XPath"),b.selectNodes(a)):[]}();u(c,function(b){U.G(b,a)});return c};function Kc(a){return(a=a.exec(w))?a[1]:""}var Lc=function(){if(lb)return Kc(/Firefox\/([0-9.]+)/);if(z||Sa||Ra)return Ya;if(pb)return Kc(/Chrome\/([0-9.]+)/);if(qb&&!(Qa()||y("iPad")||y("iPod")))return Kc(/Version\/([0-9.]+)/);if(mb||nb){var a;if(a=/Version\/(\S+).*Mobile\/(\S+)/.exec(w))return a[1]+"."+a[2]}else if(ob)return(a=Kc(/Android\s+([0-9.]+)/))?a:Kc(/Version\/([0-9.]+)/);return""}();var Mc,Nc;function Oc(a){return Pc?Mc(a):z?0<=na(bb,a):$a(a)}function Qc(a){Pc?Nc(a):ob?na(Rc,a):na(Lc,a)}
var Pc=function(){if(!A)return!1;var a=l.Components;if(!a)return!1;try{if(!a.classes)return!1}catch(f){return!1}var b=a.classes,a=a.interfaces,c=b["@mozilla.org/xpcom/version-comparator;1"].getService(a.nsIVersionComparator),b=b["@mozilla.org/xre/app-info;1"].getService(a.nsIXULAppInfo),d=b.platformVersion,e=b.version;Mc=function(a){return 0<=c.compare(d,""+a)};Nc=function(a){c.compare(e,""+a)};return!0}(),Sc;if(ob){var Tc=/Android\s+([0-9\.]+)/.exec(w);Sc=Tc?Tc[1]:"0"}else Sc="0";
var Rc=Sc,Uc=z&&!(9<=Number(bb));ob&&Qc(2.3);ob&&Qc(4);qb&&Qc(6);function Vc(a,b,c,d){this.top=a;this.right=b;this.bottom=c;this.left=d}h=Vc.prototype;h.clone=function(){return new Vc(this.top,this.right,this.bottom,this.left)};h.toString=function(){return"("+this.top+"t, "+this.right+"r, "+this.bottom+"b, "+this.left+"l)"};h.contains=function(a){return this&&a?a instanceof Vc?a.left>=this.left&&a.right<=this.right&&a.top>=this.top&&a.bottom<=this.bottom:a.x>=this.left&&a.x<=this.right&&a.y>=this.top&&a.y<=this.bottom:!1};
h.ceil=function(){this.top=Math.ceil(this.top);this.right=Math.ceil(this.right);this.bottom=Math.ceil(this.bottom);this.left=Math.ceil(this.left);return this};h.floor=function(){this.top=Math.floor(this.top);this.right=Math.floor(this.right);this.bottom=Math.floor(this.bottom);this.left=Math.floor(this.left);return this};h.round=function(){this.top=Math.round(this.top);this.right=Math.round(this.right);this.bottom=Math.round(this.bottom);this.left=Math.round(this.left);return this};
h.scale=function(a,b){var c=ea(b)?b:a;this.left*=a;this.right*=a;this.top*=c;this.bottom*=c;return this};function V(a,b,c,d){this.left=a;this.top=b;this.width=c;this.height=d}h=V.prototype;h.clone=function(){return new V(this.left,this.top,this.width,this.height)};h.toString=function(){return"("+this.left+", "+this.top+" - "+this.width+"w x "+this.height+"h)"};h.contains=function(a){return a instanceof V?this.left<=a.left&&this.left+this.width>=a.left+a.width&&this.top<=a.top&&this.top+this.height>=a.top+a.height:a.x>=this.left&&a.x<=this.left+this.width&&a.y>=this.top&&a.y<=this.top+this.height};
h.ceil=function(){this.left=Math.ceil(this.left);this.top=Math.ceil(this.top);this.width=Math.ceil(this.width);this.height=Math.ceil(this.height);return this};h.floor=function(){this.left=Math.floor(this.left);this.top=Math.floor(this.top);this.width=Math.floor(this.width);this.height=Math.floor(this.height);return this};h.round=function(){this.left=Math.round(this.left);this.top=Math.round(this.top);this.width=Math.round(this.width);this.height=Math.round(this.height);return this};
h.scale=function(a,b){var c=ea(b)?b:a;this.left*=a;this.width*=a;this.top*=c;this.height*=c;return this};function W(a,b){return!!a&&1==a.nodeType&&(!b||a.tagName.toUpperCase()==b)}function Wc(a){for(a=a.parentNode;a&&1!=a.nodeType&&9!=a.nodeType&&11!=a.nodeType;)a=a.parentNode;return W(a)?a:null}
function X(a,b){var c=pa(b);if("float"==c||"cssFloat"==c||"styleFloat"==c)c=Uc?"styleFloat":"cssFloat";var d;a:{d=c;var e=B(a);if(e.defaultView&&e.defaultView.getComputedStyle&&(e=e.defaultView.getComputedStyle(a,null))){d=e[d]||e.getPropertyValue(d)||"";break a}d=""}d=d||Xc(a,c);if(null===d)d=null;else if(0<=qa(Ba,c)){b:{var f=d.match(Ea);if(f){var c=Number(f[1]),e=Number(f[2]),g=Number(f[3]),f=Number(f[4]);if(0<=c&&255>=c&&0<=e&&255>=e&&0<=g&&255>=g&&0<=f&&1>=f){c=[c,e,g,f];break b}}c=null}if(!c)b:{if(g=
d.match(Fa))if(c=Number(g[1]),e=Number(g[2]),g=Number(g[3]),0<=c&&255>=c&&0<=e&&255>=e&&0<=g&&255>=g){c=[c,e,g,1];break b}c=null}if(!c)b:{c=d.toLowerCase();e=Aa[c.toLowerCase()];if(!e&&(e="#"==c.charAt(0)?c:"#"+c,4==e.length&&(e=e.replace(Ca,"#$1$1$2$2$3$3")),!Da.test(e))){c=null;break b}c=[parseInt(e.substr(1,2),16),parseInt(e.substr(3,2),16),parseInt(e.substr(5,2),16),1]}d=c?"rgba("+c.join(", ")+")":d}return d}
function Xc(a,b){var c=a.currentStyle||a.style,d=c[b];!m(d)&&"function"==ba(c.getPropertyValue)&&(d=c.getPropertyValue(b));return"inherit"!=d?m(d)?d:null:(c=Wc(a))?Xc(c,b):null}
function Yc(a,b,c){function d(a){var b=Zc(a);return 0<b.height&&0<b.width?!0:W(a,"PATH")&&(0<b.height||0<b.width)?(a=X(a,"stroke-width"),!!a&&0<parseInt(a,10)):"hidden"!=X(a,"overflow")&&ua(a.childNodes,function(a){return 3==a.nodeType||W(a)&&d(a)})}function e(a){return $c(a)==Y&&va(a.childNodes,function(a){return!W(a)||e(a)||!d(a)})}if(!W(a))throw Error("Argument to isShown must be of type Element");if(W(a,"BODY"))return!0;if(W(a,"OPTION")||W(a,"OPTGROUP"))return a=jb(a,function(a){return W(a,"SELECT")}),
!!a&&Yc(a,!0,c);var f=ad(a);if(f)return!!f.H&&0<f.rect.width&&0<f.rect.height&&Yc(f.H,b,c);if(W(a,"INPUT")&&"hidden"==a.type.toLowerCase()||W(a,"NOSCRIPT"))return!1;f=X(a,"visibility");return"collapse"!=f&&"hidden"!=f&&c(a)&&(b||0!=bd(a))&&d(a)?!e(a):!1}function cd(a){function b(a){if("none"==X(a,"display"))return!1;a=Wc(a);return!a||b(a)}return Yc(a,!1,b)}var Y="hidden";
function $c(a){function b(a){function b(a){return a==g?!0:0==X(a,"display").lastIndexOf("inline",0)||"absolute"==c&&"static"==X(a,"position")?!1:!0}var c=X(a,"position");if("fixed"==c)return t=!0,a==g?null:g;for(a=Wc(a);a&&!b(a);)a=Wc(a);return a}function c(a){var b=a;if("visible"==r)if(a==g&&k)b=k;else if(a==k)return{x:"visible",y:"visible"};b={x:X(b,"overflow-x"),y:X(b,"overflow-y")};a==g&&(b.x="visible"==b.x?"auto":b.x,b.y="visible"==b.y?"auto":b.y);return b}function d(a){if(a==g){var b=(new kb(f)).a;
a=b.scrollingElement?b.scrollingElement:Ta||"CSS1Compat"!=b.compatMode?b.body||b.documentElement:b.documentElement;b=b.parentWindow||b.defaultView;a=z&&$a("10")&&b.pageYOffset!=a.scrollTop?new cb(a.scrollLeft,a.scrollTop):new cb(b.pageXOffset||a.scrollLeft,b.pageYOffset||a.scrollTop)}else a=new cb(a.scrollLeft,a.scrollTop);return a}var e=dd(a),f=B(a),g=f.documentElement,k=f.body,r=X(g,"overflow"),t;for(a=b(a);a;a=b(a)){var n=c(a);if("visible"!=n.x||"visible"!=n.y){var x=Zc(a);if(0==x.width||0==x.height)return Y;
var G=e.right<x.left,da=e.bottom<x.top;if(G&&"hidden"==n.x||da&&"hidden"==n.y)return Y;if(G&&"visible"!=n.x||da&&"visible"!=n.y){G=d(a);da=e.bottom<x.top-G.y;if(e.right<x.left-G.x&&"visible"!=n.x||da&&"visible"!=n.x)return Y;e=$c(a);return e==Y?Y:"scroll"}G=e.left>=x.left+x.width;x=e.top>=x.top+x.height;if(G&&"hidden"==n.x||x&&"hidden"==n.y)return Y;if(G&&"visible"!=n.x||x&&"visible"!=n.y){if(t&&(n=d(a),e.left>=g.scrollWidth-n.x||e.right>=g.scrollHeight-n.y))return Y;e=$c(a);return e==Y?Y:"scroll"}}}return"none"}
function Zc(a){var b=ad(a);if(b)return b.rect;if(W(a,"HTML"))return a=B(a),a=((a?a.parentWindow||a.defaultView:window)||window).document,a="CSS1Compat"==a.compatMode?a.documentElement:a.body,a=new db(a.clientWidth,a.clientHeight),new V(0,0,a.width,a.height);var c;try{c=a.getBoundingClientRect()}catch(d){return new V(0,0,0,0)}b=new V(c.left,c.top,c.right-c.left,c.bottom-c.top);z&&a.ownerDocument.body&&(a=B(a),b.left-=a.documentElement.clientLeft+a.body.clientLeft,b.top-=a.documentElement.clientTop+
a.body.clientTop);return b}function ad(a){var b=W(a,"MAP");if(!b&&!W(a,"AREA"))return null;var c=b?a:W(a.parentNode,"MAP")?a.parentNode:null,d=null,e=null;c&&c.name&&(d=U.K('/descendant::*[@usemap = "#'+c.name+'"]',B(c)))&&(e=Zc(d),b||"default"==a.shape.toLowerCase()||(a=ed(a),b=Math.min(Math.max(a.left,0),e.width),c=Math.min(Math.max(a.top,0),e.height),e=new V(b+e.left,c+e.top,Math.min(a.width,e.width-b),Math.min(a.height,e.height-c))));return{H:d,rect:e||new V(0,0,0,0)}}
function ed(a){var b=a.shape.toLowerCase();a=a.coords.split(",");if("rect"==b&&4==a.length){var b=a[0],c=a[1];return new V(b,c,a[2]-b,a[3]-c)}if("circle"==b&&3==a.length)return b=a[2],new V(a[0]-b,a[1]-b,2*b,2*b);if("poly"==b&&2<a.length){for(var b=a[0],c=a[1],d=b,e=c,f=2;f+1<a.length;f+=2)b=Math.min(b,a[f]),d=Math.max(d,a[f]),c=Math.min(c,a[f+1]),e=Math.max(e,a[f+1]);return new V(b,c,d-b,e-c)}return new V(0,0,0,0)}function dd(a){a=Zc(a);return new Vc(a.top,a.left+a.width,a.top+a.height,a.left)}
function fd(a){return a.replace(/^[^\S\xa0]+|[^\S\xa0]+$/g,"")}function gd(a){var b=[];hd(a,b);a=sa(b,fd);return fd(a.join("\n")).replace(/\xa0/g," ")}
function id(a,b,c){if(W(a,"BR"))b.push("");else{var d=W(a,"TD"),e=X(a,"display"),f=!d&&!(0<=qa(jd,e)),g=m(a.previousElementSibling)?a.previousElementSibling:eb(a.previousSibling),g=g?X(g,"display"):"",k=X(a,"float")||X(a,"cssFloat")||X(a,"styleFloat");!f||"run-in"==g&&"none"==k||/^[\s\xa0]*$/.test(b[b.length-1]||"")||b.push("");var r=cd(a),t=null,n=null;r&&(t=X(a,"white-space"),n=X(a,"text-transform"));u(a.childNodes,function(a){c(a,b,r,t,n)});a=b[b.length-1]||"";!d&&"table-cell"!=e||!a||la(a)||(b[b.length-
1]+=" ");f&&"run-in"!=e&&!/^[\s\xa0]*$/.test(a)&&b.push("")}}function hd(a,b){id(a,b,function(a,b,e,f,g){3==a.nodeType&&e?kd(a,b,f,g):W(a)&&hd(a,b)})}var jd="inline inline-block inline-table none table-cell table-column table-column-group".split(" ");
function kd(a,b,c,d){a=a.nodeValue.replace(/[\u200b\u200e\u200f]/g,"");a=a.replace(/(\r\n|\r|\n)/g,"\n");if("normal"==c||"nowrap"==c)a=a.replace(/\n/g," ");a="pre"==c||"pre-wrap"==c?a.replace(/[ \f\t\v\u2028\u2029]/g,"\u00a0"):a.replace(/[\ \f\t\v\u2028\u2029]+/g," ");"capitalize"==d?a=a.replace(/(^|\s)(\S)/g,function(a,b,c){return b+c.toUpperCase()}):"uppercase"==d?a=a.toUpperCase():"lowercase"==d&&(a=a.toLowerCase());c=b.pop()||"";la(c)&&0==a.lastIndexOf(" ",0)&&(a=a.substr(1));b.push(c+a)}
function bd(a){if(Uc){if("relative"==X(a,"position"))return 1;a=X(a,"filter");return(a=a.match(/^alpha\(opacity=(\d*)\)/)||a.match(/^progid:DXImageTransform.Microsoft.Alpha\(Opacity=(\d*)\)/))?Number(a[1])/100:1}return ld(a)}function ld(a){var b=1,c=X(a,"opacity");c&&(b=Number(c));(a=Wc(a))&&(b*=ld(a));return b};Ta||Pc&&Qc(3.6);z&&Oc(10);ob&&Qc(4);function md(a,b){this.v={};this.l=[];this.b=this.a=0;var c=arguments.length;if(1<c){if(c%2)throw Error("Uneven number of arguments");for(var d=0;d<c;d+=2)nd(this,arguments[d],arguments[d+1])}else if(a){var e;if(a instanceof md)for(d=od(a),pd(a),e=[],c=0;c<a.l.length;c++)e.push(a.v[a.l[c]]);else{var c=[],f=0;for(d in a)c[f++]=d;d=c;c=[];f=0;for(e in a)c[f++]=a[e];e=c}for(c=0;c<d.length;c++)nd(this,d[c],e[c])}}function od(a){pd(a);return a.l.concat()}
md.prototype.clear=function(){this.v={};this.b=this.a=this.l.length=0};function pd(a){if(a.a!=a.l.length){for(var b=0,c=0;b<a.l.length;){var d=a.l[b];Object.prototype.hasOwnProperty.call(a.v,d)&&(a.l[c++]=d);b++}a.l.length=c}if(a.a!=a.l.length){for(var e={},c=b=0;b<a.l.length;)d=a.l[b],Object.prototype.hasOwnProperty.call(e,d)||(a.l[c++]=d,e[d]=1),b++;a.l.length=c}}md.prototype.get=function(a,b){return Object.prototype.hasOwnProperty.call(this.v,a)?this.v[a]:b};
function nd(a,b,c){Object.prototype.hasOwnProperty.call(a.v,b)||(a.a++,a.l.push(b),a.b++);a.v[b]=c}md.prototype.forEach=function(a,b){for(var c=od(this),d=0;d<c.length;d++){var e=c[d],f=this.get(e);a.call(b,f,e,this)}};md.prototype.clone=function(){return new md(this)};var qd={};function Z(a,b,c){fa(a)&&(a=A?a.f:a.g);a=new rd(a);!b||b in qd&&!c||(qd[b]={key:a,shift:!1},c&&(qd[c]={key:a,shift:!0}));return a}function rd(a){this.code=a}Z(8);Z(9);Z(13);var sd=Z(16),td=Z(17),ud=Z(18);Z(19);Z(20);Z(27);Z(32," ");Z(33);Z(34);Z(35);Z(36);Z(37);Z(38);Z(39);Z(40);Z(44);Z(45);Z(46);Z(48,"0",")");Z(49,"1","!");Z(50,"2","@");Z(51,"3","#");Z(52,"4","$");Z(53,"5","%");Z(54,"6","^");Z(55,"7","&");Z(56,"8","*");Z(57,"9","(");Z(65,"a","A");Z(66,"b","B");Z(67,"c","C");Z(68,"d","D");
Z(69,"e","E");Z(70,"f","F");Z(71,"g","G");Z(72,"h","H");Z(73,"i","I");Z(74,"j","J");Z(75,"k","K");Z(76,"l","L");Z(77,"m","M");Z(78,"n","N");Z(79,"o","O");Z(80,"p","P");Z(81,"q","Q");Z(82,"r","R");Z(83,"s","S");Z(84,"t","T");Z(85,"u","U");Z(86,"v","V");Z(87,"w","W");Z(88,"x","X");Z(89,"y","Y");Z(90,"z","Z");var vd=Z(Va?{f:91,g:91}:Ua?{f:224,g:91}:{f:0,g:91});Z(Va?{f:92,g:92}:Ua?{f:224,g:93}:{f:0,g:92});Z(Va?{f:93,g:93}:Ua?{f:0,g:0}:{f:93,g:null});Z({f:96,g:96},"0");Z({f:97,g:97},"1");
Z({f:98,g:98},"2");Z({f:99,g:99},"3");Z({f:100,g:100},"4");Z({f:101,g:101},"5");Z({f:102,g:102},"6");Z({f:103,g:103},"7");Z({f:104,g:104},"8");Z({f:105,g:105},"9");Z({f:106,g:106},"*");Z({f:107,g:107},"+");Z({f:109,g:109},"-");Z({f:110,g:110},".");Z({f:111,g:111},"/");Z(144);Z(112);Z(113);Z(114);Z(115);Z(116);Z(117);Z(118);Z(119);Z(120);Z(121);Z(122);Z(123);Z({f:107,g:187},"=","+");Z(108,",");Z({f:109,g:189},"-","_");Z(188,",","<");Z(190,".",">");Z(191,"/","?");Z(192,"`","~");Z(219,"[","{");
Z(220,"\\","|");Z(221,"]","}");Z({f:59,g:186},";",":");Z(222,"'",'"');var wd=new md;nd(wd,1,sd);nd(wd,2,td);nd(wd,4,ud);nd(wd,8,vd);(function(a){var b=new md;u(od(a),function(c){nd(b,a.get(c).code,c)});return b})(wd);A&&Oc(12);function xd(){}
function yd(a,b,c){if(null==b)c.push("null");else{if("object"==typeof b){if("array"==ba(b)){var d=b;b=d.length;c.push("[");for(var e="",f=0;f<b;f++)c.push(e),yd(a,d[f],c),e=",";c.push("]");return}if(b instanceof String||b instanceof Number||b instanceof Boolean)b=b.valueOf();else{c.push("{");e="";for(d in b)Object.prototype.hasOwnProperty.call(b,d)&&(f=b[d],"function"!=typeof f&&(c.push(e),zd(d,c),c.push(":"),yd(a,f,c),e=","));c.push("}");return}}switch(typeof b){case "string":zd(b,c);break;case "number":c.push(isFinite(b)&&
!isNaN(b)?String(b):"null");break;case "boolean":c.push(String(b));break;case "function":c.push("null");break;default:throw Error("Unknown type: "+typeof b);}}}var Ad={'"':'\\"',"\\":"\\\\","/":"\\/","\b":"\\b","\f":"\\f","\n":"\\n","\r":"\\r","\t":"\\t","\x0B":"\\u000b"},Bd=/\uffff/.test("\uffff")?/[\\\"\x00-\x1f\x7f-\uffff]/g:/[\\\"\x00-\x1f\x7f-\xff]/g;
function zd(a,b){b.push('"',a.replace(Bd,function(a){var b=Ad[a];b||(b="\\u"+(a.charCodeAt(0)|65536).toString(16).substr(1),Ad[a]=b);return b}),'"')};Ta||A&&Oc(3.5)||z&&Oc(8);function Cd(a){switch(ba(a)){case "string":case "number":case "boolean":return a;case "function":return a.toString();case "array":return sa(a,Cd);case "object":if(Ma(a,"nodeType")&&(1==a.nodeType||9==a.nodeType)){var b={};b.ELEMENT=Dd(a);return b}if(Ma(a,"document"))return b={},b.WINDOW=Dd(a),b;if(ca(a))return sa(a,Cd);a=Ka(a,function(a,b){return ea(b)||p(b)});return La(a,Cd);default:return null}}
function Ed(a,b){return"array"==ba(a)?sa(a,function(a){return Ed(a,b)}):fa(a)?"function"==typeof a?a:Ma(a,"ELEMENT")?Fd(a.ELEMENT,b):Ma(a,"WINDOW")?Fd(a.WINDOW,b):La(a,function(a){return Ed(a,b)}):a}function Gd(a){a=a||document;var b=a.$wdc_;b||(b=a.$wdc_={},b.C=ka());b.C||(b.C=ka());return b}function Dd(a){var b=Gd(a.ownerDocument),c=Na(b,function(b){return b==a});c||(c=":wdc:"+b.C++,b[c]=a);return c}
function Fd(a,b){a=decodeURIComponent(a);var c=b||document,d=Gd(c);if(!Ma(d,a))throw new Ga(10,"Element does not exist in cache");var e=d[a];if(Ma(e,"setInterval")){if(e.closed)throw delete d[a],new Ga(23,"Window has been closed.");return e}for(var f=e;f;){if(f==c.documentElement)return e;f=f.parentNode}delete d[a];throw new Ga(10,"Element is no longer attached to the DOM");};aa("_",function(a,b){var c=[a],d;try{var e;b?e=Fd(b.WINDOW):e=window;var f=Ed(c,e.document),g=gd.apply(null,f);d={status:0,value:Cd(g)}}catch(k){d={status:Ma(k,"code")?k.code:13,value:{message:k.message}}}c=[];yd(new xd,d,c);return c.join("")});; return this._.apply(null,arguments);}.apply({navigator:typeof window!=undefined?window.navigator:null,document:typeof window!=undefined?window.document:null}, arguments);}
