function(){return function(){var h,m=this;function aa(a,b){var c=a.split("."),d=m;c[0]in d||!d.execScript||d.execScript("var "+c[0]);for(var e;c.length&&(e=c.shift());)c.length||void 0===b?d[e]?d=d[e]:d=d[e]={}:d[e]=b}
function ba(a){var b=typeof a;if("object"==b)if(a){if(a instanceof Array)return"array";if(a instanceof Object)return b;var c=Object.prototype.toString.call(a);if("[object Window]"==c)return"object";if("[object Array]"==c||"number"==typeof a.length&&"undefined"!=typeof a.splice&&"undefined"!=typeof a.propertyIsEnumerable&&!a.propertyIsEnumerable("splice"))return"array";if("[object Function]"==c||"undefined"!=typeof a.call&&"undefined"!=typeof a.propertyIsEnumerable&&!a.propertyIsEnumerable("call"))return"function"}else return"null";
else if("function"==b&&"undefined"==typeof a.call)return"object";return b}function ca(a){var b=ba(a);return"array"==b||"object"==b&&"number"==typeof a.length}function n(a){return"string"==typeof a}function da(a){return"number"==typeof a}function ea(a){var b=typeof a;return"object"==b&&null!=a||"function"==b}function fa(a,b,c){return a.call.apply(a.bind,arguments)}
function ga(a,b,c){if(!a)throw Error();if(2<arguments.length){var d=Array.prototype.slice.call(arguments,2);return function(){var c=Array.prototype.slice.call(arguments);Array.prototype.unshift.apply(c,d);return a.apply(b,c)}}return function(){return a.apply(b,arguments)}}function ha(a,b,c){ha=Function.prototype.bind&&-1!=Function.prototype.bind.toString().indexOf("native code")?fa:ga;return ha.apply(null,arguments)}
function ia(a,b){var c=Array.prototype.slice.call(arguments,1);return function(){var b=c.slice();b.push.apply(b,arguments);return a.apply(this,b)}}var ja=Date.now||function(){return+new Date};function p(a,b){function c(){}c.prototype=b.prototype;a.P=b.prototype;a.prototype=new c;a.prototype.constructor=a;a.N=function(a,c,f){for(var g=Array(arguments.length-2),k=2;k<arguments.length;k++)g[k-2]=arguments[k];return b.prototype[c].apply(a,g)}};var ka=window;var la=String.prototype.trim?function(a){return a.trim()}:function(a){return a.replace(/^[\s\xa0]+|[\s\xa0]+$/g,"")};
function ma(a,b){for(var c=0,d=la(String(a)).split("."),e=la(String(b)).split("."),f=Math.max(d.length,e.length),g=0;0==c&&g<f;g++){var k=d[g]||"",l=e[g]||"",r=RegExp("(\\d*)(\\D*)","g"),G=RegExp("(\\d*)(\\D*)","g");do{var A=r.exec(k)||["","",""],t=G.exec(l)||["","",""];if(0==A[0].length&&0==t[0].length)break;c=na(0==A[1].length?0:parseInt(A[1],10),0==t[1].length?0:parseInt(t[1],10))||na(0==A[2].length,0==t[2].length)||na(A[2],t[2])}while(0==c)}return c}function na(a,b){return a<b?-1:a>b?1:0}
function oa(a){return String(a).replace(/\-([a-z])/g,function(a,c){return c.toUpperCase()})};function pa(a,b){if(n(a))return n(b)&&1==b.length?a.indexOf(b,0):-1;for(var c=0;c<a.length;c++)if(c in a&&a[c]===b)return c;return-1}function q(a,b){for(var c=a.length,d=n(a)?a.split(""):a,e=0;e<c;e++)e in d&&b.call(void 0,d[e],e,a)}function qa(a,b){for(var c=a.length,d=[],e=0,f=n(a)?a.split(""):a,g=0;g<c;g++)if(g in f){var k=f[g];b.call(void 0,k,g,a)&&(d[e++]=k)}return d}
function ra(a,b){for(var c=a.length,d=Array(c),e=n(a)?a.split(""):a,f=0;f<c;f++)f in e&&(d[f]=b.call(void 0,e[f],f,a));return d}function sa(a,b,c){var d=c;q(a,function(c,f){d=b.call(void 0,d,c,f,a)});return d}function ta(a,b){for(var c=a.length,d=n(a)?a.split(""):a,e=0;e<c;e++)if(e in d&&b.call(void 0,d[e],e,a))return!0;return!1}function ua(a,b){var c;a:{c=a.length;for(var d=n(a)?a.split(""):a,e=0;e<c;e++)if(e in d&&b.call(void 0,d[e],e,a)){c=e;break a}c=-1}return 0>c?null:n(a)?a.charAt(c):a[c]}
function va(a){return Array.prototype.concat.apply(Array.prototype,arguments)}function wa(a,b,c){return 2>=arguments.length?Array.prototype.slice.call(a,b):Array.prototype.slice.call(a,b,c)};var xa={aliceblue:"#f0f8ff",antiquewhite:"#faebd7",aqua:"#00ffff",aquamarine:"#7fffd4",azure:"#f0ffff",beige:"#f5f5dc",bisque:"#ffe4c4",black:"#000000",blanchedalmond:"#ffebcd",blue:"#0000ff",blueviolet:"#8a2be2",brown:"#a52a2a",burlywood:"#deb887",cadetblue:"#5f9ea0",chartreuse:"#7fff00",chocolate:"#d2691e",coral:"#ff7f50",cornflowerblue:"#6495ed",cornsilk:"#fff8dc",crimson:"#dc143c",cyan:"#00ffff",darkblue:"#00008b",darkcyan:"#008b8b",darkgoldenrod:"#b8860b",darkgray:"#a9a9a9",darkgreen:"#006400",
darkgrey:"#a9a9a9",darkkhaki:"#bdb76b",darkmagenta:"#8b008b",darkolivegreen:"#556b2f",darkorange:"#ff8c00",darkorchid:"#9932cc",darkred:"#8b0000",darksalmon:"#e9967a",darkseagreen:"#8fbc8f",darkslateblue:"#483d8b",darkslategray:"#2f4f4f",darkslategrey:"#2f4f4f",darkturquoise:"#00ced1",darkviolet:"#9400d3",deeppink:"#ff1493",deepskyblue:"#00bfff",dimgray:"#696969",dimgrey:"#696969",dodgerblue:"#1e90ff",firebrick:"#b22222",floralwhite:"#fffaf0",forestgreen:"#228b22",fuchsia:"#ff00ff",gainsboro:"#dcdcdc",
ghostwhite:"#f8f8ff",gold:"#ffd700",goldenrod:"#daa520",gray:"#808080",green:"#008000",greenyellow:"#adff2f",grey:"#808080",honeydew:"#f0fff0",hotpink:"#ff69b4",indianred:"#cd5c5c",indigo:"#4b0082",ivory:"#fffff0",khaki:"#f0e68c",lavender:"#e6e6fa",lavenderblush:"#fff0f5",lawngreen:"#7cfc00",lemonchiffon:"#fffacd",lightblue:"#add8e6",lightcoral:"#f08080",lightcyan:"#e0ffff",lightgoldenrodyellow:"#fafad2",lightgray:"#d3d3d3",lightgreen:"#90ee90",lightgrey:"#d3d3d3",lightpink:"#ffb6c1",lightsalmon:"#ffa07a",
lightseagreen:"#20b2aa",lightskyblue:"#87cefa",lightslategray:"#778899",lightslategrey:"#778899",lightsteelblue:"#b0c4de",lightyellow:"#ffffe0",lime:"#00ff00",limegreen:"#32cd32",linen:"#faf0e6",magenta:"#ff00ff",maroon:"#800000",mediumaquamarine:"#66cdaa",mediumblue:"#0000cd",mediumorchid:"#ba55d3",mediumpurple:"#9370db",mediumseagreen:"#3cb371",mediumslateblue:"#7b68ee",mediumspringgreen:"#00fa9a",mediumturquoise:"#48d1cc",mediumvioletred:"#c71585",midnightblue:"#191970",mintcream:"#f5fffa",mistyrose:"#ffe4e1",
moccasin:"#ffe4b5",navajowhite:"#ffdead",navy:"#000080",oldlace:"#fdf5e6",olive:"#808000",olivedrab:"#6b8e23",orange:"#ffa500",orangered:"#ff4500",orchid:"#da70d6",palegoldenrod:"#eee8aa",palegreen:"#98fb98",paleturquoise:"#afeeee",palevioletred:"#db7093",papayawhip:"#ffefd5",peachpuff:"#ffdab9",peru:"#cd853f",pink:"#ffc0cb",plum:"#dda0dd",powderblue:"#b0e0e6",purple:"#800080",red:"#ff0000",rosybrown:"#bc8f8f",royalblue:"#4169e1",saddlebrown:"#8b4513",salmon:"#fa8072",sandybrown:"#f4a460",seagreen:"#2e8b57",
seashell:"#fff5ee",sienna:"#a0522d",silver:"#c0c0c0",skyblue:"#87ceeb",slateblue:"#6a5acd",slategray:"#708090",slategrey:"#708090",snow:"#fffafa",springgreen:"#00ff7f",steelblue:"#4682b4",tan:"#d2b48c",teal:"#008080",thistle:"#d8bfd8",tomato:"#ff6347",turquoise:"#40e0d0",violet:"#ee82ee",wheat:"#f5deb3",white:"#ffffff",whitesmoke:"#f5f5f5",yellow:"#ffff00",yellowgreen:"#9acd32"};var ya="backgroundColor borderTopColor borderRightColor borderBottomColor borderLeftColor color outlineColor".split(" "),za=/#([0-9a-fA-F])([0-9a-fA-F])([0-9a-fA-F])/,Aa=/^#(?:[0-9a-f]{3}){1,2}$/i,Ba=/^(?:rgba)?\((\d{1,3}),\s?(\d{1,3}),\s?(\d{1,3}),\s?(0|1|0\.\d*)\)$/i,Ca=/^(?:rgb)?\((0|[1-9]\d{0,2}),\s?(0|[1-9]\d{0,2}),\s?(0|[1-9]\d{0,2})\)$/i;function Da(a,b){this.code=a;this.a=u[a]||Ea;this.message=b||"";var c=this.a.replace(/((?:^|\s+)[a-z])/g,function(a){return a.toUpperCase().replace(/^[\s\xa0]+/g,"")}),d=c.length-5;if(0>d||c.indexOf("Error",d)!=d)c+="Error";this.name=c;c=Error(this.message);c.name=this.name;this.stack=c.stack||""}p(Da,Error);var Ea="unknown error",u={15:"element not selectable",11:"element not visible"};u[31]=Ea;u[30]=Ea;u[24]="invalid cookie domain";u[29]="invalid element coordinates";u[12]="invalid element state";
u[32]="invalid selector";u[51]="invalid selector";u[52]="invalid selector";u[17]="javascript error";u[405]="unsupported operation";u[34]="move target out of bounds";u[27]="no such alert";u[7]="no such element";u[8]="no such frame";u[23]="no such window";u[28]="script timeout";u[33]="session not created";u[10]="stale element reference";u[21]="timeout";u[25]="unable to set cookie";u[26]="unexpected alert open";u[13]=Ea;u[9]="unknown command";Da.prototype.toString=function(){return this.name+": "+this.message};var v;a:{var Fa=m.navigator;if(Fa){var Ga=Fa.userAgent;if(Ga){v=Ga;break a}}v=""}function w(a){return-1!=v.indexOf(a)};function Ha(a,b){var c={},d;for(d in a)b.call(void 0,a[d],d,a)&&(c[d]=a[d]);return c}function Ia(a,b){var c={},d;for(d in a)c[d]=b.call(void 0,a[d],d,a);return c}function Ja(a,b){return null!==a&&b in a}function Ka(a,b){for(var c in a)if(b.call(void 0,a[c],c,a))return c};function La(){return w("Opera")||w("OPR")}function Ma(){return(w("Chrome")||w("CriOS"))&&!La()&&!w("Edge")};function Na(){return w("iPhone")&&!w("iPod")&&!w("iPad")};var Oa=La(),x=w("Trident")||w("MSIE"),Pa=w("Edge"),y=w("Gecko")&&!(-1!=v.toLowerCase().indexOf("webkit")&&!w("Edge"))&&!(w("Trident")||w("MSIE"))&&!w("Edge"),Qa=-1!=v.toLowerCase().indexOf("webkit")&&!w("Edge"),Ra=w("Macintosh"),Sa=w("Windows");function Ta(){var a=v;if(y)return/rv\:([^\);]+)(\)|;)/.exec(a);if(Pa)return/Edge\/([\d\.]+)/.exec(a);if(x)return/\b(?:MSIE|rv)[: ]([^\);]+)(\)|;)/.exec(a);if(Qa)return/WebKit\/(\S+)/.exec(a)}function Ua(){var a=m.document;return a?a.documentMode:void 0}
var Va=function(){if(Oa&&m.opera){var a;var b=m.opera.version;try{a=b()}catch(c){a=b}return a}a="";(b=Ta())&&(a=b?b[1]:"");return x&&(b=Ua(),null!=b&&b>parseFloat(a))?String(b):a}(),Wa={};function Xa(a){return Wa[a]||(Wa[a]=0<=ma(Va,a))}var Ya=m.document,z=Ya&&x?Ua()||("CSS1Compat"==Ya.compatMode?parseInt(Va,10):5):void 0;!y&&!x||x&&9<=Number(z)||y&&Xa("1.9.1");x&&Xa("9");function $a(a,b){this.x=void 0!==a?a:0;this.y=void 0!==b?b:0}h=$a.prototype;h.clone=function(){return new $a(this.x,this.y)};h.toString=function(){return"("+this.x+", "+this.y+")"};h.ceil=function(){this.x=Math.ceil(this.x);this.y=Math.ceil(this.y);return this};h.floor=function(){this.x=Math.floor(this.x);this.y=Math.floor(this.y);return this};h.round=function(){this.x=Math.round(this.x);this.y=Math.round(this.y);return this};h.scale=function(a,b){var c=da(b)?b:a;this.x*=a;this.y*=c;return this};function ab(a,b){this.width=a;this.height=b}h=ab.prototype;h.clone=function(){return new ab(this.width,this.height)};h.toString=function(){return"("+this.width+" x "+this.height+")"};h.ceil=function(){this.width=Math.ceil(this.width);this.height=Math.ceil(this.height);return this};h.floor=function(){this.width=Math.floor(this.width);this.height=Math.floor(this.height);return this};h.round=function(){this.width=Math.round(this.width);this.height=Math.round(this.height);return this};
h.scale=function(a,b){var c=da(b)?b:a;this.width*=a;this.height*=c;return this};function bb(a,b){if(!a||!b)return!1;if(a.contains&&1==b.nodeType)return a==b||a.contains(b);if("undefined"!=typeof a.compareDocumentPosition)return a==b||!!(a.compareDocumentPosition(b)&16);for(;b&&a!=b;)b=b.parentNode;return b==a}
function cb(a,b){if(a==b)return 0;if(a.compareDocumentPosition)return a.compareDocumentPosition(b)&2?1:-1;if(x&&!(9<=Number(z))){if(9==a.nodeType)return-1;if(9==b.nodeType)return 1}if("sourceIndex"in a||a.parentNode&&"sourceIndex"in a.parentNode){var c=1==a.nodeType,d=1==b.nodeType;if(c&&d)return a.sourceIndex-b.sourceIndex;var e=a.parentNode,f=b.parentNode;return e==f?db(a,b):!c&&bb(e,b)?-1*eb(a,b):!d&&bb(f,a)?eb(b,a):(c?a.sourceIndex:e.sourceIndex)-(d?b.sourceIndex:f.sourceIndex)}d=B(a);c=d.createRange();
c.selectNode(a);c.collapse(!0);d=d.createRange();d.selectNode(b);d.collapse(!0);return c.compareBoundaryPoints(m.Range.START_TO_END,d)}function eb(a,b){var c=a.parentNode;if(c==b)return-1;for(var d=b;d.parentNode!=c;)d=d.parentNode;return db(d,a)}function db(a,b){for(var c=b;c=c.previousSibling;)if(c==a)return-1;return 1}function B(a){return 9==a.nodeType?a:a.ownerDocument||a.document}function fb(a){this.a=a||m.document||document}fb.prototype.contains=bb;var gb=w("Firefox"),hb=Na()||w("iPod"),ib=w("iPad"),jb=w("Android")&&!(Ma()||w("Firefox")||La()||w("Silk")),kb=Ma(),lb=w("Safari")&&!(Ma()||w("Coast")||La()||w("Edge")||w("Silk")||w("Android"))&&!(Na()||w("iPad")||w("iPod"));/*

 The MIT License

 Copyright (c) 2007 Cybozu Labs, Inc.
 Copyright (c) 2012 Google Inc.

 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to
 deal in the Software without restriction, including without limitation the
 rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
 sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in
 all copies or substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 IN THE SOFTWARE.
*/
function mb(a,b,c){this.a=a;this.b=b||1;this.h=c||1};var C=x&&!(9<=Number(z)),nb=x&&!(8<=Number(z));function ob(a,b,c,d){this.a=a;this.nodeName=c;this.nodeValue=d;this.nodeType=2;this.parentNode=this.ownerElement=b}function pb(a,b){var c=nb&&"href"==b.nodeName?a.getAttribute(b.nodeName,2):b.nodeValue;return new ob(b,a,b.nodeName,c)};function qb(a){this.b=a;this.a=0}function rb(a){a=a.match(sb);for(var b=0;b<a.length;b++)tb.test(a[b])&&a.splice(b,1);return new qb(a)}var sb=RegExp("\\$?(?:(?![0-9-\\.])(?:\\*|[\\w-\\.]+):)?(?![0-9-\\.])(?:\\*|[\\w-\\.]+)|\\/\\/|\\.\\.|::|\\d+(?:\\.\\d*)?|\\.\\d+|\"[^\"]*\"|'[^']*'|[!<>]=|\\s+|.","g"),tb=/^\s/;function D(a,b){return a.b[a.a+(b||0)]}function E(a){return a.b[a.a++]}function ub(a){return a.b.length<=a.a};function H(a){var b=null,c=a.nodeType;1==c&&(b=a.textContent,b=void 0==b||null==b?a.innerText:b,b=void 0==b||null==b?"":b);if("string"!=typeof b)if(C&&"title"==a.nodeName.toLowerCase()&&1==c)b=a.text;else if(9==c||1==c){a=9==c?a.documentElement:a.firstChild;for(var c=0,d=[],b="";a;){do 1!=a.nodeType&&(b+=a.nodeValue),C&&"title"==a.nodeName.toLowerCase()&&(b+=a.text),d[c++]=a;while(a=a.firstChild);for(;c&&!(a=d[--c].nextSibling););}}else b=a.nodeValue;return""+b}
function J(a,b,c){if(null===b)return!0;try{if(!a.getAttribute)return!1}catch(d){return!1}nb&&"class"==b&&(b="className");return null==c?!!a.getAttribute(b):a.getAttribute(b,2)==c}function vb(a,b,c,d,e){return(C?wb:xb).call(null,a,b,n(c)?c:null,n(d)?d:null,e||new K)}
function wb(a,b,c,d,e){if(a instanceof yb||8==a.b||c&&null===a.b){var f=b.all;if(!f)return e;a=zb(a);if("*"!=a&&(f=b.getElementsByTagName(a),!f))return e;if(c){for(var g=[],k=0;b=f[k++];)J(b,c,d)&&g.push(b);f=g}for(k=0;b=f[k++];)"*"==a&&"!"==b.tagName||L(e,b);return e}Ab(a,b,c,d,e);return e}
function xb(a,b,c,d,e){b.getElementsByName&&d&&"name"==c&&!x?(b=b.getElementsByName(d),q(b,function(b){a.a(b)&&L(e,b)})):b.getElementsByClassName&&d&&"class"==c?(b=b.getElementsByClassName(d),q(b,function(b){b.className==d&&a.a(b)&&L(e,b)})):a instanceof M?Ab(a,b,c,d,e):b.getElementsByTagName&&(b=b.getElementsByTagName(a.h()),q(b,function(a){J(a,c,d)&&L(e,a)}));return e}
function Bb(a,b,c,d,e){var f;if((a instanceof yb||8==a.b||c&&null===a.b)&&(f=b.childNodes)){var g=zb(a);if("*"!=g&&(f=qa(f,function(a){return a.tagName&&a.tagName.toLowerCase()==g}),!f))return e;c&&(f=qa(f,function(a){return J(a,c,d)}));q(f,function(a){"*"==g&&("!"==a.tagName||"*"==g&&1!=a.nodeType)||L(e,a)});return e}return Cb(a,b,c,d,e)}function Cb(a,b,c,d,e){for(b=b.firstChild;b;b=b.nextSibling)J(b,c,d)&&a.a(b)&&L(e,b);return e}
function Ab(a,b,c,d,e){for(b=b.firstChild;b;b=b.nextSibling)J(b,c,d)&&a.a(b)&&L(e,b),Ab(a,b,c,d,e)}function zb(a){if(a instanceof M){if(8==a.b)return"!";if(null===a.b)return"*"}return a.h()};function K(){this.b=this.a=null;this.s=0}function Db(a){this.node=a;this.a=this.b=null}function Eb(a,b){if(!a.a)return b;if(!b.a)return a;for(var c=a.a,d=b.a,e=null,f=null,g=0;c&&d;){var f=c.node,k=d.node;f==k||f instanceof ob&&k instanceof ob&&f.a==k.a?(f=c,c=c.a,d=d.a):0<cb(c.node,d.node)?(f=d,d=d.a):(f=c,c=c.a);(f.b=e)?e.a=f:a.a=f;e=f;g++}for(f=c||d;f;)f.b=e,e=e.a=f,g++,f=f.a;a.b=e;a.s=g;return a}
K.prototype.unshift=function(a){a=new Db(a);a.a=this.a;this.b?this.a.b=a:this.a=this.b=a;this.a=a;this.s++};function L(a,b){var c=new Db(b);c.b=a.b;a.a?a.b.a=c:a.a=a.b=c;a.b=c;a.s++}function Fb(a){return(a=a.a)?a.node:null}function Gb(a){return(a=Fb(a))?H(a):""}function Hb(a,b){return new Ib(a,!!b)}function Ib(a,b){this.h=a;this.b=(this.c=b)?a.b:a.a;this.a=null}function N(a){var b=a.b;if(null==b)return null;var c=a.a=b;a.b=a.c?b.b:b.a;return c.node};function O(a){this.m=a;this.b=this.i=!1;this.h=null}function P(a){return"\n  "+a.toString().split("\n").join("\n  ")}function Jb(a,b){a.i=b}function Kb(a,b){a.b=b}function Q(a,b){var c=a.a(b);return c instanceof K?+Gb(c):+c}function R(a,b){var c=a.a(b);return c instanceof K?Gb(c):""+c}function Lb(a,b){var c=a.a(b);return c instanceof K?!!c.s:!!c};function Mb(a,b,c){O.call(this,a.m);this.c=a;this.j=b;this.w=c;this.i=b.i||c.i;this.b=b.b||c.b;this.c==Nb&&(c.b||c.i||4==c.m||0==c.m||!b.h?b.b||b.i||4==b.m||0==b.m||!c.h||(this.h={name:c.h.name,A:b}):this.h={name:b.h.name,A:c})}p(Mb,O);
function Ob(a,b,c,d,e){b=b.a(d);c=c.a(d);var f;if(b instanceof K&&c instanceof K){b=Hb(b);for(d=N(b);d;d=N(b))for(e=Hb(c),f=N(e);f;f=N(e))if(a(H(d),H(f)))return!0;return!1}if(b instanceof K||c instanceof K){b instanceof K?(e=b,d=c):(e=c,d=b);f=Hb(e);for(var g=typeof d,k=N(f);k;k=N(f)){switch(g){case "number":k=+H(k);break;case "boolean":k=!!H(k);break;case "string":k=H(k);break;default:throw Error("Illegal primitive type for comparison.");}if(e==b&&a(k,d)||e==c&&a(d,k))return!0}return!1}return e?
"boolean"==typeof b||"boolean"==typeof c?a(!!b,!!c):"number"==typeof b||"number"==typeof c?a(+b,+c):a(b,c):a(+b,+c)}Mb.prototype.a=function(a){return this.c.u(this.j,this.w,a)};Mb.prototype.toString=function(){var a="Binary Expression: "+this.c,a=a+P(this.j);return a+=P(this.w)};function Pb(a,b,c,d){this.a=a;this.H=b;this.m=c;this.u=d}Pb.prototype.toString=function(){return this.a};var Qb={};
function S(a,b,c,d){if(Qb.hasOwnProperty(a))throw Error("Binary operator already created: "+a);a=new Pb(a,b,c,d);return Qb[a.toString()]=a}S("div",6,1,function(a,b,c){return Q(a,c)/Q(b,c)});S("mod",6,1,function(a,b,c){return Q(a,c)%Q(b,c)});S("*",6,1,function(a,b,c){return Q(a,c)*Q(b,c)});S("+",5,1,function(a,b,c){return Q(a,c)+Q(b,c)});S("-",5,1,function(a,b,c){return Q(a,c)-Q(b,c)});S("<",4,2,function(a,b,c){return Ob(function(a,b){return a<b},a,b,c)});
S(">",4,2,function(a,b,c){return Ob(function(a,b){return a>b},a,b,c)});S("<=",4,2,function(a,b,c){return Ob(function(a,b){return a<=b},a,b,c)});S(">=",4,2,function(a,b,c){return Ob(function(a,b){return a>=b},a,b,c)});var Nb=S("=",3,2,function(a,b,c){return Ob(function(a,b){return a==b},a,b,c,!0)});S("!=",3,2,function(a,b,c){return Ob(function(a,b){return a!=b},a,b,c,!0)});S("and",2,2,function(a,b,c){return Lb(a,c)&&Lb(b,c)});S("or",1,2,function(a,b,c){return Lb(a,c)||Lb(b,c)});function Rb(a,b){if(b.a.length&&4!=a.m)throw Error("Primary expression must evaluate to nodeset if filter has predicate(s).");O.call(this,a.m);this.c=a;this.j=b;this.i=a.i;this.b=a.b}p(Rb,O);Rb.prototype.a=function(a){a=this.c.a(a);return Sb(this.j,a)};Rb.prototype.toString=function(){var a;a="Filter:"+P(this.c);return a+=P(this.j)};function Tb(a,b){if(b.length<a.I)throw Error("Function "+a.o+" expects at least"+a.I+" arguments, "+b.length+" given");if(null!==a.D&&b.length>a.D)throw Error("Function "+a.o+" expects at most "+a.D+" arguments, "+b.length+" given");a.M&&q(b,function(b,d){if(4!=b.m)throw Error("Argument "+d+" to function "+a.o+" is not of type Nodeset: "+b);});O.call(this,a.m);this.j=a;this.c=b;Jb(this,a.i||ta(b,function(a){return a.i}));Kb(this,a.L&&!b.length||a.K&&!!b.length||ta(b,function(a){return a.b}))}
p(Tb,O);Tb.prototype.a=function(a){return this.j.u.apply(null,va(a,this.c))};Tb.prototype.toString=function(){var a="Function: "+this.j;if(this.c.length)var b=sa(this.c,function(a,b){return a+P(b)},"Arguments:"),a=a+P(b);return a};function Ub(a,b,c,d,e,f,g,k,l){this.o=a;this.m=b;this.i=c;this.L=d;this.K=e;this.u=f;this.I=g;this.D=void 0!==k?k:g;this.M=!!l}Ub.prototype.toString=function(){return this.o};var Vb={};
function T(a,b,c,d,e,f,g,k){if(Vb.hasOwnProperty(a))throw Error("Function already created: "+a+".");Vb[a]=new Ub(a,b,c,d,!1,e,f,g,k)}T("boolean",2,!1,!1,function(a,b){return Lb(b,a)},1);T("ceiling",1,!1,!1,function(a,b){return Math.ceil(Q(b,a))},1);T("concat",3,!1,!1,function(a,b){return sa(wa(arguments,1),function(b,d){return b+R(d,a)},"")},2,null);T("contains",2,!1,!1,function(a,b,c){b=R(b,a);a=R(c,a);return-1!=b.indexOf(a)},2);T("count",1,!1,!1,function(a,b){return b.a(a).s},1,1,!0);
T("false",2,!1,!1,function(){return!1},0);T("floor",1,!1,!1,function(a,b){return Math.floor(Q(b,a))},1);T("id",4,!1,!1,function(a,b){function c(a){if(C){var b=e.all[a];if(b){if(b.nodeType&&a==b.id)return b;if(b.length)return ua(b,function(b){return a==b.id})}return null}return e.getElementById(a)}var d=a.a,e=9==d.nodeType?d:d.ownerDocument,d=R(b,a).split(/\s+/),f=[];q(d,function(a){a=c(a);!a||0<=pa(f,a)||f.push(a)});f.sort(cb);var g=new K;q(f,function(a){L(g,a)});return g},1);
T("lang",2,!1,!1,function(){return!1},1);T("last",1,!0,!1,function(a){if(1!=arguments.length)throw Error("Function last expects ()");return a.h},0);T("local-name",3,!1,!0,function(a,b){var c=b?Fb(b.a(a)):a.a;return c?c.localName||c.nodeName.toLowerCase():""},0,1,!0);T("name",3,!1,!0,function(a,b){var c=b?Fb(b.a(a)):a.a;return c?c.nodeName.toLowerCase():""},0,1,!0);T("namespace-uri",3,!0,!1,function(){return""},0,1,!0);
T("normalize-space",3,!1,!0,function(a,b){return(b?R(b,a):H(a.a)).replace(/[\s\xa0]+/g," ").replace(/^\s+|\s+$/g,"")},0,1);T("not",2,!1,!1,function(a,b){return!Lb(b,a)},1);T("number",1,!1,!0,function(a,b){return b?Q(b,a):+H(a.a)},0,1);T("position",1,!0,!1,function(a){return a.b},0);T("round",1,!1,!1,function(a,b){return Math.round(Q(b,a))},1);T("starts-with",2,!1,!1,function(a,b,c){b=R(b,a);a=R(c,a);return 0==b.lastIndexOf(a,0)},2);T("string",3,!1,!0,function(a,b){return b?R(b,a):H(a.a)},0,1);
T("string-length",1,!1,!0,function(a,b){return(b?R(b,a):H(a.a)).length},0,1);T("substring",3,!1,!1,function(a,b,c,d){c=Q(c,a);if(isNaN(c)||Infinity==c||-Infinity==c)return"";d=d?Q(d,a):Infinity;if(isNaN(d)||-Infinity===d)return"";c=Math.round(c)-1;var e=Math.max(c,0);a=R(b,a);return Infinity==d?a.substring(e):a.substring(e,c+Math.round(d))},2,3);T("substring-after",3,!1,!1,function(a,b,c){b=R(b,a);a=R(c,a);c=b.indexOf(a);return-1==c?"":b.substring(c+a.length)},2);
T("substring-before",3,!1,!1,function(a,b,c){b=R(b,a);a=R(c,a);a=b.indexOf(a);return-1==a?"":b.substring(0,a)},2);T("sum",1,!1,!1,function(a,b){for(var c=Hb(b.a(a)),d=0,e=N(c);e;e=N(c))d+=+H(e);return d},1,1,!0);T("translate",3,!1,!1,function(a,b,c,d){b=R(b,a);c=R(c,a);var e=R(d,a);a={};for(d=0;d<c.length;d++){var f=c.charAt(d);f in a||(a[f]=e.charAt(d))}c="";for(d=0;d<b.length;d++)f=b.charAt(d),c+=f in a?a[f]:f;return c},3);T("true",2,!1,!1,function(){return!0},0);function M(a,b){this.j=a;this.c=void 0!==b?b:null;this.b=null;switch(a){case "comment":this.b=8;break;case "text":this.b=3;break;case "processing-instruction":this.b=7;break;case "node":break;default:throw Error("Unexpected argument");}}function Wb(a){return"comment"==a||"text"==a||"processing-instruction"==a||"node"==a}M.prototype.a=function(a){return null===this.b||this.b==a.nodeType};M.prototype.h=function(){return this.j};
M.prototype.toString=function(){var a="Kind Test: "+this.j;null===this.c||(a+=P(this.c));return a};function Xb(a){O.call(this,3);this.c=a.substring(1,a.length-1)}p(Xb,O);Xb.prototype.a=function(){return this.c};Xb.prototype.toString=function(){return"Literal: "+this.c};function yb(a,b){this.o=a.toLowerCase();var c;c="*"==this.o?"*":"http://www.w3.org/1999/xhtml";this.c=b?b.toLowerCase():c}yb.prototype.a=function(a){var b=a.nodeType;return 1!=b&&2!=b?!1:"*"!=this.o&&this.o!=a.localName.toLowerCase()?!1:"*"==this.c?!0:this.c==(a.namespaceURI?a.namespaceURI.toLowerCase():"http://www.w3.org/1999/xhtml")};yb.prototype.h=function(){return this.o};yb.prototype.toString=function(){return"Name Test: "+("http://www.w3.org/1999/xhtml"==this.c?"":this.c+":")+this.o};function Yb(a){O.call(this,1);this.c=a}p(Yb,O);Yb.prototype.a=function(){return this.c};Yb.prototype.toString=function(){return"Number: "+this.c};function Zb(a,b){O.call(this,a.m);this.j=a;this.c=b;this.i=a.i;this.b=a.b;if(1==this.c.length){var c=this.c[0];c.B||c.c!=$b||(c=c.w,"*"!=c.h()&&(this.h={name:c.h(),A:null}))}}p(Zb,O);function ac(){O.call(this,4)}p(ac,O);ac.prototype.a=function(a){var b=new K;a=a.a;9==a.nodeType?L(b,a):L(b,a.ownerDocument);return b};ac.prototype.toString=function(){return"Root Helper Expression"};function bc(){O.call(this,4)}p(bc,O);bc.prototype.a=function(a){var b=new K;L(b,a.a);return b};bc.prototype.toString=function(){return"Context Helper Expression"};
function cc(a){return"/"==a||"//"==a}Zb.prototype.a=function(a){var b=this.j.a(a);if(!(b instanceof K))throw Error("Filter expression must evaluate to nodeset.");a=this.c;for(var c=0,d=a.length;c<d&&b.s;c++){var e=a[c],f=Hb(b,e.c.a),g;if(e.i||e.c!=dc)if(e.i||e.c!=ec)for(g=N(f),b=e.a(new mb(g));null!=(g=N(f));)g=e.a(new mb(g)),b=Eb(b,g);else g=N(f),b=e.a(new mb(g));else{for(g=N(f);(b=N(f))&&(!g.contains||g.contains(b))&&b.compareDocumentPosition(g)&8;g=b);b=e.a(new mb(g))}}return b};
Zb.prototype.toString=function(){var a;a="Path Expression:"+P(this.j);if(this.c.length){var b=sa(this.c,function(a,b){return a+P(b)},"Steps:");a+=P(b)}return a};function fc(a,b){this.a=a;this.b=!!b}
function Sb(a,b,c){for(c=c||0;c<a.a.length;c++)for(var d=a.a[c],e=Hb(b),f=b.s,g,k=0;g=N(e);k++){var l=a.b?f-k:k+1;g=d.a(new mb(g,l,f));if("number"==typeof g)l=l==g;else if("string"==typeof g||"boolean"==typeof g)l=!!g;else if(g instanceof K)l=0<g.s;else throw Error("Predicate.evaluate returned an unexpected type.");if(!l){l=e;g=l.h;var r=l.a;if(!r)throw Error("Next must be called at least once before remove.");var G=r.b,r=r.a;G?G.a=r:g.a=r;r?r.b=G:g.b=G;g.s--;l.a=null}}return b}
fc.prototype.toString=function(){return sa(this.a,function(a,b){return a+P(b)},"Predicates:")};function gc(a,b,c,d){O.call(this,4);this.c=a;this.w=b;this.j=c||new fc([]);this.B=!!d;b=this.j;b=0<b.a.length?b.a[0].h:null;a.b&&b&&(a=b.name,a=C?a.toLowerCase():a,this.h={name:a,A:b.A});a:{a=this.j;for(b=0;b<a.a.length;b++)if(c=a.a[b],c.i||1==c.m||0==c.m){a=!0;break a}a=!1}this.i=a}p(gc,O);
gc.prototype.a=function(a){var b=a.a,c=null,c=this.h,d=null,e=null,f=0;c&&(d=c.name,e=c.A?R(c.A,a):null,f=1);if(this.B)if(this.i||this.c!=hc)if(a=Hb((new gc(ic,new M("node"))).a(a)),b=N(a))for(c=this.u(b,d,e,f);null!=(b=N(a));)c=Eb(c,this.u(b,d,e,f));else c=new K;else c=vb(this.w,b,d,e),c=Sb(this.j,c,f);else c=this.u(a.a,d,e,f);return c};gc.prototype.u=function(a,b,c,d){a=this.c.h(this.w,a,b,c);return a=Sb(this.j,a,d)};
gc.prototype.toString=function(){var a;a="Step:"+P("Operator: "+(this.B?"//":"/"));this.c.o&&(a+=P("Axis: "+this.c));a+=P(this.w);if(this.j.a.length){var b=sa(this.j.a,function(a,b){return a+P(b)},"Predicates:");a+=P(b)}return a};function jc(a,b,c,d){this.o=a;this.h=b;this.a=c;this.b=d}jc.prototype.toString=function(){return this.o};var kc={};function U(a,b,c,d){if(kc.hasOwnProperty(a))throw Error("Axis already created: "+a);b=new jc(a,b,c,!!d);return kc[a]=b}
U("ancestor",function(a,b){for(var c=new K,d=b;d=d.parentNode;)a.a(d)&&c.unshift(d);return c},!0);U("ancestor-or-self",function(a,b){var c=new K,d=b;do a.a(d)&&c.unshift(d);while(d=d.parentNode);return c},!0);
var $b=U("attribute",function(a,b){var c=new K,d=a.h();if("style"==d&&b.style&&C)return L(c,new ob(b.style,b,"style",b.style.cssText)),c;var e=b.attributes;if(e)if(a instanceof M&&null===a.b||"*"==d)for(var d=0,f;f=e[d];d++)C?f.nodeValue&&L(c,pb(b,f)):L(c,f);else(f=e.getNamedItem(d))&&(C?f.nodeValue&&L(c,pb(b,f)):L(c,f));return c},!1),hc=U("child",function(a,b,c,d,e){return(C?Bb:Cb).call(null,a,b,n(c)?c:null,n(d)?d:null,e||new K)},!1,!0);U("descendant",vb,!1,!0);
var ic=U("descendant-or-self",function(a,b,c,d){var e=new K;J(b,c,d)&&a.a(b)&&L(e,b);return vb(a,b,c,d,e)},!1,!0),dc=U("following",function(a,b,c,d){var e=new K;do for(var f=b;f=f.nextSibling;)J(f,c,d)&&a.a(f)&&L(e,f),e=vb(a,f,c,d,e);while(b=b.parentNode);return e},!1,!0);U("following-sibling",function(a,b){for(var c=new K,d=b;d=d.nextSibling;)a.a(d)&&L(c,d);return c},!1);U("namespace",function(){return new K},!1);
var lc=U("parent",function(a,b){var c=new K;if(9==b.nodeType)return c;if(2==b.nodeType)return L(c,b.ownerElement),c;var d=b.parentNode;a.a(d)&&L(c,d);return c},!1),ec=U("preceding",function(a,b,c,d){var e=new K,f=[];do f.unshift(b);while(b=b.parentNode);for(var g=1,k=f.length;g<k;g++){var l=[];for(b=f[g];b=b.previousSibling;)l.unshift(b);for(var r=0,G=l.length;r<G;r++)b=l[r],J(b,c,d)&&a.a(b)&&L(e,b),e=vb(a,b,c,d,e)}return e},!0,!0);
U("preceding-sibling",function(a,b){for(var c=new K,d=b;d=d.previousSibling;)a.a(d)&&c.unshift(d);return c},!0);var mc=U("self",function(a,b){var c=new K;a.a(b)&&L(c,b);return c},!1);function nc(a){O.call(this,1);this.c=a;this.i=a.i;this.b=a.b}p(nc,O);nc.prototype.a=function(a){return-Q(this.c,a)};nc.prototype.toString=function(){return"Unary Expression: -"+P(this.c)};function oc(a){O.call(this,4);this.c=a;Jb(this,ta(this.c,function(a){return a.i}));Kb(this,ta(this.c,function(a){return a.b}))}p(oc,O);oc.prototype.a=function(a){var b=new K;q(this.c,function(c){c=c.a(a);if(!(c instanceof K))throw Error("Path expression must evaluate to NodeSet.");b=Eb(b,c)});return b};oc.prototype.toString=function(){return sa(this.c,function(a,b){return a+P(b)},"Union Expression:")};function pc(a,b){this.a=a;this.b=b}function qc(a){for(var b,c=[];;){V(a,"Missing right hand side of binary expression.");b=rc(a);var d=E(a.a);if(!d)break;var e=(d=Qb[d]||null)&&d.H;if(!e){a.a.a--;break}for(;c.length&&e<=c[c.length-1].H;)b=new Mb(c.pop(),c.pop(),b);c.push(b,d)}for(;c.length;)b=new Mb(c.pop(),c.pop(),b);return b}function V(a,b){if(ub(a.a))throw Error(b);}function sc(a,b){var c=E(a.a);if(c!=b)throw Error("Bad token, expected: "+b+" got: "+c);}
function tc(a){a=E(a.a);if(")"!=a)throw Error("Bad token: "+a);}function uc(a){a=E(a.a);if(2>a.length)throw Error("Unclosed literal string");return new Xb(a)}
function vc(a){var b,c=[],d;if(cc(D(a.a))){b=E(a.a);d=D(a.a);if("/"==b&&(ub(a.a)||"."!=d&&".."!=d&&"@"!=d&&"*"!=d&&!/(?![0-9])[\w]/.test(d)))return new ac;d=new ac;V(a,"Missing next location step.");b=wc(a,b);c.push(b)}else{a:{b=D(a.a);d=b.charAt(0);switch(d){case "$":throw Error("Variable reference not allowed in HTML XPath");case "(":E(a.a);b=qc(a);V(a,'unclosed "("');sc(a,")");break;case '"':case "'":b=uc(a);break;default:if(isNaN(+b))if(!Wb(b)&&/(?![0-9])[\w]/.test(d)&&"("==D(a.a,1)){b=E(a.a);
b=Vb[b]||null;E(a.a);for(d=[];")"!=D(a.a);){V(a,"Missing function argument list.");d.push(qc(a));if(","!=D(a.a))break;E(a.a)}V(a,"Unclosed function argument list.");tc(a);b=new Tb(b,d)}else{b=null;break a}else b=new Yb(+E(a.a))}"["==D(a.a)&&(d=new fc(xc(a)),b=new Rb(b,d))}if(b)if(cc(D(a.a)))d=b;else return b;else b=wc(a,"/"),d=new bc,c.push(b)}for(;cc(D(a.a));)b=E(a.a),V(a,"Missing next location step."),b=wc(a,b),c.push(b);return new Zb(d,c)}
function wc(a,b){var c,d,e;if("/"!=b&&"//"!=b)throw Error('Step op should be "/" or "//"');if("."==D(a.a))return d=new gc(mc,new M("node")),E(a.a),d;if(".."==D(a.a))return d=new gc(lc,new M("node")),E(a.a),d;var f;if("@"==D(a.a))f=$b,E(a.a),V(a,"Missing attribute name");else if("::"==D(a.a,1)){if(!/(?![0-9])[\w]/.test(D(a.a).charAt(0)))throw Error("Bad token: "+E(a.a));c=E(a.a);f=kc[c]||null;if(!f)throw Error("No axis with name: "+c);E(a.a);V(a,"Missing node name")}else f=hc;c=D(a.a);if(/(?![0-9])[\w\*]/.test(c.charAt(0)))if("("==
D(a.a,1)){if(!Wb(c))throw Error("Invalid node type: "+c);c=E(a.a);if(!Wb(c))throw Error("Invalid type name: "+c);sc(a,"(");V(a,"Bad nodetype");e=D(a.a).charAt(0);var g=null;if('"'==e||"'"==e)g=uc(a);V(a,"Bad nodetype");tc(a);c=new M(c,g)}else if(c=E(a.a),e=c.indexOf(":"),-1==e)c=new yb(c);else{var g=c.substring(0,e),k;if("*"==g)k="*";else if(k=a.b(g),!k)throw Error("Namespace prefix not declared: "+g);c=c.substr(e+1);c=new yb(c,k)}else throw Error("Bad token: "+E(a.a));e=new fc(xc(a),f.a);return d||
new gc(f,c,e,"//"==b)}function xc(a){for(var b=[];"["==D(a.a);){E(a.a);V(a,"Missing predicate expression.");var c=qc(a);b.push(c);V(a,"Unclosed predicate expression.");sc(a,"]")}return b}function rc(a){if("-"==D(a.a))return E(a.a),new nc(rc(a));var b=vc(a);if("|"!=D(a.a))a=b;else{for(b=[b];"|"==E(a.a);)V(a,"Missing next union location path."),b.push(vc(a));a.a.a--;a=new oc(b)}return a};function yc(a){switch(a.nodeType){case 1:return ia(zc,a);case 9:return yc(a.documentElement);case 11:case 10:case 6:case 12:return Ac;default:return a.parentNode?yc(a.parentNode):Ac}}function Ac(){return null}function zc(a,b){if(a.prefix==b)return a.namespaceURI||"http://www.w3.org/1999/xhtml";var c=a.getAttributeNode("xmlns:"+b);return c&&c.specified?c.value||null:a.parentNode&&9!=a.parentNode.nodeType?zc(a.parentNode,b):null};function Bc(a,b){if(!a.length)throw Error("Empty XPath expression.");var c=rb(a);if(ub(c))throw Error("Invalid XPath expression.");b?"function"==ba(b)||(b=ha(b.lookupNamespaceURI,b)):b=function(){return null};var d=qc(new pc(c,b));if(!ub(c))throw Error("Bad token: "+E(c));this.evaluate=function(a,b){var c=d.a(new mb(a));return new W(c,b)}}
function W(a,b){if(0==b)if(a instanceof K)b=4;else if("string"==typeof a)b=2;else if("number"==typeof a)b=1;else if("boolean"==typeof a)b=3;else throw Error("Unexpected evaluation result.");if(2!=b&&1!=b&&3!=b&&!(a instanceof K))throw Error("value could not be converted to the specified type");this.resultType=b;var c;switch(b){case 2:this.stringValue=a instanceof K?Gb(a):""+a;break;case 1:this.numberValue=a instanceof K?+Gb(a):+a;break;case 3:this.booleanValue=a instanceof K?0<a.s:!!a;break;case 4:case 5:case 6:case 7:var d=
Hb(a);c=[];for(var e=N(d);e;e=N(d))c.push(e instanceof ob?e.a:e);this.snapshotLength=a.s;this.invalidIteratorState=!1;break;case 8:case 9:d=Fb(a);this.singleNodeValue=d instanceof ob?d.a:d;break;default:throw Error("Unknown XPathResult type.");}var f=0;this.iterateNext=function(){if(4!=b&&5!=b)throw Error("iterateNext called with wrong result type");return f>=c.length?null:c[f++]};this.snapshotItem=function(a){if(6!=b&&7!=b)throw Error("snapshotItem called with wrong result type");return a>=c.length||
0>a?null:c[a]}}W.ANY_TYPE=0;W.NUMBER_TYPE=1;W.STRING_TYPE=2;W.BOOLEAN_TYPE=3;W.UNORDERED_NODE_ITERATOR_TYPE=4;W.ORDERED_NODE_ITERATOR_TYPE=5;W.UNORDERED_NODE_SNAPSHOT_TYPE=6;W.ORDERED_NODE_SNAPSHOT_TYPE=7;W.ANY_UNORDERED_NODE_TYPE=8;W.FIRST_ORDERED_NODE_TYPE=9;function Cc(a){this.lookupNamespaceURI=yc(a)}
function Dc(a,b){var c=a||m,d=c.document;if(!d.evaluate||b)c.XPathResult=W,d.evaluate=function(a,b,c,d){return(new Bc(a,c)).evaluate(b,d)},d.createExpression=function(a,b){return new Bc(a,b)},d.createNSResolver=function(a){return new Cc(a)}}aa("wgxpath.install",Dc);var X={};X.F=function(){var a={R:"http://www.w3.org/2000/svg"};return function(b){return a[b]||null}}();
X.u=function(a,b,c){var d=B(a);if(!d.documentElement)return null;(x||jb)&&Dc(d?d.parentWindow||d.defaultView:window);try{var e=d.createNSResolver?d.createNSResolver(d.documentElement):X.F;if(x&&!Xa(7))return d.evaluate.call(d,b,a,e,c,null);if(!x||9<=Number(z)){for(var f={},g=d.getElementsByTagName("*"),k=0;k<g.length;++k){var l=g[k],r=l.namespaceURI;if(r&&!f[r]){var G=l.lookupPrefix(r);if(!G)var A=r.match(".*/(\\w+)/?$"),G=A?A[1]:"xhtml";f[r]=G}}var t={},F;for(F in f)t[f[F]]=F;e=function(a){return t[a]||
null}}try{return d.evaluate(b,a,e,c,null)}catch(I){if("TypeError"===I.name)return e=d.createNSResolver?d.createNSResolver(d.documentElement):X.F,d.evaluate(b,a,e,c,null);throw I;}}catch(I){if(!y||"NS_ERROR_ILLEGAL_VALUE"!=I.name)throw new Da(32,"Unable to locate an element with the xpath expression "+b+" because of the following error:\n"+I);}};X.G=function(a,b){if(!a||1!=a.nodeType)throw new Da(32,'The result of the xpath expression "'+b+'" is: '+a+". It should be an element.");};
X.J=function(a,b){var c=function(){var c=X.u(b,a,9);return c?c.singleNodeValue||null:b.selectSingleNode?(c=B(b),c.setProperty&&c.setProperty("SelectionLanguage","XPath"),b.selectSingleNode(a)):null}();null===c||X.G(c,a);return c};
X.O=function(a,b){var c=function(){var c=X.u(b,a,7);if(c){for(var e=c.snapshotLength,f=[],g=0;g<e;++g)f.push(c.snapshotItem(g));return f}return b.selectNodes?(c=B(b),c.setProperty&&c.setProperty("SelectionLanguage","XPath"),b.selectNodes(a)):[]}();q(c,function(b){X.G(b,a)});return c};function Ec(a){return(a=a.exec(v))?a[1]:""}var Fc=function(){if(gb)return Ec(/Firefox\/([0-9.]+)/);if(x||Pa||Oa)return Va;if(kb)return Ec(/Chrome\/([0-9.]+)/);if(lb&&!(Na()||w("iPad")||w("iPod")))return Ec(/Version\/([0-9.]+)/);if(hb||ib){var a;if(a=/Version\/(\S+).*Mobile\/(\S+)/.exec(v))return a[1]+"."+a[2]}else if(jb)return(a=Ec(/Android\s+([0-9.]+)/))?a:Ec(/Version\/([0-9.]+)/);return""}();var Gc,Hc;function Ic(a){return Jc?Gc(a):x?0<=ma(z,a):Xa(a)}function Kc(a){Jc?Hc(a):jb?ma(Lc,a):ma(Fc,a)}
var Jc=function(){if(!y)return!1;var a=m.Components;if(!a)return!1;try{if(!a.classes)return!1}catch(f){return!1}var b=a.classes,a=a.interfaces,c=b["@mozilla.org/xpcom/version-comparator;1"].getService(a.nsIVersionComparator),b=b["@mozilla.org/xre/app-info;1"].getService(a.nsIXULAppInfo),d=b.platformVersion,e=b.version;Gc=function(a){return 0<=c.compare(d,""+a)};Hc=function(a){c.compare(e,""+a)};return!0}(),Mc;if(jb){var Nc=/Android\s+([0-9\.]+)/.exec(v);Mc=Nc?Nc[1]:"0"}else Mc="0";
var Lc=Mc,Oc=x&&!(9<=Number(z));jb&&Kc(2.3);jb&&Kc(4);lb&&Kc(6);function Pc(a,b,c,d){this.top=a;this.right=b;this.bottom=c;this.left=d}h=Pc.prototype;h.clone=function(){return new Pc(this.top,this.right,this.bottom,this.left)};h.toString=function(){return"("+this.top+"t, "+this.right+"r, "+this.bottom+"b, "+this.left+"l)"};h.contains=function(a){return this&&a?a instanceof Pc?a.left>=this.left&&a.right<=this.right&&a.top>=this.top&&a.bottom<=this.bottom:a.x>=this.left&&a.x<=this.right&&a.y>=this.top&&a.y<=this.bottom:!1};
h.ceil=function(){this.top=Math.ceil(this.top);this.right=Math.ceil(this.right);this.bottom=Math.ceil(this.bottom);this.left=Math.ceil(this.left);return this};h.floor=function(){this.top=Math.floor(this.top);this.right=Math.floor(this.right);this.bottom=Math.floor(this.bottom);this.left=Math.floor(this.left);return this};h.round=function(){this.top=Math.round(this.top);this.right=Math.round(this.right);this.bottom=Math.round(this.bottom);this.left=Math.round(this.left);return this};
h.scale=function(a,b){var c=da(b)?b:a;this.left*=a;this.right*=a;this.top*=c;this.bottom*=c;return this};function Y(a,b,c,d){this.left=a;this.top=b;this.width=c;this.height=d}h=Y.prototype;h.clone=function(){return new Y(this.left,this.top,this.width,this.height)};h.toString=function(){return"("+this.left+", "+this.top+" - "+this.width+"w x "+this.height+"h)"};h.contains=function(a){return a instanceof Y?this.left<=a.left&&this.left+this.width>=a.left+a.width&&this.top<=a.top&&this.top+this.height>=a.top+a.height:a.x>=this.left&&a.x<=this.left+this.width&&a.y>=this.top&&a.y<=this.top+this.height};
h.ceil=function(){this.left=Math.ceil(this.left);this.top=Math.ceil(this.top);this.width=Math.ceil(this.width);this.height=Math.ceil(this.height);return this};h.floor=function(){this.left=Math.floor(this.left);this.top=Math.floor(this.top);this.width=Math.floor(this.width);this.height=Math.floor(this.height);return this};h.round=function(){this.left=Math.round(this.left);this.top=Math.round(this.top);this.width=Math.round(this.width);this.height=Math.round(this.height);return this};
h.scale=function(a,b){var c=da(b)?b:a;this.left*=a;this.width*=a;this.top*=c;this.height*=c;return this};function Qc(a,b){var c=B(a);return c.defaultView&&c.defaultView.getComputedStyle&&(c=c.defaultView.getComputedStyle(a,null))?c[b]||c.getPropertyValue(b)||"":""}var Rc={thin:2,medium:4,thick:6};
function Sc(a,b){if("none"==(a.currentStyle?a.currentStyle[b+"Style"]:null))return 0;var c=a.currentStyle?a.currentStyle[b+"Width"]:null,d;if(c in Rc)d=Rc[c];else if(/^\d+px?$/.test(c))d=parseInt(c,10);else{d=a.style.left;var e=a.runtimeStyle.left;a.runtimeStyle.left=a.currentStyle.left;a.style.left=c;c=a.style.pixelLeft;a.style.left=d;a.runtimeStyle.left=e;d=c}return d};function Tc(a,b){return!!a&&1==a.nodeType&&(!b||a.tagName.toUpperCase()==b)}function Uc(a){for(a=a.parentNode;a&&1!=a.nodeType&&9!=a.nodeType&&11!=a.nodeType;)a=a.parentNode;return Tc(a)?a:null}
function Vc(a,b){var c=oa(b);if("float"==c||"cssFloat"==c||"styleFloat"==c)c=Oc?"styleFloat":"cssFloat";var d=Qc(a,c)||Wc(a,c);if(null===d)d=null;else if(0<=pa(ya,c)){b:{var e=d.match(Ba);if(e){var c=Number(e[1]),f=Number(e[2]),g=Number(e[3]),e=Number(e[4]);if(0<=c&&255>=c&&0<=f&&255>=f&&0<=g&&255>=g&&0<=e&&1>=e){c=[c,f,g,e];break b}}c=null}if(!c)b:{if(g=d.match(Ca))if(c=Number(g[1]),f=Number(g[2]),g=Number(g[3]),0<=c&&255>=c&&0<=f&&255>=f&&0<=g&&255>=g){c=[c,f,g,1];break b}c=null}if(!c)b:{c=d.toLowerCase();
f=xa[c.toLowerCase()];if(!f&&(f="#"==c.charAt(0)?c:"#"+c,4==f.length&&(f=f.replace(za,"#$1$1$2$2$3$3")),!Aa.test(f))){c=null;break b}c=[parseInt(f.substr(1,2),16),parseInt(f.substr(3,2),16),parseInt(f.substr(5,2),16),1]}d=c?"rgba("+c.join(", ")+")":d}return d}function Wc(a,b){var c=a.currentStyle||a.style,d=c[b];void 0===d&&"function"==ba(c.getPropertyValue)&&(d=c.getPropertyValue(b));return"inherit"!=d?void 0!==d?d:null:(c=Uc(a))?Wc(c,b):null}
function Xc(a,b){function c(a){function b(a){return a==k?!0:0==Vc(a,"display").lastIndexOf("inline",0)||"absolute"==c&&"static"==Vc(a,"position")?!1:!0}var c=Vc(a,"position");if("fixed"==c)return G=!0,a==k?null:k;for(a=Uc(a);a&&!b(a);)a=Uc(a);return a}function d(a){var b=a;if("visible"==r)if(a==k&&l)b=l;else if(a==l)return{x:"visible",y:"visible"};b={x:Vc(b,"overflow-x"),y:Vc(b,"overflow-y")};a==k&&(b.x="visible"==b.x?"auto":b.x,b.y="visible"==b.y?"auto":b.y);return b}function e(a){if(a==k){var b=
(new fb(g)).a;a=b.scrollingElement?b.scrollingElement:Qa||"CSS1Compat"!=b.compatMode?b.body||b.documentElement:b.documentElement;b=b.parentWindow||b.defaultView;a=x&&Xa("10")&&b.pageYOffset!=a.scrollTop?new $a(a.scrollLeft,a.scrollTop):new $a(b.pageXOffset||a.scrollLeft,b.pageYOffset||a.scrollTop)}else a=new $a(a.scrollLeft,a.scrollTop);return a}for(var f=Yc(a,b),g=B(a),k=g.documentElement,l=g.body,r=Vc(k,"overflow"),G,A=c(a);A;A=c(A)){var t=d(A);if("visible"!=t.x||"visible"!=t.y){var F=Zc(A);if(0==
F.width||0==F.height)return"hidden";var I=f.right<F.left,Za=f.bottom<F.top;if(I&&"hidden"==t.x||Za&&"hidden"==t.y)return"hidden";if(I&&"visible"!=t.x||Za&&"visible"!=t.y){I=e(A);Za=f.bottom<F.top-I.y;if(f.right<F.left-I.x&&"visible"!=t.x||Za&&"visible"!=t.x)return"hidden";f=Xc(A);return"hidden"==f?"hidden":"scroll"}I=f.left>=F.left+F.width;F=f.top>=F.top+F.height;if(I&&"hidden"==t.x||F&&"hidden"==t.y)return"hidden";if(I&&"visible"!=t.x||F&&"visible"!=t.y){if(G&&(t=e(A),f.left>=k.scrollWidth-t.x||
f.right>=k.scrollHeight-t.y))return"hidden";f=Xc(A);return"hidden"==f?"hidden":"scroll"}}}return"none"}
function Zc(a){var b;var c=Tc(a,"MAP");if(c||Tc(a,"AREA")){var d=c?a:Tc(a.parentNode,"MAP")?a.parentNode:null,e=b=null;if(d&&d.name&&(b=X.J('/descendant::*[@usemap = "#'+d.name+'"]',B(d)))&&(e=Zc(b),!c&&"default"!=a.shape.toLowerCase()))var c=$c(a),d=Math.min(Math.max(c.left,0),e.width),f=Math.min(Math.max(c.top,0),e.height),e=new Y(d+e.left,f+e.top,Math.min(c.width,e.width-d),Math.min(c.height,e.height-f));b={a:b,rect:e||new Y(0,0,0,0)}}else b=null;if(b)return b.rect;if(Tc(a,"HTML"))return a=B(a),
a=((a?a.parentWindow||a.defaultView:window)||window).document,a="CSS1Compat"==a.compatMode?a.documentElement:a.body,a=new ab(a.clientWidth,a.clientHeight),new Y(0,0,a.width,a.height);var g;try{g=a.getBoundingClientRect()}catch(k){return new Y(0,0,0,0)}g=new Y(g.left,g.top,g.right-g.left,g.bottom-g.top);x&&a.ownerDocument.body&&(a=B(a),g.left-=a.documentElement.clientLeft+a.body.clientLeft,g.top-=a.documentElement.clientTop+a.body.clientTop);return g}
function $c(a){var b=a.shape.toLowerCase();a=a.coords.split(",");if("rect"==b&&4==a.length){var b=a[0],c=a[1];return new Y(b,c,a[2]-b,a[3]-c)}if("circle"==b&&3==a.length)return b=a[2],new Y(a[0]-b,a[1]-b,2*b,2*b);if("poly"==b&&2<a.length){for(var b=a[0],c=a[1],d=b,e=c,f=2;f+1<a.length;f+=2)b=Math.min(b,a[f]),d=Math.max(d,a[f]),c=Math.min(c,a[f+1]),e=Math.max(e,a[f+1]);return new Y(b,c,d-b,e-c)}return new Y(0,0,0,0)}
function Yc(a,b){var c;c=Zc(a);c=new Pc(c.top,c.left+c.width,c.top+c.height,c.left);if(b){var d=b instanceof Y?b:new Y(b.x,b.y,1,1);c.left=Math.min(Math.max(c.left+d.left,c.left),c.right);c.top=Math.min(Math.max(c.top+d.top,c.top),c.bottom);c.right=Math.min(Math.max(c.left+d.width,c.left),c.right);c.bottom=Math.min(Math.max(c.top+d.height,c.top),c.bottom)}return c};Qa||Jc&&Kc(3.6);x&&Ic(10);jb&&Kc(4);function ad(a,b){this.v={};this.l=[];this.b=this.a=0;var c=arguments.length;if(1<c){if(c%2)throw Error("Uneven number of arguments");for(var d=0;d<c;d+=2)bd(this,arguments[d],arguments[d+1])}else if(a){var e;if(a instanceof ad)for(d=cd(a),dd(a),e=[],c=0;c<a.l.length;c++)e.push(a.v[a.l[c]]);else{var c=[],f=0;for(d in a)c[f++]=d;d=c;c=[];f=0;for(e in a)c[f++]=a[e];e=c}for(c=0;c<d.length;c++)bd(this,d[c],e[c])}}function cd(a){dd(a);return a.l.concat()}
ad.prototype.clear=function(){this.v={};this.b=this.a=this.l.length=0};function dd(a){if(a.a!=a.l.length){for(var b=0,c=0;b<a.l.length;){var d=a.l[b];Object.prototype.hasOwnProperty.call(a.v,d)&&(a.l[c++]=d);b++}a.l.length=c}if(a.a!=a.l.length){for(var e={},c=b=0;b<a.l.length;)d=a.l[b],Object.prototype.hasOwnProperty.call(e,d)||(a.l[c++]=d,e[d]=1),b++;a.l.length=c}}ad.prototype.get=function(a,b){return Object.prototype.hasOwnProperty.call(this.v,a)?this.v[a]:b};
function bd(a,b,c){Object.prototype.hasOwnProperty.call(a.v,b)||(a.a++,a.l.push(b),a.b++);a.v[b]=c}ad.prototype.forEach=function(a,b){for(var c=cd(this),d=0;d<c.length;d++){var e=c[d],f=this.get(e);a.call(b,f,e,this)}};ad.prototype.clone=function(){return new ad(this)};var ed={};function Z(a,b,c){ea(a)&&(a=y?a.f:a.g);a=new fd(a);!b||b in ed&&!c||(ed[b]={key:a,shift:!1},c&&(ed[c]={key:a,shift:!0}));return a}function fd(a){this.code=a}Z(8);Z(9);Z(13);var gd=Z(16),hd=Z(17),id=Z(18);Z(19);Z(20);Z(27);Z(32," ");Z(33);Z(34);Z(35);Z(36);Z(37);Z(38);Z(39);Z(40);Z(44);Z(45);Z(46);Z(48,"0",")");Z(49,"1","!");Z(50,"2","@");Z(51,"3","#");Z(52,"4","$");Z(53,"5","%");Z(54,"6","^");Z(55,"7","&");Z(56,"8","*");Z(57,"9","(");Z(65,"a","A");Z(66,"b","B");Z(67,"c","C");Z(68,"d","D");
Z(69,"e","E");Z(70,"f","F");Z(71,"g","G");Z(72,"h","H");Z(73,"i","I");Z(74,"j","J");Z(75,"k","K");Z(76,"l","L");Z(77,"m","M");Z(78,"n","N");Z(79,"o","O");Z(80,"p","P");Z(81,"q","Q");Z(82,"r","R");Z(83,"s","S");Z(84,"t","T");Z(85,"u","U");Z(86,"v","V");Z(87,"w","W");Z(88,"x","X");Z(89,"y","Y");Z(90,"z","Z");var jd=Z(Sa?{f:91,g:91}:Ra?{f:224,g:91}:{f:0,g:91});Z(Sa?{f:92,g:92}:Ra?{f:224,g:93}:{f:0,g:92});Z(Sa?{f:93,g:93}:Ra?{f:0,g:0}:{f:93,g:null});Z({f:96,g:96},"0");Z({f:97,g:97},"1");
Z({f:98,g:98},"2");Z({f:99,g:99},"3");Z({f:100,g:100},"4");Z({f:101,g:101},"5");Z({f:102,g:102},"6");Z({f:103,g:103},"7");Z({f:104,g:104},"8");Z({f:105,g:105},"9");Z({f:106,g:106},"*");Z({f:107,g:107},"+");Z({f:109,g:109},"-");Z({f:110,g:110},".");Z({f:111,g:111},"/");Z(144);Z(112);Z(113);Z(114);Z(115);Z(116);Z(117);Z(118);Z(119);Z(120);Z(121);Z(122);Z(123);Z({f:107,g:187},"=","+");Z(108,",");Z({f:109,g:189},"-","_");Z(188,",","<");Z(190,".",">");Z(191,"/","?");Z(192,"`","~");Z(219,"[","{");
Z(220,"\\","|");Z(221,"]","}");Z({f:59,g:186},";",":");Z(222,"'",'"');var kd=new ad;bd(kd,1,gd);bd(kd,2,hd);bd(kd,4,id);bd(kd,8,jd);(function(a){var b=new ad;q(cd(a),function(c){bd(b,a.get(c).code,c)});return b})(kd);y&&Ic(12);function ld(a,b){var c=Xc(a,b);if("scroll"!=c)return"none"==c;if(a.scrollIntoView&&(a.scrollIntoView(),"none"==Xc(a,b)))return!0;for(var c=Yc(a,b),d=Uc(a);d;d=Uc(d)){var e=d,f=Zc(e),g;var k=e;if(!x||9<=Number(z))l=Qc(k,"borderLeftWidth"),g=Qc(k,"borderRightWidth"),r=Qc(k,"borderTopWidth"),k=Qc(k,"borderBottomWidth"),g=new Pc(parseFloat(r),parseFloat(g),parseFloat(k),parseFloat(l));else{var l=Sc(k,"borderLeft");g=Sc(k,"borderRight");var r=Sc(k,"borderTop"),k=Sc(k,"borderBottom");g=new Pc(r,g,k,l)}l=
c.left-f.left-g.left;f=c.top-f.top-g.top;g=e.clientHeight+c.top-c.bottom;e.scrollLeft+=Math.min(l,Math.max(l-(e.clientWidth+c.left-c.right),0));e.scrollTop+=Math.min(f,Math.max(f-g,0))}return"none"==Xc(a,b)};function md(){}
function nd(a,b,c){if(null==b)c.push("null");else{if("object"==typeof b){if("array"==ba(b)){var d=b;b=d.length;c.push("[");for(var e="",f=0;f<b;f++)c.push(e),nd(a,d[f],c),e=",";c.push("]");return}if(b instanceof String||b instanceof Number||b instanceof Boolean)b=b.valueOf();else{c.push("{");e="";for(d in b)Object.prototype.hasOwnProperty.call(b,d)&&(f=b[d],"function"!=typeof f&&(c.push(e),od(d,c),c.push(":"),nd(a,f,c),e=","));c.push("}");return}}switch(typeof b){case "string":od(b,c);break;case "number":c.push(isFinite(b)&&
!isNaN(b)?String(b):"null");break;case "boolean":c.push(String(b));break;case "function":c.push("null");break;default:throw Error("Unknown type: "+typeof b);}}}var pd={'"':'\\"',"\\":"\\\\","/":"\\/","\b":"\\b","\f":"\\f","\n":"\\n","\r":"\\r","\t":"\\t","\x0B":"\\u000b"},qd=/\uffff/.test("\uffff")?/[\\\"\x00-\x1f\x7f-\uffff]/g:/[\\\"\x00-\x1f\x7f-\xff]/g;
function od(a,b){b.push('"',a.replace(qd,function(a){var b=pd[a];b||(b="\\u"+(a.charCodeAt(0)|65536).toString(16).substr(1),pd[a]=b);return b}),'"')};Qa||y&&Ic(3.5)||x&&Ic(8);function rd(a){switch(ba(a)){case "string":case "number":case "boolean":return a;case "function":return a.toString();case "array":return ra(a,rd);case "object":if(Ja(a,"nodeType")&&(1==a.nodeType||9==a.nodeType)){var b={};b.ELEMENT=sd(a);return b}if(Ja(a,"document"))return b={},b.WINDOW=sd(a),b;if(ca(a))return ra(a,rd);a=Ha(a,function(a,b){return da(b)||n(b)});return Ia(a,rd);default:return null}}
function td(a,b){return"array"==ba(a)?ra(a,function(a){return td(a,b)}):ea(a)?"function"==typeof a?a:Ja(a,"ELEMENT")?ud(a.ELEMENT,b):Ja(a,"WINDOW")?ud(a.WINDOW,b):Ia(a,function(a){return td(a,b)}):a}function vd(a){a=a||document;var b=a.$wdc_;b||(b=a.$wdc_={},b.C=ja());b.C||(b.C=ja());return b}function sd(a){var b=vd(a.ownerDocument),c=Ka(b,function(b){return b==a});c||(c=":wdc:"+b.C++,b[c]=a);return c}
function ud(a,b){a=decodeURIComponent(a);var c=b||document,d=vd(c);if(!Ja(d,a))throw new Da(10,"Element does not exist in cache");var e=d[a];if(Ja(e,"setInterval")){if(e.closed)throw delete d[a],new Da(23,"Window has been closed.");return e}for(var f=e;f;){if(f==c.documentElement)return e;f=f.parentNode}delete d[a];throw new Da(10,"Element is no longer attached to the DOM");};aa("_",function(a,b){var c=[a,b],d=ld,e;try{a:{var f=d;if(n(f))try{d=new ka.Function(f);break a}catch(l){if(x&&ka.execScript){ka.execScript(";");d=new ka.Function(f);break a}throw l;}d=ka==window?f:new ka.Function("return ("+f+").apply(null,arguments);")}var g=td(c,ka.document),k=d.apply(null,g);e={status:0,value:rd(k)}}catch(l){e={status:Ja(l,"code")?l.code:13,value:{message:l.message}}}c=[];nd(new md,e,c);return c.join("")});; return this._.apply(null,arguments);}.apply({navigator:typeof window!=undefined?window.navigator:null,document:typeof window!=undefined?window.document:null}, arguments);}
