function(){return function(){var l=this;function aa(a){return void 0!==a}function ba(a,b){var c=a.split("."),d=l;c[0]in d||!d.execScript||d.execScript("var "+c[0]);for(var e;c.length&&(e=c.shift());)!c.length&&aa(b)?d[e]=b:d[e]?d=d[e]:d=d[e]={}}
function ca(a){var b=typeof a;if("object"==b)if(a){if(a instanceof Array)return"array";if(a instanceof Object)return b;var c=Object.prototype.toString.call(a);if("[object Window]"==c)return"object";if("[object Array]"==c||"number"==typeof a.length&&"undefined"!=typeof a.splice&&"undefined"!=typeof a.propertyIsEnumerable&&!a.propertyIsEnumerable("splice"))return"array";if("[object Function]"==c||"undefined"!=typeof a.call&&"undefined"!=typeof a.propertyIsEnumerable&&!a.propertyIsEnumerable("call"))return"function"}else return"null";
else if("function"==b&&"undefined"==typeof a.call)return"object";return b}function da(a){var b=ca(a);return"array"==b||"object"==b&&"number"==typeof a.length}function m(a){return"string"==typeof a}function ea(a){return"function"==ca(a)}function fa(a){var b=typeof a;return"object"==b&&null!=a||"function"==b}function ga(a,b,c){return a.call.apply(a.bind,arguments)}
function ha(a,b,c){if(!a)throw Error();if(2<arguments.length){var d=Array.prototype.slice.call(arguments,2);return function(){var c=Array.prototype.slice.call(arguments);Array.prototype.unshift.apply(c,d);return a.apply(b,c)}}return function(){return a.apply(b,arguments)}}function ia(a,b,c){ia=Function.prototype.bind&&-1!=Function.prototype.bind.toString().indexOf("native code")?ga:ha;return ia.apply(null,arguments)}
function ja(a,b){var c=Array.prototype.slice.call(arguments,1);return function(){var b=c.slice();b.push.apply(b,arguments);return a.apply(this,b)}}var ka=Date.now||function(){return+new Date};function q(a,b){function c(){}c.prototype=b.prototype;a.R=b.prototype;a.prototype=new c;a.prototype.constructor=a;a.P=function(a,c,f){for(var g=Array(arguments.length-2),h=2;h<arguments.length;h++)g[h-2]=arguments[h];return b.prototype[c].apply(a,g)}};var la=window;function t(a,b){this.code=a;this.a=u[a]||ma;this.message=b||"";var c=this.a.replace(/((?:^|\s+)[a-z])/g,function(a){return a.toUpperCase().replace(/^[\s\xa0]+/g,"")}),d=c.length-5;if(0>d||c.indexOf("Error",d)!=d)c+="Error";this.name=c;c=Error(this.message);c.name=this.name;this.stack=c.stack||""}q(t,Error);var ma="unknown error",u={15:"element not selectable",11:"element not visible"};u[31]=ma;u[30]=ma;u[24]="invalid cookie domain";u[29]="invalid element coordinates";u[12]="invalid element state";
u[32]="invalid selector";u[51]="invalid selector";u[52]="invalid selector";u[17]="javascript error";u[405]="unsupported operation";u[34]="move target out of bounds";u[27]="no such alert";u[7]="no such element";u[8]="no such frame";u[23]="no such window";u[28]="script timeout";u[33]="session not created";u[10]="stale element reference";u[21]="timeout";u[25]="unable to set cookie";u[26]="unexpected alert open";u[13]=ma;u[9]="unknown command";t.prototype.toString=function(){return this.name+": "+this.message};var na;function oa(a){var b=a.length-1;return 0<=b&&a.indexOf(" ",b)==b}var pa=String.prototype.trim?function(a){return a.trim()}:function(a){return a.replace(/^[\s\xa0]+|[\s\xa0]+$/g,"")};
function qa(a,b){for(var c=0,d=pa(String(a)).split("."),e=pa(String(b)).split("."),f=Math.max(d.length,e.length),g=0;0==c&&g<f;g++){var h=d[g]||"",n=e[g]||"",p=RegExp("(\\d*)(\\D*)","g"),k=RegExp("(\\d*)(\\D*)","g");do{var r=p.exec(h)||["","",""],y=k.exec(n)||["","",""];if(0==r[0].length&&0==y[0].length)break;c=ra(0==r[1].length?0:parseInt(r[1],10),0==y[1].length?0:parseInt(y[1],10))||ra(0==r[2].length,0==y[2].length)||ra(r[2],y[2])}while(0==c)}return c}function ra(a,b){return a<b?-1:a>b?1:0}
function sa(a){return String(a).replace(/\-([a-z])/g,function(a,c){return c.toUpperCase()})};function ta(a,b){if(m(a))return m(b)&&1==b.length?a.indexOf(b,0):-1;for(var c=0;c<a.length;c++)if(c in a&&a[c]===b)return c;return-1}function v(a,b){for(var c=a.length,d=m(a)?a.split(""):a,e=0;e<c;e++)e in d&&b.call(void 0,d[e],e,a)}function ua(a,b){for(var c=a.length,d=[],e=0,f=m(a)?a.split(""):a,g=0;g<c;g++)if(g in f){var h=f[g];b.call(void 0,h,g,a)&&(d[e++]=h)}return d}
function va(a,b){for(var c=a.length,d=Array(c),e=m(a)?a.split(""):a,f=0;f<c;f++)f in e&&(d[f]=b.call(void 0,e[f],f,a));return d}function wa(a,b,c){var d=c;v(a,function(c,f){d=b.call(void 0,d,c,f,a)});return d}function xa(a,b){for(var c=a.length,d=m(a)?a.split(""):a,e=0;e<c;e++)if(e in d&&b.call(void 0,d[e],e,a))return!0;return!1}function ya(a,b){for(var c=a.length,d=m(a)?a.split(""):a,e=0;e<c;e++)if(e in d&&!b.call(void 0,d[e],e,a))return!1;return!0}
function za(a,b){var c;a:{c=a.length;for(var d=m(a)?a.split(""):a,e=0;e<c;e++)if(e in d&&b.call(void 0,d[e],e,a)){c=e;break a}c=-1}return 0>c?null:m(a)?a.charAt(c):a[c]}function Ba(a){return Array.prototype.concat.apply(Array.prototype,arguments)}function Ca(a,b,c){return 2>=arguments.length?Array.prototype.slice.call(a,b):Array.prototype.slice.call(a,b,c)};var w;a:{var Da=l.navigator;if(Da){var Ea=Da.userAgent;if(Ea){w=Ea;break a}}w=""}function x(a){return-1!=w.indexOf(a)};function Fa(a,b){var c={},d;for(d in a)b.call(void 0,a[d],d,a)&&(c[d]=a[d]);return c}function Ga(a){var b=Ha,c={},d;for(d in a)c[d]=b.call(void 0,a[d],d,a);return c}function Ia(a,b){for(var c in a)if(b.call(void 0,a[c],c,a))return c};function Ja(){return x("Opera")||x("OPR")}function Ka(){return(x("Chrome")||x("CriOS"))&&!Ja()&&!x("Edge")};function La(){return x("iPhone")&&!x("iPod")&&!x("iPad")};var Ma=Ja(),z=x("Trident")||x("MSIE"),Na=x("Edge"),Oa=x("Gecko")&&!(-1!=w.toLowerCase().indexOf("webkit")&&!x("Edge"))&&!(x("Trident")||x("MSIE"))&&!x("Edge"),Pa=-1!=w.toLowerCase().indexOf("webkit")&&!x("Edge");function Qa(){var a=w;if(Oa)return/rv\:([^\);]+)(\)|;)/.exec(a);if(Na)return/Edge\/([\d\.]+)/.exec(a);if(z)return/\b(?:MSIE|rv)[: ]([^\);]+)(\)|;)/.exec(a);if(Pa)return/WebKit\/(\S+)/.exec(a)}function Ra(){var a=l.document;return a?a.documentMode:void 0}
var Sa=function(){if(Ma&&l.opera){var a;var b=l.opera.version;try{a=b()}catch(c){a=b}return a}a="";(b=Qa())&&(a=b?b[1]:"");return z&&(b=Ra(),null!=b&&b>parseFloat(a))?String(b):a}(),Ta={};function Ua(a){return Ta[a]||(Ta[a]=0<=qa(Sa,a))}var Va=l.document,Wa=Va&&z?Ra()||("CSS1Compat"==Va.compatMode?parseInt(Sa,10):5):void 0;!Oa&&!z||z&&9<=Number(Wa)||Oa&&Ua("1.9.1");z&&Ua("9");function A(a,b){this.x=aa(a)?a:0;this.y=aa(b)?b:0}A.prototype.clone=function(){return new A(this.x,this.y)};A.prototype.toString=function(){return"("+this.x+", "+this.y+")"};A.prototype.ceil=function(){this.x=Math.ceil(this.x);this.y=Math.ceil(this.y);return this};A.prototype.floor=function(){this.x=Math.floor(this.x);this.y=Math.floor(this.y);return this};A.prototype.round=function(){this.x=Math.round(this.x);this.y=Math.round(this.y);return this};function Xa(a,b){this.width=a;this.height=b}Xa.prototype.clone=function(){return new Xa(this.width,this.height)};Xa.prototype.toString=function(){return"("+this.width+" x "+this.height+")"};Xa.prototype.ceil=function(){this.width=Math.ceil(this.width);this.height=Math.ceil(this.height);return this};Xa.prototype.floor=function(){this.width=Math.floor(this.width);this.height=Math.floor(this.height);return this};
Xa.prototype.round=function(){this.width=Math.round(this.width);this.height=Math.round(this.height);return this};function Ya(a){return a?new Za(B(a)):na||(na=new Za)}function $a(a){for(;a&&1!=a.nodeType;)a=a.previousSibling;return a}function ab(a,b){if(!a||!b)return!1;if(a.contains&&1==b.nodeType)return a==b||a.contains(b);if("undefined"!=typeof a.compareDocumentPosition)return a==b||!!(a.compareDocumentPosition(b)&16);for(;b&&a!=b;)b=b.parentNode;return b==a}
function bb(a,b){if(a==b)return 0;if(a.compareDocumentPosition)return a.compareDocumentPosition(b)&2?1:-1;if(z&&!(9<=Number(Wa))){if(9==a.nodeType)return-1;if(9==b.nodeType)return 1}if("sourceIndex"in a||a.parentNode&&"sourceIndex"in a.parentNode){var c=1==a.nodeType,d=1==b.nodeType;if(c&&d)return a.sourceIndex-b.sourceIndex;var e=a.parentNode,f=b.parentNode;return e==f?cb(a,b):!c&&ab(e,b)?-1*db(a,b):!d&&ab(f,a)?db(b,a):(c?a.sourceIndex:e.sourceIndex)-(d?b.sourceIndex:f.sourceIndex)}d=B(a);c=d.createRange();
c.selectNode(a);c.collapse(!0);d=d.createRange();d.selectNode(b);d.collapse(!0);return c.compareBoundaryPoints(l.Range.START_TO_END,d)}function db(a,b){var c=a.parentNode;if(c==b)return-1;for(var d=b;d.parentNode!=c;)d=d.parentNode;return cb(d,a)}function cb(a,b){for(var c=b;c=c.previousSibling;)if(c==a)return-1;return 1}function B(a){return 9==a.nodeType?a:a.ownerDocument||a.document}function eb(a,b){a=a.parentNode;for(var c=0;a;){if(b(a))return a;a=a.parentNode;c++}return null}
function Za(a){this.a=a||l.document||document}
function fb(a,b,c,d){a=d||a.a;var e=b&&"*"!=b?b.toUpperCase():"";if(a.querySelectorAll&&a.querySelector&&(e||c))c=a.querySelectorAll(e+(c?"."+c:""));else if(c&&a.getElementsByClassName)if(b=a.getElementsByClassName(c),e){a={};for(var f=d=0,g;g=b[f];f++)e==g.nodeName&&(a[d++]=g);a.length=d;c=a}else c=b;else if(b=a.getElementsByTagName(e||"*"),c){a={};for(f=d=0;g=b[f];f++){var e=g.className,h;if(h="function"==typeof e.split)h=0<=ta(e.split(/\s+/),c);h&&(a[d++]=g)}a.length=d;c=a}else c=b;return c};var gb={w:function(a){return!(!a.querySelectorAll||!a.querySelector)},s:function(a,b){if(!a)throw new t(32,"No class name specified");a=pa(a);if(-1!==a.indexOf(" "))throw new t(32,"Compound class names not permitted");if(gb.w(b))try{return b.querySelector("."+a.replace(/\./g,"\\."))||null}catch(d){throw new t(32,"An invalid or illegal class name was specified");}var c=fb(Ya(b),"*",a,b);return c.length?c[0]:null},m:function(a,b){if(!a)throw new t(32,"No class name specified");a=pa(a);if(-1!==a.indexOf(" "))throw new t(32,
"Compound class names not permitted");if(gb.w(b))try{return b.querySelectorAll("."+a.replace(/\./g,"\\."))}catch(c){throw new t(32,"An invalid or illegal class name was specified");}return fb(Ya(b),"*",a,b)}};var hb=x("Firefox"),ib=La()||x("iPod"),jb=x("iPad"),kb=x("Android")&&!(Ka()||x("Firefox")||Ja()||x("Silk")),lb=Ka(),mb=x("Safari")&&!(Ka()||x("Coast")||Ja()||x("Edge")||x("Silk")||x("Android"))&&!(La()||x("iPad")||x("iPod"));function nb(a){return(a=a.exec(w))?a[1]:""}var ob=function(){if(hb)return nb(/Firefox\/([0-9.]+)/);if(z||Na||Ma)return Sa;if(lb)return nb(/Chrome\/([0-9.]+)/);if(mb&&!(La()||x("iPad")||x("iPod")))return nb(/Version\/([0-9.]+)/);if(ib||jb){var a;if(a=/Version\/(\S+).*Mobile\/(\S+)/.exec(w))return a[1]+"."+a[2]}else if(kb)return(a=nb(/Android\s+([0-9.]+)/))?a:nb(/Version\/([0-9.]+)/);return""}();var pb,qb;function rb(a){return sb?pb(a):z?0<=qa(Wa,a):Ua(a)}function tb(a){sb?qb(a):kb?qa(ub,a):qa(ob,a)}
var sb=function(){if(!Oa)return!1;var a=l.Components;if(!a)return!1;try{if(!a.classes)return!1}catch(f){return!1}var b=a.classes,a=a.interfaces,c=b["@mozilla.org/xpcom/version-comparator;1"].getService(a.nsIVersionComparator),b=b["@mozilla.org/xre/app-info;1"].getService(a.nsIXULAppInfo),d=b.platformVersion,e=b.version;pb=function(a){return 0<=c.compare(d,""+a)};qb=function(a){c.compare(e,""+a)};return!0}(),vb;if(kb){var wb=/Android\s+([0-9\.]+)/.exec(w);vb=wb?wb[1]:"0"}else vb="0";
var ub=vb,xb=z&&!(8<=Number(Wa)),yb=z&&!(9<=Number(Wa));kb&&tb(2.3);kb&&tb(4);mb&&tb(6);var zb={s:function(a,b){if(!ea(b.querySelector)&&z&&rb(8)&&!fa(b.querySelector))throw Error("CSS selection is not supported");if(!a)throw new t(32,"No selector specified");a=pa(a);var c;try{c=b.querySelector(a)}catch(d){throw new t(32,"An invalid or illegal selector was specified");}return c&&1==c.nodeType?c:null},m:function(a,b){if(!ea(b.querySelectorAll)&&z&&rb(8)&&!fa(b.querySelector))throw Error("CSS selection is not supported");if(!a)throw new t(32,"No selector specified");a=pa(a);try{return b.querySelectorAll(a)}catch(c){throw new t(32,
"An invalid or illegal selector was specified");}}};var Ab={aliceblue:"#f0f8ff",antiquewhite:"#faebd7",aqua:"#00ffff",aquamarine:"#7fffd4",azure:"#f0ffff",beige:"#f5f5dc",bisque:"#ffe4c4",black:"#000000",blanchedalmond:"#ffebcd",blue:"#0000ff",blueviolet:"#8a2be2",brown:"#a52a2a",burlywood:"#deb887",cadetblue:"#5f9ea0",chartreuse:"#7fff00",chocolate:"#d2691e",coral:"#ff7f50",cornflowerblue:"#6495ed",cornsilk:"#fff8dc",crimson:"#dc143c",cyan:"#00ffff",darkblue:"#00008b",darkcyan:"#008b8b",darkgoldenrod:"#b8860b",darkgray:"#a9a9a9",darkgreen:"#006400",
darkgrey:"#a9a9a9",darkkhaki:"#bdb76b",darkmagenta:"#8b008b",darkolivegreen:"#556b2f",darkorange:"#ff8c00",darkorchid:"#9932cc",darkred:"#8b0000",darksalmon:"#e9967a",darkseagreen:"#8fbc8f",darkslateblue:"#483d8b",darkslategray:"#2f4f4f",darkslategrey:"#2f4f4f",darkturquoise:"#00ced1",darkviolet:"#9400d3",deeppink:"#ff1493",deepskyblue:"#00bfff",dimgray:"#696969",dimgrey:"#696969",dodgerblue:"#1e90ff",firebrick:"#b22222",floralwhite:"#fffaf0",forestgreen:"#228b22",fuchsia:"#ff00ff",gainsboro:"#dcdcdc",
ghostwhite:"#f8f8ff",gold:"#ffd700",goldenrod:"#daa520",gray:"#808080",green:"#008000",greenyellow:"#adff2f",grey:"#808080",honeydew:"#f0fff0",hotpink:"#ff69b4",indianred:"#cd5c5c",indigo:"#4b0082",ivory:"#fffff0",khaki:"#f0e68c",lavender:"#e6e6fa",lavenderblush:"#fff0f5",lawngreen:"#7cfc00",lemonchiffon:"#fffacd",lightblue:"#add8e6",lightcoral:"#f08080",lightcyan:"#e0ffff",lightgoldenrodyellow:"#fafad2",lightgray:"#d3d3d3",lightgreen:"#90ee90",lightgrey:"#d3d3d3",lightpink:"#ffb6c1",lightsalmon:"#ffa07a",
lightseagreen:"#20b2aa",lightskyblue:"#87cefa",lightslategray:"#778899",lightslategrey:"#778899",lightsteelblue:"#b0c4de",lightyellow:"#ffffe0",lime:"#00ff00",limegreen:"#32cd32",linen:"#faf0e6",magenta:"#ff00ff",maroon:"#800000",mediumaquamarine:"#66cdaa",mediumblue:"#0000cd",mediumorchid:"#ba55d3",mediumpurple:"#9370db",mediumseagreen:"#3cb371",mediumslateblue:"#7b68ee",mediumspringgreen:"#00fa9a",mediumturquoise:"#48d1cc",mediumvioletred:"#c71585",midnightblue:"#191970",mintcream:"#f5fffa",mistyrose:"#ffe4e1",
moccasin:"#ffe4b5",navajowhite:"#ffdead",navy:"#000080",oldlace:"#fdf5e6",olive:"#808000",olivedrab:"#6b8e23",orange:"#ffa500",orangered:"#ff4500",orchid:"#da70d6",palegoldenrod:"#eee8aa",palegreen:"#98fb98",paleturquoise:"#afeeee",palevioletred:"#db7093",papayawhip:"#ffefd5",peachpuff:"#ffdab9",peru:"#cd853f",pink:"#ffc0cb",plum:"#dda0dd",powderblue:"#b0e0e6",purple:"#800080",red:"#ff0000",rosybrown:"#bc8f8f",royalblue:"#4169e1",saddlebrown:"#8b4513",salmon:"#fa8072",sandybrown:"#f4a460",seagreen:"#2e8b57",
seashell:"#fff5ee",sienna:"#a0522d",silver:"#c0c0c0",skyblue:"#87ceeb",slateblue:"#6a5acd",slategray:"#708090",slategrey:"#708090",snow:"#fffafa",springgreen:"#00ff7f",steelblue:"#4682b4",tan:"#d2b48c",teal:"#008080",thistle:"#d8bfd8",tomato:"#ff6347",turquoise:"#40e0d0",violet:"#ee82ee",wheat:"#f5deb3",white:"#ffffff",whitesmoke:"#f5f5f5",yellow:"#ffff00",yellowgreen:"#9acd32"};var Bb="backgroundColor borderTopColor borderRightColor borderBottomColor borderLeftColor color outlineColor".split(" "),Cb=/#([0-9a-fA-F])([0-9a-fA-F])([0-9a-fA-F])/,Db=/^#(?:[0-9a-f]{3}){1,2}$/i,Eb=/^(?:rgba)?\((\d{1,3}),\s?(\d{1,3}),\s?(\d{1,3}),\s?(0|1|0\.\d*)\)$/i,Fb=/^(?:rgb)?\((0|[1-9]\d{0,2}),\s?(0|[1-9]\d{0,2}),\s?(0|[1-9]\d{0,2})\)$/i;/*

 The MIT License

 Copyright (c) 2007 Cybozu Labs, Inc.
 Copyright (c) 2012 Google Inc.

 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to
 deal in the Software without restriction, including without limitation the
 rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
 sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in
 all copies or substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 IN THE SOFTWARE.
*/
function Gb(a,b,c){this.a=a;this.b=b||1;this.f=c||1};var C=z&&!(9<=Number(Wa)),Hb=z&&!(8<=Number(Wa));function Ib(a,b,c,d){this.a=a;this.nodeName=c;this.nodeValue=d;this.nodeType=2;this.parentNode=this.ownerElement=b}function Jb(a,b){var c=Hb&&"href"==b.nodeName?a.getAttribute(b.nodeName,2):b.nodeValue;return new Ib(b,a,b.nodeName,c)};function Kb(a){this.b=a;this.a=0}function Lb(a){a=a.match(Mb);for(var b=0;b<a.length;b++)Nb.test(a[b])&&a.splice(b,1);return new Kb(a)}var Mb=RegExp("\\$?(?:(?![0-9-\\.])(?:\\*|[\\w-\\.]+):)?(?![0-9-\\.])(?:\\*|[\\w-\\.]+)|\\/\\/|\\.\\.|::|\\d+(?:\\.\\d*)?|\\.\\d+|\"[^\"]*\"|'[^']*'|[!<>]=|\\s+|.","g"),Nb=/^\s/;function D(a,b){return a.b[a.a+(b||0)]}function E(a){return a.b[a.a++]}function Ob(a){return a.b.length<=a.a};function F(a){var b=null,c=a.nodeType;1==c&&(b=a.textContent,b=void 0==b||null==b?a.innerText:b,b=void 0==b||null==b?"":b);if("string"!=typeof b)if(C&&"title"==a.nodeName.toLowerCase()&&1==c)b=a.text;else if(9==c||1==c){a=9==c?a.documentElement:a.firstChild;for(var c=0,d=[],b="";a;){do 1!=a.nodeType&&(b+=a.nodeValue),C&&"title"==a.nodeName.toLowerCase()&&(b+=a.text),d[c++]=a;while(a=a.firstChild);for(;c&&!(a=d[--c].nextSibling););}}else b=a.nodeValue;return""+b}
function Pb(a,b,c){if(null===b)return!0;try{if(!a.getAttribute)return!1}catch(d){return!1}Hb&&"class"==b&&(b="className");return null==c?!!a.getAttribute(b):a.getAttribute(b,2)==c}function Qb(a,b,c,d,e){return(C?Rb:Sb).call(null,a,b,m(c)?c:null,m(d)?d:null,e||new G)}
function Rb(a,b,c,d,e){if(a instanceof Tb||8==a.b||c&&null===a.b){var f=b.all;if(!f)return e;a=Ub(a);if("*"!=a&&(f=b.getElementsByTagName(a),!f))return e;if(c){for(var g=[],h=0;b=f[h++];)Pb(b,c,d)&&g.push(b);f=g}for(h=0;b=f[h++];)"*"==a&&"!"==b.tagName||H(e,b);return e}Vb(a,b,c,d,e);return e}
function Sb(a,b,c,d,e){b.getElementsByName&&d&&"name"==c&&!z?(b=b.getElementsByName(d),v(b,function(b){a.a(b)&&H(e,b)})):b.getElementsByClassName&&d&&"class"==c?(b=b.getElementsByClassName(d),v(b,function(b){b.className==d&&a.a(b)&&H(e,b)})):a instanceof I?Vb(a,b,c,d,e):b.getElementsByTagName&&(b=b.getElementsByTagName(a.f()),v(b,function(a){Pb(a,c,d)&&H(e,a)}));return e}
function Wb(a,b,c,d,e){var f;if((a instanceof Tb||8==a.b||c&&null===a.b)&&(f=b.childNodes)){var g=Ub(a);if("*"!=g&&(f=ua(f,function(a){return a.tagName&&a.tagName.toLowerCase()==g}),!f))return e;c&&(f=ua(f,function(a){return Pb(a,c,d)}));v(f,function(a){"*"==g&&("!"==a.tagName||"*"==g&&1!=a.nodeType)||H(e,a)});return e}return Xb(a,b,c,d,e)}function Xb(a,b,c,d,e){for(b=b.firstChild;b;b=b.nextSibling)Pb(b,c,d)&&a.a(b)&&H(e,b);return e}
function Vb(a,b,c,d,e){for(b=b.firstChild;b;b=b.nextSibling)Pb(b,c,d)&&a.a(b)&&H(e,b),Vb(a,b,c,d,e)}function Ub(a){if(a instanceof I){if(8==a.b)return"!";if(null===a.b)return"*"}return a.f()};function G(){this.b=this.a=null;this.l=0}function Yb(a){this.node=a;this.a=this.b=null}function Zb(a,b){if(!a.a)return b;if(!b.a)return a;for(var c=a.a,d=b.a,e=null,f=null,g=0;c&&d;){var f=c.node,h=d.node;f==h||f instanceof Ib&&h instanceof Ib&&f.a==h.a?(f=c,c=c.a,d=d.a):0<bb(c.node,d.node)?(f=d,d=d.a):(f=c,c=c.a);(f.b=e)?e.a=f:a.a=f;e=f;g++}for(f=c||d;f;)f.b=e,e=e.a=f,g++,f=f.a;a.b=e;a.l=g;return a}
G.prototype.unshift=function(a){a=new Yb(a);a.a=this.a;this.b?this.a.b=a:this.a=this.b=a;this.a=a;this.l++};function H(a,b){var c=new Yb(b);c.b=a.b;a.a?a.b.a=c:a.a=a.b=c;a.b=c;a.l++}function $b(a){return(a=a.a)?a.node:null}function ac(a){return(a=$b(a))?F(a):""}function bc(a,b){return new cc(a,!!b)}function cc(a,b){this.f=a;this.b=(this.c=b)?a.b:a.a;this.a=null}function J(a){var b=a.b;if(null==b)return null;var c=a.a=b;a.b=a.c?b.b:b.a;return c.node};function K(a){this.i=a;this.b=this.g=!1;this.f=null}function L(a){return"\n  "+a.toString().split("\n").join("\n  ")}function dc(a,b){a.g=b}function ec(a,b){a.b=b}function M(a,b){var c=a.a(b);return c instanceof G?+ac(c):+c}function O(a,b){var c=a.a(b);return c instanceof G?ac(c):""+c}function fc(a,b){var c=a.a(b);return c instanceof G?!!c.l:!!c};function gc(a,b,c){K.call(this,a.i);this.c=a;this.h=b;this.u=c;this.g=b.g||c.g;this.b=b.b||c.b;this.c==hc&&(c.b||c.g||4==c.i||0==c.i||!b.f?b.b||b.g||4==b.i||0==b.i||!c.f||(this.f={name:c.f.name,v:b}):this.f={name:b.f.name,v:c})}q(gc,K);
function ic(a,b,c,d,e){b=b.a(d);c=c.a(d);var f;if(b instanceof G&&c instanceof G){b=bc(b);for(d=J(b);d;d=J(b))for(e=bc(c),f=J(e);f;f=J(e))if(a(F(d),F(f)))return!0;return!1}if(b instanceof G||c instanceof G){b instanceof G?(e=b,d=c):(e=c,d=b);f=bc(e);for(var g=typeof d,h=J(f);h;h=J(f)){switch(g){case "number":h=+F(h);break;case "boolean":h=!!F(h);break;case "string":h=F(h);break;default:throw Error("Illegal primitive type for comparison.");}if(e==b&&a(h,d)||e==c&&a(d,h))return!0}return!1}return e?
"boolean"==typeof b||"boolean"==typeof c?a(!!b,!!c):"number"==typeof b||"number"==typeof c?a(+b,+c):a(b,c):a(+b,+c)}gc.prototype.a=function(a){return this.c.o(this.h,this.u,a)};gc.prototype.toString=function(){var a="Binary Expression: "+this.c,a=a+L(this.h);return a+=L(this.u)};function jc(a,b,c,d){this.a=a;this.I=b;this.i=c;this.o=d}jc.prototype.toString=function(){return this.a};var kc={};
function P(a,b,c,d){if(kc.hasOwnProperty(a))throw Error("Binary operator already created: "+a);a=new jc(a,b,c,d);return kc[a.toString()]=a}P("div",6,1,function(a,b,c){return M(a,c)/M(b,c)});P("mod",6,1,function(a,b,c){return M(a,c)%M(b,c)});P("*",6,1,function(a,b,c){return M(a,c)*M(b,c)});P("+",5,1,function(a,b,c){return M(a,c)+M(b,c)});P("-",5,1,function(a,b,c){return M(a,c)-M(b,c)});P("<",4,2,function(a,b,c){return ic(function(a,b){return a<b},a,b,c)});
P(">",4,2,function(a,b,c){return ic(function(a,b){return a>b},a,b,c)});P("<=",4,2,function(a,b,c){return ic(function(a,b){return a<=b},a,b,c)});P(">=",4,2,function(a,b,c){return ic(function(a,b){return a>=b},a,b,c)});var hc=P("=",3,2,function(a,b,c){return ic(function(a,b){return a==b},a,b,c,!0)});P("!=",3,2,function(a,b,c){return ic(function(a,b){return a!=b},a,b,c,!0)});P("and",2,2,function(a,b,c){return fc(a,c)&&fc(b,c)});P("or",1,2,function(a,b,c){return fc(a,c)||fc(b,c)});function lc(a,b){if(b.a.length&&4!=a.i)throw Error("Primary expression must evaluate to nodeset if filter has predicate(s).");K.call(this,a.i);this.c=a;this.h=b;this.g=a.g;this.b=a.b}q(lc,K);lc.prototype.a=function(a){a=this.c.a(a);return mc(this.h,a)};lc.prototype.toString=function(){var a;a="Filter:"+L(this.c);return a+=L(this.h)};function nc(a,b){if(b.length<a.J)throw Error("Function "+a.j+" expects at least"+a.J+" arguments, "+b.length+" given");if(null!==a.C&&b.length>a.C)throw Error("Function "+a.j+" expects at most "+a.C+" arguments, "+b.length+" given");a.O&&v(b,function(b,d){if(4!=b.i)throw Error("Argument "+d+" to function "+a.j+" is not of type Nodeset: "+b);});K.call(this,a.i);this.h=a;this.c=b;dc(this,a.g||xa(b,function(a){return a.g}));ec(this,a.N&&!b.length||a.M&&!!b.length||xa(b,function(a){return a.b}))}
q(nc,K);nc.prototype.a=function(a){return this.h.o.apply(null,Ba(a,this.c))};nc.prototype.toString=function(){var a="Function: "+this.h;if(this.c.length)var b=wa(this.c,function(a,b){return a+L(b)},"Arguments:"),a=a+L(b);return a};function oc(a,b,c,d,e,f,g,h,n){this.j=a;this.i=b;this.g=c;this.N=d;this.M=e;this.o=f;this.J=g;this.C=aa(h)?h:g;this.O=!!n}oc.prototype.toString=function(){return this.j};var pc={};
function Q(a,b,c,d,e,f,g,h){if(pc.hasOwnProperty(a))throw Error("Function already created: "+a+".");pc[a]=new oc(a,b,c,d,!1,e,f,g,h)}Q("boolean",2,!1,!1,function(a,b){return fc(b,a)},1);Q("ceiling",1,!1,!1,function(a,b){return Math.ceil(M(b,a))},1);Q("concat",3,!1,!1,function(a,b){return wa(Ca(arguments,1),function(b,d){return b+O(d,a)},"")},2,null);Q("contains",2,!1,!1,function(a,b,c){b=O(b,a);a=O(c,a);return-1!=b.indexOf(a)},2);Q("count",1,!1,!1,function(a,b){return b.a(a).l},1,1,!0);
Q("false",2,!1,!1,function(){return!1},0);Q("floor",1,!1,!1,function(a,b){return Math.floor(M(b,a))},1);Q("id",4,!1,!1,function(a,b){function c(a){if(C){var b=e.all[a];if(b){if(b.nodeType&&a==b.id)return b;if(b.length)return za(b,function(b){return a==b.id})}return null}return e.getElementById(a)}var d=a.a,e=9==d.nodeType?d:d.ownerDocument,d=O(b,a).split(/\s+/),f=[];v(d,function(a){a=c(a);!a||0<=ta(f,a)||f.push(a)});f.sort(bb);var g=new G;v(f,function(a){H(g,a)});return g},1);
Q("lang",2,!1,!1,function(){return!1},1);Q("last",1,!0,!1,function(a){if(1!=arguments.length)throw Error("Function last expects ()");return a.f},0);Q("local-name",3,!1,!0,function(a,b){var c=b?$b(b.a(a)):a.a;return c?c.localName||c.nodeName.toLowerCase():""},0,1,!0);Q("name",3,!1,!0,function(a,b){var c=b?$b(b.a(a)):a.a;return c?c.nodeName.toLowerCase():""},0,1,!0);Q("namespace-uri",3,!0,!1,function(){return""},0,1,!0);
Q("normalize-space",3,!1,!0,function(a,b){return(b?O(b,a):F(a.a)).replace(/[\s\xa0]+/g," ").replace(/^\s+|\s+$/g,"")},0,1);Q("not",2,!1,!1,function(a,b){return!fc(b,a)},1);Q("number",1,!1,!0,function(a,b){return b?M(b,a):+F(a.a)},0,1);Q("position",1,!0,!1,function(a){return a.b},0);Q("round",1,!1,!1,function(a,b){return Math.round(M(b,a))},1);Q("starts-with",2,!1,!1,function(a,b,c){b=O(b,a);a=O(c,a);return 0==b.lastIndexOf(a,0)},2);Q("string",3,!1,!0,function(a,b){return b?O(b,a):F(a.a)},0,1);
Q("string-length",1,!1,!0,function(a,b){return(b?O(b,a):F(a.a)).length},0,1);Q("substring",3,!1,!1,function(a,b,c,d){c=M(c,a);if(isNaN(c)||Infinity==c||-Infinity==c)return"";d=d?M(d,a):Infinity;if(isNaN(d)||-Infinity===d)return"";c=Math.round(c)-1;var e=Math.max(c,0);a=O(b,a);return Infinity==d?a.substring(e):a.substring(e,c+Math.round(d))},2,3);Q("substring-after",3,!1,!1,function(a,b,c){b=O(b,a);a=O(c,a);c=b.indexOf(a);return-1==c?"":b.substring(c+a.length)},2);
Q("substring-before",3,!1,!1,function(a,b,c){b=O(b,a);a=O(c,a);a=b.indexOf(a);return-1==a?"":b.substring(0,a)},2);Q("sum",1,!1,!1,function(a,b){for(var c=bc(b.a(a)),d=0,e=J(c);e;e=J(c))d+=+F(e);return d},1,1,!0);Q("translate",3,!1,!1,function(a,b,c,d){b=O(b,a);c=O(c,a);var e=O(d,a);a={};for(d=0;d<c.length;d++){var f=c.charAt(d);f in a||(a[f]=e.charAt(d))}c="";for(d=0;d<b.length;d++)f=b.charAt(d),c+=f in a?a[f]:f;return c},3);Q("true",2,!1,!1,function(){return!0},0);function I(a,b){this.h=a;this.c=aa(b)?b:null;this.b=null;switch(a){case "comment":this.b=8;break;case "text":this.b=3;break;case "processing-instruction":this.b=7;break;case "node":break;default:throw Error("Unexpected argument");}}function qc(a){return"comment"==a||"text"==a||"processing-instruction"==a||"node"==a}I.prototype.a=function(a){return null===this.b||this.b==a.nodeType};I.prototype.f=function(){return this.h};
I.prototype.toString=function(){var a="Kind Test: "+this.h;null===this.c||(a+=L(this.c));return a};function rc(a){K.call(this,3);this.c=a.substring(1,a.length-1)}q(rc,K);rc.prototype.a=function(){return this.c};rc.prototype.toString=function(){return"Literal: "+this.c};function Tb(a,b){this.j=a.toLowerCase();var c;c="*"==this.j?"*":"http://www.w3.org/1999/xhtml";this.c=b?b.toLowerCase():c}Tb.prototype.a=function(a){var b=a.nodeType;return 1!=b&&2!=b?!1:"*"!=this.j&&this.j!=a.localName.toLowerCase()?!1:"*"==this.c?!0:this.c==(a.namespaceURI?a.namespaceURI.toLowerCase():"http://www.w3.org/1999/xhtml")};Tb.prototype.f=function(){return this.j};Tb.prototype.toString=function(){return"Name Test: "+("http://www.w3.org/1999/xhtml"==this.c?"":this.c+":")+this.j};function sc(a){K.call(this,1);this.c=a}q(sc,K);sc.prototype.a=function(){return this.c};sc.prototype.toString=function(){return"Number: "+this.c};function tc(a,b){K.call(this,a.i);this.h=a;this.c=b;this.g=a.g;this.b=a.b;if(1==this.c.length){var c=this.c[0];c.A||c.c!=uc||(c=c.u,"*"!=c.f()&&(this.f={name:c.f(),v:null}))}}q(tc,K);function vc(){K.call(this,4)}q(vc,K);vc.prototype.a=function(a){var b=new G;a=a.a;9==a.nodeType?H(b,a):H(b,a.ownerDocument);return b};vc.prototype.toString=function(){return"Root Helper Expression"};function wc(){K.call(this,4)}q(wc,K);wc.prototype.a=function(a){var b=new G;H(b,a.a);return b};wc.prototype.toString=function(){return"Context Helper Expression"};
function xc(a){return"/"==a||"//"==a}tc.prototype.a=function(a){var b=this.h.a(a);if(!(b instanceof G))throw Error("Filter expression must evaluate to nodeset.");a=this.c;for(var c=0,d=a.length;c<d&&b.l;c++){var e=a[c],f=bc(b,e.c.a),g;if(e.g||e.c!=yc)if(e.g||e.c!=zc)for(g=J(f),b=e.a(new Gb(g));null!=(g=J(f));)g=e.a(new Gb(g)),b=Zb(b,g);else g=J(f),b=e.a(new Gb(g));else{for(g=J(f);(b=J(f))&&(!g.contains||g.contains(b))&&b.compareDocumentPosition(g)&8;g=b);b=e.a(new Gb(g))}}return b};
tc.prototype.toString=function(){var a;a="Path Expression:"+L(this.h);if(this.c.length){var b=wa(this.c,function(a,b){return a+L(b)},"Steps:");a+=L(b)}return a};function Ac(a,b){this.a=a;this.b=!!b}
function mc(a,b,c){for(c=c||0;c<a.a.length;c++)for(var d=a.a[c],e=bc(b),f=b.l,g,h=0;g=J(e);h++){var n=a.b?f-h:h+1;g=d.a(new Gb(g,n,f));if("number"==typeof g)n=n==g;else if("string"==typeof g||"boolean"==typeof g)n=!!g;else if(g instanceof G)n=0<g.l;else throw Error("Predicate.evaluate returned an unexpected type.");if(!n){n=e;g=n.f;var p=n.a;if(!p)throw Error("Next must be called at least once before remove.");var k=p.b,p=p.a;k?k.a=p:g.a=p;p?p.b=k:g.b=k;g.l--;n.a=null}}return b}
Ac.prototype.toString=function(){return wa(this.a,function(a,b){return a+L(b)},"Predicates:")};function Bc(a,b,c,d){K.call(this,4);this.c=a;this.u=b;this.h=c||new Ac([]);this.A=!!d;b=this.h;b=0<b.a.length?b.a[0].f:null;a.b&&b&&(a=b.name,a=C?a.toLowerCase():a,this.f={name:a,v:b.v});a:{a=this.h;for(b=0;b<a.a.length;b++)if(c=a.a[b],c.g||1==c.i||0==c.i){a=!0;break a}a=!1}this.g=a}q(Bc,K);
Bc.prototype.a=function(a){var b=a.a,c=null,c=this.f,d=null,e=null,f=0;c&&(d=c.name,e=c.v?O(c.v,a):null,f=1);if(this.A)if(this.g||this.c!=Cc)if(a=bc((new Bc(Dc,new I("node"))).a(a)),b=J(a))for(c=this.o(b,d,e,f);null!=(b=J(a));)c=Zb(c,this.o(b,d,e,f));else c=new G;else c=Qb(this.u,b,d,e),c=mc(this.h,c,f);else c=this.o(a.a,d,e,f);return c};Bc.prototype.o=function(a,b,c,d){a=this.c.f(this.u,a,b,c);return a=mc(this.h,a,d)};
Bc.prototype.toString=function(){var a;a="Step:"+L("Operator: "+(this.A?"//":"/"));this.c.j&&(a+=L("Axis: "+this.c));a+=L(this.u);if(this.h.a.length){var b=wa(this.h.a,function(a,b){return a+L(b)},"Predicates:");a+=L(b)}return a};function Ec(a,b,c,d){this.j=a;this.f=b;this.a=c;this.b=d}Ec.prototype.toString=function(){return this.j};var Fc={};function R(a,b,c,d){if(Fc.hasOwnProperty(a))throw Error("Axis already created: "+a);b=new Ec(a,b,c,!!d);return Fc[a]=b}
R("ancestor",function(a,b){for(var c=new G,d=b;d=d.parentNode;)a.a(d)&&c.unshift(d);return c},!0);R("ancestor-or-self",function(a,b){var c=new G,d=b;do a.a(d)&&c.unshift(d);while(d=d.parentNode);return c},!0);
var uc=R("attribute",function(a,b){var c=new G,d=a.f();if("style"==d&&b.style&&C)return H(c,new Ib(b.style,b,"style",b.style.cssText)),c;var e=b.attributes;if(e)if(a instanceof I&&null===a.b||"*"==d)for(var d=0,f;f=e[d];d++)C?f.nodeValue&&H(c,Jb(b,f)):H(c,f);else(f=e.getNamedItem(d))&&(C?f.nodeValue&&H(c,Jb(b,f)):H(c,f));return c},!1),Cc=R("child",function(a,b,c,d,e){return(C?Wb:Xb).call(null,a,b,m(c)?c:null,m(d)?d:null,e||new G)},!1,!0);R("descendant",Qb,!1,!0);
var Dc=R("descendant-or-self",function(a,b,c,d){var e=new G;Pb(b,c,d)&&a.a(b)&&H(e,b);return Qb(a,b,c,d,e)},!1,!0),yc=R("following",function(a,b,c,d){var e=new G;do for(var f=b;f=f.nextSibling;)Pb(f,c,d)&&a.a(f)&&H(e,f),e=Qb(a,f,c,d,e);while(b=b.parentNode);return e},!1,!0);R("following-sibling",function(a,b){for(var c=new G,d=b;d=d.nextSibling;)a.a(d)&&H(c,d);return c},!1);R("namespace",function(){return new G},!1);
var Gc=R("parent",function(a,b){var c=new G;if(9==b.nodeType)return c;if(2==b.nodeType)return H(c,b.ownerElement),c;var d=b.parentNode;a.a(d)&&H(c,d);return c},!1),zc=R("preceding",function(a,b,c,d){var e=new G,f=[];do f.unshift(b);while(b=b.parentNode);for(var g=1,h=f.length;g<h;g++){var n=[];for(b=f[g];b=b.previousSibling;)n.unshift(b);for(var p=0,k=n.length;p<k;p++)b=n[p],Pb(b,c,d)&&a.a(b)&&H(e,b),e=Qb(a,b,c,d,e)}return e},!0,!0);
R("preceding-sibling",function(a,b){for(var c=new G,d=b;d=d.previousSibling;)a.a(d)&&c.unshift(d);return c},!0);var Hc=R("self",function(a,b){var c=new G;a.a(b)&&H(c,b);return c},!1);function Ic(a){K.call(this,1);this.c=a;this.g=a.g;this.b=a.b}q(Ic,K);Ic.prototype.a=function(a){return-M(this.c,a)};Ic.prototype.toString=function(){return"Unary Expression: -"+L(this.c)};function Jc(a){K.call(this,4);this.c=a;dc(this,xa(this.c,function(a){return a.g}));ec(this,xa(this.c,function(a){return a.b}))}q(Jc,K);Jc.prototype.a=function(a){var b=new G;v(this.c,function(c){c=c.a(a);if(!(c instanceof G))throw Error("Path expression must evaluate to NodeSet.");b=Zb(b,c)});return b};Jc.prototype.toString=function(){return wa(this.c,function(a,b){return a+L(b)},"Union Expression:")};function Kc(a,b){this.a=a;this.b=b}function Lc(a){for(var b,c=[];;){S(a,"Missing right hand side of binary expression.");b=Mc(a);var d=E(a.a);if(!d)break;var e=(d=kc[d]||null)&&d.I;if(!e){a.a.a--;break}for(;c.length&&e<=c[c.length-1].I;)b=new gc(c.pop(),c.pop(),b);c.push(b,d)}for(;c.length;)b=new gc(c.pop(),c.pop(),b);return b}function S(a,b){if(Ob(a.a))throw Error(b);}function Nc(a,b){var c=E(a.a);if(c!=b)throw Error("Bad token, expected: "+b+" got: "+c);}
function Oc(a){a=E(a.a);if(")"!=a)throw Error("Bad token: "+a);}function Pc(a){a=E(a.a);if(2>a.length)throw Error("Unclosed literal string");return new rc(a)}
function Qc(a){var b,c=[],d;if(xc(D(a.a))){b=E(a.a);d=D(a.a);if("/"==b&&(Ob(a.a)||"."!=d&&".."!=d&&"@"!=d&&"*"!=d&&!/(?![0-9])[\w]/.test(d)))return new vc;d=new vc;S(a,"Missing next location step.");b=Rc(a,b);c.push(b)}else{a:{b=D(a.a);d=b.charAt(0);switch(d){case "$":throw Error("Variable reference not allowed in HTML XPath");case "(":E(a.a);b=Lc(a);S(a,'unclosed "("');Nc(a,")");break;case '"':case "'":b=Pc(a);break;default:if(isNaN(+b))if(!qc(b)&&/(?![0-9])[\w]/.test(d)&&"("==D(a.a,1)){b=E(a.a);
b=pc[b]||null;E(a.a);for(d=[];")"!=D(a.a);){S(a,"Missing function argument list.");d.push(Lc(a));if(","!=D(a.a))break;E(a.a)}S(a,"Unclosed function argument list.");Oc(a);b=new nc(b,d)}else{b=null;break a}else b=new sc(+E(a.a))}"["==D(a.a)&&(d=new Ac(Sc(a)),b=new lc(b,d))}if(b)if(xc(D(a.a)))d=b;else return b;else b=Rc(a,"/"),d=new wc,c.push(b)}for(;xc(D(a.a));)b=E(a.a),S(a,"Missing next location step."),b=Rc(a,b),c.push(b);return new tc(d,c)}
function Rc(a,b){var c,d,e;if("/"!=b&&"//"!=b)throw Error('Step op should be "/" or "//"');if("."==D(a.a))return d=new Bc(Hc,new I("node")),E(a.a),d;if(".."==D(a.a))return d=new Bc(Gc,new I("node")),E(a.a),d;var f;if("@"==D(a.a))f=uc,E(a.a),S(a,"Missing attribute name");else if("::"==D(a.a,1)){if(!/(?![0-9])[\w]/.test(D(a.a).charAt(0)))throw Error("Bad token: "+E(a.a));c=E(a.a);f=Fc[c]||null;if(!f)throw Error("No axis with name: "+c);E(a.a);S(a,"Missing node name")}else f=Cc;c=D(a.a);if(/(?![0-9])[\w\*]/.test(c.charAt(0)))if("("==
D(a.a,1)){if(!qc(c))throw Error("Invalid node type: "+c);c=E(a.a);if(!qc(c))throw Error("Invalid type name: "+c);Nc(a,"(");S(a,"Bad nodetype");e=D(a.a).charAt(0);var g=null;if('"'==e||"'"==e)g=Pc(a);S(a,"Bad nodetype");Oc(a);c=new I(c,g)}else if(c=E(a.a),e=c.indexOf(":"),-1==e)c=new Tb(c);else{var g=c.substring(0,e),h;if("*"==g)h="*";else if(h=a.b(g),!h)throw Error("Namespace prefix not declared: "+g);c=c.substr(e+1);c=new Tb(c,h)}else throw Error("Bad token: "+E(a.a));e=new Ac(Sc(a),f.a);return d||
new Bc(f,c,e,"//"==b)}function Sc(a){for(var b=[];"["==D(a.a);){E(a.a);S(a,"Missing predicate expression.");var c=Lc(a);b.push(c);S(a,"Unclosed predicate expression.");Nc(a,"]")}return b}function Mc(a){if("-"==D(a.a))return E(a.a),new Ic(Mc(a));var b=Qc(a);if("|"!=D(a.a))a=b;else{for(b=[b];"|"==E(a.a);)S(a,"Missing next union location path."),b.push(Qc(a));a.a.a--;a=new Jc(b)}return a};function Tc(a){switch(a.nodeType){case 1:return ja(Uc,a);case 9:return Tc(a.documentElement);case 11:case 10:case 6:case 12:return Vc;default:return a.parentNode?Tc(a.parentNode):Vc}}function Vc(){return null}function Uc(a,b){if(a.prefix==b)return a.namespaceURI||"http://www.w3.org/1999/xhtml";var c=a.getAttributeNode("xmlns:"+b);return c&&c.specified?c.value||null:a.parentNode&&9!=a.parentNode.nodeType?Uc(a.parentNode,b):null};function Wc(a,b){if(!a.length)throw Error("Empty XPath expression.");var c=Lb(a);if(Ob(c))throw Error("Invalid XPath expression.");b?ea(b)||(b=ia(b.lookupNamespaceURI,b)):b=function(){return null};var d=Lc(new Kc(c,b));if(!Ob(c))throw Error("Bad token: "+E(c));this.evaluate=function(a,b){var c=d.a(new Gb(a));return new T(c,b)}}
function T(a,b){if(0==b)if(a instanceof G)b=4;else if("string"==typeof a)b=2;else if("number"==typeof a)b=1;else if("boolean"==typeof a)b=3;else throw Error("Unexpected evaluation result.");if(2!=b&&1!=b&&3!=b&&!(a instanceof G))throw Error("value could not be converted to the specified type");this.resultType=b;var c;switch(b){case 2:this.stringValue=a instanceof G?ac(a):""+a;break;case 1:this.numberValue=a instanceof G?+ac(a):+a;break;case 3:this.booleanValue=a instanceof G?0<a.l:!!a;break;case 4:case 5:case 6:case 7:var d=
bc(a);c=[];for(var e=J(d);e;e=J(d))c.push(e instanceof Ib?e.a:e);this.snapshotLength=a.l;this.invalidIteratorState=!1;break;case 8:case 9:d=$b(a);this.singleNodeValue=d instanceof Ib?d.a:d;break;default:throw Error("Unknown XPathResult type.");}var f=0;this.iterateNext=function(){if(4!=b&&5!=b)throw Error("iterateNext called with wrong result type");return f>=c.length?null:c[f++]};this.snapshotItem=function(a){if(6!=b&&7!=b)throw Error("snapshotItem called with wrong result type");return a>=c.length||
0>a?null:c[a]}}T.ANY_TYPE=0;T.NUMBER_TYPE=1;T.STRING_TYPE=2;T.BOOLEAN_TYPE=3;T.UNORDERED_NODE_ITERATOR_TYPE=4;T.ORDERED_NODE_ITERATOR_TYPE=5;T.UNORDERED_NODE_SNAPSHOT_TYPE=6;T.ORDERED_NODE_SNAPSHOT_TYPE=7;T.ANY_UNORDERED_NODE_TYPE=8;T.FIRST_ORDERED_NODE_TYPE=9;function Xc(a){this.lookupNamespaceURI=Tc(a)}
function Yc(a,b){var c=a||l,d=c.document;if(!d.evaluate||b)c.XPathResult=T,d.evaluate=function(a,b,c,d){return(new Wc(a,c)).evaluate(b,d)},d.createExpression=function(a,b){return new Wc(a,b)},d.createNSResolver=function(a){return new Xc(a)}}ba("wgxpath.install",Yc);var U={};U.D=function(){var a={S:"http://www.w3.org/2000/svg"};return function(b){return a[b]||null}}();
U.o=function(a,b,c){var d=B(a);if(!d.documentElement)return null;(z||kb)&&Yc(d?d.parentWindow||d.defaultView:window);try{var e=d.createNSResolver?d.createNSResolver(d.documentElement):U.D;if(z&&!Ua(7))return d.evaluate.call(d,b,a,e,c,null);if(!z||9<=Number(Wa)){for(var f={},g=d.getElementsByTagName("*"),h=0;h<g.length;++h){var n=g[h],p=n.namespaceURI;if(p&&!f[p]){var k=n.lookupPrefix(p);if(!k)var r=p.match(".*/(\\w+)/?$"),k=r?r[1]:"xhtml";f[p]=k}}var y={},N;for(N in f)y[f[N]]=N;e=function(a){return y[a]||
null}}try{return d.evaluate(b,a,e,c,null)}catch(Aa){if("TypeError"===Aa.name)return e=d.createNSResolver?d.createNSResolver(d.documentElement):U.D,d.evaluate(b,a,e,c,null);throw Aa;}}catch(Aa){if(!Oa||"NS_ERROR_ILLEGAL_VALUE"!=Aa.name)throw new t(32,"Unable to locate an element with the xpath expression "+b+" because of the following error:\n"+Aa);}};U.F=function(a,b){if(!a||1!=a.nodeType)throw new t(32,'The result of the xpath expression "'+b+'" is: '+a+". It should be an element.");};
U.s=function(a,b){var c=function(){var c=U.o(b,a,9);return c?c.singleNodeValue||null:b.selectSingleNode?(c=B(b),c.setProperty&&c.setProperty("SelectionLanguage","XPath"),b.selectSingleNode(a)):null}();null===c||U.F(c,a);return c};
U.m=function(a,b){var c=function(){var c=U.o(b,a,7);if(c){for(var e=c.snapshotLength,f=[],g=0;g<e;++g)f.push(c.snapshotItem(g));return f}return b.selectNodes?(c=B(b),c.setProperty&&c.setProperty("SelectionLanguage","XPath"),b.selectNodes(a)):[]}();v(c,function(b){U.F(b,a)});return c};function Zc(a,b,c,d){this.top=a;this.right=b;this.bottom=c;this.left=d}Zc.prototype.clone=function(){return new Zc(this.top,this.right,this.bottom,this.left)};Zc.prototype.toString=function(){return"("+this.top+"t, "+this.right+"r, "+this.bottom+"b, "+this.left+"l)"};Zc.prototype.ceil=function(){this.top=Math.ceil(this.top);this.right=Math.ceil(this.right);this.bottom=Math.ceil(this.bottom);this.left=Math.ceil(this.left);return this};
Zc.prototype.floor=function(){this.top=Math.floor(this.top);this.right=Math.floor(this.right);this.bottom=Math.floor(this.bottom);this.left=Math.floor(this.left);return this};Zc.prototype.round=function(){this.top=Math.round(this.top);this.right=Math.round(this.right);this.bottom=Math.round(this.bottom);this.left=Math.round(this.left);return this};function V(a,b,c,d){this.left=a;this.top=b;this.width=c;this.height=d}V.prototype.clone=function(){return new V(this.left,this.top,this.width,this.height)};V.prototype.toString=function(){return"("+this.left+", "+this.top+" - "+this.width+"w x "+this.height+"h)"};V.prototype.ceil=function(){this.left=Math.ceil(this.left);this.top=Math.ceil(this.top);this.width=Math.ceil(this.width);this.height=Math.ceil(this.height);return this};
V.prototype.floor=function(){this.left=Math.floor(this.left);this.top=Math.floor(this.top);this.width=Math.floor(this.width);this.height=Math.floor(this.height);return this};V.prototype.round=function(){this.left=Math.round(this.left);this.top=Math.round(this.top);this.width=Math.round(this.width);this.height=Math.round(this.height);return this};function W(a,b){return!!a&&1==a.nodeType&&(!b||a.tagName.toUpperCase()==b)}var $c=/[;]+(?=(?:(?:[^"]*"){2})*[^"]*$)(?=(?:(?:[^']*'){2})*[^']*$)(?=(?:[^()]*\([^()]*\))*[^()]*$)/;function ad(a){var b=[];v(a.split($c),function(a){var d=a.indexOf(":");0<d&&(a=[a.slice(0,d),a.slice(d+1)],2==a.length&&b.push(a[0].toLowerCase(),":",a[1],";"))});b=b.join("");return b=";"==b.charAt(b.length-1)?b:b+";"}
function bd(a,b){b=b.toLowerCase();if("style"==b)return ad(a.style.cssText);if(xb&&"value"==b&&W(a,"INPUT"))return a.value;if(yb&&!0===a[b])return String(a.getAttribute(b));var c=a.getAttributeNode(b);return c&&c.specified?c.value:null}function cd(a){for(a=a.parentNode;a&&1!=a.nodeType&&9!=a.nodeType&&11!=a.nodeType;)a=a.parentNode;return W(a)?a:null}
function X(a,b){var c=sa(b);if("float"==c||"cssFloat"==c||"styleFloat"==c)c=yb?"styleFloat":"cssFloat";var d;a:{d=c;var e=B(a);if(e.defaultView&&e.defaultView.getComputedStyle&&(e=e.defaultView.getComputedStyle(a,null))){d=e[d]||e.getPropertyValue(d)||"";break a}d=""}d=d||dd(a,c);if(null===d)d=null;else if(0<=ta(Bb,c)){b:{var f=d.match(Eb);if(f){var c=Number(f[1]),e=Number(f[2]),g=Number(f[3]),f=Number(f[4]);if(0<=c&&255>=c&&0<=e&&255>=e&&0<=g&&255>=g&&0<=f&&1>=f){c=[c,e,g,f];break b}}c=null}if(!c)b:{if(g=
d.match(Fb))if(c=Number(g[1]),e=Number(g[2]),g=Number(g[3]),0<=c&&255>=c&&0<=e&&255>=e&&0<=g&&255>=g){c=[c,e,g,1];break b}c=null}if(!c)b:{c=d.toLowerCase();e=Ab[c.toLowerCase()];if(!e&&(e="#"==c.charAt(0)?c:"#"+c,4==e.length&&(e=e.replace(Cb,"#$1$1$2$2$3$3")),!Db.test(e))){c=null;break b}c=[parseInt(e.substr(1,2),16),parseInt(e.substr(3,2),16),parseInt(e.substr(5,2),16),1]}d=c?"rgba("+c.join(", ")+")":d}return d}
function dd(a,b){var c=a.currentStyle||a.style,d=c[b];!aa(d)&&ea(c.getPropertyValue)&&(d=c.getPropertyValue(b));return"inherit"!=d?aa(d)?d:null:(c=cd(a))?dd(c,b):null}
function ed(a,b,c){function d(a){var b=fd(a);return 0<b.height&&0<b.width?!0:W(a,"PATH")&&(0<b.height||0<b.width)?(a=X(a,"stroke-width"),!!a&&0<parseInt(a,10)):"hidden"!=X(a,"overflow")&&xa(a.childNodes,function(a){return 3==a.nodeType||W(a)&&d(a)})}function e(a){return gd(a)==Y&&ya(a.childNodes,function(a){return!W(a)||e(a)||!d(a)})}if(!W(a))throw Error("Argument to isShown must be of type Element");if(W(a,"BODY"))return!0;if(W(a,"OPTION")||W(a,"OPTGROUP"))return a=eb(a,function(a){return W(a,"SELECT")}),
!!a&&ed(a,!0,c);var f=hd(a);if(f)return!!f.G&&0<f.rect.width&&0<f.rect.height&&ed(f.G,b,c);if(W(a,"INPUT")&&"hidden"==a.type.toLowerCase()||W(a,"NOSCRIPT"))return!1;f=X(a,"visibility");return"collapse"!=f&&"hidden"!=f&&c(a)&&(b||0!=id(a))&&d(a)?!e(a):!1}function jd(a){function b(a){if("none"==X(a,"display"))return!1;a=cd(a);return!a||b(a)}return ed(a,!1,b)}var Y="hidden";
function gd(a){function b(a){function b(a){return a==g?!0:0==X(a,"display").lastIndexOf("inline",0)||"absolute"==c&&"static"==X(a,"position")?!1:!0}var c=X(a,"position");if("fixed"==c)return p=!0,a==g?null:g;for(a=cd(a);a&&!b(a);)a=cd(a);return a}function c(a){var b=a;if("visible"==n)if(a==g&&h)b=h;else if(a==h)return{x:"visible",y:"visible"};b={x:X(b,"overflow-x"),y:X(b,"overflow-y")};a==g&&(b.x="visible"==b.x?"auto":b.x,b.y="visible"==b.y?"auto":b.y);return b}function d(a){if(a==g){var b=(new Za(f)).a;
a=b.scrollingElement?b.scrollingElement:Pa||"CSS1Compat"!=b.compatMode?b.body||b.documentElement:b.documentElement;b=b.parentWindow||b.defaultView;a=z&&Ua("10")&&b.pageYOffset!=a.scrollTop?new A(a.scrollLeft,a.scrollTop):new A(b.pageXOffset||a.scrollLeft,b.pageYOffset||a.scrollTop)}else a=new A(a.scrollLeft,a.scrollTop);return a}var e=kd(a),f=B(a),g=f.documentElement,h=f.body,n=X(g,"overflow"),p;for(a=b(a);a;a=b(a)){var k=c(a);if("visible"!=k.x||"visible"!=k.y){var r=fd(a);if(0==r.width||0==r.height)return Y;
var y=e.right<r.left,N=e.bottom<r.top;if(y&&"hidden"==k.x||N&&"hidden"==k.y)return Y;if(y&&"visible"!=k.x||N&&"visible"!=k.y){y=d(a);N=e.bottom<r.top-y.y;if(e.right<r.left-y.x&&"visible"!=k.x||N&&"visible"!=k.x)return Y;e=gd(a);return e==Y?Y:"scroll"}y=e.left>=r.left+r.width;r=e.top>=r.top+r.height;if(y&&"hidden"==k.x||r&&"hidden"==k.y)return Y;if(y&&"visible"!=k.x||r&&"visible"!=k.y){if(p&&(k=d(a),e.left>=g.scrollWidth-k.x||e.right>=g.scrollHeight-k.y))return Y;e=gd(a);return e==Y?Y:"scroll"}}}return"none"}
function fd(a){var b=hd(a);if(b)return b.rect;if(W(a,"HTML"))return a=B(a),a=((a?a.parentWindow||a.defaultView:window)||window).document,a="CSS1Compat"==a.compatMode?a.documentElement:a.body,a=new Xa(a.clientWidth,a.clientHeight),new V(0,0,a.width,a.height);var c;try{c=a.getBoundingClientRect()}catch(d){return new V(0,0,0,0)}b=new V(c.left,c.top,c.right-c.left,c.bottom-c.top);z&&a.ownerDocument.body&&(a=B(a),b.left-=a.documentElement.clientLeft+a.body.clientLeft,b.top-=a.documentElement.clientTop+
a.body.clientTop);return b}function hd(a){var b=W(a,"MAP");if(!b&&!W(a,"AREA"))return null;var c=b?a:W(a.parentNode,"MAP")?a.parentNode:null,d=null,e=null;c&&c.name&&(d=U.s('/descendant::*[@usemap = "#'+c.name+'"]',B(c)))&&(e=fd(d),b||"default"==a.shape.toLowerCase()||(a=ld(a),b=Math.min(Math.max(a.left,0),e.width),c=Math.min(Math.max(a.top,0),e.height),e=new V(b+e.left,c+e.top,Math.min(a.width,e.width-b),Math.min(a.height,e.height-c))));return{G:d,rect:e||new V(0,0,0,0)}}
function ld(a){var b=a.shape.toLowerCase();a=a.coords.split(",");if("rect"==b&&4==a.length){var b=a[0],c=a[1];return new V(b,c,a[2]-b,a[3]-c)}if("circle"==b&&3==a.length)return b=a[2],new V(a[0]-b,a[1]-b,2*b,2*b);if("poly"==b&&2<a.length){for(var b=a[0],c=a[1],d=b,e=c,f=2;f+1<a.length;f+=2)b=Math.min(b,a[f]),d=Math.max(d,a[f]),c=Math.min(c,a[f+1]),e=Math.max(e,a[f+1]);return new V(b,c,d-b,e-c)}return new V(0,0,0,0)}function kd(a){a=fd(a);return new Zc(a.top,a.left+a.width,a.top+a.height,a.left)}
function md(a){return a.replace(/^[^\S\xa0]+|[^\S\xa0]+$/g,"")}function nd(a){var b=[];od(a,b);a=va(b,md);return md(a.join("\n")).replace(/\xa0/g," ")}
function pd(a,b,c){if(W(a,"BR"))b.push("");else{var d=W(a,"TD"),e=X(a,"display"),f=!d&&!(0<=ta(qd,e)),g=aa(a.previousElementSibling)?a.previousElementSibling:$a(a.previousSibling),g=g?X(g,"display"):"",h=X(a,"float")||X(a,"cssFloat")||X(a,"styleFloat");!f||"run-in"==g&&"none"==h||/^[\s\xa0]*$/.test(b[b.length-1]||"")||b.push("");var n=jd(a),p=null,k=null;n&&(p=X(a,"white-space"),k=X(a,"text-transform"));v(a.childNodes,function(a){c(a,b,n,p,k)});a=b[b.length-1]||"";!d&&"table-cell"!=e||!a||oa(a)||
(b[b.length-1]+=" ");f&&"run-in"!=e&&!/^[\s\xa0]*$/.test(a)&&b.push("")}}function od(a,b){pd(a,b,function(a,b,e,f,g){3==a.nodeType&&e?rd(a,b,f,g):W(a)&&od(a,b)})}var qd="inline inline-block inline-table none table-cell table-column table-column-group".split(" ");
function rd(a,b,c,d){a=a.nodeValue.replace(/[\u200b\u200e\u200f]/g,"");a=a.replace(/(\r\n|\r|\n)/g,"\n");if("normal"==c||"nowrap"==c)a=a.replace(/\n/g," ");a="pre"==c||"pre-wrap"==c?a.replace(/[ \f\t\v\u2028\u2029]/g,"\u00a0"):a.replace(/[\ \f\t\v\u2028\u2029]+/g," ");"capitalize"==d?a=a.replace(/(^|\s)(\S)/g,function(a,b,c){return b+c.toUpperCase()}):"uppercase"==d?a=a.toUpperCase():"lowercase"==d&&(a=a.toLowerCase());c=b.pop()||"";oa(c)&&0==a.lastIndexOf(" ",0)&&(a=a.substr(1));b.push(c+a)}
function id(a){if(yb){if("relative"==X(a,"position"))return 1;a=X(a,"filter");return(a=a.match(/^alpha\(opacity=(\d*)\)/)||a.match(/^progid:DXImageTransform.Microsoft.Alpha\(Opacity=(\d*)\)/))?Number(a[1])/100:1}return sd(a)}function sd(a){var b=1,c=X(a,"opacity");c&&(b=Number(c));(a=cd(a))&&(b*=sd(a));return b};var td={w:function(a,b){return!(!a.querySelectorAll||!a.querySelector)&&!/^\d.*/.test(b)},s:function(a,b){var c=Ya(b),d=m(a)?c.a.getElementById(a):a;if(!d)return null;if(bd(d,"id")==a&&ab(b,d))return d;c=fb(c,"*");return za(c,function(c){return bd(c,"id")==a&&ab(b,c)})},m:function(a,b){if(!a)return[];if(td.w(b,a))try{return b.querySelectorAll("#"+td.L(a))}catch(d){return[]}var c=fb(Ya(b),"*",null,b);return ua(c,function(b){return bd(b,"id")==a})},L:function(a){return a.replace(/(['"\\#.:;,!?+<>=~*^$|%&@`{}\-\/\[\]\(\)])/g,
"\\$1")}};var Z={},ud={};Z.K=function(a,b,c){var d;try{d=zb.m("a",b)}catch(e){d=fb(Ya(b),"A",null,b)}return za(d,function(b){b=nd(b);return c&&-1!=b.indexOf(a)||b==a})};Z.H=function(a,b,c){var d;try{d=zb.m("a",b)}catch(e){d=fb(Ya(b),"A",null,b)}return ua(d,function(b){b=nd(b);return c&&-1!=b.indexOf(a)||b==a})};Z.s=function(a,b){return Z.K(a,b,!1)};Z.m=function(a,b){return Z.H(a,b,!1)};ud.s=function(a,b){return Z.K(a,b,!0)};ud.m=function(a,b){return Z.H(a,b,!0)};var vd={s:function(a,b){if(""===a)throw new t(32,'Unable to locate an element with the tagName ""');return b.getElementsByTagName(a)[0]||null},m:function(a,b){if(""===a)throw new t(32,'Unable to locate an element with the tagName ""');return b.getElementsByTagName(a)}};var wd={className:gb,"class name":gb,css:zb,"css selector":zb,id:td,linkText:Z,"link text":Z,name:{s:function(a,b){var c=fb(Ya(b),"*",null,b);return za(c,function(b){return bd(b,"name")==a})},m:function(a,b){var c=fb(Ya(b),"*",null,b);return ua(c,function(b){return bd(b,"name")==a})}},partialLinkText:ud,"partial link text":ud,tagName:vd,"tag name":vd,xpath:U};function xd(){}
function yd(a,b,c){if(null==b)c.push("null");else{if("object"==typeof b){if("array"==ca(b)){var d=b;b=d.length;c.push("[");for(var e="",f=0;f<b;f++)c.push(e),yd(a,d[f],c),e=",";c.push("]");return}if(b instanceof String||b instanceof Number||b instanceof Boolean)b=b.valueOf();else{c.push("{");e="";for(d in b)Object.prototype.hasOwnProperty.call(b,d)&&(f=b[d],"function"!=typeof f&&(c.push(e),zd(d,c),c.push(":"),yd(a,f,c),e=","));c.push("}");return}}switch(typeof b){case "string":zd(b,c);break;case "number":c.push(isFinite(b)&&
!isNaN(b)?String(b):"null");break;case "boolean":c.push(String(b));break;case "function":c.push("null");break;default:throw Error("Unknown type: "+typeof b);}}}var Ad={'"':'\\"',"\\":"\\\\","/":"\\/","\b":"\\b","\f":"\\f","\n":"\\n","\r":"\\r","\t":"\\t","\x0B":"\\u000b"},Bd=/\uffff/.test("\uffff")?/[\\\"\x00-\x1f\x7f-\uffff]/g:/[\\\"\x00-\x1f\x7f-\xff]/g;
function zd(a,b){b.push('"',a.replace(Bd,function(a){var b=Ad[a];b||(b="\\u"+(a.charCodeAt(0)|65536).toString(16).substr(1),Ad[a]=b);return b}),'"')};Pa||Oa&&rb(3.5)||z&&rb(8);function Ha(a){switch(ca(a)){case "string":case "number":case "boolean":return a;case "function":return a.toString();case "array":return va(a,Ha);case "object":if(null!==a&&"nodeType"in a&&(1==a.nodeType||9==a.nodeType)){var b={};b.ELEMENT=Cd(a);return b}if(null!==a&&"document"in a)return b={},b.WINDOW=Cd(a),b;if(da(a))return va(a,Ha);a=Fa(a,function(a,b){return"number"==typeof b||m(b)});return Ga(a);default:return null}}
function Dd(a){a=a||document;var b=a.$wdc_;b||(b=a.$wdc_={},b.B=ka());b.B||(b.B=ka());return b}function Cd(a){var b=Dd(a.ownerDocument),c=Ia(b,function(b){return b==a});c||(c=":wdc:"+b.B++,b[c]=a);return c}
function Ed(a,b){a=decodeURIComponent(a);var c=b||document,d=Dd(c);if(!(null!==d&&a in d))throw new t(10,"Element does not exist in cache");var e=d[a];if(null!==e&&"setInterval"in e){if(e.closed)throw delete d[a],new t(23,"Window has been closed.");return e}for(var f=e;f;){if(f==c.documentElement)return e;f=f.parentNode}delete d[a];throw new t(10,"Element is no longer attached to the DOM");};ba("_",function(a,b,c,d){var e={};e[a]=b;var f;try{var g,h;d?h=Ed(d.WINDOW):h=window;g=h;var n;c?n=Ed(c.ELEMENT,g.document):n=g.document;var p;a:{a=n;var k;b:{for(var r in e)if(e.hasOwnProperty(r)){k=r;break b}k=null}if(k){var y=wd[k];if(y&&ea(y.m)){p=y.m(e[k],a||la.document);break a}}throw Error("Unsupported locator strategy: "+k);}f={status:0,value:Ha(p)}}catch(N){f={status:null!==N&&"code"in N?N.code:13,value:{message:N.message}}}e=[];yd(new xd,f,e);return e.join("")});; return this._.apply(null,arguments);}.apply({navigator:typeof window!=undefined?window.navigator:null,document:typeof window!=undefined?window.document:null}, arguments);}
