function(){return function(){var h,l=this;function aa(a,b){var c=a.split("."),d=l;c[0]in d||!d.execScript||d.execScript("var "+c[0]);for(var e;c.length&&(e=c.shift());)c.length||void 0===b?d[e]?d=d[e]:d=d[e]={}:d[e]=b}
function ba(a){var b=typeof a;if("object"==b)if(a){if(a instanceof Array)return"array";if(a instanceof Object)return b;var c=Object.prototype.toString.call(a);if("[object Window]"==c)return"object";if("[object Array]"==c||"number"==typeof a.length&&"undefined"!=typeof a.splice&&"undefined"!=typeof a.propertyIsEnumerable&&!a.propertyIsEnumerable("splice"))return"array";if("[object Function]"==c||"undefined"!=typeof a.call&&"undefined"!=typeof a.propertyIsEnumerable&&!a.propertyIsEnumerable("call"))return"function"}else return"null";
else if("function"==b&&"undefined"==typeof a.call)return"object";return b}function da(a){var b=ba(a);return"array"==b||"object"==b&&"number"==typeof a.length}function m(a){return"string"==typeof a}function ea(a){return"number"==typeof a}function fa(a){var b=typeof a;return"object"==b&&null!=a||"function"==b}function ga(a,b,c){return a.call.apply(a.bind,arguments)}
function ha(a,b,c){if(!a)throw Error();if(2<arguments.length){var d=Array.prototype.slice.call(arguments,2);return function(){var c=Array.prototype.slice.call(arguments);Array.prototype.unshift.apply(c,d);return a.apply(b,c)}}return function(){return a.apply(b,arguments)}}function ia(a,b,c){ia=Function.prototype.bind&&-1!=Function.prototype.bind.toString().indexOf("native code")?ga:ha;return ia.apply(null,arguments)}
function ja(a,b){var c=Array.prototype.slice.call(arguments,1);return function(){var b=c.slice();b.push.apply(b,arguments);return a.apply(this,b)}}var ka=Date.now||function(){return+new Date};function n(a,b){function c(){}c.prototype=b.prototype;a.R=b.prototype;a.prototype=new c;a.prototype.constructor=a;a.O=function(a,c,f){for(var g=Array(arguments.length-2),k=2;k<arguments.length;k++)g[k-2]=arguments[k];return b.prototype[c].apply(a,g)}};var la=String.prototype.trim?function(a){return a.trim()}:function(a){return a.replace(/^[\s\xa0]+|[\s\xa0]+$/g,"")};
function ma(a,b){for(var c=0,d=la(String(a)).split("."),e=la(String(b)).split("."),f=Math.max(d.length,e.length),g=0;0==c&&g<f;g++){var k=d[g]||"",u=e[g]||"",v=RegExp("(\\d*)(\\D*)","g"),p=RegExp("(\\d*)(\\D*)","g");do{var x=v.exec(k)||["","",""],E=p.exec(u)||["","",""];if(0==x[0].length&&0==E[0].length)break;c=na(0==x[1].length?0:parseInt(x[1],10),0==E[1].length?0:parseInt(E[1],10))||na(0==x[2].length,0==E[2].length)||na(x[2],E[2])}while(0==c)}return c}function na(a,b){return a<b?-1:a>b?1:0}
function oa(a){return String(a).replace(/\-([a-z])/g,function(a,c){return c.toUpperCase()})};function pa(a,b){if(m(a))return m(b)&&1==b.length?a.indexOf(b,0):-1;for(var c=0;c<a.length;c++)if(c in a&&a[c]===b)return c;return-1}function q(a,b){for(var c=a.length,d=m(a)?a.split(""):a,e=0;e<c;e++)e in d&&b.call(void 0,d[e],e,a)}function qa(a,b){for(var c=a.length,d=[],e=0,f=m(a)?a.split(""):a,g=0;g<c;g++)if(g in f){var k=f[g];b.call(void 0,k,g,a)&&(d[e++]=k)}return d}
function ra(a,b){for(var c=a.length,d=Array(c),e=m(a)?a.split(""):a,f=0;f<c;f++)f in e&&(d[f]=b.call(void 0,e[f],f,a));return d}function sa(a,b,c){var d=c;q(a,function(c,f){d=b.call(void 0,d,c,f,a)});return d}function ta(a,b){for(var c=a.length,d=m(a)?a.split(""):a,e=0;e<c;e++)if(e in d&&b.call(void 0,d[e],e,a))return!0;return!1}function ua(a,b){for(var c=a.length,d=m(a)?a.split(""):a,e=0;e<c;e++)if(e in d&&!b.call(void 0,d[e],e,a))return!1;return!0}
function va(a,b){var c;a:{c=a.length;for(var d=m(a)?a.split(""):a,e=0;e<c;e++)if(e in d&&b.call(void 0,d[e],e,a)){c=e;break a}c=-1}return 0>c?null:m(a)?a.charAt(c):a[c]}function wa(a){return Array.prototype.concat.apply(Array.prototype,arguments)}function ya(a,b,c){return 2>=arguments.length?Array.prototype.slice.call(a,b):Array.prototype.slice.call(a,b,c)};var za={aliceblue:"#f0f8ff",antiquewhite:"#faebd7",aqua:"#00ffff",aquamarine:"#7fffd4",azure:"#f0ffff",beige:"#f5f5dc",bisque:"#ffe4c4",black:"#000000",blanchedalmond:"#ffebcd",blue:"#0000ff",blueviolet:"#8a2be2",brown:"#a52a2a",burlywood:"#deb887",cadetblue:"#5f9ea0",chartreuse:"#7fff00",chocolate:"#d2691e",coral:"#ff7f50",cornflowerblue:"#6495ed",cornsilk:"#fff8dc",crimson:"#dc143c",cyan:"#00ffff",darkblue:"#00008b",darkcyan:"#008b8b",darkgoldenrod:"#b8860b",darkgray:"#a9a9a9",darkgreen:"#006400",
darkgrey:"#a9a9a9",darkkhaki:"#bdb76b",darkmagenta:"#8b008b",darkolivegreen:"#556b2f",darkorange:"#ff8c00",darkorchid:"#9932cc",darkred:"#8b0000",darksalmon:"#e9967a",darkseagreen:"#8fbc8f",darkslateblue:"#483d8b",darkslategray:"#2f4f4f",darkslategrey:"#2f4f4f",darkturquoise:"#00ced1",darkviolet:"#9400d3",deeppink:"#ff1493",deepskyblue:"#00bfff",dimgray:"#696969",dimgrey:"#696969",dodgerblue:"#1e90ff",firebrick:"#b22222",floralwhite:"#fffaf0",forestgreen:"#228b22",fuchsia:"#ff00ff",gainsboro:"#dcdcdc",
ghostwhite:"#f8f8ff",gold:"#ffd700",goldenrod:"#daa520",gray:"#808080",green:"#008000",greenyellow:"#adff2f",grey:"#808080",honeydew:"#f0fff0",hotpink:"#ff69b4",indianred:"#cd5c5c",indigo:"#4b0082",ivory:"#fffff0",khaki:"#f0e68c",lavender:"#e6e6fa",lavenderblush:"#fff0f5",lawngreen:"#7cfc00",lemonchiffon:"#fffacd",lightblue:"#add8e6",lightcoral:"#f08080",lightcyan:"#e0ffff",lightgoldenrodyellow:"#fafad2",lightgray:"#d3d3d3",lightgreen:"#90ee90",lightgrey:"#d3d3d3",lightpink:"#ffb6c1",lightsalmon:"#ffa07a",
lightseagreen:"#20b2aa",lightskyblue:"#87cefa",lightslategray:"#778899",lightslategrey:"#778899",lightsteelblue:"#b0c4de",lightyellow:"#ffffe0",lime:"#00ff00",limegreen:"#32cd32",linen:"#faf0e6",magenta:"#ff00ff",maroon:"#800000",mediumaquamarine:"#66cdaa",mediumblue:"#0000cd",mediumorchid:"#ba55d3",mediumpurple:"#9370db",mediumseagreen:"#3cb371",mediumslateblue:"#7b68ee",mediumspringgreen:"#00fa9a",mediumturquoise:"#48d1cc",mediumvioletred:"#c71585",midnightblue:"#191970",mintcream:"#f5fffa",mistyrose:"#ffe4e1",
moccasin:"#ffe4b5",navajowhite:"#ffdead",navy:"#000080",oldlace:"#fdf5e6",olive:"#808000",olivedrab:"#6b8e23",orange:"#ffa500",orangered:"#ff4500",orchid:"#da70d6",palegoldenrod:"#eee8aa",palegreen:"#98fb98",paleturquoise:"#afeeee",palevioletred:"#db7093",papayawhip:"#ffefd5",peachpuff:"#ffdab9",peru:"#cd853f",pink:"#ffc0cb",plum:"#dda0dd",powderblue:"#b0e0e6",purple:"#800080",red:"#ff0000",rosybrown:"#bc8f8f",royalblue:"#4169e1",saddlebrown:"#8b4513",salmon:"#fa8072",sandybrown:"#f4a460",seagreen:"#2e8b57",
seashell:"#fff5ee",sienna:"#a0522d",silver:"#c0c0c0",skyblue:"#87ceeb",slateblue:"#6a5acd",slategray:"#708090",slategrey:"#708090",snow:"#fffafa",springgreen:"#00ff7f",steelblue:"#4682b4",tan:"#d2b48c",teal:"#008080",thistle:"#d8bfd8",tomato:"#ff6347",turquoise:"#40e0d0",violet:"#ee82ee",wheat:"#f5deb3",white:"#ffffff",whitesmoke:"#f5f5f5",yellow:"#ffff00",yellowgreen:"#9acd32"};var Aa="backgroundColor borderTopColor borderRightColor borderBottomColor borderLeftColor color outlineColor".split(" "),Ba=/#([0-9a-fA-F])([0-9a-fA-F])([0-9a-fA-F])/,Ca=/^#(?:[0-9a-f]{3}){1,2}$/i,Da=/^(?:rgba)?\((\d{1,3}),\s?(\d{1,3}),\s?(\d{1,3}),\s?(0|1|0\.\d*)\)$/i,Ea=/^(?:rgb)?\((0|[1-9]\d{0,2}),\s?(0|[1-9]\d{0,2}),\s?(0|[1-9]\d{0,2})\)$/i;function Fa(a,b){this.code=a;this.a=r[a]||Ga;this.message=b||"";var c=this.a.replace(/((?:^|\s+)[a-z])/g,function(a){return a.toUpperCase().replace(/^[\s\xa0]+/g,"")}),d=c.length-5;if(0>d||c.indexOf("Error",d)!=d)c+="Error";this.name=c;c=Error(this.message);c.name=this.name;this.stack=c.stack||""}n(Fa,Error);var Ga="unknown error",r={15:"element not selectable",11:"element not visible"};r[31]=Ga;r[30]=Ga;r[24]="invalid cookie domain";r[29]="invalid element coordinates";r[12]="invalid element state";
r[32]="invalid selector";r[51]="invalid selector";r[52]="invalid selector";r[17]="javascript error";r[405]="unsupported operation";r[34]="move target out of bounds";r[27]="no such alert";r[7]="no such element";r[8]="no such frame";r[23]="no such window";r[28]="script timeout";r[33]="session not created";r[10]="stale element reference";r[21]="timeout";r[25]="unable to set cookie";r[26]="unexpected alert open";r[13]=Ga;r[9]="unknown command";Fa.prototype.toString=function(){return this.name+": "+this.message};var t;a:{var Ha=l.navigator;if(Ha){var Ia=Ha.userAgent;if(Ia){t=Ia;break a}}t=""}function w(a){return-1!=t.indexOf(a)};function Ja(a,b){var c={},d;for(d in a)b.call(void 0,a[d],d,a)&&(c[d]=a[d]);return c}function Ka(a,b){var c={},d;for(d in a)c[d]=b.call(void 0,a[d],d,a);return c}function La(a,b){return null!==a&&b in a}function Ma(a,b){for(var c in a)if(b.call(void 0,a[c],c,a))return c};function Na(){return w("Opera")||w("OPR")}function Oa(){return(w("Chrome")||w("CriOS"))&&!Na()&&!w("Edge")};function Pa(){return w("iPhone")&&!w("iPod")&&!w("iPad")};var Qa=Na(),y=w("Trident")||w("MSIE"),Ra=w("Edge"),z=w("Gecko")&&!(-1!=t.toLowerCase().indexOf("webkit")&&!w("Edge"))&&!(w("Trident")||w("MSIE"))&&!w("Edge"),Sa=-1!=t.toLowerCase().indexOf("webkit")&&!w("Edge"),Ta=w("Macintosh"),Ua=w("Windows");function Va(){var a=t;if(z)return/rv\:([^\);]+)(\)|;)/.exec(a);if(Ra)return/Edge\/([\d\.]+)/.exec(a);if(y)return/\b(?:MSIE|rv)[: ]([^\);]+)(\)|;)/.exec(a);if(Sa)return/WebKit\/(\S+)/.exec(a)}function Wa(){var a=l.document;return a?a.documentMode:void 0}
var Xa=function(){if(Qa&&l.opera){var a;var b=l.opera.version;try{a=b()}catch(c){a=b}return a}a="";(b=Va())&&(a=b?b[1]:"");return y&&(b=Wa(),null!=b&&b>parseFloat(a))?String(b):a}(),Ya={};function Za(a){return Ya[a]||(Ya[a]=0<=ma(Xa,a))}var $a=l.document,ab=$a&&y?Wa()||("CSS1Compat"==$a.compatMode?parseInt(Xa,10):5):void 0;!z&&!y||y&&9<=Number(ab)||z&&Za("1.9.1");y&&Za("9");function bb(a,b){this.x=void 0!==a?a:0;this.y=void 0!==b?b:0}h=bb.prototype;h.clone=function(){return new bb(this.x,this.y)};h.toString=function(){return"("+this.x+", "+this.y+")"};h.ceil=function(){this.x=Math.ceil(this.x);this.y=Math.ceil(this.y);return this};h.floor=function(){this.x=Math.floor(this.x);this.y=Math.floor(this.y);return this};h.round=function(){this.x=Math.round(this.x);this.y=Math.round(this.y);return this};h.scale=function(a,b){var c=ea(b)?b:a;this.x*=a;this.y*=c;return this};function cb(a,b){this.width=a;this.height=b}h=cb.prototype;h.clone=function(){return new cb(this.width,this.height)};h.toString=function(){return"("+this.width+" x "+this.height+")"};h.ceil=function(){this.width=Math.ceil(this.width);this.height=Math.ceil(this.height);return this};h.floor=function(){this.width=Math.floor(this.width);this.height=Math.floor(this.height);return this};h.round=function(){this.width=Math.round(this.width);this.height=Math.round(this.height);return this};
h.scale=function(a,b){var c=ea(b)?b:a;this.width*=a;this.height*=c;return this};function db(a,b){if(!a||!b)return!1;if(a.contains&&1==b.nodeType)return a==b||a.contains(b);if("undefined"!=typeof a.compareDocumentPosition)return a==b||!!(a.compareDocumentPosition(b)&16);for(;b&&a!=b;)b=b.parentNode;return b==a}
function eb(a,b){if(a==b)return 0;if(a.compareDocumentPosition)return a.compareDocumentPosition(b)&2?1:-1;if(y&&!(9<=Number(ab))){if(9==a.nodeType)return-1;if(9==b.nodeType)return 1}if("sourceIndex"in a||a.parentNode&&"sourceIndex"in a.parentNode){var c=1==a.nodeType,d=1==b.nodeType;if(c&&d)return a.sourceIndex-b.sourceIndex;var e=a.parentNode,f=b.parentNode;return e==f?fb(a,b):!c&&db(e,b)?-1*gb(a,b):!d&&db(f,a)?gb(b,a):(c?a.sourceIndex:e.sourceIndex)-(d?b.sourceIndex:f.sourceIndex)}d=A(a);c=d.createRange();
c.selectNode(a);c.collapse(!0);d=d.createRange();d.selectNode(b);d.collapse(!0);return c.compareBoundaryPoints(l.Range.START_TO_END,d)}function gb(a,b){var c=a.parentNode;if(c==b)return-1;for(var d=b;d.parentNode!=c;)d=d.parentNode;return fb(d,a)}function fb(a,b){for(var c=b;c=c.previousSibling;)if(c==a)return-1;return 1}function A(a){return 9==a.nodeType?a:a.ownerDocument||a.document}function hb(a,b){a=a.parentNode;for(var c=0;a;){if(b(a))return a;a=a.parentNode;c++}return null}
function ib(a){this.a=a||l.document||document}ib.prototype.contains=db;var jb=w("Firefox"),kb=Pa()||w("iPod"),lb=w("iPad"),mb=w("Android")&&!(Oa()||w("Firefox")||Na()||w("Silk")),nb=Oa(),ob=w("Safari")&&!(Oa()||w("Coast")||Na()||w("Edge")||w("Silk")||w("Android"))&&!(Pa()||w("iPad")||w("iPod"));/*

 The MIT License

 Copyright (c) 2007 Cybozu Labs, Inc.
 Copyright (c) 2012 Google Inc.

 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to
 deal in the Software without restriction, including without limitation the
 rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
 sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in
 all copies or substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 IN THE SOFTWARE.
*/
function pb(a,b,c){this.a=a;this.b=b||1;this.h=c||1};var B=y&&!(9<=Number(ab)),qb=y&&!(8<=Number(ab));function rb(a,b,c,d){this.a=a;this.nodeName=c;this.nodeValue=d;this.nodeType=2;this.parentNode=this.ownerElement=b}function sb(a,b){var c=qb&&"href"==b.nodeName?a.getAttribute(b.nodeName,2):b.nodeValue;return new rb(b,a,b.nodeName,c)};function tb(a){this.b=a;this.a=0}function ub(a){a=a.match(vb);for(var b=0;b<a.length;b++)wb.test(a[b])&&a.splice(b,1);return new tb(a)}var vb=RegExp("\\$?(?:(?![0-9-\\.])(?:\\*|[\\w-\\.]+):)?(?![0-9-\\.])(?:\\*|[\\w-\\.]+)|\\/\\/|\\.\\.|::|\\d+(?:\\.\\d*)?|\\.\\d+|\"[^\"]*\"|'[^']*'|[!<>]=|\\s+|.","g"),wb=/^\s/;function C(a,b){return a.b[a.a+(b||0)]}function D(a){return a.b[a.a++]}function xb(a){return a.b.length<=a.a};function F(a){var b=null,c=a.nodeType;1==c&&(b=a.textContent,b=void 0==b||null==b?a.innerText:b,b=void 0==b||null==b?"":b);if("string"!=typeof b)if(B&&"title"==a.nodeName.toLowerCase()&&1==c)b=a.text;else if(9==c||1==c){a=9==c?a.documentElement:a.firstChild;for(var c=0,d=[],b="";a;){do 1!=a.nodeType&&(b+=a.nodeValue),B&&"title"==a.nodeName.toLowerCase()&&(b+=a.text),d[c++]=a;while(a=a.firstChild);for(;c&&!(a=d[--c].nextSibling););}}else b=a.nodeValue;return""+b}
function G(a,b,c){if(null===b)return!0;try{if(!a.getAttribute)return!1}catch(d){return!1}qb&&"class"==b&&(b="className");return null==c?!!a.getAttribute(b):a.getAttribute(b,2)==c}function yb(a,b,c,d,e){return(B?zb:Ab).call(null,a,b,m(c)?c:null,m(d)?d:null,e||new H)}
function zb(a,b,c,d,e){if(a instanceof Bb||8==a.b||c&&null===a.b){var f=b.all;if(!f)return e;a=Cb(a);if("*"!=a&&(f=b.getElementsByTagName(a),!f))return e;if(c){for(var g=[],k=0;b=f[k++];)G(b,c,d)&&g.push(b);f=g}for(k=0;b=f[k++];)"*"==a&&"!"==b.tagName||I(e,b);return e}Db(a,b,c,d,e);return e}
function Ab(a,b,c,d,e){b.getElementsByName&&d&&"name"==c&&!y?(b=b.getElementsByName(d),q(b,function(b){a.a(b)&&I(e,b)})):b.getElementsByClassName&&d&&"class"==c?(b=b.getElementsByClassName(d),q(b,function(b){b.className==d&&a.a(b)&&I(e,b)})):a instanceof J?Db(a,b,c,d,e):b.getElementsByTagName&&(b=b.getElementsByTagName(a.h()),q(b,function(a){G(a,c,d)&&I(e,a)}));return e}
function Eb(a,b,c,d,e){var f;if((a instanceof Bb||8==a.b||c&&null===a.b)&&(f=b.childNodes)){var g=Cb(a);if("*"!=g&&(f=qa(f,function(a){return a.tagName&&a.tagName.toLowerCase()==g}),!f))return e;c&&(f=qa(f,function(a){return G(a,c,d)}));q(f,function(a){"*"==g&&("!"==a.tagName||"*"==g&&1!=a.nodeType)||I(e,a)});return e}return Fb(a,b,c,d,e)}function Fb(a,b,c,d,e){for(b=b.firstChild;b;b=b.nextSibling)G(b,c,d)&&a.a(b)&&I(e,b);return e}
function Db(a,b,c,d,e){for(b=b.firstChild;b;b=b.nextSibling)G(b,c,d)&&a.a(b)&&I(e,b),Db(a,b,c,d,e)}function Cb(a){if(a instanceof J){if(8==a.b)return"!";if(null===a.b)return"*"}return a.h()};function H(){this.b=this.a=null;this.s=0}function Gb(a){this.node=a;this.a=this.b=null}function Hb(a,b){if(!a.a)return b;if(!b.a)return a;for(var c=a.a,d=b.a,e=null,f=null,g=0;c&&d;){var f=c.node,k=d.node;f==k||f instanceof rb&&k instanceof rb&&f.a==k.a?(f=c,c=c.a,d=d.a):0<eb(c.node,d.node)?(f=d,d=d.a):(f=c,c=c.a);(f.b=e)?e.a=f:a.a=f;e=f;g++}for(f=c||d;f;)f.b=e,e=e.a=f,g++,f=f.a;a.b=e;a.s=g;return a}
H.prototype.unshift=function(a){a=new Gb(a);a.a=this.a;this.b?this.a.b=a:this.a=this.b=a;this.a=a;this.s++};function I(a,b){var c=new Gb(b);c.b=a.b;a.a?a.b.a=c:a.a=a.b=c;a.b=c;a.s++}function Ib(a){return(a=a.a)?a.node:null}function Jb(a){return(a=Ib(a))?F(a):""}function Kb(a,b){return new Lb(a,!!b)}function Lb(a,b){this.h=a;this.b=(this.c=b)?a.b:a.a;this.a=null}function K(a){var b=a.b;if(null==b)return null;var c=a.a=b;a.b=a.c?b.b:b.a;return c.node};function L(a){this.m=a;this.b=this.i=!1;this.h=null}function M(a){return"\n  "+a.toString().split("\n").join("\n  ")}function Mb(a,b){a.i=b}function Nb(a,b){a.b=b}function N(a,b){var c=a.a(b);return c instanceof H?+Jb(c):+c}function O(a,b){var c=a.a(b);return c instanceof H?Jb(c):""+c}function Ob(a,b){var c=a.a(b);return c instanceof H?!!c.s:!!c};function Pb(a,b,c){L.call(this,a.m);this.c=a;this.j=b;this.w=c;this.i=b.i||c.i;this.b=b.b||c.b;this.c==Qb&&(c.b||c.i||4==c.m||0==c.m||!b.h?b.b||b.i||4==b.m||0==b.m||!c.h||(this.h={name:c.h.name,A:b}):this.h={name:b.h.name,A:c})}n(Pb,L);
function Rb(a,b,c,d,e){b=b.a(d);c=c.a(d);var f;if(b instanceof H&&c instanceof H){b=Kb(b);for(d=K(b);d;d=K(b))for(e=Kb(c),f=K(e);f;f=K(e))if(a(F(d),F(f)))return!0;return!1}if(b instanceof H||c instanceof H){b instanceof H?(e=b,d=c):(e=c,d=b);f=Kb(e);for(var g=typeof d,k=K(f);k;k=K(f)){switch(g){case "number":k=+F(k);break;case "boolean":k=!!F(k);break;case "string":k=F(k);break;default:throw Error("Illegal primitive type for comparison.");}if(e==b&&a(k,d)||e==c&&a(d,k))return!0}return!1}return e?
"boolean"==typeof b||"boolean"==typeof c?a(!!b,!!c):"number"==typeof b||"number"==typeof c?a(+b,+c):a(b,c):a(+b,+c)}Pb.prototype.a=function(a){return this.c.u(this.j,this.w,a)};Pb.prototype.toString=function(){var a="Binary Expression: "+this.c,a=a+M(this.j);return a+=M(this.w)};function Sb(a,b,c,d){this.a=a;this.I=b;this.m=c;this.u=d}Sb.prototype.toString=function(){return this.a};var Tb={};
function P(a,b,c,d){if(Tb.hasOwnProperty(a))throw Error("Binary operator already created: "+a);a=new Sb(a,b,c,d);return Tb[a.toString()]=a}P("div",6,1,function(a,b,c){return N(a,c)/N(b,c)});P("mod",6,1,function(a,b,c){return N(a,c)%N(b,c)});P("*",6,1,function(a,b,c){return N(a,c)*N(b,c)});P("+",5,1,function(a,b,c){return N(a,c)+N(b,c)});P("-",5,1,function(a,b,c){return N(a,c)-N(b,c)});P("<",4,2,function(a,b,c){return Rb(function(a,b){return a<b},a,b,c)});
P(">",4,2,function(a,b,c){return Rb(function(a,b){return a>b},a,b,c)});P("<=",4,2,function(a,b,c){return Rb(function(a,b){return a<=b},a,b,c)});P(">=",4,2,function(a,b,c){return Rb(function(a,b){return a>=b},a,b,c)});var Qb=P("=",3,2,function(a,b,c){return Rb(function(a,b){return a==b},a,b,c,!0)});P("!=",3,2,function(a,b,c){return Rb(function(a,b){return a!=b},a,b,c,!0)});P("and",2,2,function(a,b,c){return Ob(a,c)&&Ob(b,c)});P("or",1,2,function(a,b,c){return Ob(a,c)||Ob(b,c)});function Ub(a,b){if(b.a.length&&4!=a.m)throw Error("Primary expression must evaluate to nodeset if filter has predicate(s).");L.call(this,a.m);this.c=a;this.j=b;this.i=a.i;this.b=a.b}n(Ub,L);Ub.prototype.a=function(a){a=this.c.a(a);return Vb(this.j,a)};Ub.prototype.toString=function(){var a;a="Filter:"+M(this.c);return a+=M(this.j)};function Wb(a,b){if(b.length<a.J)throw Error("Function "+a.o+" expects at least"+a.J+" arguments, "+b.length+" given");if(null!==a.D&&b.length>a.D)throw Error("Function "+a.o+" expects at most "+a.D+" arguments, "+b.length+" given");a.N&&q(b,function(b,d){if(4!=b.m)throw Error("Argument "+d+" to function "+a.o+" is not of type Nodeset: "+b);});L.call(this,a.m);this.j=a;this.c=b;Mb(this,a.i||ta(b,function(a){return a.i}));Nb(this,a.M&&!b.length||a.L&&!!b.length||ta(b,function(a){return a.b}))}
n(Wb,L);Wb.prototype.a=function(a){return this.j.u.apply(null,wa(a,this.c))};Wb.prototype.toString=function(){var a="Function: "+this.j;if(this.c.length)var b=sa(this.c,function(a,b){return a+M(b)},"Arguments:"),a=a+M(b);return a};function Xb(a,b,c,d,e,f,g,k,u){this.o=a;this.m=b;this.i=c;this.M=d;this.L=e;this.u=f;this.J=g;this.D=void 0!==k?k:g;this.N=!!u}Xb.prototype.toString=function(){return this.o};var Yb={};
function Q(a,b,c,d,e,f,g,k){if(Yb.hasOwnProperty(a))throw Error("Function already created: "+a+".");Yb[a]=new Xb(a,b,c,d,!1,e,f,g,k)}Q("boolean",2,!1,!1,function(a,b){return Ob(b,a)},1);Q("ceiling",1,!1,!1,function(a,b){return Math.ceil(N(b,a))},1);Q("concat",3,!1,!1,function(a,b){return sa(ya(arguments,1),function(b,d){return b+O(d,a)},"")},2,null);Q("contains",2,!1,!1,function(a,b,c){b=O(b,a);a=O(c,a);return-1!=b.indexOf(a)},2);Q("count",1,!1,!1,function(a,b){return b.a(a).s},1,1,!0);
Q("false",2,!1,!1,function(){return!1},0);Q("floor",1,!1,!1,function(a,b){return Math.floor(N(b,a))},1);Q("id",4,!1,!1,function(a,b){function c(a){if(B){var b=e.all[a];if(b){if(b.nodeType&&a==b.id)return b;if(b.length)return va(b,function(b){return a==b.id})}return null}return e.getElementById(a)}var d=a.a,e=9==d.nodeType?d:d.ownerDocument,d=O(b,a).split(/\s+/),f=[];q(d,function(a){a=c(a);!a||0<=pa(f,a)||f.push(a)});f.sort(eb);var g=new H;q(f,function(a){I(g,a)});return g},1);
Q("lang",2,!1,!1,function(){return!1},1);Q("last",1,!0,!1,function(a){if(1!=arguments.length)throw Error("Function last expects ()");return a.h},0);Q("local-name",3,!1,!0,function(a,b){var c=b?Ib(b.a(a)):a.a;return c?c.localName||c.nodeName.toLowerCase():""},0,1,!0);Q("name",3,!1,!0,function(a,b){var c=b?Ib(b.a(a)):a.a;return c?c.nodeName.toLowerCase():""},0,1,!0);Q("namespace-uri",3,!0,!1,function(){return""},0,1,!0);
Q("normalize-space",3,!1,!0,function(a,b){return(b?O(b,a):F(a.a)).replace(/[\s\xa0]+/g," ").replace(/^\s+|\s+$/g,"")},0,1);Q("not",2,!1,!1,function(a,b){return!Ob(b,a)},1);Q("number",1,!1,!0,function(a,b){return b?N(b,a):+F(a.a)},0,1);Q("position",1,!0,!1,function(a){return a.b},0);Q("round",1,!1,!1,function(a,b){return Math.round(N(b,a))},1);Q("starts-with",2,!1,!1,function(a,b,c){b=O(b,a);a=O(c,a);return 0==b.lastIndexOf(a,0)},2);Q("string",3,!1,!0,function(a,b){return b?O(b,a):F(a.a)},0,1);
Q("string-length",1,!1,!0,function(a,b){return(b?O(b,a):F(a.a)).length},0,1);Q("substring",3,!1,!1,function(a,b,c,d){c=N(c,a);if(isNaN(c)||Infinity==c||-Infinity==c)return"";d=d?N(d,a):Infinity;if(isNaN(d)||-Infinity===d)return"";c=Math.round(c)-1;var e=Math.max(c,0);a=O(b,a);return Infinity==d?a.substring(e):a.substring(e,c+Math.round(d))},2,3);Q("substring-after",3,!1,!1,function(a,b,c){b=O(b,a);a=O(c,a);c=b.indexOf(a);return-1==c?"":b.substring(c+a.length)},2);
Q("substring-before",3,!1,!1,function(a,b,c){b=O(b,a);a=O(c,a);a=b.indexOf(a);return-1==a?"":b.substring(0,a)},2);Q("sum",1,!1,!1,function(a,b){for(var c=Kb(b.a(a)),d=0,e=K(c);e;e=K(c))d+=+F(e);return d},1,1,!0);Q("translate",3,!1,!1,function(a,b,c,d){b=O(b,a);c=O(c,a);var e=O(d,a);a={};for(d=0;d<c.length;d++){var f=c.charAt(d);f in a||(a[f]=e.charAt(d))}c="";for(d=0;d<b.length;d++)f=b.charAt(d),c+=f in a?a[f]:f;return c},3);Q("true",2,!1,!1,function(){return!0},0);function J(a,b){this.j=a;this.c=void 0!==b?b:null;this.b=null;switch(a){case "comment":this.b=8;break;case "text":this.b=3;break;case "processing-instruction":this.b=7;break;case "node":break;default:throw Error("Unexpected argument");}}function Zb(a){return"comment"==a||"text"==a||"processing-instruction"==a||"node"==a}J.prototype.a=function(a){return null===this.b||this.b==a.nodeType};J.prototype.h=function(){return this.j};
J.prototype.toString=function(){var a="Kind Test: "+this.j;null===this.c||(a+=M(this.c));return a};function $b(a){L.call(this,3);this.c=a.substring(1,a.length-1)}n($b,L);$b.prototype.a=function(){return this.c};$b.prototype.toString=function(){return"Literal: "+this.c};function Bb(a,b){this.o=a.toLowerCase();var c;c="*"==this.o?"*":"http://www.w3.org/1999/xhtml";this.c=b?b.toLowerCase():c}Bb.prototype.a=function(a){var b=a.nodeType;return 1!=b&&2!=b?!1:"*"!=this.o&&this.o!=a.localName.toLowerCase()?!1:"*"==this.c?!0:this.c==(a.namespaceURI?a.namespaceURI.toLowerCase():"http://www.w3.org/1999/xhtml")};Bb.prototype.h=function(){return this.o};Bb.prototype.toString=function(){return"Name Test: "+("http://www.w3.org/1999/xhtml"==this.c?"":this.c+":")+this.o};function ac(a){L.call(this,1);this.c=a}n(ac,L);ac.prototype.a=function(){return this.c};ac.prototype.toString=function(){return"Number: "+this.c};function bc(a,b){L.call(this,a.m);this.j=a;this.c=b;this.i=a.i;this.b=a.b;if(1==this.c.length){var c=this.c[0];c.B||c.c!=cc||(c=c.w,"*"!=c.h()&&(this.h={name:c.h(),A:null}))}}n(bc,L);function dc(){L.call(this,4)}n(dc,L);dc.prototype.a=function(a){var b=new H;a=a.a;9==a.nodeType?I(b,a):I(b,a.ownerDocument);return b};dc.prototype.toString=function(){return"Root Helper Expression"};function ec(){L.call(this,4)}n(ec,L);ec.prototype.a=function(a){var b=new H;I(b,a.a);return b};ec.prototype.toString=function(){return"Context Helper Expression"};
function fc(a){return"/"==a||"//"==a}bc.prototype.a=function(a){var b=this.j.a(a);if(!(b instanceof H))throw Error("Filter expression must evaluate to nodeset.");a=this.c;for(var c=0,d=a.length;c<d&&b.s;c++){var e=a[c],f=Kb(b,e.c.a),g;if(e.i||e.c!=gc)if(e.i||e.c!=hc)for(g=K(f),b=e.a(new pb(g));null!=(g=K(f));)g=e.a(new pb(g)),b=Hb(b,g);else g=K(f),b=e.a(new pb(g));else{for(g=K(f);(b=K(f))&&(!g.contains||g.contains(b))&&b.compareDocumentPosition(g)&8;g=b);b=e.a(new pb(g))}}return b};
bc.prototype.toString=function(){var a;a="Path Expression:"+M(this.j);if(this.c.length){var b=sa(this.c,function(a,b){return a+M(b)},"Steps:");a+=M(b)}return a};function ic(a,b){this.a=a;this.b=!!b}
function Vb(a,b,c){for(c=c||0;c<a.a.length;c++)for(var d=a.a[c],e=Kb(b),f=b.s,g,k=0;g=K(e);k++){var u=a.b?f-k:k+1;g=d.a(new pb(g,u,f));if("number"==typeof g)u=u==g;else if("string"==typeof g||"boolean"==typeof g)u=!!g;else if(g instanceof H)u=0<g.s;else throw Error("Predicate.evaluate returned an unexpected type.");if(!u){u=e;g=u.h;var v=u.a;if(!v)throw Error("Next must be called at least once before remove.");var p=v.b,v=v.a;p?p.a=v:g.a=v;v?v.b=p:g.b=p;g.s--;u.a=null}}return b}
ic.prototype.toString=function(){return sa(this.a,function(a,b){return a+M(b)},"Predicates:")};function jc(a,b,c,d){L.call(this,4);this.c=a;this.w=b;this.j=c||new ic([]);this.B=!!d;b=this.j;b=0<b.a.length?b.a[0].h:null;a.b&&b&&(a=b.name,a=B?a.toLowerCase():a,this.h={name:a,A:b.A});a:{a=this.j;for(b=0;b<a.a.length;b++)if(c=a.a[b],c.i||1==c.m||0==c.m){a=!0;break a}a=!1}this.i=a}n(jc,L);
jc.prototype.a=function(a){var b=a.a,c=null,c=this.h,d=null,e=null,f=0;c&&(d=c.name,e=c.A?O(c.A,a):null,f=1);if(this.B)if(this.i||this.c!=kc)if(a=Kb((new jc(lc,new J("node"))).a(a)),b=K(a))for(c=this.u(b,d,e,f);null!=(b=K(a));)c=Hb(c,this.u(b,d,e,f));else c=new H;else c=yb(this.w,b,d,e),c=Vb(this.j,c,f);else c=this.u(a.a,d,e,f);return c};jc.prototype.u=function(a,b,c,d){a=this.c.h(this.w,a,b,c);return a=Vb(this.j,a,d)};
jc.prototype.toString=function(){var a;a="Step:"+M("Operator: "+(this.B?"//":"/"));this.c.o&&(a+=M("Axis: "+this.c));a+=M(this.w);if(this.j.a.length){var b=sa(this.j.a,function(a,b){return a+M(b)},"Predicates:");a+=M(b)}return a};function mc(a,b,c,d){this.o=a;this.h=b;this.a=c;this.b=d}mc.prototype.toString=function(){return this.o};var nc={};function R(a,b,c,d){if(nc.hasOwnProperty(a))throw Error("Axis already created: "+a);b=new mc(a,b,c,!!d);return nc[a]=b}
R("ancestor",function(a,b){for(var c=new H,d=b;d=d.parentNode;)a.a(d)&&c.unshift(d);return c},!0);R("ancestor-or-self",function(a,b){var c=new H,d=b;do a.a(d)&&c.unshift(d);while(d=d.parentNode);return c},!0);
var cc=R("attribute",function(a,b){var c=new H,d=a.h();if("style"==d&&b.style&&B)return I(c,new rb(b.style,b,"style",b.style.cssText)),c;var e=b.attributes;if(e)if(a instanceof J&&null===a.b||"*"==d)for(var d=0,f;f=e[d];d++)B?f.nodeValue&&I(c,sb(b,f)):I(c,f);else(f=e.getNamedItem(d))&&(B?f.nodeValue&&I(c,sb(b,f)):I(c,f));return c},!1),kc=R("child",function(a,b,c,d,e){return(B?Eb:Fb).call(null,a,b,m(c)?c:null,m(d)?d:null,e||new H)},!1,!0);R("descendant",yb,!1,!0);
var lc=R("descendant-or-self",function(a,b,c,d){var e=new H;G(b,c,d)&&a.a(b)&&I(e,b);return yb(a,b,c,d,e)},!1,!0),gc=R("following",function(a,b,c,d){var e=new H;do for(var f=b;f=f.nextSibling;)G(f,c,d)&&a.a(f)&&I(e,f),e=yb(a,f,c,d,e);while(b=b.parentNode);return e},!1,!0);R("following-sibling",function(a,b){for(var c=new H,d=b;d=d.nextSibling;)a.a(d)&&I(c,d);return c},!1);R("namespace",function(){return new H},!1);
var oc=R("parent",function(a,b){var c=new H;if(9==b.nodeType)return c;if(2==b.nodeType)return I(c,b.ownerElement),c;var d=b.parentNode;a.a(d)&&I(c,d);return c},!1),hc=R("preceding",function(a,b,c,d){var e=new H,f=[];do f.unshift(b);while(b=b.parentNode);for(var g=1,k=f.length;g<k;g++){var u=[];for(b=f[g];b=b.previousSibling;)u.unshift(b);for(var v=0,p=u.length;v<p;v++)b=u[v],G(b,c,d)&&a.a(b)&&I(e,b),e=yb(a,b,c,d,e)}return e},!0,!0);
R("preceding-sibling",function(a,b){for(var c=new H,d=b;d=d.previousSibling;)a.a(d)&&c.unshift(d);return c},!0);var pc=R("self",function(a,b){var c=new H;a.a(b)&&I(c,b);return c},!1);function qc(a){L.call(this,1);this.c=a;this.i=a.i;this.b=a.b}n(qc,L);qc.prototype.a=function(a){return-N(this.c,a)};qc.prototype.toString=function(){return"Unary Expression: -"+M(this.c)};function rc(a){L.call(this,4);this.c=a;Mb(this,ta(this.c,function(a){return a.i}));Nb(this,ta(this.c,function(a){return a.b}))}n(rc,L);rc.prototype.a=function(a){var b=new H;q(this.c,function(c){c=c.a(a);if(!(c instanceof H))throw Error("Path expression must evaluate to NodeSet.");b=Hb(b,c)});return b};rc.prototype.toString=function(){return sa(this.c,function(a,b){return a+M(b)},"Union Expression:")};function sc(a,b){this.a=a;this.b=b}function tc(a){for(var b,c=[];;){S(a,"Missing right hand side of binary expression.");b=uc(a);var d=D(a.a);if(!d)break;var e=(d=Tb[d]||null)&&d.I;if(!e){a.a.a--;break}for(;c.length&&e<=c[c.length-1].I;)b=new Pb(c.pop(),c.pop(),b);c.push(b,d)}for(;c.length;)b=new Pb(c.pop(),c.pop(),b);return b}function S(a,b){if(xb(a.a))throw Error(b);}function vc(a,b){var c=D(a.a);if(c!=b)throw Error("Bad token, expected: "+b+" got: "+c);}
function wc(a){a=D(a.a);if(")"!=a)throw Error("Bad token: "+a);}function xc(a){a=D(a.a);if(2>a.length)throw Error("Unclosed literal string");return new $b(a)}
function yc(a){var b,c=[],d;if(fc(C(a.a))){b=D(a.a);d=C(a.a);if("/"==b&&(xb(a.a)||"."!=d&&".."!=d&&"@"!=d&&"*"!=d&&!/(?![0-9])[\w]/.test(d)))return new dc;d=new dc;S(a,"Missing next location step.");b=zc(a,b);c.push(b)}else{a:{b=C(a.a);d=b.charAt(0);switch(d){case "$":throw Error("Variable reference not allowed in HTML XPath");case "(":D(a.a);b=tc(a);S(a,'unclosed "("');vc(a,")");break;case '"':case "'":b=xc(a);break;default:if(isNaN(+b))if(!Zb(b)&&/(?![0-9])[\w]/.test(d)&&"("==C(a.a,1)){b=D(a.a);
b=Yb[b]||null;D(a.a);for(d=[];")"!=C(a.a);){S(a,"Missing function argument list.");d.push(tc(a));if(","!=C(a.a))break;D(a.a)}S(a,"Unclosed function argument list.");wc(a);b=new Wb(b,d)}else{b=null;break a}else b=new ac(+D(a.a))}"["==C(a.a)&&(d=new ic(Ac(a)),b=new Ub(b,d))}if(b)if(fc(C(a.a)))d=b;else return b;else b=zc(a,"/"),d=new ec,c.push(b)}for(;fc(C(a.a));)b=D(a.a),S(a,"Missing next location step."),b=zc(a,b),c.push(b);return new bc(d,c)}
function zc(a,b){var c,d,e;if("/"!=b&&"//"!=b)throw Error('Step op should be "/" or "//"');if("."==C(a.a))return d=new jc(pc,new J("node")),D(a.a),d;if(".."==C(a.a))return d=new jc(oc,new J("node")),D(a.a),d;var f;if("@"==C(a.a))f=cc,D(a.a),S(a,"Missing attribute name");else if("::"==C(a.a,1)){if(!/(?![0-9])[\w]/.test(C(a.a).charAt(0)))throw Error("Bad token: "+D(a.a));c=D(a.a);f=nc[c]||null;if(!f)throw Error("No axis with name: "+c);D(a.a);S(a,"Missing node name")}else f=kc;c=C(a.a);if(/(?![0-9])[\w\*]/.test(c.charAt(0)))if("("==
C(a.a,1)){if(!Zb(c))throw Error("Invalid node type: "+c);c=D(a.a);if(!Zb(c))throw Error("Invalid type name: "+c);vc(a,"(");S(a,"Bad nodetype");e=C(a.a).charAt(0);var g=null;if('"'==e||"'"==e)g=xc(a);S(a,"Bad nodetype");wc(a);c=new J(c,g)}else if(c=D(a.a),e=c.indexOf(":"),-1==e)c=new Bb(c);else{var g=c.substring(0,e),k;if("*"==g)k="*";else if(k=a.b(g),!k)throw Error("Namespace prefix not declared: "+g);c=c.substr(e+1);c=new Bb(c,k)}else throw Error("Bad token: "+D(a.a));e=new ic(Ac(a),f.a);return d||
new jc(f,c,e,"//"==b)}function Ac(a){for(var b=[];"["==C(a.a);){D(a.a);S(a,"Missing predicate expression.");var c=tc(a);b.push(c);S(a,"Unclosed predicate expression.");vc(a,"]")}return b}function uc(a){if("-"==C(a.a))return D(a.a),new qc(uc(a));var b=yc(a);if("|"!=C(a.a))a=b;else{for(b=[b];"|"==D(a.a);)S(a,"Missing next union location path."),b.push(yc(a));a.a.a--;a=new rc(b)}return a};function Bc(a){switch(a.nodeType){case 1:return ja(Cc,a);case 9:return Bc(a.documentElement);case 11:case 10:case 6:case 12:return Dc;default:return a.parentNode?Bc(a.parentNode):Dc}}function Dc(){return null}function Cc(a,b){if(a.prefix==b)return a.namespaceURI||"http://www.w3.org/1999/xhtml";var c=a.getAttributeNode("xmlns:"+b);return c&&c.specified?c.value||null:a.parentNode&&9!=a.parentNode.nodeType?Cc(a.parentNode,b):null};function Ec(a,b){if(!a.length)throw Error("Empty XPath expression.");var c=ub(a);if(xb(c))throw Error("Invalid XPath expression.");b?"function"==ba(b)||(b=ia(b.lookupNamespaceURI,b)):b=function(){return null};var d=tc(new sc(c,b));if(!xb(c))throw Error("Bad token: "+D(c));this.evaluate=function(a,b){var c=d.a(new pb(a));return new T(c,b)}}
function T(a,b){if(0==b)if(a instanceof H)b=4;else if("string"==typeof a)b=2;else if("number"==typeof a)b=1;else if("boolean"==typeof a)b=3;else throw Error("Unexpected evaluation result.");if(2!=b&&1!=b&&3!=b&&!(a instanceof H))throw Error("value could not be converted to the specified type");this.resultType=b;var c;switch(b){case 2:this.stringValue=a instanceof H?Jb(a):""+a;break;case 1:this.numberValue=a instanceof H?+Jb(a):+a;break;case 3:this.booleanValue=a instanceof H?0<a.s:!!a;break;case 4:case 5:case 6:case 7:var d=
Kb(a);c=[];for(var e=K(d);e;e=K(d))c.push(e instanceof rb?e.a:e);this.snapshotLength=a.s;this.invalidIteratorState=!1;break;case 8:case 9:d=Ib(a);this.singleNodeValue=d instanceof rb?d.a:d;break;default:throw Error("Unknown XPathResult type.");}var f=0;this.iterateNext=function(){if(4!=b&&5!=b)throw Error("iterateNext called with wrong result type");return f>=c.length?null:c[f++]};this.snapshotItem=function(a){if(6!=b&&7!=b)throw Error("snapshotItem called with wrong result type");return a>=c.length||
0>a?null:c[a]}}T.ANY_TYPE=0;T.NUMBER_TYPE=1;T.STRING_TYPE=2;T.BOOLEAN_TYPE=3;T.UNORDERED_NODE_ITERATOR_TYPE=4;T.ORDERED_NODE_ITERATOR_TYPE=5;T.UNORDERED_NODE_SNAPSHOT_TYPE=6;T.ORDERED_NODE_SNAPSHOT_TYPE=7;T.ANY_UNORDERED_NODE_TYPE=8;T.FIRST_ORDERED_NODE_TYPE=9;function Fc(a){this.lookupNamespaceURI=Bc(a)}
function Gc(a,b){var c=a||l,d=c.document;if(!d.evaluate||b)c.XPathResult=T,d.evaluate=function(a,b,c,d){return(new Ec(a,c)).evaluate(b,d)},d.createExpression=function(a,b){return new Ec(a,b)},d.createNSResolver=function(a){return new Fc(a)}}aa("wgxpath.install",Gc);var U={};U.F=function(){var a={S:"http://www.w3.org/2000/svg"};return function(b){return a[b]||null}}();
U.u=function(a,b,c){var d=A(a);if(!d.documentElement)return null;(y||mb)&&Gc(d?d.parentWindow||d.defaultView:window);try{var e=d.createNSResolver?d.createNSResolver(d.documentElement):U.F;if(y&&!Za(7))return d.evaluate.call(d,b,a,e,c,null);if(!y||9<=Number(ab)){for(var f={},g=d.getElementsByTagName("*"),k=0;k<g.length;++k){var u=g[k],v=u.namespaceURI;if(v&&!f[v]){var p=u.lookupPrefix(v);if(!p)var x=v.match(".*/(\\w+)/?$"),p=x?x[1]:"xhtml";f[v]=p}}var E={},ca;for(ca in f)E[f[ca]]=ca;e=function(a){return E[a]||
null}}try{return d.evaluate(b,a,e,c,null)}catch(xa){if("TypeError"===xa.name)return e=d.createNSResolver?d.createNSResolver(d.documentElement):U.F,d.evaluate(b,a,e,c,null);throw xa;}}catch(xa){if(!z||"NS_ERROR_ILLEGAL_VALUE"!=xa.name)throw new Fa(32,"Unable to locate an element with the xpath expression "+b+" because of the following error:\n"+xa);}};U.G=function(a,b){if(!a||1!=a.nodeType)throw new Fa(32,'The result of the xpath expression "'+b+'" is: '+a+". It should be an element.");};
U.K=function(a,b){var c=function(){var c=U.u(b,a,9);return c?c.singleNodeValue||null:b.selectSingleNode?(c=A(b),c.setProperty&&c.setProperty("SelectionLanguage","XPath"),b.selectSingleNode(a)):null}();null===c||U.G(c,a);return c};
U.P=function(a,b){var c=function(){var c=U.u(b,a,7);if(c){for(var e=c.snapshotLength,f=[],g=0;g<e;++g)f.push(c.snapshotItem(g));return f}return b.selectNodes?(c=A(b),c.setProperty&&c.setProperty("SelectionLanguage","XPath"),b.selectNodes(a)):[]}();q(c,function(b){U.G(b,a)});return c};function Hc(a){return(a=a.exec(t))?a[1]:""}var Ic=function(){if(jb)return Hc(/Firefox\/([0-9.]+)/);if(y||Ra||Qa)return Xa;if(nb)return Hc(/Chrome\/([0-9.]+)/);if(ob&&!(Pa()||w("iPad")||w("iPod")))return Hc(/Version\/([0-9.]+)/);if(kb||lb){var a;if(a=/Version\/(\S+).*Mobile\/(\S+)/.exec(t))return a[1]+"."+a[2]}else if(mb)return(a=Hc(/Android\s+([0-9.]+)/))?a:Hc(/Version\/([0-9.]+)/);return""}();var Jc,Kc;function Lc(a){return Mc?Jc(a):y?0<=ma(ab,a):Za(a)}function Nc(a){Mc?Kc(a):mb?ma(Oc,a):ma(Ic,a)}
var Mc=function(){if(!z)return!1;var a=l.Components;if(!a)return!1;try{if(!a.classes)return!1}catch(f){return!1}var b=a.classes,a=a.interfaces,c=b["@mozilla.org/xpcom/version-comparator;1"].getService(a.nsIVersionComparator),b=b["@mozilla.org/xre/app-info;1"].getService(a.nsIXULAppInfo),d=b.platformVersion,e=b.version;Jc=function(a){return 0<=c.compare(d,""+a)};Kc=function(a){c.compare(e,""+a)};return!0}(),Pc;if(mb){var Qc=/Android\s+([0-9\.]+)/.exec(t);Pc=Qc?Qc[1]:"0"}else Pc="0";
var Oc=Pc,Rc=y&&!(9<=Number(ab));mb&&Nc(2.3);mb&&Nc(4);ob&&Nc(6);function Sc(a,b,c,d){this.top=a;this.right=b;this.bottom=c;this.left=d}h=Sc.prototype;h.clone=function(){return new Sc(this.top,this.right,this.bottom,this.left)};h.toString=function(){return"("+this.top+"t, "+this.right+"r, "+this.bottom+"b, "+this.left+"l)"};h.contains=function(a){return this&&a?a instanceof Sc?a.left>=this.left&&a.right<=this.right&&a.top>=this.top&&a.bottom<=this.bottom:a.x>=this.left&&a.x<=this.right&&a.y>=this.top&&a.y<=this.bottom:!1};
h.ceil=function(){this.top=Math.ceil(this.top);this.right=Math.ceil(this.right);this.bottom=Math.ceil(this.bottom);this.left=Math.ceil(this.left);return this};h.floor=function(){this.top=Math.floor(this.top);this.right=Math.floor(this.right);this.bottom=Math.floor(this.bottom);this.left=Math.floor(this.left);return this};h.round=function(){this.top=Math.round(this.top);this.right=Math.round(this.right);this.bottom=Math.round(this.bottom);this.left=Math.round(this.left);return this};
h.scale=function(a,b){var c=ea(b)?b:a;this.left*=a;this.right*=a;this.top*=c;this.bottom*=c;return this};function V(a,b,c,d){this.left=a;this.top=b;this.width=c;this.height=d}h=V.prototype;h.clone=function(){return new V(this.left,this.top,this.width,this.height)};h.toString=function(){return"("+this.left+", "+this.top+" - "+this.width+"w x "+this.height+"h)"};h.contains=function(a){return a instanceof V?this.left<=a.left&&this.left+this.width>=a.left+a.width&&this.top<=a.top&&this.top+this.height>=a.top+a.height:a.x>=this.left&&a.x<=this.left+this.width&&a.y>=this.top&&a.y<=this.top+this.height};
h.ceil=function(){this.left=Math.ceil(this.left);this.top=Math.ceil(this.top);this.width=Math.ceil(this.width);this.height=Math.ceil(this.height);return this};h.floor=function(){this.left=Math.floor(this.left);this.top=Math.floor(this.top);this.width=Math.floor(this.width);this.height=Math.floor(this.height);return this};h.round=function(){this.left=Math.round(this.left);this.top=Math.round(this.top);this.width=Math.round(this.width);this.height=Math.round(this.height);return this};
h.scale=function(a,b){var c=ea(b)?b:a;this.left*=a;this.width*=a;this.top*=c;this.height*=c;return this};function W(a,b){return!!a&&1==a.nodeType&&(!b||a.tagName.toUpperCase()==b)}function Tc(a){for(a=a.parentNode;a&&1!=a.nodeType&&9!=a.nodeType&&11!=a.nodeType;)a=a.parentNode;return W(a)?a:null}
function X(a,b){var c=oa(b);if("float"==c||"cssFloat"==c||"styleFloat"==c)c=Rc?"styleFloat":"cssFloat";var d;a:{d=c;var e=A(a);if(e.defaultView&&e.defaultView.getComputedStyle&&(e=e.defaultView.getComputedStyle(a,null))){d=e[d]||e.getPropertyValue(d)||"";break a}d=""}d=d||Uc(a,c);if(null===d)d=null;else if(0<=pa(Aa,c)){b:{var f=d.match(Da);if(f){var c=Number(f[1]),e=Number(f[2]),g=Number(f[3]),f=Number(f[4]);if(0<=c&&255>=c&&0<=e&&255>=e&&0<=g&&255>=g&&0<=f&&1>=f){c=[c,e,g,f];break b}}c=null}if(!c)b:{if(g=
d.match(Ea))if(c=Number(g[1]),e=Number(g[2]),g=Number(g[3]),0<=c&&255>=c&&0<=e&&255>=e&&0<=g&&255>=g){c=[c,e,g,1];break b}c=null}if(!c)b:{c=d.toLowerCase();e=za[c.toLowerCase()];if(!e&&(e="#"==c.charAt(0)?c:"#"+c,4==e.length&&(e=e.replace(Ba,"#$1$1$2$2$3$3")),!Ca.test(e))){c=null;break b}c=[parseInt(e.substr(1,2),16),parseInt(e.substr(3,2),16),parseInt(e.substr(5,2),16),1]}d=c?"rgba("+c.join(", ")+")":d}return d}
function Uc(a,b){var c=a.currentStyle||a.style,d=c[b];void 0===d&&"function"==ba(c.getPropertyValue)&&(d=c.getPropertyValue(b));return"inherit"!=d?void 0!==d?d:null:(c=Tc(a))?Uc(c,b):null}
function Vc(a,b,c){function d(a){var b=Wc(a);return 0<b.height&&0<b.width?!0:W(a,"PATH")&&(0<b.height||0<b.width)?(a=X(a,"stroke-width"),!!a&&0<parseInt(a,10)):"hidden"!=X(a,"overflow")&&ta(a.childNodes,function(a){return 3==a.nodeType||W(a)&&d(a)})}function e(a){return Xc(a)==Y&&ua(a.childNodes,function(a){return!W(a)||e(a)||!d(a)})}if(!W(a))throw Error("Argument to isShown must be of type Element");if(W(a,"BODY"))return!0;if(W(a,"OPTION")||W(a,"OPTGROUP"))return a=hb(a,function(a){return W(a,"SELECT")}),
!!a&&Vc(a,!0,c);var f=Yc(a);if(f)return!!f.H&&0<f.rect.width&&0<f.rect.height&&Vc(f.H,b,c);if(W(a,"INPUT")&&"hidden"==a.type.toLowerCase()||W(a,"NOSCRIPT"))return!1;f=X(a,"visibility");return"collapse"!=f&&"hidden"!=f&&c(a)&&(b||0!=Zc(a))&&d(a)?!e(a):!1}function $c(a,b){function c(a){if("none"==X(a,"display"))return!1;a=Tc(a);return!a||c(a)}return Vc(a,!!b,c)}var Y="hidden";
function Xc(a){function b(a){function b(a){return a==g?!0:0==X(a,"display").lastIndexOf("inline",0)||"absolute"==c&&"static"==X(a,"position")?!1:!0}var c=X(a,"position");if("fixed"==c)return v=!0,a==g?null:g;for(a=Tc(a);a&&!b(a);)a=Tc(a);return a}function c(a){var b=a;if("visible"==u)if(a==g&&k)b=k;else if(a==k)return{x:"visible",y:"visible"};b={x:X(b,"overflow-x"),y:X(b,"overflow-y")};a==g&&(b.x="visible"==b.x?"auto":b.x,b.y="visible"==b.y?"auto":b.y);return b}function d(a){if(a==g){var b=(new ib(f)).a;
a=b.scrollingElement?b.scrollingElement:Sa||"CSS1Compat"!=b.compatMode?b.body||b.documentElement:b.documentElement;b=b.parentWindow||b.defaultView;a=y&&Za("10")&&b.pageYOffset!=a.scrollTop?new bb(a.scrollLeft,a.scrollTop):new bb(b.pageXOffset||a.scrollLeft,b.pageYOffset||a.scrollTop)}else a=new bb(a.scrollLeft,a.scrollTop);return a}var e=ad(a),f=A(a),g=f.documentElement,k=f.body,u=X(g,"overflow"),v;for(a=b(a);a;a=b(a)){var p=c(a);if("visible"!=p.x||"visible"!=p.y){var x=Wc(a);if(0==x.width||0==x.height)return Y;
var E=e.right<x.left,ca=e.bottom<x.top;if(E&&"hidden"==p.x||ca&&"hidden"==p.y)return Y;if(E&&"visible"!=p.x||ca&&"visible"!=p.y){E=d(a);ca=e.bottom<x.top-E.y;if(e.right<x.left-E.x&&"visible"!=p.x||ca&&"visible"!=p.x)return Y;e=Xc(a);return e==Y?Y:"scroll"}E=e.left>=x.left+x.width;x=e.top>=x.top+x.height;if(E&&"hidden"==p.x||x&&"hidden"==p.y)return Y;if(E&&"visible"!=p.x||x&&"visible"!=p.y){if(v&&(p=d(a),e.left>=g.scrollWidth-p.x||e.right>=g.scrollHeight-p.y))return Y;e=Xc(a);return e==Y?Y:"scroll"}}}return"none"}
function Wc(a){var b=Yc(a);if(b)return b.rect;if(W(a,"HTML"))return a=A(a),a=((a?a.parentWindow||a.defaultView:window)||window).document,a="CSS1Compat"==a.compatMode?a.documentElement:a.body,a=new cb(a.clientWidth,a.clientHeight),new V(0,0,a.width,a.height);var c;try{c=a.getBoundingClientRect()}catch(d){return new V(0,0,0,0)}b=new V(c.left,c.top,c.right-c.left,c.bottom-c.top);y&&a.ownerDocument.body&&(a=A(a),b.left-=a.documentElement.clientLeft+a.body.clientLeft,b.top-=a.documentElement.clientTop+
a.body.clientTop);return b}function Yc(a){var b=W(a,"MAP");if(!b&&!W(a,"AREA"))return null;var c=b?a:W(a.parentNode,"MAP")?a.parentNode:null,d=null,e=null;c&&c.name&&(d=U.K('/descendant::*[@usemap = "#'+c.name+'"]',A(c)))&&(e=Wc(d),b||"default"==a.shape.toLowerCase()||(a=bd(a),b=Math.min(Math.max(a.left,0),e.width),c=Math.min(Math.max(a.top,0),e.height),e=new V(b+e.left,c+e.top,Math.min(a.width,e.width-b),Math.min(a.height,e.height-c))));return{H:d,rect:e||new V(0,0,0,0)}}
function bd(a){var b=a.shape.toLowerCase();a=a.coords.split(",");if("rect"==b&&4==a.length){var b=a[0],c=a[1];return new V(b,c,a[2]-b,a[3]-c)}if("circle"==b&&3==a.length)return b=a[2],new V(a[0]-b,a[1]-b,2*b,2*b);if("poly"==b&&2<a.length){for(var b=a[0],c=a[1],d=b,e=c,f=2;f+1<a.length;f+=2)b=Math.min(b,a[f]),d=Math.max(d,a[f]),c=Math.min(c,a[f+1]),e=Math.max(e,a[f+1]);return new V(b,c,d-b,e-c)}return new V(0,0,0,0)}function ad(a){a=Wc(a);return new Sc(a.top,a.left+a.width,a.top+a.height,a.left)}
function Zc(a){if(Rc){if("relative"==X(a,"position"))return 1;a=X(a,"filter");return(a=a.match(/^alpha\(opacity=(\d*)\)/)||a.match(/^progid:DXImageTransform.Microsoft.Alpha\(Opacity=(\d*)\)/))?Number(a[1])/100:1}return cd(a)}function cd(a){var b=1,c=X(a,"opacity");c&&(b=Number(c));(a=Tc(a))&&(b*=cd(a));return b};Sa||Mc&&Nc(3.6);y&&Lc(10);mb&&Nc(4);function dd(a,b){this.v={};this.l=[];this.b=this.a=0;var c=arguments.length;if(1<c){if(c%2)throw Error("Uneven number of arguments");for(var d=0;d<c;d+=2)ed(this,arguments[d],arguments[d+1])}else if(a){var e;if(a instanceof dd)for(d=fd(a),gd(a),e=[],c=0;c<a.l.length;c++)e.push(a.v[a.l[c]]);else{var c=[],f=0;for(d in a)c[f++]=d;d=c;c=[];f=0;for(e in a)c[f++]=a[e];e=c}for(c=0;c<d.length;c++)ed(this,d[c],e[c])}}function fd(a){gd(a);return a.l.concat()}
dd.prototype.clear=function(){this.v={};this.b=this.a=this.l.length=0};function gd(a){if(a.a!=a.l.length){for(var b=0,c=0;b<a.l.length;){var d=a.l[b];Object.prototype.hasOwnProperty.call(a.v,d)&&(a.l[c++]=d);b++}a.l.length=c}if(a.a!=a.l.length){for(var e={},c=b=0;b<a.l.length;)d=a.l[b],Object.prototype.hasOwnProperty.call(e,d)||(a.l[c++]=d,e[d]=1),b++;a.l.length=c}}dd.prototype.get=function(a,b){return Object.prototype.hasOwnProperty.call(this.v,a)?this.v[a]:b};
function ed(a,b,c){Object.prototype.hasOwnProperty.call(a.v,b)||(a.a++,a.l.push(b),a.b++);a.v[b]=c}dd.prototype.forEach=function(a,b){for(var c=fd(this),d=0;d<c.length;d++){var e=c[d],f=this.get(e);a.call(b,f,e,this)}};dd.prototype.clone=function(){return new dd(this)};var hd={};function Z(a,b,c){fa(a)&&(a=z?a.f:a.g);a=new id(a);!b||b in hd&&!c||(hd[b]={key:a,shift:!1},c&&(hd[c]={key:a,shift:!0}));return a}function id(a){this.code=a}Z(8);Z(9);Z(13);var jd=Z(16),kd=Z(17),ld=Z(18);Z(19);Z(20);Z(27);Z(32," ");Z(33);Z(34);Z(35);Z(36);Z(37);Z(38);Z(39);Z(40);Z(44);Z(45);Z(46);Z(48,"0",")");Z(49,"1","!");Z(50,"2","@");Z(51,"3","#");Z(52,"4","$");Z(53,"5","%");Z(54,"6","^");Z(55,"7","&");Z(56,"8","*");Z(57,"9","(");Z(65,"a","A");Z(66,"b","B");Z(67,"c","C");Z(68,"d","D");
Z(69,"e","E");Z(70,"f","F");Z(71,"g","G");Z(72,"h","H");Z(73,"i","I");Z(74,"j","J");Z(75,"k","K");Z(76,"l","L");Z(77,"m","M");Z(78,"n","N");Z(79,"o","O");Z(80,"p","P");Z(81,"q","Q");Z(82,"r","R");Z(83,"s","S");Z(84,"t","T");Z(85,"u","U");Z(86,"v","V");Z(87,"w","W");Z(88,"x","X");Z(89,"y","Y");Z(90,"z","Z");var md=Z(Ua?{f:91,g:91}:Ta?{f:224,g:91}:{f:0,g:91});Z(Ua?{f:92,g:92}:Ta?{f:224,g:93}:{f:0,g:92});Z(Ua?{f:93,g:93}:Ta?{f:0,g:0}:{f:93,g:null});Z({f:96,g:96},"0");Z({f:97,g:97},"1");
Z({f:98,g:98},"2");Z({f:99,g:99},"3");Z({f:100,g:100},"4");Z({f:101,g:101},"5");Z({f:102,g:102},"6");Z({f:103,g:103},"7");Z({f:104,g:104},"8");Z({f:105,g:105},"9");Z({f:106,g:106},"*");Z({f:107,g:107},"+");Z({f:109,g:109},"-");Z({f:110,g:110},".");Z({f:111,g:111},"/");Z(144);Z(112);Z(113);Z(114);Z(115);Z(116);Z(117);Z(118);Z(119);Z(120);Z(121);Z(122);Z(123);Z({f:107,g:187},"=","+");Z(108,",");Z({f:109,g:189},"-","_");Z(188,",","<");Z(190,".",">");Z(191,"/","?");Z(192,"`","~");Z(219,"[","{");
Z(220,"\\","|");Z(221,"]","}");Z({f:59,g:186},";",":");Z(222,"'",'"');var nd=new dd;ed(nd,1,jd);ed(nd,2,kd);ed(nd,4,ld);ed(nd,8,md);(function(a){var b=new dd;q(fd(a),function(c){ed(b,a.get(c).code,c)});return b})(nd);z&&Lc(12);function od(){}
function pd(a,b,c){if(null==b)c.push("null");else{if("object"==typeof b){if("array"==ba(b)){var d=b;b=d.length;c.push("[");for(var e="",f=0;f<b;f++)c.push(e),pd(a,d[f],c),e=",";c.push("]");return}if(b instanceof String||b instanceof Number||b instanceof Boolean)b=b.valueOf();else{c.push("{");e="";for(d in b)Object.prototype.hasOwnProperty.call(b,d)&&(f=b[d],"function"!=typeof f&&(c.push(e),qd(d,c),c.push(":"),pd(a,f,c),e=","));c.push("}");return}}switch(typeof b){case "string":qd(b,c);break;case "number":c.push(isFinite(b)&&
!isNaN(b)?String(b):"null");break;case "boolean":c.push(String(b));break;case "function":c.push("null");break;default:throw Error("Unknown type: "+typeof b);}}}var rd={'"':'\\"',"\\":"\\\\","/":"\\/","\b":"\\b","\f":"\\f","\n":"\\n","\r":"\\r","\t":"\\t","\x0B":"\\u000b"},sd=/\uffff/.test("\uffff")?/[\\\"\x00-\x1f\x7f-\uffff]/g:/[\\\"\x00-\x1f\x7f-\xff]/g;
function qd(a,b){b.push('"',a.replace(sd,function(a){var b=rd[a];b||(b="\\u"+(a.charCodeAt(0)|65536).toString(16).substr(1),rd[a]=b);return b}),'"')};Sa||z&&Lc(3.5)||y&&Lc(8);function td(a){switch(ba(a)){case "string":case "number":case "boolean":return a;case "function":return a.toString();case "array":return ra(a,td);case "object":if(La(a,"nodeType")&&(1==a.nodeType||9==a.nodeType)){var b={};b.ELEMENT=ud(a);return b}if(La(a,"document"))return b={},b.WINDOW=ud(a),b;if(da(a))return ra(a,td);a=Ja(a,function(a,b){return ea(b)||m(b)});return Ka(a,td);default:return null}}
function vd(a,b){return"array"==ba(a)?ra(a,function(a){return vd(a,b)}):fa(a)?"function"==typeof a?a:La(a,"ELEMENT")?wd(a.ELEMENT,b):La(a,"WINDOW")?wd(a.WINDOW,b):Ka(a,function(a){return vd(a,b)}):a}function xd(a){a=a||document;var b=a.$wdc_;b||(b=a.$wdc_={},b.C=ka());b.C||(b.C=ka());return b}function ud(a){var b=xd(a.ownerDocument),c=Ma(b,function(b){return b==a});c||(c=":wdc:"+b.C++,b[c]=a);return c}
function wd(a,b){a=decodeURIComponent(a);var c=b||document,d=xd(c);if(!La(d,a))throw new Fa(10,"Element does not exist in cache");var e=d[a];if(La(e,"setInterval")){if(e.closed)throw delete d[a],new Fa(23,"Window has been closed.");return e}for(var f=e;f;){if(f==c.documentElement)return e;f=f.parentNode}delete d[a];throw new Fa(10,"Element is no longer attached to the DOM");};aa("_",function(a,b){var c=[a,!0],d;try{var e;b?e=wd(b.WINDOW):e=window;var f=vd(c,e.document),g=$c.apply(null,f);d={status:0,value:td(g)}}catch(k){d={status:La(k,"code")?k.code:13,value:{message:k.message}}}c=[];pd(new od,d,c);return c.join("")});; return this._.apply(null,arguments);}.apply({navigator:typeof window!=undefined?window.navigator:null,document:typeof window!=undefined?window.document:null}, arguments);}
