function(){return function(){var g=this;function aa(a,b){var c=a.split("."),d=g;c[0]in d||!d.execScript||d.execScript("var "+c[0]);for(var e;c.length&&(e=c.shift());)c.length||void 0===b?d[e]?d=d[e]:d=d[e]={}:d[e]=b}
function ba(a){var b=typeof a;if("object"==b)if(a){if(a instanceof Array)return"array";if(a instanceof Object)return b;var c=Object.prototype.toString.call(a);if("[object Window]"==c)return"object";if("[object Array]"==c||"number"==typeof a.length&&"undefined"!=typeof a.splice&&"undefined"!=typeof a.propertyIsEnumerable&&!a.propertyIsEnumerable("splice"))return"array";if("[object Function]"==c||"undefined"!=typeof a.call&&"undefined"!=typeof a.propertyIsEnumerable&&!a.propertyIsEnumerable("call"))return"function"}else return"null";
else if("function"==b&&"undefined"==typeof a.call)return"object";return b}function ca(a){var b=ba(a);return"array"==b||"object"==b&&"number"==typeof a.length}function l(a){return"string"==typeof a}function da(a){var b=typeof a;return"object"==b&&null!=a||"function"==b}function ea(a,b,c){return a.call.apply(a.bind,arguments)}
function ha(a,b,c){if(!a)throw Error();if(2<arguments.length){var d=Array.prototype.slice.call(arguments,2);return function(){var c=Array.prototype.slice.call(arguments);Array.prototype.unshift.apply(c,d);return a.apply(b,c)}}return function(){return a.apply(b,arguments)}}function ia(a,b,c){ia=Function.prototype.bind&&-1!=Function.prototype.bind.toString().indexOf("native code")?ea:ha;return ia.apply(null,arguments)}
function ja(a,b){var c=Array.prototype.slice.call(arguments,1);return function(){var b=c.slice();b.push.apply(b,arguments);return a.apply(this,b)}}var ka=Date.now||function(){return+new Date};function m(a,b){function c(){}c.prototype=b.prototype;a.L=b.prototype;a.prototype=new c;a.prototype.constructor=a;a.K=function(a,c,f){for(var h=Array(arguments.length-2),k=2;k<arguments.length;k++)h[k-2]=arguments[k];return b.prototype[c].apply(a,h)}};var n=window;var la=String.prototype.trim?function(a){return a.trim()}:function(a){return a.replace(/^[\s\xa0]+|[\s\xa0]+$/g,"")};
function ma(a,b){for(var c=0,d=la(String(a)).split("."),e=la(String(b)).split("."),f=Math.max(d.length,e.length),h=0;0==c&&h<f;h++){var k=d[h]||"",v=e[h]||"",C=RegExp("(\\d*)(\\D*)","g"),O=RegExp("(\\d*)(\\D*)","g");do{var fa=C.exec(k)||["","",""],ga=O.exec(v)||["","",""];if(0==fa[0].length&&0==ga[0].length)break;c=na(0==fa[1].length?0:parseInt(fa[1],10),0==ga[1].length?0:parseInt(ga[1],10))||na(0==fa[2].length,0==ga[2].length)||na(fa[2],ga[2])}while(0==c)}return c}
function na(a,b){return a<b?-1:a>b?1:0};function p(a,b){for(var c=a.length,d=l(a)?a.split(""):a,e=0;e<c;e++)e in d&&b.call(void 0,d[e],e,a)}function oa(a,b){for(var c=a.length,d=[],e=0,f=l(a)?a.split(""):a,h=0;h<c;h++)if(h in f){var k=f[h];b.call(void 0,k,h,a)&&(d[e++]=k)}return d}function pa(a,b){for(var c=a.length,d=Array(c),e=l(a)?a.split(""):a,f=0;f<c;f++)f in e&&(d[f]=b.call(void 0,e[f],f,a));return d}function q(a,b,c){var d=c;p(a,function(c,f){d=b.call(void 0,d,c,f,a)});return d}
function qa(a,b){for(var c=a.length,d=l(a)?a.split(""):a,e=0;e<c;e++)if(e in d&&b.call(void 0,d[e],e,a))return!0;return!1}function ra(a,b){var c;a:{c=a.length;for(var d=l(a)?a.split(""):a,e=0;e<c;e++)if(e in d&&b.call(void 0,d[e],e,a)){c=e;break a}c=-1}return 0>c?null:l(a)?a.charAt(c):a[c]}function sa(a){return Array.prototype.concat.apply(Array.prototype,arguments)}function ta(a,b,c){return 2>=arguments.length?Array.prototype.slice.call(a,b):Array.prototype.slice.call(a,b,c)};function ua(a,b){this.code=a;this.a=r[a]||va;this.message=b||"";var c=this.a.replace(/((?:^|\s+)[a-z])/g,function(a){return a.toUpperCase().replace(/^[\s\xa0]+/g,"")}),d=c.length-5;if(0>d||c.indexOf("Error",d)!=d)c+="Error";this.name=c;c=Error(this.message);c.name=this.name;this.stack=c.stack||""}m(ua,Error);var va="unknown error",r={15:"element not selectable",11:"element not visible"};r[31]=va;r[30]=va;r[24]="invalid cookie domain";r[29]="invalid element coordinates";r[12]="invalid element state";
r[32]="invalid selector";r[51]="invalid selector";r[52]="invalid selector";r[17]="javascript error";r[405]="unsupported operation";r[34]="move target out of bounds";r[27]="no such alert";r[7]="no such element";r[8]="no such frame";r[23]="no such window";r[28]="script timeout";r[33]="session not created";r[10]="stale element reference";r[21]="timeout";r[25]="unable to set cookie";r[26]="unexpected alert open";r[13]=va;r[9]="unknown command";ua.prototype.toString=function(){return this.name+": "+this.message};var t;a:{var wa=g.navigator;if(wa){var xa=wa.userAgent;if(xa){t=xa;break a}}t=""}function u(a){return-1!=t.indexOf(a)};function ya(a,b){var c={},d;for(d in a)b.call(void 0,a[d],d,a)&&(c[d]=a[d]);return c}function za(a,b){var c={},d;for(d in a)c[d]=b.call(void 0,a[d],d,a);return c}function w(a,b){return null!==a&&b in a}function Aa(a,b){for(var c in a)if(b.call(void 0,a[c],c,a))return c};function Ba(){return u("Opera")||u("OPR")}function Ca(){return(u("Chrome")||u("CriOS"))&&!Ba()&&!u("Edge")};function Da(){return u("iPhone")&&!u("iPod")&&!u("iPad")};var Ea=Ba(),x=u("Trident")||u("MSIE"),Fa=u("Edge"),y=u("Gecko")&&!(-1!=t.toLowerCase().indexOf("webkit")&&!u("Edge"))&&!(u("Trident")||u("MSIE"))&&!u("Edge"),Ga=-1!=t.toLowerCase().indexOf("webkit")&&!u("Edge"),Ha=u("Macintosh"),Ia=u("Windows");function Ja(){var a=t;if(y)return/rv\:([^\);]+)(\)|;)/.exec(a);if(Fa)return/Edge\/([\d\.]+)/.exec(a);if(x)return/\b(?:MSIE|rv)[: ]([^\);]+)(\)|;)/.exec(a);if(Ga)return/WebKit\/(\S+)/.exec(a)}function Ka(){var a=g.document;return a?a.documentMode:void 0}
var La=function(){if(Ea&&g.opera){var a;var b=g.opera.version;try{a=b()}catch(c){a=b}return a}a="";(b=Ja())&&(a=b?b[1]:"");return x&&(b=Ka(),null!=b&&b>parseFloat(a))?String(b):a}(),Ma={};function Na(a){return Ma[a]||(Ma[a]=0<=ma(La,a))}var Oa=g.document,Pa=Oa&&x?Ka()||("CSS1Compat"==Oa.compatMode?parseInt(La,10):5):void 0;!y&&!x||x&&9<=Number(Pa)||y&&Na("1.9.1");x&&Na("9");function Qa(a,b){if(!a||!b)return!1;if(a.contains&&1==b.nodeType)return a==b||a.contains(b);if("undefined"!=typeof a.compareDocumentPosition)return a==b||!!(a.compareDocumentPosition(b)&16);for(;b&&a!=b;)b=b.parentNode;return b==a}
function Ra(a,b){if(a==b)return 0;if(a.compareDocumentPosition)return a.compareDocumentPosition(b)&2?1:-1;if(x&&!(9<=Number(Pa))){if(9==a.nodeType)return-1;if(9==b.nodeType)return 1}if("sourceIndex"in a||a.parentNode&&"sourceIndex"in a.parentNode){var c=1==a.nodeType,d=1==b.nodeType;if(c&&d)return a.sourceIndex-b.sourceIndex;var e=a.parentNode,f=b.parentNode;return e==f?Sa(a,b):!c&&Qa(e,b)?-1*Ta(a,b):!d&&Qa(f,a)?Ta(b,a):(c?a.sourceIndex:e.sourceIndex)-(d?b.sourceIndex:f.sourceIndex)}d=9==a.nodeType?
a:a.ownerDocument||a.document;c=d.createRange();c.selectNode(a);c.collapse(!0);d=d.createRange();d.selectNode(b);d.collapse(!0);return c.compareBoundaryPoints(g.Range.START_TO_END,d)}function Ta(a,b){var c=a.parentNode;if(c==b)return-1;for(var d=b;d.parentNode!=c;)d=d.parentNode;return Sa(d,a)}function Sa(a,b){for(var c=b;c=c.previousSibling;)if(c==a)return-1;return 1};var Ua=u("Firefox"),Va=Da()||u("iPod"),Wa=u("iPad"),z=u("Android")&&!(Ca()||u("Firefox")||Ba()||u("Silk")),Xa=Ca(),Ya=u("Safari")&&!(Ca()||u("Coast")||Ba()||u("Edge")||u("Silk")||u("Android"))&&!(Da()||u("iPad")||u("iPod"));/*

 The MIT License

 Copyright (c) 2007 Cybozu Labs, Inc.
 Copyright (c) 2012 Google Inc.

 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to
 deal in the Software without restriction, including without limitation the
 rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
 sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in
 all copies or substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 IN THE SOFTWARE.
*/
function Za(a,b,c){this.a=a;this.b=b||1;this.h=c||1};var A=x&&!(9<=Number(Pa)),$a=x&&!(8<=Number(Pa));function ab(a,b,c,d){this.a=a;this.nodeName=c;this.nodeValue=d;this.nodeType=2;this.parentNode=this.ownerElement=b}function bb(a,b){var c=$a&&"href"==b.nodeName?a.getAttribute(b.nodeName,2):b.nodeValue;return new ab(b,a,b.nodeName,c)};function cb(a){this.b=a;this.a=0}function db(a){a=a.match(eb);for(var b=0;b<a.length;b++)fb.test(a[b])&&a.splice(b,1);return new cb(a)}var eb=RegExp("\\$?(?:(?![0-9-\\.])(?:\\*|[\\w-\\.]+):)?(?![0-9-\\.])(?:\\*|[\\w-\\.]+)|\\/\\/|\\.\\.|::|\\d+(?:\\.\\d*)?|\\.\\d+|\"[^\"]*\"|'[^']*'|[!<>]=|\\s+|.","g"),fb=/^\s/;function B(a,b){return a.b[a.a+(b||0)]}function D(a){return a.b[a.a++]}function gb(a){return a.b.length<=a.a};function E(a){var b=null,c=a.nodeType;1==c&&(b=a.textContent,b=void 0==b||null==b?a.innerText:b,b=void 0==b||null==b?"":b);if("string"!=typeof b)if(A&&"title"==a.nodeName.toLowerCase()&&1==c)b=a.text;else if(9==c||1==c){a=9==c?a.documentElement:a.firstChild;for(var c=0,d=[],b="";a;){do 1!=a.nodeType&&(b+=a.nodeValue),A&&"title"==a.nodeName.toLowerCase()&&(b+=a.text),d[c++]=a;while(a=a.firstChild);for(;c&&!(a=d[--c].nextSibling););}}else b=a.nodeValue;return""+b}
function F(a,b,c){if(null===b)return!0;try{if(!a.getAttribute)return!1}catch(d){return!1}$a&&"class"==b&&(b="className");return null==c?!!a.getAttribute(b):a.getAttribute(b,2)==c}function hb(a,b,c,d,e){return(A?ib:jb).call(null,a,b,l(c)?c:null,l(d)?d:null,e||new G)}
function ib(a,b,c,d,e){if(a instanceof H||8==a.b||c&&null===a.b){var f=b.all;if(!f)return e;a=kb(a);if("*"!=a&&(f=b.getElementsByTagName(a),!f))return e;if(c){for(var h=[],k=0;b=f[k++];)F(b,c,d)&&h.push(b);f=h}for(k=0;b=f[k++];)"*"==a&&"!"==b.tagName||I(e,b);return e}lb(a,b,c,d,e);return e}
function jb(a,b,c,d,e){b.getElementsByName&&d&&"name"==c&&!x?(b=b.getElementsByName(d),p(b,function(b){a.a(b)&&I(e,b)})):b.getElementsByClassName&&d&&"class"==c?(b=b.getElementsByClassName(d),p(b,function(b){b.className==d&&a.a(b)&&I(e,b)})):a instanceof J?lb(a,b,c,d,e):b.getElementsByTagName&&(b=b.getElementsByTagName(a.h()),p(b,function(a){F(a,c,d)&&I(e,a)}));return e}
function mb(a,b,c,d,e){var f;if((a instanceof H||8==a.b||c&&null===a.b)&&(f=b.childNodes)){var h=kb(a);if("*"!=h&&(f=oa(f,function(a){return a.tagName&&a.tagName.toLowerCase()==h}),!f))return e;c&&(f=oa(f,function(a){return F(a,c,d)}));p(f,function(a){"*"==h&&("!"==a.tagName||"*"==h&&1!=a.nodeType)||I(e,a)});return e}return nb(a,b,c,d,e)}function nb(a,b,c,d,e){for(b=b.firstChild;b;b=b.nextSibling)F(b,c,d)&&a.a(b)&&I(e,b);return e}
function lb(a,b,c,d,e){for(b=b.firstChild;b;b=b.nextSibling)F(b,c,d)&&a.a(b)&&I(e,b),lb(a,b,c,d,e)}function kb(a){if(a instanceof J){if(8==a.b)return"!";if(null===a.b)return"*"}return a.h()};function G(){this.b=this.a=null;this.s=0}function ob(a){this.node=a;this.a=this.b=null}function pb(a,b){if(!a.a)return b;if(!b.a)return a;for(var c=a.a,d=b.a,e=null,f=null,h=0;c&&d;){var f=c.node,k=d.node;f==k||f instanceof ab&&k instanceof ab&&f.a==k.a?(f=c,c=c.a,d=d.a):0<Ra(c.node,d.node)?(f=d,d=d.a):(f=c,c=c.a);(f.b=e)?e.a=f:a.a=f;e=f;h++}for(f=c||d;f;)f.b=e,e=e.a=f,h++,f=f.a;a.b=e;a.s=h;return a}
G.prototype.unshift=function(a){a=new ob(a);a.a=this.a;this.b?this.a.b=a:this.a=this.b=a;this.a=a;this.s++};function I(a,b){var c=new ob(b);c.b=a.b;a.a?a.b.a=c:a.a=a.b=c;a.b=c;a.s++}function qb(a){return(a=a.a)?a.node:null}function rb(a){return(a=qb(a))?E(a):""}function K(a,b){return new sb(a,!!b)}function sb(a,b){this.h=a;this.b=(this.c=b)?a.b:a.a;this.a=null}function L(a){var b=a.b;if(null==b)return null;var c=a.a=b;a.b=a.c?b.b:b.a;return c.node};function M(a){this.m=a;this.b=this.i=!1;this.h=null}function N(a){return"\n  "+a.toString().split("\n").join("\n  ")}function tb(a,b){a.i=b}function ub(a,b){a.b=b}function P(a,b){var c=a.a(b);return c instanceof G?+rb(c):+c}function Q(a,b){var c=a.a(b);return c instanceof G?rb(c):""+c}function vb(a,b){var c=a.a(b);return c instanceof G?!!c.s:!!c};function wb(a,b,c){M.call(this,a.m);this.c=a;this.j=b;this.w=c;this.i=b.i||c.i;this.b=b.b||c.b;this.c==xb&&(c.b||c.i||4==c.m||0==c.m||!b.h?b.b||b.i||4==b.m||0==b.m||!c.h||(this.h={name:c.h.name,A:b}):this.h={name:b.h.name,A:c})}m(wb,M);
function yb(a,b,c,d,e){b=b.a(d);c=c.a(d);var f;if(b instanceof G&&c instanceof G){b=K(b);for(d=L(b);d;d=L(b))for(e=K(c),f=L(e);f;f=L(e))if(a(E(d),E(f)))return!0;return!1}if(b instanceof G||c instanceof G){b instanceof G?(e=b,d=c):(e=c,d=b);f=K(e);for(var h=typeof d,k=L(f);k;k=L(f)){switch(h){case "number":k=+E(k);break;case "boolean":k=!!E(k);break;case "string":k=E(k);break;default:throw Error("Illegal primitive type for comparison.");}if(e==b&&a(k,d)||e==c&&a(d,k))return!0}return!1}return e?"boolean"==
typeof b||"boolean"==typeof c?a(!!b,!!c):"number"==typeof b||"number"==typeof c?a(+b,+c):a(b,c):a(+b,+c)}wb.prototype.a=function(a){return this.c.v(this.j,this.w,a)};wb.prototype.toString=function(){var a="Binary Expression: "+this.c,a=a+N(this.j);return a+=N(this.w)};function zb(a,b,c,d){this.a=a;this.F=b;this.m=c;this.v=d}zb.prototype.toString=function(){return this.a};var Ab={};
function R(a,b,c,d){if(Ab.hasOwnProperty(a))throw Error("Binary operator already created: "+a);a=new zb(a,b,c,d);return Ab[a.toString()]=a}R("div",6,1,function(a,b,c){return P(a,c)/P(b,c)});R("mod",6,1,function(a,b,c){return P(a,c)%P(b,c)});R("*",6,1,function(a,b,c){return P(a,c)*P(b,c)});R("+",5,1,function(a,b,c){return P(a,c)+P(b,c)});R("-",5,1,function(a,b,c){return P(a,c)-P(b,c)});R("<",4,2,function(a,b,c){return yb(function(a,b){return a<b},a,b,c)});
R(">",4,2,function(a,b,c){return yb(function(a,b){return a>b},a,b,c)});R("<=",4,2,function(a,b,c){return yb(function(a,b){return a<=b},a,b,c)});R(">=",4,2,function(a,b,c){return yb(function(a,b){return a>=b},a,b,c)});var xb=R("=",3,2,function(a,b,c){return yb(function(a,b){return a==b},a,b,c,!0)});R("!=",3,2,function(a,b,c){return yb(function(a,b){return a!=b},a,b,c,!0)});R("and",2,2,function(a,b,c){return vb(a,c)&&vb(b,c)});R("or",1,2,function(a,b,c){return vb(a,c)||vb(b,c)});function Bb(a,b){if(b.a.length&&4!=a.m)throw Error("Primary expression must evaluate to nodeset if filter has predicate(s).");M.call(this,a.m);this.c=a;this.j=b;this.i=a.i;this.b=a.b}m(Bb,M);Bb.prototype.a=function(a){a=this.c.a(a);return Cb(this.j,a)};Bb.prototype.toString=function(){var a;a="Filter:"+N(this.c);return a+=N(this.j)};function Db(a,b){if(b.length<a.G)throw Error("Function "+a.o+" expects at least"+a.G+" arguments, "+b.length+" given");if(null!==a.D&&b.length>a.D)throw Error("Function "+a.o+" expects at most "+a.D+" arguments, "+b.length+" given");a.H&&p(b,function(b,d){if(4!=b.m)throw Error("Argument "+d+" to function "+a.o+" is not of type Nodeset: "+b);});M.call(this,a.m);this.j=a;this.c=b;tb(this,a.i||qa(b,function(a){return a.i}));ub(this,a.J&&!b.length||a.I&&!!b.length||qa(b,function(a){return a.b}))}
m(Db,M);Db.prototype.a=function(a){return this.j.v.apply(null,sa(a,this.c))};Db.prototype.toString=function(){var a="Function: "+this.j;if(this.c.length)var b=q(this.c,function(a,b){return a+N(b)},"Arguments:"),a=a+N(b);return a};function Eb(a,b,c,d,e,f,h,k,v){this.o=a;this.m=b;this.i=c;this.J=d;this.I=e;this.v=f;this.G=h;this.D=void 0!==k?k:h;this.H=!!v}Eb.prototype.toString=function(){return this.o};var Fb={};
function S(a,b,c,d,e,f,h,k){if(Fb.hasOwnProperty(a))throw Error("Function already created: "+a+".");Fb[a]=new Eb(a,b,c,d,!1,e,f,h,k)}S("boolean",2,!1,!1,function(a,b){return vb(b,a)},1);S("ceiling",1,!1,!1,function(a,b){return Math.ceil(P(b,a))},1);S("concat",3,!1,!1,function(a,b){return q(ta(arguments,1),function(b,d){return b+Q(d,a)},"")},2,null);S("contains",2,!1,!1,function(a,b,c){b=Q(b,a);a=Q(c,a);return-1!=b.indexOf(a)},2);S("count",1,!1,!1,function(a,b){return b.a(a).s},1,1,!0);
S("false",2,!1,!1,function(){return!1},0);S("floor",1,!1,!1,function(a,b){return Math.floor(P(b,a))},1);
S("id",4,!1,!1,function(a,b){function c(a){if(A){var b=e.all[a];if(b){if(b.nodeType&&a==b.id)return b;if(b.length)return ra(b,function(b){return a==b.id})}return null}return e.getElementById(a)}var d=a.a,e=9==d.nodeType?d:d.ownerDocument,d=Q(b,a).split(/\s+/),f=[];p(d,function(a){a=c(a);var b;if(!(b=!a)){a:if(l(f))b=l(a)&&1==a.length?f.indexOf(a,0):-1;else{for(b=0;b<f.length;b++)if(b in f&&f[b]===a)break a;b=-1}b=0<=b}b||f.push(a)});f.sort(Ra);var h=new G;p(f,function(a){I(h,a)});return h},1);
S("lang",2,!1,!1,function(){return!1},1);S("last",1,!0,!1,function(a){if(1!=arguments.length)throw Error("Function last expects ()");return a.h},0);S("local-name",3,!1,!0,function(a,b){var c=b?qb(b.a(a)):a.a;return c?c.localName||c.nodeName.toLowerCase():""},0,1,!0);S("name",3,!1,!0,function(a,b){var c=b?qb(b.a(a)):a.a;return c?c.nodeName.toLowerCase():""},0,1,!0);S("namespace-uri",3,!0,!1,function(){return""},0,1,!0);
S("normalize-space",3,!1,!0,function(a,b){return(b?Q(b,a):E(a.a)).replace(/[\s\xa0]+/g," ").replace(/^\s+|\s+$/g,"")},0,1);S("not",2,!1,!1,function(a,b){return!vb(b,a)},1);S("number",1,!1,!0,function(a,b){return b?P(b,a):+E(a.a)},0,1);S("position",1,!0,!1,function(a){return a.b},0);S("round",1,!1,!1,function(a,b){return Math.round(P(b,a))},1);S("starts-with",2,!1,!1,function(a,b,c){b=Q(b,a);a=Q(c,a);return 0==b.lastIndexOf(a,0)},2);S("string",3,!1,!0,function(a,b){return b?Q(b,a):E(a.a)},0,1);
S("string-length",1,!1,!0,function(a,b){return(b?Q(b,a):E(a.a)).length},0,1);S("substring",3,!1,!1,function(a,b,c,d){c=P(c,a);if(isNaN(c)||Infinity==c||-Infinity==c)return"";d=d?P(d,a):Infinity;if(isNaN(d)||-Infinity===d)return"";c=Math.round(c)-1;var e=Math.max(c,0);a=Q(b,a);return Infinity==d?a.substring(e):a.substring(e,c+Math.round(d))},2,3);S("substring-after",3,!1,!1,function(a,b,c){b=Q(b,a);a=Q(c,a);c=b.indexOf(a);return-1==c?"":b.substring(c+a.length)},2);
S("substring-before",3,!1,!1,function(a,b,c){b=Q(b,a);a=Q(c,a);a=b.indexOf(a);return-1==a?"":b.substring(0,a)},2);S("sum",1,!1,!1,function(a,b){for(var c=K(b.a(a)),d=0,e=L(c);e;e=L(c))d+=+E(e);return d},1,1,!0);S("translate",3,!1,!1,function(a,b,c,d){b=Q(b,a);c=Q(c,a);var e=Q(d,a);a={};for(d=0;d<c.length;d++){var f=c.charAt(d);f in a||(a[f]=e.charAt(d))}c="";for(d=0;d<b.length;d++)f=b.charAt(d),c+=f in a?a[f]:f;return c},3);S("true",2,!1,!1,function(){return!0},0);function J(a,b){this.j=a;this.c=void 0!==b?b:null;this.b=null;switch(a){case "comment":this.b=8;break;case "text":this.b=3;break;case "processing-instruction":this.b=7;break;case "node":break;default:throw Error("Unexpected argument");}}function Gb(a){return"comment"==a||"text"==a||"processing-instruction"==a||"node"==a}J.prototype.a=function(a){return null===this.b||this.b==a.nodeType};J.prototype.h=function(){return this.j};
J.prototype.toString=function(){var a="Kind Test: "+this.j;null===this.c||(a+=N(this.c));return a};function Hb(a){M.call(this,3);this.c=a.substring(1,a.length-1)}m(Hb,M);Hb.prototype.a=function(){return this.c};Hb.prototype.toString=function(){return"Literal: "+this.c};function H(a,b){this.o=a.toLowerCase();var c;c="*"==this.o?"*":"http://www.w3.org/1999/xhtml";this.c=b?b.toLowerCase():c}H.prototype.a=function(a){var b=a.nodeType;return 1!=b&&2!=b?!1:"*"!=this.o&&this.o!=a.localName.toLowerCase()?!1:"*"==this.c?!0:this.c==(a.namespaceURI?a.namespaceURI.toLowerCase():"http://www.w3.org/1999/xhtml")};H.prototype.h=function(){return this.o};H.prototype.toString=function(){return"Name Test: "+("http://www.w3.org/1999/xhtml"==this.c?"":this.c+":")+this.o};function Ib(a){M.call(this,1);this.c=a}m(Ib,M);Ib.prototype.a=function(){return this.c};Ib.prototype.toString=function(){return"Number: "+this.c};function Jb(a,b){M.call(this,a.m);this.j=a;this.c=b;this.i=a.i;this.b=a.b;if(1==this.c.length){var c=this.c[0];c.C||c.c!=Kb||(c=c.w,"*"!=c.h()&&(this.h={name:c.h(),A:null}))}}m(Jb,M);function Lb(){M.call(this,4)}m(Lb,M);Lb.prototype.a=function(a){var b=new G;a=a.a;9==a.nodeType?I(b,a):I(b,a.ownerDocument);return b};Lb.prototype.toString=function(){return"Root Helper Expression"};function Mb(){M.call(this,4)}m(Mb,M);Mb.prototype.a=function(a){var b=new G;I(b,a.a);return b};Mb.prototype.toString=function(){return"Context Helper Expression"};
function Nb(a){return"/"==a||"//"==a}Jb.prototype.a=function(a){var b=this.j.a(a);if(!(b instanceof G))throw Error("Filter expression must evaluate to nodeset.");a=this.c;for(var c=0,d=a.length;c<d&&b.s;c++){var e=a[c],f=K(b,e.c.a),h;if(e.i||e.c!=Ob)if(e.i||e.c!=Pb)for(h=L(f),b=e.a(new Za(h));null!=(h=L(f));)h=e.a(new Za(h)),b=pb(b,h);else h=L(f),b=e.a(new Za(h));else{for(h=L(f);(b=L(f))&&(!h.contains||h.contains(b))&&b.compareDocumentPosition(h)&8;h=b);b=e.a(new Za(h))}}return b};
Jb.prototype.toString=function(){var a;a="Path Expression:"+N(this.j);if(this.c.length){var b=q(this.c,function(a,b){return a+N(b)},"Steps:");a+=N(b)}return a};function Qb(a,b){this.a=a;this.b=!!b}
function Cb(a,b,c){for(c=c||0;c<a.a.length;c++)for(var d=a.a[c],e=K(b),f=b.s,h,k=0;h=L(e);k++){var v=a.b?f-k:k+1;h=d.a(new Za(h,v,f));if("number"==typeof h)v=v==h;else if("string"==typeof h||"boolean"==typeof h)v=!!h;else if(h instanceof G)v=0<h.s;else throw Error("Predicate.evaluate returned an unexpected type.");if(!v){v=e;h=v.h;var C=v.a;if(!C)throw Error("Next must be called at least once before remove.");var O=C.b,C=C.a;O?O.a=C:h.a=C;C?C.b=O:h.b=O;h.s--;v.a=null}}return b}
Qb.prototype.toString=function(){return q(this.a,function(a,b){return a+N(b)},"Predicates:")};function T(a,b,c,d){M.call(this,4);this.c=a;this.w=b;this.j=c||new Qb([]);this.C=!!d;b=this.j;b=0<b.a.length?b.a[0].h:null;a.b&&b&&(a=b.name,a=A?a.toLowerCase():a,this.h={name:a,A:b.A});a:{a=this.j;for(b=0;b<a.a.length;b++)if(c=a.a[b],c.i||1==c.m||0==c.m){a=!0;break a}a=!1}this.i=a}m(T,M);
T.prototype.a=function(a){var b=a.a,c=null,c=this.h,d=null,e=null,f=0;c&&(d=c.name,e=c.A?Q(c.A,a):null,f=1);if(this.C)if(this.i||this.c!=Rb)if(a=K((new T(Sb,new J("node"))).a(a)),b=L(a))for(c=this.v(b,d,e,f);null!=(b=L(a));)c=pb(c,this.v(b,d,e,f));else c=new G;else c=hb(this.w,b,d,e),c=Cb(this.j,c,f);else c=this.v(a.a,d,e,f);return c};T.prototype.v=function(a,b,c,d){a=this.c.h(this.w,a,b,c);return a=Cb(this.j,a,d)};
T.prototype.toString=function(){var a;a="Step:"+N("Operator: "+(this.C?"//":"/"));this.c.o&&(a+=N("Axis: "+this.c));a+=N(this.w);if(this.j.a.length){var b=q(this.j.a,function(a,b){return a+N(b)},"Predicates:");a+=N(b)}return a};function Tb(a,b,c,d){this.o=a;this.h=b;this.a=c;this.b=d}Tb.prototype.toString=function(){return this.o};var Ub={};function U(a,b,c,d){if(Ub.hasOwnProperty(a))throw Error("Axis already created: "+a);b=new Tb(a,b,c,!!d);return Ub[a]=b}
U("ancestor",function(a,b){for(var c=new G,d=b;d=d.parentNode;)a.a(d)&&c.unshift(d);return c},!0);U("ancestor-or-self",function(a,b){var c=new G,d=b;do a.a(d)&&c.unshift(d);while(d=d.parentNode);return c},!0);
var Kb=U("attribute",function(a,b){var c=new G,d=a.h();if("style"==d&&b.style&&A)return I(c,new ab(b.style,b,"style",b.style.cssText)),c;var e=b.attributes;if(e)if(a instanceof J&&null===a.b||"*"==d)for(var d=0,f;f=e[d];d++)A?f.nodeValue&&I(c,bb(b,f)):I(c,f);else(f=e.getNamedItem(d))&&(A?f.nodeValue&&I(c,bb(b,f)):I(c,f));return c},!1),Rb=U("child",function(a,b,c,d,e){return(A?mb:nb).call(null,a,b,l(c)?c:null,l(d)?d:null,e||new G)},!1,!0);U("descendant",hb,!1,!0);
var Sb=U("descendant-or-self",function(a,b,c,d){var e=new G;F(b,c,d)&&a.a(b)&&I(e,b);return hb(a,b,c,d,e)},!1,!0),Ob=U("following",function(a,b,c,d){var e=new G;do for(var f=b;f=f.nextSibling;)F(f,c,d)&&a.a(f)&&I(e,f),e=hb(a,f,c,d,e);while(b=b.parentNode);return e},!1,!0);U("following-sibling",function(a,b){for(var c=new G,d=b;d=d.nextSibling;)a.a(d)&&I(c,d);return c},!1);U("namespace",function(){return new G},!1);
var Vb=U("parent",function(a,b){var c=new G;if(9==b.nodeType)return c;if(2==b.nodeType)return I(c,b.ownerElement),c;var d=b.parentNode;a.a(d)&&I(c,d);return c},!1),Pb=U("preceding",function(a,b,c,d){var e=new G,f=[];do f.unshift(b);while(b=b.parentNode);for(var h=1,k=f.length;h<k;h++){var v=[];for(b=f[h];b=b.previousSibling;)v.unshift(b);for(var C=0,O=v.length;C<O;C++)b=v[C],F(b,c,d)&&a.a(b)&&I(e,b),e=hb(a,b,c,d,e)}return e},!0,!0);
U("preceding-sibling",function(a,b){for(var c=new G,d=b;d=d.previousSibling;)a.a(d)&&c.unshift(d);return c},!0);var Wb=U("self",function(a,b){var c=new G;a.a(b)&&I(c,b);return c},!1);function Xb(a){M.call(this,1);this.c=a;this.i=a.i;this.b=a.b}m(Xb,M);Xb.prototype.a=function(a){return-P(this.c,a)};Xb.prototype.toString=function(){return"Unary Expression: -"+N(this.c)};function Yb(a){M.call(this,4);this.c=a;tb(this,qa(this.c,function(a){return a.i}));ub(this,qa(this.c,function(a){return a.b}))}m(Yb,M);Yb.prototype.a=function(a){var b=new G;p(this.c,function(c){c=c.a(a);if(!(c instanceof G))throw Error("Path expression must evaluate to NodeSet.");b=pb(b,c)});return b};Yb.prototype.toString=function(){return q(this.c,function(a,b){return a+N(b)},"Union Expression:")};function Zb(a,b){this.a=a;this.b=b}function $b(a){for(var b,c=[];;){V(a,"Missing right hand side of binary expression.");b=ac(a);var d=D(a.a);if(!d)break;var e=(d=Ab[d]||null)&&d.F;if(!e){a.a.a--;break}for(;c.length&&e<=c[c.length-1].F;)b=new wb(c.pop(),c.pop(),b);c.push(b,d)}for(;c.length;)b=new wb(c.pop(),c.pop(),b);return b}function V(a,b){if(gb(a.a))throw Error(b);}function bc(a,b){var c=D(a.a);if(c!=b)throw Error("Bad token, expected: "+b+" got: "+c);}
function cc(a){a=D(a.a);if(")"!=a)throw Error("Bad token: "+a);}function dc(a){a=D(a.a);if(2>a.length)throw Error("Unclosed literal string");return new Hb(a)}
function ec(a){var b,c=[],d;if(Nb(B(a.a))){b=D(a.a);d=B(a.a);if("/"==b&&(gb(a.a)||"."!=d&&".."!=d&&"@"!=d&&"*"!=d&&!/(?![0-9])[\w]/.test(d)))return new Lb;d=new Lb;V(a,"Missing next location step.");b=fc(a,b);c.push(b)}else{a:{b=B(a.a);d=b.charAt(0);switch(d){case "$":throw Error("Variable reference not allowed in HTML XPath");case "(":D(a.a);b=$b(a);V(a,'unclosed "("');bc(a,")");break;case '"':case "'":b=dc(a);break;default:if(isNaN(+b))if(!Gb(b)&&/(?![0-9])[\w]/.test(d)&&"("==B(a.a,1)){b=D(a.a);
b=Fb[b]||null;D(a.a);for(d=[];")"!=B(a.a);){V(a,"Missing function argument list.");d.push($b(a));if(","!=B(a.a))break;D(a.a)}V(a,"Unclosed function argument list.");cc(a);b=new Db(b,d)}else{b=null;break a}else b=new Ib(+D(a.a))}"["==B(a.a)&&(d=new Qb(gc(a)),b=new Bb(b,d))}if(b)if(Nb(B(a.a)))d=b;else return b;else b=fc(a,"/"),d=new Mb,c.push(b)}for(;Nb(B(a.a));)b=D(a.a),V(a,"Missing next location step."),b=fc(a,b),c.push(b);return new Jb(d,c)}
function fc(a,b){var c,d,e;if("/"!=b&&"//"!=b)throw Error('Step op should be "/" or "//"');if("."==B(a.a))return d=new T(Wb,new J("node")),D(a.a),d;if(".."==B(a.a))return d=new T(Vb,new J("node")),D(a.a),d;var f;if("@"==B(a.a))f=Kb,D(a.a),V(a,"Missing attribute name");else if("::"==B(a.a,1)){if(!/(?![0-9])[\w]/.test(B(a.a).charAt(0)))throw Error("Bad token: "+D(a.a));c=D(a.a);f=Ub[c]||null;if(!f)throw Error("No axis with name: "+c);D(a.a);V(a,"Missing node name")}else f=Rb;c=B(a.a);if(/(?![0-9])[\w\*]/.test(c.charAt(0)))if("("==
B(a.a,1)){if(!Gb(c))throw Error("Invalid node type: "+c);c=D(a.a);if(!Gb(c))throw Error("Invalid type name: "+c);bc(a,"(");V(a,"Bad nodetype");e=B(a.a).charAt(0);var h=null;if('"'==e||"'"==e)h=dc(a);V(a,"Bad nodetype");cc(a);c=new J(c,h)}else if(c=D(a.a),e=c.indexOf(":"),-1==e)c=new H(c);else{var h=c.substring(0,e),k;if("*"==h)k="*";else if(k=a.b(h),!k)throw Error("Namespace prefix not declared: "+h);c=c.substr(e+1);c=new H(c,k)}else throw Error("Bad token: "+D(a.a));e=new Qb(gc(a),f.a);return d||
new T(f,c,e,"//"==b)}function gc(a){for(var b=[];"["==B(a.a);){D(a.a);V(a,"Missing predicate expression.");var c=$b(a);b.push(c);V(a,"Unclosed predicate expression.");bc(a,"]")}return b}function ac(a){if("-"==B(a.a))return D(a.a),new Xb(ac(a));var b=ec(a);if("|"!=B(a.a))a=b;else{for(b=[b];"|"==D(a.a);)V(a,"Missing next union location path."),b.push(ec(a));a.a.a--;a=new Yb(b)}return a};function hc(a){switch(a.nodeType){case 1:return ja(ic,a);case 9:return hc(a.documentElement);case 11:case 10:case 6:case 12:return jc;default:return a.parentNode?hc(a.parentNode):jc}}function jc(){return null}function ic(a,b){if(a.prefix==b)return a.namespaceURI||"http://www.w3.org/1999/xhtml";var c=a.getAttributeNode("xmlns:"+b);return c&&c.specified?c.value||null:a.parentNode&&9!=a.parentNode.nodeType?ic(a.parentNode,b):null};function kc(a,b){if(!a.length)throw Error("Empty XPath expression.");var c=db(a);if(gb(c))throw Error("Invalid XPath expression.");b?"function"==ba(b)||(b=ia(b.lookupNamespaceURI,b)):b=function(){return null};var d=$b(new Zb(c,b));if(!gb(c))throw Error("Bad token: "+D(c));this.evaluate=function(a,b){var c=d.a(new Za(a));return new W(c,b)}}
function W(a,b){if(0==b)if(a instanceof G)b=4;else if("string"==typeof a)b=2;else if("number"==typeof a)b=1;else if("boolean"==typeof a)b=3;else throw Error("Unexpected evaluation result.");if(2!=b&&1!=b&&3!=b&&!(a instanceof G))throw Error("value could not be converted to the specified type");this.resultType=b;var c;switch(b){case 2:this.stringValue=a instanceof G?rb(a):""+a;break;case 1:this.numberValue=a instanceof G?+rb(a):+a;break;case 3:this.booleanValue=a instanceof G?0<a.s:!!a;break;case 4:case 5:case 6:case 7:var d=
K(a);c=[];for(var e=L(d);e;e=L(d))c.push(e instanceof ab?e.a:e);this.snapshotLength=a.s;this.invalidIteratorState=!1;break;case 8:case 9:d=qb(a);this.singleNodeValue=d instanceof ab?d.a:d;break;default:throw Error("Unknown XPathResult type.");}var f=0;this.iterateNext=function(){if(4!=b&&5!=b)throw Error("iterateNext called with wrong result type");return f>=c.length?null:c[f++]};this.snapshotItem=function(a){if(6!=b&&7!=b)throw Error("snapshotItem called with wrong result type");return a>=c.length||
0>a?null:c[a]}}W.ANY_TYPE=0;W.NUMBER_TYPE=1;W.STRING_TYPE=2;W.BOOLEAN_TYPE=3;W.UNORDERED_NODE_ITERATOR_TYPE=4;W.ORDERED_NODE_ITERATOR_TYPE=5;W.UNORDERED_NODE_SNAPSHOT_TYPE=6;W.ORDERED_NODE_SNAPSHOT_TYPE=7;W.ANY_UNORDERED_NODE_TYPE=8;W.FIRST_ORDERED_NODE_TYPE=9;function lc(a){this.lookupNamespaceURI=hc(a)}
aa("wgxpath.install",function(a,b){var c=a||g,d=c.document;if(!d.evaluate||b)c.XPathResult=W,d.evaluate=function(a,b,c,d){return(new kc(a,c)).evaluate(b,d)},d.createExpression=function(a,b){return new kc(a,b)},d.createNSResolver=function(a){return new lc(a)}});function mc(a){return(a=a.exec(t))?a[1]:""}var nc=function(){if(Ua)return mc(/Firefox\/([0-9.]+)/);if(x||Fa||Ea)return La;if(Xa)return mc(/Chrome\/([0-9.]+)/);if(Ya&&!(Da()||u("iPad")||u("iPod")))return mc(/Version\/([0-9.]+)/);if(Va||Wa){var a;if(a=/Version\/(\S+).*Mobile\/(\S+)/.exec(t))return a[1]+"."+a[2]}else if(z)return(a=mc(/Android\s+([0-9.]+)/))?a:mc(/Version\/([0-9.]+)/);return""}();var oc,pc;function qc(a){return rc?oc(a):x?0<=ma(Pa,a):Na(a)}function sc(a){rc?pc(a):z?ma(tc,a):ma(nc,a)}
var rc=function(){if(!y)return!1;var a=g.Components;if(!a)return!1;try{if(!a.classes)return!1}catch(f){return!1}var b=a.classes,a=a.interfaces,c=b["@mozilla.org/xpcom/version-comparator;1"].getService(a.nsIVersionComparator),b=b["@mozilla.org/xre/app-info;1"].getService(a.nsIXULAppInfo),d=b.platformVersion,e=b.version;oc=function(a){return 0<=c.compare(d,""+a)};pc=function(a){c.compare(e,""+a)};return!0}(),uc;if(z){var vc=/Android\s+([0-9\.]+)/.exec(t);uc=vc?vc[1]:"0"}else uc="0";var tc=uc;z&&sc(2.3);
z&&sc(4);Ya&&sc(6);Ga||rc&&sc(3.6);x&&qc(10);z&&sc(4);function X(a,b){this.u={};this.l=[];this.b=this.a=0;var c=arguments.length;if(1<c){if(c%2)throw Error("Uneven number of arguments");for(var d=0;d<c;d+=2)Y(this,arguments[d],arguments[d+1])}else if(a){var e;if(a instanceof X)for(d=wc(a),xc(a),e=[],c=0;c<a.l.length;c++)e.push(a.u[a.l[c]]);else{var c=[],f=0;for(d in a)c[f++]=d;d=c;c=[];f=0;for(e in a)c[f++]=a[e];e=c}for(c=0;c<d.length;c++)Y(this,d[c],e[c])}}function wc(a){xc(a);return a.l.concat()}
X.prototype.clear=function(){this.u={};this.b=this.a=this.l.length=0};function xc(a){if(a.a!=a.l.length){for(var b=0,c=0;b<a.l.length;){var d=a.l[b];Object.prototype.hasOwnProperty.call(a.u,d)&&(a.l[c++]=d);b++}a.l.length=c}if(a.a!=a.l.length){for(var e={},c=b=0;b<a.l.length;)d=a.l[b],Object.prototype.hasOwnProperty.call(e,d)||(a.l[c++]=d,e[d]=1),b++;a.l.length=c}}X.prototype.get=function(a,b){return Object.prototype.hasOwnProperty.call(this.u,a)?this.u[a]:b};
function Y(a,b,c){Object.prototype.hasOwnProperty.call(a.u,b)||(a.a++,a.l.push(b),a.b++);a.u[b]=c}X.prototype.forEach=function(a,b){for(var c=wc(this),d=0;d<c.length;d++){var e=c[d],f=this.get(e);a.call(b,f,e,this)}};X.prototype.clone=function(){return new X(this)};var yc={};function Z(a,b,c){da(a)&&(a=y?a.f:a.g);a=new zc(a);!b||b in yc&&!c||(yc[b]={key:a,shift:!1},c&&(yc[c]={key:a,shift:!0}));return a}function zc(a){this.code=a}Z(8);Z(9);Z(13);var Ac=Z(16),Bc=Z(17),Cc=Z(18);Z(19);Z(20);Z(27);Z(32," ");Z(33);Z(34);Z(35);Z(36);Z(37);Z(38);Z(39);Z(40);Z(44);Z(45);Z(46);Z(48,"0",")");Z(49,"1","!");Z(50,"2","@");Z(51,"3","#");Z(52,"4","$");Z(53,"5","%");Z(54,"6","^");Z(55,"7","&");Z(56,"8","*");Z(57,"9","(");Z(65,"a","A");Z(66,"b","B");Z(67,"c","C");Z(68,"d","D");
Z(69,"e","E");Z(70,"f","F");Z(71,"g","G");Z(72,"h","H");Z(73,"i","I");Z(74,"j","J");Z(75,"k","K");Z(76,"l","L");Z(77,"m","M");Z(78,"n","N");Z(79,"o","O");Z(80,"p","P");Z(81,"q","Q");Z(82,"r","R");Z(83,"s","S");Z(84,"t","T");Z(85,"u","U");Z(86,"v","V");Z(87,"w","W");Z(88,"x","X");Z(89,"y","Y");Z(90,"z","Z");var Dc=Z(Ia?{f:91,g:91}:Ha?{f:224,g:91}:{f:0,g:91});Z(Ia?{f:92,g:92}:Ha?{f:224,g:93}:{f:0,g:92});Z(Ia?{f:93,g:93}:Ha?{f:0,g:0}:{f:93,g:null});Z({f:96,g:96},"0");Z({f:97,g:97},"1");
Z({f:98,g:98},"2");Z({f:99,g:99},"3");Z({f:100,g:100},"4");Z({f:101,g:101},"5");Z({f:102,g:102},"6");Z({f:103,g:103},"7");Z({f:104,g:104},"8");Z({f:105,g:105},"9");Z({f:106,g:106},"*");Z({f:107,g:107},"+");Z({f:109,g:109},"-");Z({f:110,g:110},".");Z({f:111,g:111},"/");Z(144);Z(112);Z(113);Z(114);Z(115);Z(116);Z(117);Z(118);Z(119);Z(120);Z(121);Z(122);Z(123);Z({f:107,g:187},"=","+");Z(108,",");Z({f:109,g:189},"-","_");Z(188,",","<");Z(190,".",">");Z(191,"/","?");Z(192,"`","~");Z(219,"[","{");
Z(220,"\\","|");Z(221,"]","}");Z({f:59,g:186},";",":");Z(222,"'",'"');var Ec=new X;Y(Ec,1,Ac);Y(Ec,2,Bc);Y(Ec,4,Cc);Y(Ec,8,Dc);(function(a){var b=new X;p(wc(a),function(c){Y(b,a.get(c).code,c)});return b})(Ec);y&&qc(12);function Fc(){}
function Gc(a,b,c){if(null==b)c.push("null");else{if("object"==typeof b){if("array"==ba(b)){var d=b;b=d.length;c.push("[");for(var e="",f=0;f<b;f++)c.push(e),Gc(a,d[f],c),e=",";c.push("]");return}if(b instanceof String||b instanceof Number||b instanceof Boolean)b=b.valueOf();else{c.push("{");e="";for(d in b)Object.prototype.hasOwnProperty.call(b,d)&&(f=b[d],"function"!=typeof f&&(c.push(e),Hc(d,c),c.push(":"),Gc(a,f,c),e=","));c.push("}");return}}switch(typeof b){case "string":Hc(b,c);break;case "number":c.push(isFinite(b)&&
!isNaN(b)?String(b):"null");break;case "boolean":c.push(String(b));break;case "function":c.push("null");break;default:throw Error("Unknown type: "+typeof b);}}}var Ic={'"':'\\"',"\\":"\\\\","/":"\\/","\b":"\\b","\f":"\\f","\n":"\\n","\r":"\\r","\t":"\\t","\x0B":"\\u000b"},Jc=/\uffff/.test("\uffff")?/[\\\"\x00-\x1f\x7f-\uffff]/g:/[\\\"\x00-\x1f\x7f-\xff]/g;
function Hc(a,b){b.push('"',a.replace(Jc,function(a){var b=Ic[a];b||(b="\\u"+(a.charCodeAt(0)|65536).toString(16).substr(1),Ic[a]=b);return b}),'"')};Ga||y&&qc(3.5)||x&&qc(8);function Kc(a){switch(ba(a)){case "string":case "number":case "boolean":return a;case "function":return a.toString();case "array":return pa(a,Kc);case "object":if(w(a,"nodeType")&&(1==a.nodeType||9==a.nodeType)){var b={};b.ELEMENT=Lc(a);return b}if(w(a,"document"))return b={},b.WINDOW=Lc(a),b;if(ca(a))return pa(a,Kc);a=ya(a,function(a,b){return"number"==typeof b||l(b)});return za(a,Kc);default:return null}}
function Mc(a,b){return"array"==ba(a)?pa(a,function(a){return Mc(a,b)}):da(a)?"function"==typeof a?a:w(a,"ELEMENT")?Nc(a.ELEMENT,b):w(a,"WINDOW")?Nc(a.WINDOW,b):za(a,function(a){return Mc(a,b)}):a}
function Oc(a,b){var c;try{a:{var d=a;if(l(d))try{a=new n.Function(d);break a}catch(h){if(x&&n.execScript){n.execScript(";");a=new n.Function(d);break a}throw h;}a=n==window?d:new n.Function("return ("+d+").apply(null,arguments);")}var e=Mc(b,n.document),f=a.apply(null,e);c={status:0,value:Kc(f)}}catch(h){c={status:w(h,"code")?h.code:13,value:{message:h.message}}}d=[];Gc(new Fc,c,d);return d.join("")}function Pc(a){a=a||document;var b=a.$wdc_;b||(b=a.$wdc_={},b.B=ka());b.B||(b.B=ka());return b}
function Lc(a){var b=Pc(a.ownerDocument),c=Aa(b,function(b){return b==a});c||(c=":wdc:"+b.B++,b[c]=a);return c}function Nc(a,b){a=decodeURIComponent(a);var c=b||document,d=Pc(c);if(!w(d,a))throw new ua(10,"Element does not exist in cache");var e=d[a];if(w(e,"setInterval")){if(e.closed)throw delete d[a],new ua(23,"Window has been closed.");return e}for(var f=e;f;){if(f==c.documentElement)return e;f=f.parentNode}delete d[a];throw new ua(10,"Element is no longer attached to the DOM");};aa("_",function(a){return Oc(function(a){return a.tagName.toLowerCase()},[a])});; return this._.apply(null,arguments);}.apply({navigator:typeof window!=undefined?window.navigator:null,document:typeof window!=undefined?window.document:null}, arguments);}
