function(){return function(){var h,aa=this;function l(a){return void 0!==a}function ba(a,b){var c=a.split("."),d=aa;c[0]in d||!d.execScript||d.execScript("var "+c[0]);for(var e;c.length&&(e=c.shift());)!c.length&&l(b)?d[e]=b:d[e]?d=d[e]:d=d[e]={}}
function ca(a){var b=typeof a;if("object"==b)if(a){if(a instanceof Array)return"array";if(a instanceof Object)return b;var c=Object.prototype.toString.call(a);if("[object Window]"==c)return"object";if("[object Array]"==c||"number"==typeof a.length&&"undefined"!=typeof a.splice&&"undefined"!=typeof a.propertyIsEnumerable&&!a.propertyIsEnumerable("splice"))return"array";if("[object Function]"==c||"undefined"!=typeof a.call&&"undefined"!=typeof a.propertyIsEnumerable&&!a.propertyIsEnumerable("call"))return"function"}else return"null";
else if("function"==b&&"undefined"==typeof a.call)return"object";return b}function da(a){var b=ca(a);return"array"==b||"object"==b&&"number"==typeof a.length}function m(a){return"string"==typeof a}function ea(a){return"number"==typeof a}function fa(a){return"function"==ca(a)}function ga(a){var b=typeof a;return"object"==b&&null!=a||"function"==b}var ha="closure_uid_"+(1E9*Math.random()>>>0),ia=0;function ja(a,b,c){return a.call.apply(a.bind,arguments)}
function ka(a,b,c){if(!a)throw Error();if(2<arguments.length){var d=Array.prototype.slice.call(arguments,2);return function(){var c=Array.prototype.slice.call(arguments);Array.prototype.unshift.apply(c,d);return a.apply(b,c)}}return function(){return a.apply(b,arguments)}}function la(a,b,c){la=Function.prototype.bind&&-1!=Function.prototype.bind.toString().indexOf("native code")?ja:ka;return la.apply(null,arguments)}
function ma(a,b){var c=Array.prototype.slice.call(arguments,1);return function(){var b=c.slice();b.push.apply(b,arguments);return a.apply(this,b)}}var na=Date.now||function(){return+new Date};function p(a,b){function c(){}c.prototype=b.prototype;a.V=b.prototype;a.prototype=new c;a.prototype.constructor=a;a.U=function(a,c,f){for(var g=Array(arguments.length-2),k=2;k<arguments.length;k++)g[k-2]=arguments[k];return b.prototype[c].apply(a,g)}};var oa=window;var pa;function qa(a){var b=a.length-1;return 0<=b&&a.indexOf(" ",b)==b}var ra=String.prototype.trim?function(a){return a.trim()}:function(a){return a.replace(/^[\s\xa0]+|[\s\xa0]+$/g,"")};
function sa(a,b){for(var c=0,d=ra(String(a)).split("."),e=ra(String(b)).split("."),f=Math.max(d.length,e.length),g=0;0==c&&g<f;g++){var k=d[g]||"",n=e[g]||"",v=RegExp("(\\d*)(\\D*)","g"),u=RegExp("(\\d*)(\\D*)","g");do{var E=v.exec(k)||["","",""],y=u.exec(n)||["","",""];if(0==E[0].length&&0==y[0].length)break;c=ta(0==E[1].length?0:parseInt(E[1],10),0==y[1].length?0:parseInt(y[1],10))||ta(0==E[2].length,0==y[2].length)||ta(E[2],y[2])}while(0==c)}return c}function ta(a,b){return a<b?-1:a>b?1:0}
function ua(a){return String(a).replace(/\-([a-z])/g,function(a,c){return c.toUpperCase()})};function q(a,b,c){for(var d=a.length,e=m(a)?a.split(""):a,f=0;f<d;f++)f in e&&b.call(c,e[f],f,a)}function va(a,b){for(var c=a.length,d=[],e=0,f=m(a)?a.split(""):a,g=0;g<c;g++)if(g in f){var k=f[g];b.call(void 0,k,g,a)&&(d[e++]=k)}return d}function wa(a,b){for(var c=a.length,d=Array(c),e=m(a)?a.split(""):a,f=0;f<c;f++)f in e&&(d[f]=b.call(void 0,e[f],f,a));return d}function xa(a,b,c){var d=c;q(a,function(c,f){d=b.call(void 0,d,c,f,a)});return d}
function ya(a,b){for(var c=a.length,d=m(a)?a.split(""):a,e=0;e<c;e++)if(e in d&&b.call(void 0,d[e],e,a))return!0;return!1}function za(a,b){for(var c=a.length,d=m(a)?a.split(""):a,e=0;e<c;e++)if(e in d&&!b.call(void 0,d[e],e,a))return!1;return!0}function Aa(a,b){var c;a:{c=a.length;for(var d=m(a)?a.split(""):a,e=0;e<c;e++)if(e in d&&b.call(void 0,d[e],e,a)){c=e;break a}c=-1}return 0>c?null:m(a)?a.charAt(c):a[c]}
function Ba(a,b){var c;a:if(m(a))c=m(b)&&1==b.length?a.indexOf(b,0):-1;else{for(c=0;c<a.length;c++)if(c in a&&a[c]===b)break a;c=-1}return 0<=c}function Ca(a){return Array.prototype.concat.apply(Array.prototype,arguments)}function Da(a,b,c){return 2>=arguments.length?Array.prototype.slice.call(a,b):Array.prototype.slice.call(a,b,c)};var Ea={aliceblue:"#f0f8ff",antiquewhite:"#faebd7",aqua:"#00ffff",aquamarine:"#7fffd4",azure:"#f0ffff",beige:"#f5f5dc",bisque:"#ffe4c4",black:"#000000",blanchedalmond:"#ffebcd",blue:"#0000ff",blueviolet:"#8a2be2",brown:"#a52a2a",burlywood:"#deb887",cadetblue:"#5f9ea0",chartreuse:"#7fff00",chocolate:"#d2691e",coral:"#ff7f50",cornflowerblue:"#6495ed",cornsilk:"#fff8dc",crimson:"#dc143c",cyan:"#00ffff",darkblue:"#00008b",darkcyan:"#008b8b",darkgoldenrod:"#b8860b",darkgray:"#a9a9a9",darkgreen:"#006400",
darkgrey:"#a9a9a9",darkkhaki:"#bdb76b",darkmagenta:"#8b008b",darkolivegreen:"#556b2f",darkorange:"#ff8c00",darkorchid:"#9932cc",darkred:"#8b0000",darksalmon:"#e9967a",darkseagreen:"#8fbc8f",darkslateblue:"#483d8b",darkslategray:"#2f4f4f",darkslategrey:"#2f4f4f",darkturquoise:"#00ced1",darkviolet:"#9400d3",deeppink:"#ff1493",deepskyblue:"#00bfff",dimgray:"#696969",dimgrey:"#696969",dodgerblue:"#1e90ff",firebrick:"#b22222",floralwhite:"#fffaf0",forestgreen:"#228b22",fuchsia:"#ff00ff",gainsboro:"#dcdcdc",
ghostwhite:"#f8f8ff",gold:"#ffd700",goldenrod:"#daa520",gray:"#808080",green:"#008000",greenyellow:"#adff2f",grey:"#808080",honeydew:"#f0fff0",hotpink:"#ff69b4",indianred:"#cd5c5c",indigo:"#4b0082",ivory:"#fffff0",khaki:"#f0e68c",lavender:"#e6e6fa",lavenderblush:"#fff0f5",lawngreen:"#7cfc00",lemonchiffon:"#fffacd",lightblue:"#add8e6",lightcoral:"#f08080",lightcyan:"#e0ffff",lightgoldenrodyellow:"#fafad2",lightgray:"#d3d3d3",lightgreen:"#90ee90",lightgrey:"#d3d3d3",lightpink:"#ffb6c1",lightsalmon:"#ffa07a",
lightseagreen:"#20b2aa",lightskyblue:"#87cefa",lightslategray:"#778899",lightslategrey:"#778899",lightsteelblue:"#b0c4de",lightyellow:"#ffffe0",lime:"#00ff00",limegreen:"#32cd32",linen:"#faf0e6",magenta:"#ff00ff",maroon:"#800000",mediumaquamarine:"#66cdaa",mediumblue:"#0000cd",mediumorchid:"#ba55d3",mediumpurple:"#9370db",mediumseagreen:"#3cb371",mediumslateblue:"#7b68ee",mediumspringgreen:"#00fa9a",mediumturquoise:"#48d1cc",mediumvioletred:"#c71585",midnightblue:"#191970",mintcream:"#f5fffa",mistyrose:"#ffe4e1",
moccasin:"#ffe4b5",navajowhite:"#ffdead",navy:"#000080",oldlace:"#fdf5e6",olive:"#808000",olivedrab:"#6b8e23",orange:"#ffa500",orangered:"#ff4500",orchid:"#da70d6",palegoldenrod:"#eee8aa",palegreen:"#98fb98",paleturquoise:"#afeeee",palevioletred:"#db7093",papayawhip:"#ffefd5",peachpuff:"#ffdab9",peru:"#cd853f",pink:"#ffc0cb",plum:"#dda0dd",powderblue:"#b0e0e6",purple:"#800080",red:"#ff0000",rosybrown:"#bc8f8f",royalblue:"#4169e1",saddlebrown:"#8b4513",salmon:"#fa8072",sandybrown:"#f4a460",seagreen:"#2e8b57",
seashell:"#fff5ee",sienna:"#a0522d",silver:"#c0c0c0",skyblue:"#87ceeb",slateblue:"#6a5acd",slategray:"#708090",slategrey:"#708090",snow:"#fffafa",springgreen:"#00ff7f",steelblue:"#4682b4",tan:"#d2b48c",teal:"#008080",thistle:"#d8bfd8",tomato:"#ff6347",turquoise:"#40e0d0",violet:"#ee82ee",wheat:"#f5deb3",white:"#ffffff",whitesmoke:"#f5f5f5",yellow:"#ffff00",yellowgreen:"#9acd32"};var Fa="backgroundColor borderTopColor borderRightColor borderBottomColor borderLeftColor color outlineColor".split(" "),Ga=/#([0-9a-fA-F])([0-9a-fA-F])([0-9a-fA-F])/,Ha=/^#(?:[0-9a-f]{3}){1,2}$/i,Ia=/^(?:rgba)?\((\d{1,3}),\s?(\d{1,3}),\s?(\d{1,3}),\s?(0|1|0\.\d*)\)$/i,Ja=/^(?:rgb)?\((0|[1-9]\d{0,2}),\s?(0|[1-9]\d{0,2}),\s?(0|[1-9]\d{0,2})\)$/i;function r(a,b){this.code=a;this.a=t[a]||Ka;this.message=b||"";var c=this.a.replace(/((?:^|\s+)[a-z])/g,function(a){return a.toUpperCase().replace(/^[\s\xa0]+/g,"")}),d=c.length-5;if(0>d||c.indexOf("Error",d)!=d)c+="Error";this.name=c;c=Error(this.message);c.name=this.name;this.stack=c.stack||""}p(r,Error);var Ka="unknown error",t={15:"element not selectable",11:"element not visible"};t[31]=Ka;t[30]=Ka;t[24]="invalid cookie domain";t[29]="invalid element coordinates";t[12]="invalid element state";
t[32]="invalid selector";t[51]="invalid selector";t[52]="invalid selector";t[17]="javascript error";t[405]="unsupported operation";t[34]="move target out of bounds";t[27]="no such alert";t[7]="no such element";t[8]="no such frame";t[23]="no such window";t[28]="script timeout";t[33]="session not created";t[10]="stale element reference";t[21]="timeout";t[25]="unable to set cookie";t[26]="unexpected alert open";t[13]=Ka;t[9]="unknown command";r.prototype.toString=function(){return this.name+": "+this.message};var La;a:{var Ma=aa.navigator;if(Ma){var Na=Ma.userAgent;if(Na){La=Na;break a}}La=""}function w(a){return-1!=La.indexOf(a)};function Oa(a,b){var c={},d;for(d in a)b.call(void 0,a[d],d,a)&&(c[d]=a[d]);return c}function Pa(a,b){var c={},d;for(d in a)c[d]=b.call(void 0,a[d],d,a);return c}function Qa(a){var b=[],c=0,d;for(d in a)b[c++]=a[d];return b}function Ra(a,b){return null!==a&&b in a}function Sa(a,b){for(var c in a)if(b.call(void 0,a[c],c,a))return c};function Ta(){return w("Opera")||w("OPR")}function Ua(){return(w("Chrome")||w("CriOS"))&&!Ta()&&!w("Edge")};function Va(){return w("iPhone")&&!w("iPod")&&!w("iPad")};var Wa=Ta(),x=w("Trident")||w("MSIE"),Xa=w("Edge"),z=w("Gecko")&&!(-1!=La.toLowerCase().indexOf("webkit")&&!w("Edge"))&&!(w("Trident")||w("MSIE"))&&!w("Edge"),Ya=-1!=La.toLowerCase().indexOf("webkit")&&!w("Edge"),Za=Ya&&w("Mobile"),$a=w("Macintosh"),ab=w("Windows");function bb(){var a=La;if(z)return/rv\:([^\);]+)(\)|;)/.exec(a);if(Xa)return/Edge\/([\d\.]+)/.exec(a);if(x)return/\b(?:MSIE|rv)[: ]([^\);]+)(\)|;)/.exec(a);if(Ya)return/WebKit\/(\S+)/.exec(a)}
function cb(){var a=aa.document;return a?a.documentMode:void 0}var db=function(){if(Wa&&aa.opera){var a;var b=aa.opera.version;try{a=b()}catch(c){a=b}return a}a="";(b=bb())&&(a=b?b[1]:"");return x&&(b=cb(),null!=b&&b>parseFloat(a))?String(b):a}(),eb={};function fb(a){return eb[a]||(eb[a]=0<=sa(db,a))}var gb=aa.document,hb=gb&&x?cb()||("CSS1Compat"==gb.compatMode?parseInt(db,10):5):void 0;!z&&!x||x&&9<=Number(hb)||z&&fb("1.9.1");x&&fb("9");function ib(a,b){this.x=l(a)?a:0;this.y=l(b)?b:0}h=ib.prototype;h.clone=function(){return new ib(this.x,this.y)};h.toString=function(){return"("+this.x+", "+this.y+")"};h.ceil=function(){this.x=Math.ceil(this.x);this.y=Math.ceil(this.y);return this};h.floor=function(){this.x=Math.floor(this.x);this.y=Math.floor(this.y);return this};h.round=function(){this.x=Math.round(this.x);this.y=Math.round(this.y);return this};h.scale=function(a,b){var c=ea(b)?b:a;this.x*=a;this.y*=c;return this};function jb(a,b){this.width=a;this.height=b}h=jb.prototype;h.clone=function(){return new jb(this.width,this.height)};h.toString=function(){return"("+this.width+" x "+this.height+")"};h.ceil=function(){this.width=Math.ceil(this.width);this.height=Math.ceil(this.height);return this};h.floor=function(){this.width=Math.floor(this.width);this.height=Math.floor(this.height);return this};h.round=function(){this.width=Math.round(this.width);this.height=Math.round(this.height);return this};
h.scale=function(a,b){var c=ea(b)?b:a;this.width*=a;this.height*=c;return this};function kb(a){return a?new lb(A(a)):pa||(pa=new lb)}function mb(a){return a?a.parentWindow||a.defaultView:window}function nb(a){for(;a&&1!=a.nodeType;)a=a.previousSibling;return a}function ob(a,b){if(!a||!b)return!1;if(a.contains&&1==b.nodeType)return a==b||a.contains(b);if("undefined"!=typeof a.compareDocumentPosition)return a==b||!!(a.compareDocumentPosition(b)&16);for(;b&&a!=b;)b=b.parentNode;return b==a}
function pb(a,b){if(a==b)return 0;if(a.compareDocumentPosition)return a.compareDocumentPosition(b)&2?1:-1;if(x&&!(9<=Number(hb))){if(9==a.nodeType)return-1;if(9==b.nodeType)return 1}if("sourceIndex"in a||a.parentNode&&"sourceIndex"in a.parentNode){var c=1==a.nodeType,d=1==b.nodeType;if(c&&d)return a.sourceIndex-b.sourceIndex;var e=a.parentNode,f=b.parentNode;return e==f?qb(a,b):!c&&ob(e,b)?-1*rb(a,b):!d&&ob(f,a)?rb(b,a):(c?a.sourceIndex:e.sourceIndex)-(d?b.sourceIndex:f.sourceIndex)}d=A(a);c=d.createRange();
c.selectNode(a);c.collapse(!0);d=d.createRange();d.selectNode(b);d.collapse(!0);return c.compareBoundaryPoints(aa.Range.START_TO_END,d)}function rb(a,b){var c=a.parentNode;if(c==b)return-1;for(var d=b;d.parentNode!=c;)d=d.parentNode;return qb(d,a)}function qb(a,b){for(var c=b;c=c.previousSibling;)if(c==a)return-1;return 1}function A(a){return 9==a.nodeType?a:a.ownerDocument||a.document}var sb={SCRIPT:1,STYLE:1,HEAD:1,IFRAME:1,OBJECT:1},tb={IMG:" ",BR:"\n"};
function ub(a,b,c){if(!(a.nodeName in sb))if(3==a.nodeType)c?b.push(String(a.nodeValue).replace(/(\r\n|\r|\n)/g,"")):b.push(a.nodeValue);else if(a.nodeName in tb)b.push(tb[a.nodeName]);else for(a=a.firstChild;a;)ub(a,b,c),a=a.nextSibling}function vb(a,b,c){c||(a=a.parentNode);for(c=0;a;){if(b(a))return a;a=a.parentNode;c++}return null}function lb(a){this.a=a||aa.document||document}
function wb(a,b,c,d){a=d||a.a;b=b&&"*"!=b?b.toUpperCase():"";if(a.querySelectorAll&&a.querySelector&&(b||c))c=a.querySelectorAll(b+(c?"."+c:""));else if(c&&a.getElementsByClassName)if(a=a.getElementsByClassName(c),b){d={};for(var e=0,f=0,g;g=a[f];f++)b==g.nodeName&&(d[e++]=g);d.length=e;c=d}else c=a;else if(a=a.getElementsByTagName(b||"*"),c){d={};for(f=e=0;g=a[f];f++)b=g.className,"function"==typeof b.split&&Ba(b.split(/\s+/),c)&&(d[e++]=g);d.length=e;c=d}else c=a;return c}
lb.prototype.contains=ob;var xb=w("Firefox"),yb=Va()||w("iPod"),zb=w("iPad"),Ab=w("Android")&&!(Ua()||w("Firefox")||Ta()||w("Silk")),Bb=Ua(),Cb=w("Safari")&&!(Ua()||w("Coast")||Ta()||w("Edge")||w("Silk")||w("Android"))&&!(Va()||w("iPad")||w("iPod"));/*

 The MIT License

 Copyright (c) 2007 Cybozu Labs, Inc.
 Copyright (c) 2012 Google Inc.

 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to
 deal in the Software without restriction, including without limitation the
 rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
 sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in
 all copies or substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 IN THE SOFTWARE.
*/
function Db(a,b,c){this.a=a;this.b=b||1;this.f=c||1};var Eb=x&&!(9<=Number(hb)),Fb=x&&!(8<=Number(hb));function Gb(a,b,c,d){this.a=a;this.nodeName=c;this.nodeValue=d;this.nodeType=2;this.parentNode=this.ownerElement=b}function Hb(a,b){var c=Fb&&"href"==b.nodeName?a.getAttribute(b.nodeName,2):b.nodeValue;return new Gb(b,a,b.nodeName,c)};function Ib(a){this.b=a;this.a=0}function Kb(a){a=a.match(Lb);for(var b=0;b<a.length;b++)Mb.test(a[b])&&a.splice(b,1);return new Ib(a)}var Lb=RegExp("\\$?(?:(?![0-9-\\.])(?:\\*|[\\w-\\.]+):)?(?![0-9-\\.])(?:\\*|[\\w-\\.]+)|\\/\\/|\\.\\.|::|\\d+(?:\\.\\d*)?|\\.\\d+|\"[^\"]*\"|'[^']*'|[!<>]=|\\s+|.","g"),Mb=/^\s/;function B(a,b){return a.b[a.a+(b||0)]}function C(a){return a.b[a.a++]}function Nb(a){return a.b.length<=a.a};function Ob(a){var b=null,c=a.nodeType;1==c&&(b=a.textContent,b=void 0==b||null==b?a.innerText:b,b=void 0==b||null==b?"":b);if("string"!=typeof b)if(Eb&&"title"==a.nodeName.toLowerCase()&&1==c)b=a.text;else if(9==c||1==c){a=9==c?a.documentElement:a.firstChild;for(var c=0,d=[],b="";a;){do 1!=a.nodeType&&(b+=a.nodeValue),Eb&&"title"==a.nodeName.toLowerCase()&&(b+=a.text),d[c++]=a;while(a=a.firstChild);for(;c&&!(a=d[--c].nextSibling););}}else b=a.nodeValue;return""+b}
function Pb(a,b,c){if(null===b)return!0;try{if(!a.getAttribute)return!1}catch(d){return!1}Fb&&"class"==b&&(b="className");return null==c?!!a.getAttribute(b):a.getAttribute(b,2)==c}function Qb(a,b,c,d,e){return(Eb?Rb:Sb).call(null,a,b,m(c)?c:null,m(d)?d:null,e||new D)}
function Rb(a,b,c,d,e){if(a instanceof Tb||8==a.b||c&&null===a.b){var f=b.all;if(!f)return e;a=Ub(a);if("*"!=a&&(f=b.getElementsByTagName(a),!f))return e;if(c){for(var g=[],k=0;b=f[k++];)Pb(b,c,d)&&g.push(b);f=g}for(k=0;b=f[k++];)"*"==a&&"!"==b.tagName||F(e,b);return e}Vb(a,b,c,d,e);return e}
function Sb(a,b,c,d,e){b.getElementsByName&&d&&"name"==c&&!x?(b=b.getElementsByName(d),q(b,function(b){a.a(b)&&F(e,b)})):b.getElementsByClassName&&d&&"class"==c?(b=b.getElementsByClassName(d),q(b,function(b){b.className==d&&a.a(b)&&F(e,b)})):a instanceof Wb?Vb(a,b,c,d,e):b.getElementsByTagName&&(b=b.getElementsByTagName(a.f()),q(b,function(a){Pb(a,c,d)&&F(e,a)}));return e}
function Xb(a,b,c,d,e){var f;if((a instanceof Tb||8==a.b||c&&null===a.b)&&(f=b.childNodes)){var g=Ub(a);if("*"!=g&&(f=va(f,function(a){return a.tagName&&a.tagName.toLowerCase()==g}),!f))return e;c&&(f=va(f,function(a){return Pb(a,c,d)}));q(f,function(a){"*"==g&&("!"==a.tagName||"*"==g&&1!=a.nodeType)||F(e,a)});return e}return Yb(a,b,c,d,e)}function Yb(a,b,c,d,e){for(b=b.firstChild;b;b=b.nextSibling)Pb(b,c,d)&&a.a(b)&&F(e,b);return e}
function Vb(a,b,c,d,e){for(b=b.firstChild;b;b=b.nextSibling)Pb(b,c,d)&&a.a(b)&&F(e,b),Vb(a,b,c,d,e)}function Ub(a){if(a instanceof Wb){if(8==a.b)return"!";if(null===a.b)return"*"}return a.f()};function D(){this.b=this.a=null;this.o=0}function Zb(a){this.node=a;this.a=this.b=null}function $b(a,b){if(!a.a)return b;if(!b.a)return a;for(var c=a.a,d=b.a,e=null,f=null,g=0;c&&d;){var f=c.node,k=d.node;f==k||f instanceof Gb&&k instanceof Gb&&f.a==k.a?(f=c,c=c.a,d=d.a):0<pb(c.node,d.node)?(f=d,d=d.a):(f=c,c=c.a);(f.b=e)?e.a=f:a.a=f;e=f;g++}for(f=c||d;f;)f.b=e,e=e.a=f,g++,f=f.a;a.b=e;a.o=g;return a}
D.prototype.unshift=function(a){a=new Zb(a);a.a=this.a;this.b?this.a.b=a:this.a=this.b=a;this.a=a;this.o++};function F(a,b){var c=new Zb(b);c.b=a.b;a.a?a.b.a=c:a.a=a.b=c;a.b=c;a.o++}function ac(a){return(a=a.a)?a.node:null}function bc(a){return(a=ac(a))?Ob(a):""}function cc(a,b){return new dc(a,!!b)}function dc(a,b){this.f=a;this.b=(this.c=b)?a.b:a.a;this.a=null}function G(a){var b=a.b;if(null==b)return null;var c=a.a=b;a.b=a.c?b.b:b.a;return c.node};function H(a){this.l=a;this.b=this.j=!1;this.f=null}function I(a){return"\n  "+a.toString().split("\n").join("\n  ")}function ec(a,b){a.j=b}function fc(a,b){a.b=b}function J(a,b){var c=a.a(b);return c instanceof D?+bc(c):+c}function K(a,b){var c=a.a(b);return c instanceof D?bc(c):""+c}function gc(a,b){var c=a.a(b);return c instanceof D?!!c.o:!!c};function hc(a,b,c){H.call(this,a.l);this.c=a;this.i=b;this.v=c;this.j=b.j||c.j;this.b=b.b||c.b;this.c==ic&&(c.b||c.j||4==c.l||0==c.l||!b.f?b.b||b.j||4==b.l||0==b.l||!c.f||(this.f={name:c.f.name,B:b}):this.f={name:b.f.name,B:c})}p(hc,H);
function jc(a,b,c,d,e){b=b.a(d);c=c.a(d);var f;if(b instanceof D&&c instanceof D){b=cc(b);for(d=G(b);d;d=G(b))for(e=cc(c),f=G(e);f;f=G(e))if(a(Ob(d),Ob(f)))return!0;return!1}if(b instanceof D||c instanceof D){b instanceof D?(e=b,d=c):(e=c,d=b);f=cc(e);for(var g=typeof d,k=G(f);k;k=G(f)){switch(g){case "number":k=+Ob(k);break;case "boolean":k=!!Ob(k);break;case "string":k=Ob(k);break;default:throw Error("Illegal primitive type for comparison.");}if(e==b&&a(k,d)||e==c&&a(d,k))return!0}return!1}return e?
"boolean"==typeof b||"boolean"==typeof c?a(!!b,!!c):"number"==typeof b||"number"==typeof c?a(+b,+c):a(b,c):a(+b,+c)}hc.prototype.a=function(a){return this.c.u(this.i,this.v,a)};hc.prototype.toString=function(){var a="Binary Expression: "+this.c,a=a+I(this.i);return a+=I(this.v)};function kc(a,b,c,d){this.a=a;this.M=b;this.l=c;this.u=d}kc.prototype.toString=function(){return this.a};var lc={};
function L(a,b,c,d){if(lc.hasOwnProperty(a))throw Error("Binary operator already created: "+a);a=new kc(a,b,c,d);return lc[a.toString()]=a}L("div",6,1,function(a,b,c){return J(a,c)/J(b,c)});L("mod",6,1,function(a,b,c){return J(a,c)%J(b,c)});L("*",6,1,function(a,b,c){return J(a,c)*J(b,c)});L("+",5,1,function(a,b,c){return J(a,c)+J(b,c)});L("-",5,1,function(a,b,c){return J(a,c)-J(b,c)});L("<",4,2,function(a,b,c){return jc(function(a,b){return a<b},a,b,c)});
L(">",4,2,function(a,b,c){return jc(function(a,b){return a>b},a,b,c)});L("<=",4,2,function(a,b,c){return jc(function(a,b){return a<=b},a,b,c)});L(">=",4,2,function(a,b,c){return jc(function(a,b){return a>=b},a,b,c)});var ic=L("=",3,2,function(a,b,c){return jc(function(a,b){return a==b},a,b,c,!0)});L("!=",3,2,function(a,b,c){return jc(function(a,b){return a!=b},a,b,c,!0)});L("and",2,2,function(a,b,c){return gc(a,c)&&gc(b,c)});L("or",1,2,function(a,b,c){return gc(a,c)||gc(b,c)});function mc(a,b){if(b.a.length&&4!=a.l)throw Error("Primary expression must evaluate to nodeset if filter has predicate(s).");H.call(this,a.l);this.c=a;this.i=b;this.j=a.j;this.b=a.b}p(mc,H);mc.prototype.a=function(a){a=this.c.a(a);return nc(this.i,a)};mc.prototype.toString=function(){var a;a="Filter:"+I(this.c);return a+=I(this.i)};function oc(a,b){if(b.length<a.N)throw Error("Function "+a.m+" expects at least"+a.N+" arguments, "+b.length+" given");if(null!==a.G&&b.length>a.G)throw Error("Function "+a.m+" expects at most "+a.G+" arguments, "+b.length+" given");a.T&&q(b,function(b,d){if(4!=b.l)throw Error("Argument "+d+" to function "+a.m+" is not of type Nodeset: "+b);});H.call(this,a.l);this.i=a;this.c=b;ec(this,a.j||ya(b,function(a){return a.j}));fc(this,a.S&&!b.length||a.R&&!!b.length||ya(b,function(a){return a.b}))}
p(oc,H);oc.prototype.a=function(a){return this.i.u.apply(null,Ca(a,this.c))};oc.prototype.toString=function(){var a="Function: "+this.i;if(this.c.length)var b=xa(this.c,function(a,b){return a+I(b)},"Arguments:"),a=a+I(b);return a};function pc(a,b,c,d,e,f,g,k,n){this.m=a;this.l=b;this.j=c;this.S=d;this.R=e;this.u=f;this.N=g;this.G=l(k)?k:g;this.T=!!n}pc.prototype.toString=function(){return this.m};var qc={};
function N(a,b,c,d,e,f,g,k){if(qc.hasOwnProperty(a))throw Error("Function already created: "+a+".");qc[a]=new pc(a,b,c,d,!1,e,f,g,k)}N("boolean",2,!1,!1,function(a,b){return gc(b,a)},1);N("ceiling",1,!1,!1,function(a,b){return Math.ceil(J(b,a))},1);N("concat",3,!1,!1,function(a,b){return xa(Da(arguments,1),function(b,d){return b+K(d,a)},"")},2,null);N("contains",2,!1,!1,function(a,b,c){b=K(b,a);a=K(c,a);return-1!=b.indexOf(a)},2);N("count",1,!1,!1,function(a,b){return b.a(a).o},1,1,!0);
N("false",2,!1,!1,function(){return!1},0);N("floor",1,!1,!1,function(a,b){return Math.floor(J(b,a))},1);N("id",4,!1,!1,function(a,b){function c(a){if(Eb){var b=e.all[a];if(b){if(b.nodeType&&a==b.id)return b;if(b.length)return Aa(b,function(b){return a==b.id})}return null}return e.getElementById(a)}var d=a.a,e=9==d.nodeType?d:d.ownerDocument,d=K(b,a).split(/\s+/),f=[];q(d,function(a){(a=c(a))&&!Ba(f,a)&&f.push(a)});f.sort(pb);var g=new D;q(f,function(a){F(g,a)});return g},1);
N("lang",2,!1,!1,function(){return!1},1);N("last",1,!0,!1,function(a){if(1!=arguments.length)throw Error("Function last expects ()");return a.f},0);N("local-name",3,!1,!0,function(a,b){var c=b?ac(b.a(a)):a.a;return c?c.localName||c.nodeName.toLowerCase():""},0,1,!0);N("name",3,!1,!0,function(a,b){var c=b?ac(b.a(a)):a.a;return c?c.nodeName.toLowerCase():""},0,1,!0);N("namespace-uri",3,!0,!1,function(){return""},0,1,!0);
N("normalize-space",3,!1,!0,function(a,b){return(b?K(b,a):Ob(a.a)).replace(/[\s\xa0]+/g," ").replace(/^\s+|\s+$/g,"")},0,1);N("not",2,!1,!1,function(a,b){return!gc(b,a)},1);N("number",1,!1,!0,function(a,b){return b?J(b,a):+Ob(a.a)},0,1);N("position",1,!0,!1,function(a){return a.b},0);N("round",1,!1,!1,function(a,b){return Math.round(J(b,a))},1);N("starts-with",2,!1,!1,function(a,b,c){b=K(b,a);a=K(c,a);return 0==b.lastIndexOf(a,0)},2);N("string",3,!1,!0,function(a,b){return b?K(b,a):Ob(a.a)},0,1);
N("string-length",1,!1,!0,function(a,b){return(b?K(b,a):Ob(a.a)).length},0,1);N("substring",3,!1,!1,function(a,b,c,d){c=J(c,a);if(isNaN(c)||Infinity==c||-Infinity==c)return"";d=d?J(d,a):Infinity;if(isNaN(d)||-Infinity===d)return"";c=Math.round(c)-1;var e=Math.max(c,0);a=K(b,a);return Infinity==d?a.substring(e):a.substring(e,c+Math.round(d))},2,3);N("substring-after",3,!1,!1,function(a,b,c){b=K(b,a);a=K(c,a);c=b.indexOf(a);return-1==c?"":b.substring(c+a.length)},2);
N("substring-before",3,!1,!1,function(a,b,c){b=K(b,a);a=K(c,a);a=b.indexOf(a);return-1==a?"":b.substring(0,a)},2);N("sum",1,!1,!1,function(a,b){for(var c=cc(b.a(a)),d=0,e=G(c);e;e=G(c))d+=+Ob(e);return d},1,1,!0);N("translate",3,!1,!1,function(a,b,c,d){b=K(b,a);c=K(c,a);var e=K(d,a);a={};for(d=0;d<c.length;d++){var f=c.charAt(d);f in a||(a[f]=e.charAt(d))}c="";for(d=0;d<b.length;d++)f=b.charAt(d),c+=f in a?a[f]:f;return c},3);N("true",2,!1,!1,function(){return!0},0);function Wb(a,b){this.i=a;this.c=l(b)?b:null;this.b=null;switch(a){case "comment":this.b=8;break;case "text":this.b=3;break;case "processing-instruction":this.b=7;break;case "node":break;default:throw Error("Unexpected argument");}}function rc(a){return"comment"==a||"text"==a||"processing-instruction"==a||"node"==a}Wb.prototype.a=function(a){return null===this.b||this.b==a.nodeType};Wb.prototype.f=function(){return this.i};
Wb.prototype.toString=function(){var a="Kind Test: "+this.i;null===this.c||(a+=I(this.c));return a};function sc(a){H.call(this,3);this.c=a.substring(1,a.length-1)}p(sc,H);sc.prototype.a=function(){return this.c};sc.prototype.toString=function(){return"Literal: "+this.c};function Tb(a,b){this.m=a.toLowerCase();var c;c="*"==this.m?"*":"http://www.w3.org/1999/xhtml";this.c=b?b.toLowerCase():c}Tb.prototype.a=function(a){var b=a.nodeType;return 1!=b&&2!=b?!1:"*"!=this.m&&this.m!=a.localName.toLowerCase()?!1:"*"==this.c?!0:this.c==(a.namespaceURI?a.namespaceURI.toLowerCase():"http://www.w3.org/1999/xhtml")};Tb.prototype.f=function(){return this.m};Tb.prototype.toString=function(){return"Name Test: "+("http://www.w3.org/1999/xhtml"==this.c?"":this.c+":")+this.m};function tc(a){H.call(this,1);this.c=a}p(tc,H);tc.prototype.a=function(){return this.c};tc.prototype.toString=function(){return"Number: "+this.c};function uc(a,b){H.call(this,a.l);this.i=a;this.c=b;this.j=a.j;this.b=a.b;if(1==this.c.length){var c=this.c[0];c.D||c.c!=vc||(c=c.v,"*"!=c.f()&&(this.f={name:c.f(),B:null}))}}p(uc,H);function wc(){H.call(this,4)}p(wc,H);wc.prototype.a=function(a){var b=new D;a=a.a;9==a.nodeType?F(b,a):F(b,a.ownerDocument);return b};wc.prototype.toString=function(){return"Root Helper Expression"};function xc(){H.call(this,4)}p(xc,H);xc.prototype.a=function(a){var b=new D;F(b,a.a);return b};xc.prototype.toString=function(){return"Context Helper Expression"};
function yc(a){return"/"==a||"//"==a}uc.prototype.a=function(a){var b=this.i.a(a);if(!(b instanceof D))throw Error("Filter expression must evaluate to nodeset.");a=this.c;for(var c=0,d=a.length;c<d&&b.o;c++){var e=a[c],f=cc(b,e.c.a),g;if(e.j||e.c!=zc)if(e.j||e.c!=Ac)for(g=G(f),b=e.a(new Db(g));null!=(g=G(f));)g=e.a(new Db(g)),b=$b(b,g);else g=G(f),b=e.a(new Db(g));else{for(g=G(f);(b=G(f))&&(!g.contains||g.contains(b))&&b.compareDocumentPosition(g)&8;g=b);b=e.a(new Db(g))}}return b};
uc.prototype.toString=function(){var a;a="Path Expression:"+I(this.i);if(this.c.length){var b=xa(this.c,function(a,b){return a+I(b)},"Steps:");a+=I(b)}return a};function Bc(a,b){this.a=a;this.b=!!b}
function nc(a,b,c){for(c=c||0;c<a.a.length;c++)for(var d=a.a[c],e=cc(b),f=b.o,g,k=0;g=G(e);k++){var n=a.b?f-k:k+1;g=d.a(new Db(g,n,f));if("number"==typeof g)n=n==g;else if("string"==typeof g||"boolean"==typeof g)n=!!g;else if(g instanceof D)n=0<g.o;else throw Error("Predicate.evaluate returned an unexpected type.");if(!n){n=e;g=n.f;var v=n.a;if(!v)throw Error("Next must be called at least once before remove.");var u=v.b,v=v.a;u?u.a=v:g.a=v;v?v.b=u:g.b=u;g.o--;n.a=null}}return b}
Bc.prototype.toString=function(){return xa(this.a,function(a,b){return a+I(b)},"Predicates:")};function Cc(a,b,c,d){H.call(this,4);this.c=a;this.v=b;this.i=c||new Bc([]);this.D=!!d;b=this.i;b=0<b.a.length?b.a[0].f:null;a.b&&b&&(a=b.name,a=Eb?a.toLowerCase():a,this.f={name:a,B:b.B});a:{a=this.i;for(b=0;b<a.a.length;b++)if(c=a.a[b],c.j||1==c.l||0==c.l){a=!0;break a}a=!1}this.j=a}p(Cc,H);
Cc.prototype.a=function(a){var b=a.a,c=null,c=this.f,d=null,e=null,f=0;c&&(d=c.name,e=c.B?K(c.B,a):null,f=1);if(this.D)if(this.j||this.c!=Dc)if(a=cc((new Cc(Ec,new Wb("node"))).a(a)),b=G(a))for(c=this.u(b,d,e,f);null!=(b=G(a));)c=$b(c,this.u(b,d,e,f));else c=new D;else c=Qb(this.v,b,d,e),c=nc(this.i,c,f);else c=this.u(a.a,d,e,f);return c};Cc.prototype.u=function(a,b,c,d){a=this.c.f(this.v,a,b,c);return a=nc(this.i,a,d)};
Cc.prototype.toString=function(){var a;a="Step:"+I("Operator: "+(this.D?"//":"/"));this.c.m&&(a+=I("Axis: "+this.c));a+=I(this.v);if(this.i.a.length){var b=xa(this.i.a,function(a,b){return a+I(b)},"Predicates:");a+=I(b)}return a};function Fc(a,b,c,d){this.m=a;this.f=b;this.a=c;this.b=d}Fc.prototype.toString=function(){return this.m};var Gc={};function O(a,b,c,d){if(Gc.hasOwnProperty(a))throw Error("Axis already created: "+a);b=new Fc(a,b,c,!!d);return Gc[a]=b}
O("ancestor",function(a,b){for(var c=new D,d=b;d=d.parentNode;)a.a(d)&&c.unshift(d);return c},!0);O("ancestor-or-self",function(a,b){var c=new D,d=b;do a.a(d)&&c.unshift(d);while(d=d.parentNode);return c},!0);
var vc=O("attribute",function(a,b){var c=new D,d=a.f();if("style"==d&&b.style&&Eb)return F(c,new Gb(b.style,b,"style",b.style.cssText)),c;var e=b.attributes;if(e)if(a instanceof Wb&&null===a.b||"*"==d)for(var d=0,f;f=e[d];d++)Eb?f.nodeValue&&F(c,Hb(b,f)):F(c,f);else(f=e.getNamedItem(d))&&(Eb?f.nodeValue&&F(c,Hb(b,f)):F(c,f));return c},!1),Dc=O("child",function(a,b,c,d,e){return(Eb?Xb:Yb).call(null,a,b,m(c)?c:null,m(d)?d:null,e||new D)},!1,!0);O("descendant",Qb,!1,!0);
var Ec=O("descendant-or-self",function(a,b,c,d){var e=new D;Pb(b,c,d)&&a.a(b)&&F(e,b);return Qb(a,b,c,d,e)},!1,!0),zc=O("following",function(a,b,c,d){var e=new D;do for(var f=b;f=f.nextSibling;)Pb(f,c,d)&&a.a(f)&&F(e,f),e=Qb(a,f,c,d,e);while(b=b.parentNode);return e},!1,!0);O("following-sibling",function(a,b){for(var c=new D,d=b;d=d.nextSibling;)a.a(d)&&F(c,d);return c},!1);O("namespace",function(){return new D},!1);
var Hc=O("parent",function(a,b){var c=new D;if(9==b.nodeType)return c;if(2==b.nodeType)return F(c,b.ownerElement),c;var d=b.parentNode;a.a(d)&&F(c,d);return c},!1),Ac=O("preceding",function(a,b,c,d){var e=new D,f=[];do f.unshift(b);while(b=b.parentNode);for(var g=1,k=f.length;g<k;g++){var n=[];for(b=f[g];b=b.previousSibling;)n.unshift(b);for(var v=0,u=n.length;v<u;v++)b=n[v],Pb(b,c,d)&&a.a(b)&&F(e,b),e=Qb(a,b,c,d,e)}return e},!0,!0);
O("preceding-sibling",function(a,b){for(var c=new D,d=b;d=d.previousSibling;)a.a(d)&&c.unshift(d);return c},!0);var Ic=O("self",function(a,b){var c=new D;a.a(b)&&F(c,b);return c},!1);function Jc(a){H.call(this,1);this.c=a;this.j=a.j;this.b=a.b}p(Jc,H);Jc.prototype.a=function(a){return-J(this.c,a)};Jc.prototype.toString=function(){return"Unary Expression: -"+I(this.c)};function Kc(a){H.call(this,4);this.c=a;ec(this,ya(this.c,function(a){return a.j}));fc(this,ya(this.c,function(a){return a.b}))}p(Kc,H);Kc.prototype.a=function(a){var b=new D;q(this.c,function(c){c=c.a(a);if(!(c instanceof D))throw Error("Path expression must evaluate to NodeSet.");b=$b(b,c)});return b};Kc.prototype.toString=function(){return xa(this.c,function(a,b){return a+I(b)},"Union Expression:")};function Lc(a,b){this.a=a;this.b=b}function Mc(a){for(var b,c=[];;){P(a,"Missing right hand side of binary expression.");b=Nc(a);var d=C(a.a);if(!d)break;var e=(d=lc[d]||null)&&d.M;if(!e){a.a.a--;break}for(;c.length&&e<=c[c.length-1].M;)b=new hc(c.pop(),c.pop(),b);c.push(b,d)}for(;c.length;)b=new hc(c.pop(),c.pop(),b);return b}function P(a,b){if(Nb(a.a))throw Error(b);}function Oc(a,b){var c=C(a.a);if(c!=b)throw Error("Bad token, expected: "+b+" got: "+c);}
function Pc(a){a=C(a.a);if(")"!=a)throw Error("Bad token: "+a);}function Qc(a){a=C(a.a);if(2>a.length)throw Error("Unclosed literal string");return new sc(a)}
function Rc(a){var b,c=[],d;if(yc(B(a.a))){b=C(a.a);d=B(a.a);if("/"==b&&(Nb(a.a)||"."!=d&&".."!=d&&"@"!=d&&"*"!=d&&!/(?![0-9])[\w]/.test(d)))return new wc;d=new wc;P(a,"Missing next location step.");b=Sc(a,b);c.push(b)}else{a:{b=B(a.a);d=b.charAt(0);switch(d){case "$":throw Error("Variable reference not allowed in HTML XPath");case "(":C(a.a);b=Mc(a);P(a,'unclosed "("');Oc(a,")");break;case '"':case "'":b=Qc(a);break;default:if(isNaN(+b))if(!rc(b)&&/(?![0-9])[\w]/.test(d)&&"("==B(a.a,1)){b=C(a.a);
b=qc[b]||null;C(a.a);for(d=[];")"!=B(a.a);){P(a,"Missing function argument list.");d.push(Mc(a));if(","!=B(a.a))break;C(a.a)}P(a,"Unclosed function argument list.");Pc(a);b=new oc(b,d)}else{b=null;break a}else b=new tc(+C(a.a))}"["==B(a.a)&&(d=new Bc(Tc(a)),b=new mc(b,d))}if(b)if(yc(B(a.a)))d=b;else return b;else b=Sc(a,"/"),d=new xc,c.push(b)}for(;yc(B(a.a));)b=C(a.a),P(a,"Missing next location step."),b=Sc(a,b),c.push(b);return new uc(d,c)}
function Sc(a,b){var c,d,e;if("/"!=b&&"//"!=b)throw Error('Step op should be "/" or "//"');if("."==B(a.a))return d=new Cc(Ic,new Wb("node")),C(a.a),d;if(".."==B(a.a))return d=new Cc(Hc,new Wb("node")),C(a.a),d;var f;if("@"==B(a.a))f=vc,C(a.a),P(a,"Missing attribute name");else if("::"==B(a.a,1)){if(!/(?![0-9])[\w]/.test(B(a.a).charAt(0)))throw Error("Bad token: "+C(a.a));c=C(a.a);f=Gc[c]||null;if(!f)throw Error("No axis with name: "+c);C(a.a);P(a,"Missing node name")}else f=Dc;c=B(a.a);if(/(?![0-9])[\w\*]/.test(c.charAt(0)))if("("==
B(a.a,1)){if(!rc(c))throw Error("Invalid node type: "+c);c=C(a.a);if(!rc(c))throw Error("Invalid type name: "+c);Oc(a,"(");P(a,"Bad nodetype");e=B(a.a).charAt(0);var g=null;if('"'==e||"'"==e)g=Qc(a);P(a,"Bad nodetype");Pc(a);c=new Wb(c,g)}else if(c=C(a.a),e=c.indexOf(":"),-1==e)c=new Tb(c);else{var g=c.substring(0,e),k;if("*"==g)k="*";else if(k=a.b(g),!k)throw Error("Namespace prefix not declared: "+g);c=c.substr(e+1);c=new Tb(c,k)}else throw Error("Bad token: "+C(a.a));e=new Bc(Tc(a),f.a);return d||
new Cc(f,c,e,"//"==b)}function Tc(a){for(var b=[];"["==B(a.a);){C(a.a);P(a,"Missing predicate expression.");var c=Mc(a);b.push(c);P(a,"Unclosed predicate expression.");Oc(a,"]")}return b}function Nc(a){if("-"==B(a.a))return C(a.a),new Jc(Nc(a));var b=Rc(a);if("|"!=B(a.a))a=b;else{for(b=[b];"|"==C(a.a);)P(a,"Missing next union location path."),b.push(Rc(a));a.a.a--;a=new Kc(b)}return a};function Uc(a){switch(a.nodeType){case 1:return ma(Vc,a);case 9:return Uc(a.documentElement);case 11:case 10:case 6:case 12:return Wc;default:return a.parentNode?Uc(a.parentNode):Wc}}function Wc(){return null}function Vc(a,b){if(a.prefix==b)return a.namespaceURI||"http://www.w3.org/1999/xhtml";var c=a.getAttributeNode("xmlns:"+b);return c&&c.specified?c.value||null:a.parentNode&&9!=a.parentNode.nodeType?Vc(a.parentNode,b):null};function Xc(a,b){if(!a.length)throw Error("Empty XPath expression.");var c=Kb(a);if(Nb(c))throw Error("Invalid XPath expression.");b?fa(b)||(b=la(b.lookupNamespaceURI,b)):b=function(){return null};var d=Mc(new Lc(c,b));if(!Nb(c))throw Error("Bad token: "+C(c));this.evaluate=function(a,b){var c=d.a(new Db(a));return new Q(c,b)}}
function Q(a,b){if(0==b)if(a instanceof D)b=4;else if("string"==typeof a)b=2;else if("number"==typeof a)b=1;else if("boolean"==typeof a)b=3;else throw Error("Unexpected evaluation result.");if(2!=b&&1!=b&&3!=b&&!(a instanceof D))throw Error("value could not be converted to the specified type");this.resultType=b;var c;switch(b){case 2:this.stringValue=a instanceof D?bc(a):""+a;break;case 1:this.numberValue=a instanceof D?+bc(a):+a;break;case 3:this.booleanValue=a instanceof D?0<a.o:!!a;break;case 4:case 5:case 6:case 7:var d=
cc(a);c=[];for(var e=G(d);e;e=G(d))c.push(e instanceof Gb?e.a:e);this.snapshotLength=a.o;this.invalidIteratorState=!1;break;case 8:case 9:d=ac(a);this.singleNodeValue=d instanceof Gb?d.a:d;break;default:throw Error("Unknown XPathResult type.");}var f=0;this.iterateNext=function(){if(4!=b&&5!=b)throw Error("iterateNext called with wrong result type");return f>=c.length?null:c[f++]};this.snapshotItem=function(a){if(6!=b&&7!=b)throw Error("snapshotItem called with wrong result type");return a>=c.length||
0>a?null:c[a]}}Q.ANY_TYPE=0;Q.NUMBER_TYPE=1;Q.STRING_TYPE=2;Q.BOOLEAN_TYPE=3;Q.UNORDERED_NODE_ITERATOR_TYPE=4;Q.ORDERED_NODE_ITERATOR_TYPE=5;Q.UNORDERED_NODE_SNAPSHOT_TYPE=6;Q.ORDERED_NODE_SNAPSHOT_TYPE=7;Q.ANY_UNORDERED_NODE_TYPE=8;Q.FIRST_ORDERED_NODE_TYPE=9;function Yc(a){this.lookupNamespaceURI=Uc(a)}
function Zc(a,b){var c=a||aa,d=c.document;if(!d.evaluate||b)c.XPathResult=Q,d.evaluate=function(a,b,c,d){return(new Xc(a,c)).evaluate(b,d)},d.createExpression=function(a,b){return new Xc(a,b)},d.createNSResolver=function(a){return new Yc(a)}}ba("wgxpath.install",Zc);var S={};S.H=function(){var a={W:"http://www.w3.org/2000/svg"};return function(b){return a[b]||null}}();
S.u=function(a,b,c){var d=A(a);if(!d.documentElement)return null;(x||Ab)&&Zc(mb(d));try{var e=d.createNSResolver?d.createNSResolver(d.documentElement):S.H;if(x&&!fb(7))return d.evaluate.call(d,b,a,e,c,null);if(!x||9<=Number(hb)){for(var f={},g=d.getElementsByTagName("*"),k=0;k<g.length;++k){var n=g[k],v=n.namespaceURI;if(v&&!f[v]){var u=n.lookupPrefix(v);if(!u)var E=v.match(".*/(\\w+)/?$"),u=E?E[1]:"xhtml";f[v]=u}}var y={},M;for(M in f)y[f[M]]=M;e=function(a){return y[a]||null}}try{return d.evaluate(b,
a,e,c,null)}catch(R){if("TypeError"===R.name)return e=d.createNSResolver?d.createNSResolver(d.documentElement):S.H,d.evaluate(b,a,e,c,null);throw R;}}catch(R){if(!z||"NS_ERROR_ILLEGAL_VALUE"!=R.name)throw new r(32,"Unable to locate an element with the xpath expression "+b+" because of the following error:\n"+R);}};S.I=function(a,b){if(!a||1!=a.nodeType)throw new r(32,'The result of the xpath expression "'+b+'" is: '+a+". It should be an element.");};
S.w=function(a,b){var c=function(){var c=S.u(b,a,9);return c?c.singleNodeValue||null:b.selectSingleNode?(c=A(b),c.setProperty&&c.setProperty("SelectionLanguage","XPath"),b.selectSingleNode(a)):null}();null===c||S.I(c,a);return c};
S.s=function(a,b){var c=function(){var c=S.u(b,a,7);if(c){for(var e=c.snapshotLength,f=[],g=0;g<e;++g)f.push(c.snapshotItem(g));return f}return b.selectNodes?(c=A(b),c.setProperty&&c.setProperty("SelectionLanguage","XPath"),b.selectNodes(a)):[]}();q(c,function(b){S.I(b,a)});return c};function $c(a){return(a=a.exec(La))?a[1]:""}var ad=function(){if(xb)return $c(/Firefox\/([0-9.]+)/);if(x||Xa||Wa)return db;if(Bb)return $c(/Chrome\/([0-9.]+)/);if(Cb&&!(Va()||w("iPad")||w("iPod")))return $c(/Version\/([0-9.]+)/);if(yb||zb){var a;if(a=/Version\/(\S+).*Mobile\/(\S+)/.exec(La))return a[1]+"."+a[2]}else if(Ab)return(a=$c(/Android\s+([0-9.]+)/))?a:$c(/Version\/([0-9.]+)/);return""}();var bd,cd;function dd(a){return ed?bd(a):x?0<=sa(hb,a):fb(a)}function fd(a){return ed?cd(a):Ab?0<=sa(gd,a):0<=sa(ad,a)}
var ed=function(){if(!z)return!1;var a=aa.Components;if(!a)return!1;try{if(!a.classes)return!1}catch(f){return!1}var b=a.classes,a=a.interfaces,c=b["@mozilla.org/xpcom/version-comparator;1"].getService(a.nsIVersionComparator),b=b["@mozilla.org/xre/app-info;1"].getService(a.nsIXULAppInfo),d=b.platformVersion,e=b.version;bd=function(a){return 0<=c.compare(d,""+a)};cd=function(a){return 0<=c.compare(e,""+a)};return!0}(),hd=zb||yb,id;
if(Ab){var jd=/Android\s+([0-9\.]+)/.exec(La);id=jd?jd[1]:"0"}else id="0";var gd=id,kd=x&&!(8<=Number(hb)),ld=x&&!(9<=Number(hb));Ab&&fd(2.3);Ab&&fd(4);Cb&&fd(6);function md(a,b,c,d){this.top=a;this.right=b;this.bottom=c;this.left=d}h=md.prototype;h.clone=function(){return new md(this.top,this.right,this.bottom,this.left)};h.toString=function(){return"("+this.top+"t, "+this.right+"r, "+this.bottom+"b, "+this.left+"l)"};h.contains=function(a){return this&&a?a instanceof md?a.left>=this.left&&a.right<=this.right&&a.top>=this.top&&a.bottom<=this.bottom:a.x>=this.left&&a.x<=this.right&&a.y>=this.top&&a.y<=this.bottom:!1};
h.ceil=function(){this.top=Math.ceil(this.top);this.right=Math.ceil(this.right);this.bottom=Math.ceil(this.bottom);this.left=Math.ceil(this.left);return this};h.floor=function(){this.top=Math.floor(this.top);this.right=Math.floor(this.right);this.bottom=Math.floor(this.bottom);this.left=Math.floor(this.left);return this};h.round=function(){this.top=Math.round(this.top);this.right=Math.round(this.right);this.bottom=Math.round(this.bottom);this.left=Math.round(this.left);return this};
h.scale=function(a,b){var c=ea(b)?b:a;this.left*=a;this.right*=a;this.top*=c;this.bottom*=c;return this};function T(a,b,c,d){this.left=a;this.top=b;this.width=c;this.height=d}h=T.prototype;h.clone=function(){return new T(this.left,this.top,this.width,this.height)};h.toString=function(){return"("+this.left+", "+this.top+" - "+this.width+"w x "+this.height+"h)"};h.contains=function(a){return a instanceof T?this.left<=a.left&&this.left+this.width>=a.left+a.width&&this.top<=a.top&&this.top+this.height>=a.top+a.height:a.x>=this.left&&a.x<=this.left+this.width&&a.y>=this.top&&a.y<=this.top+this.height};
h.ceil=function(){this.left=Math.ceil(this.left);this.top=Math.ceil(this.top);this.width=Math.ceil(this.width);this.height=Math.ceil(this.height);return this};h.floor=function(){this.left=Math.floor(this.left);this.top=Math.floor(this.top);this.width=Math.floor(this.width);this.height=Math.floor(this.height);return this};h.round=function(){this.left=Math.round(this.left);this.top=Math.round(this.top);this.width=Math.round(this.width);this.height=Math.round(this.height);return this};
h.scale=function(a,b){var c=ea(b)?b:a;this.left*=a;this.width*=a;this.top*=c;this.height*=c;return this};function nd(a,b){var c=A(a);return c.defaultView&&c.defaultView.getComputedStyle&&(c=c.defaultView.getComputedStyle(a,null))?c[b]||c.getPropertyValue(b)||"":""}var od={thin:2,medium:4,thick:6};
function pd(a,b){if("none"==(a.currentStyle?a.currentStyle[b+"Style"]:null))return 0;var c=a.currentStyle?a.currentStyle[b+"Width"]:null,d;if(c in od)d=od[c];else if(/^\d+px?$/.test(c))d=parseInt(c,10);else{d=a.style.left;var e=a.runtimeStyle.left;a.runtimeStyle.left=a.currentStyle.left;a.style.left=c;c=a.style.pixelLeft;a.style.left=d;a.runtimeStyle.left=e;d=c}return d};function qd(a){var b;a:{a=A(a);try{b=a&&a.activeElement;break a}catch(c){}b=null}return x&&b&&"undefined"===typeof b.nodeType?null:b}function U(a,b){return!!a&&1==a.nodeType&&(!b||a.tagName.toUpperCase()==b)}function rd(a){var b;if(b=sd(a,!0)&&td(a))b=!(x||z&&!dd("1.9.2")?0:"none"==V(a,"pointer-events"));return b}function ud(a,b){var c;if(c=kd&&"value"==b&&U(a,"OPTION"))c=null===vd(a,"value");c?(c=[],ub(a,c,!1),c=c.join("")):c=a[b];return c}var wd=/[;]+(?=(?:(?:[^"]*"){2})*[^"]*$)(?=(?:(?:[^']*'){2})*[^']*$)(?=(?:[^()]*\([^()]*\))*[^()]*$)/;
function xd(a){var b=[];q(a.split(wd),function(a){var d=a.indexOf(":");0<d&&(a=[a.slice(0,d),a.slice(d+1)],2==a.length&&b.push(a[0].toLowerCase(),":",a[1],";"))});b=b.join("");return b=";"==b.charAt(b.length-1)?b:b+";"}function vd(a,b){b=b.toLowerCase();if("style"==b)return xd(a.style.cssText);if(kd&&"value"==b&&U(a,"INPUT"))return a.value;if(ld&&!0===a[b])return String(a.getAttribute(b));var c=a.getAttributeNode(b);return c&&c.specified?c.value:null}var yd="BUTTON INPUT OPTGROUP OPTION SELECT TEXTAREA".split(" ");
function td(a){var b=a.tagName.toUpperCase();return Ba(yd,b)?ud(a,"disabled")?!1:a.parentNode&&1==a.parentNode.nodeType&&"OPTGROUP"==b||"OPTION"==b?td(a.parentNode):!vb(a,function(a){var b=a.parentNode;if(b&&U(b,"FIELDSET")&&ud(b,"disabled")){if(!U(a,"LEGEND"))return!0;for(;a=l(a.previousElementSibling)?a.previousElementSibling:nb(a.previousSibling);)if(U(a,"LEGEND"))return!0}return!1},!0):!0}var zd="text search tel url email password number".split(" ");
function Ad(a){function b(a){return"inherit"==a.contentEditable?(a=Bd(a))?b(a):!1:"true"==a.contentEditable}return l(a.contentEditable)?!x&&l(a.isContentEditable)?a.isContentEditable:b(a):!1}function Cd(a){return((U(a,"TEXTAREA")?!0:U(a,"INPUT")?Ba(zd,a.type.toLowerCase()):Ad(a)?!0:!1)||(U(a,"INPUT")?"file"==a.type.toLowerCase():!1))&&!ud(a,"readOnly")}function Bd(a){for(a=a.parentNode;a&&1!=a.nodeType&&9!=a.nodeType&&11!=a.nodeType;)a=a.parentNode;return U(a)?a:null}
function V(a,b){var c=ua(b);if("float"==c||"cssFloat"==c||"styleFloat"==c)c=ld?"styleFloat":"cssFloat";var d=nd(a,c)||Dd(a,c);if(null===d)d=null;else if(Ba(Fa,c)){b:{var e=d.match(Ia);if(e){var c=Number(e[1]),f=Number(e[2]),g=Number(e[3]),e=Number(e[4]);if(0<=c&&255>=c&&0<=f&&255>=f&&0<=g&&255>=g&&0<=e&&1>=e){c=[c,f,g,e];break b}}c=null}if(!c)b:{if(g=d.match(Ja))if(c=Number(g[1]),f=Number(g[2]),g=Number(g[3]),0<=c&&255>=c&&0<=f&&255>=f&&0<=g&&255>=g){c=[c,f,g,1];break b}c=null}if(!c)b:{c=d.toLowerCase();
f=Ea[c.toLowerCase()];if(!f&&(f="#"==c.charAt(0)?c:"#"+c,4==f.length&&(f=f.replace(Ga,"#$1$1$2$2$3$3")),!Ha.test(f))){c=null;break b}c=[parseInt(f.substr(1,2),16),parseInt(f.substr(3,2),16),parseInt(f.substr(5,2),16),1]}d=c?"rgba("+c.join(", ")+")":d}return d}function Dd(a,b){var c=a.currentStyle||a.style,d=c[b];!l(d)&&fa(c.getPropertyValue)&&(d=c.getPropertyValue(b));return"inherit"!=d?l(d)?d:null:(c=Bd(a))?Dd(c,b):null}
function Ed(a,b,c){function d(a){var b=Fd(a);return 0<b.height&&0<b.width?!0:U(a,"PATH")&&(0<b.height||0<b.width)?(a=V(a,"stroke-width"),!!a&&0<parseInt(a,10)):"hidden"!=V(a,"overflow")&&ya(a.childNodes,function(a){return 3==a.nodeType||U(a)&&d(a)})}function e(a){return Gd(a)==Hd&&za(a.childNodes,function(a){return!U(a)||e(a)||!d(a)})}if(!U(a))throw Error("Argument to isShown must be of type Element");if(U(a,"BODY"))return!0;if(U(a,"OPTION")||U(a,"OPTGROUP"))return a=vb(a,function(a){return U(a,"SELECT")}),
!!a&&Ed(a,!0,c);var f=Id(a);if(f)return!!f.J&&0<f.rect.width&&0<f.rect.height&&Ed(f.J,b,c);if(U(a,"INPUT")&&"hidden"==a.type.toLowerCase()||U(a,"NOSCRIPT"))return!1;f=V(a,"visibility");return"collapse"!=f&&"hidden"!=f&&c(a)&&(b||0!=Jd(a))&&d(a)?!e(a):!1}function sd(a,b){function c(a){if("none"==V(a,"display"))return!1;a=Bd(a);return!a||c(a)}return Ed(a,!!b,c)}var Hd="hidden";
function Gd(a,b){function c(a){function b(a){return a==k?!0:0==V(a,"display").lastIndexOf("inline",0)||"absolute"==c&&"static"==V(a,"position")?!1:!0}var c=V(a,"position");if("fixed"==c)return u=!0,a==k?null:k;for(a=Bd(a);a&&!b(a);)a=Bd(a);return a}function d(a){var b=a;if("visible"==v)if(a==k&&n)b=n;else if(a==n)return{x:"visible",y:"visible"};b={x:V(b,"overflow-x"),y:V(b,"overflow-y")};a==k&&(b.x="visible"==b.x?"auto":b.x,b.y="visible"==b.y?"auto":b.y);return b}function e(a){if(a==k){var b=(new lb(g)).a;
a=b.scrollingElement?b.scrollingElement:Ya||"CSS1Compat"!=b.compatMode?b.body||b.documentElement:b.documentElement;b=b.parentWindow||b.defaultView;a=x&&fb("10")&&b.pageYOffset!=a.scrollTop?new ib(a.scrollLeft,a.scrollTop):new ib(b.pageXOffset||a.scrollLeft,b.pageYOffset||a.scrollTop)}else a=new ib(a.scrollLeft,a.scrollTop);return a}for(var f=Kd(a,b),g=A(a),k=g.documentElement,n=g.body,v=V(k,"overflow"),u,E=c(a);E;E=c(E)){var y=d(E);if("visible"!=y.x||"visible"!=y.y){var M=Fd(E);if(0==M.width||0==
M.height)return Hd;var R=f.right<M.left,Jb=f.bottom<M.top;if(R&&"hidden"==y.x||Jb&&"hidden"==y.y)return Hd;if(R&&"visible"!=y.x||Jb&&"visible"!=y.y){R=e(E);Jb=f.bottom<M.top-R.y;if(f.right<M.left-R.x&&"visible"!=y.x||Jb&&"visible"!=y.x)return Hd;f=Gd(E);return f==Hd?Hd:"scroll"}R=f.left>=M.left+M.width;M=f.top>=M.top+M.height;if(R&&"hidden"==y.x||M&&"hidden"==y.y)return Hd;if(R&&"visible"!=y.x||M&&"visible"!=y.y){if(u&&(y=e(E),f.left>=k.scrollWidth-y.x||f.right>=k.scrollHeight-y.y))return Hd;f=Gd(E);
return f==Hd?Hd:"scroll"}}}return"none"}
function Fd(a){var b=Id(a);if(b)return b.rect;if(U(a,"HTML"))return a=A(a),a=(mb(a)||window).document,a="CSS1Compat"==a.compatMode?a.documentElement:a.body,a=new jb(a.clientWidth,a.clientHeight),new T(0,0,a.width,a.height);var c;try{c=a.getBoundingClientRect()}catch(d){return new T(0,0,0,0)}b=new T(c.left,c.top,c.right-c.left,c.bottom-c.top);x&&a.ownerDocument.body&&(a=A(a),b.left-=a.documentElement.clientLeft+a.body.clientLeft,b.top-=a.documentElement.clientTop+a.body.clientTop);return b}
function Id(a){var b=U(a,"MAP");if(!b&&!U(a,"AREA"))return null;var c=b?a:U(a.parentNode,"MAP")?a.parentNode:null,d=null,e=null;c&&c.name&&(d=S.w('/descendant::*[@usemap = "#'+c.name+'"]',A(c)))&&(e=Fd(d),b||"default"==a.shape.toLowerCase()||(a=Ld(a),b=Math.min(Math.max(a.left,0),e.width),c=Math.min(Math.max(a.top,0),e.height),e=new T(b+e.left,c+e.top,Math.min(a.width,e.width-b),Math.min(a.height,e.height-c))));return{J:d,rect:e||new T(0,0,0,0)}}
function Ld(a){var b=a.shape.toLowerCase();a=a.coords.split(",");if("rect"==b&&4==a.length){var b=a[0],c=a[1];return new T(b,c,a[2]-b,a[3]-c)}if("circle"==b&&3==a.length)return b=a[2],new T(a[0]-b,a[1]-b,2*b,2*b);if("poly"==b&&2<a.length){for(var b=a[0],c=a[1],d=b,e=c,f=2;f+1<a.length;f+=2)b=Math.min(b,a[f]),d=Math.max(d,a[f]),c=Math.min(c,a[f+1]),e=Math.max(e,a[f+1]);return new T(b,c,d-b,e-c)}return new T(0,0,0,0)}
function Kd(a,b){var c;c=Fd(a);c=new md(c.top,c.left+c.width,c.top+c.height,c.left);if(b){var d=b instanceof T?b:new T(b.x,b.y,1,1);c.left=Math.min(Math.max(c.left+d.left,c.left),c.right);c.top=Math.min(Math.max(c.top+d.top,c.top),c.bottom);c.right=Math.min(Math.max(c.left+d.width,c.left),c.right);c.bottom=Math.min(Math.max(c.top+d.height,c.top),c.bottom)}return c}function Md(a){return a.replace(/^[^\S\xa0]+|[^\S\xa0]+$/g,"")}
function Nd(a){var b=[];Od(a,b);a=wa(b,Md);return Md(a.join("\n")).replace(/\xa0/g," ")}
function Pd(a,b,c){var d=sd;if(U(a,"BR"))b.push("");else{var e=U(a,"TD"),f=V(a,"display"),g=!e&&!Ba(Qd,f),k=l(a.previousElementSibling)?a.previousElementSibling:nb(a.previousSibling),k=k?V(k,"display"):"",n=V(a,"float")||V(a,"cssFloat")||V(a,"styleFloat");!g||"run-in"==k&&"none"==n||/^[\s\xa0]*$/.test(b[b.length-1]||"")||b.push("");var v=d(a),u=null,E=null;v&&(u=V(a,"white-space"),E=V(a,"text-transform"));q(a.childNodes,function(a){c(a,b,v,u,E)});a=b[b.length-1]||"";!e&&"table-cell"!=f||!a||qa(a)||
(b[b.length-1]+=" ");g&&"run-in"!=f&&!/^[\s\xa0]*$/.test(a)&&b.push("")}}function Od(a,b){Pd(a,b,function(a,b,e,f,g){3==a.nodeType&&e?Rd(a,b,f,g):U(a)&&Od(a,b)})}var Qd="inline inline-block inline-table none table-cell table-column table-column-group".split(" ");
function Rd(a,b,c,d){a=a.nodeValue.replace(/[\u200b\u200e\u200f]/g,"");a=a.replace(/(\r\n|\r|\n)/g,"\n");if("normal"==c||"nowrap"==c)a=a.replace(/\n/g," ");a="pre"==c||"pre-wrap"==c?a.replace(/[ \f\t\v\u2028\u2029]/g,"\u00a0"):a.replace(/[\ \f\t\v\u2028\u2029]+/g," ");"capitalize"==d?a=a.replace(/(^|\s)(\S)/g,function(a,b,c){return b+c.toUpperCase()}):"uppercase"==d?a=a.toUpperCase():"lowercase"==d&&(a=a.toLowerCase());c=b.pop()||"";qa(c)&&0==a.lastIndexOf(" ",0)&&(a=a.substr(1));b.push(c+a)}
function Jd(a){if(ld){if("relative"==V(a,"position"))return 1;a=V(a,"filter");return(a=a.match(/^alpha\(opacity=(\d*)\)/)||a.match(/^progid:DXImageTransform.Microsoft.Alpha\(Opacity=(\d*)\)/))?Number(a[1])/100:1}return Sd(a)}function Sd(a){var b=1,c=V(a,"opacity");c&&(b=Number(c));(a=Bd(a))&&(b*=Sd(a));return b};var Td={C:function(a){return!(!a.querySelectorAll||!a.querySelector)},w:function(a,b){if(!a)throw new r(32,"No class name specified");a=ra(a);if(-1!==a.indexOf(" "))throw new r(32,"Compound class names not permitted");if(Td.C(b))try{return b.querySelector("."+a.replace(/\./g,"\\."))||null}catch(d){throw new r(32,"An invalid or illegal class name was specified");}var c=wb(kb(b),"*",a,b);return c.length?c[0]:null},s:function(a,b){if(!a)throw new r(32,"No class name specified");a=ra(a);if(-1!==a.indexOf(" "))throw new r(32,
"Compound class names not permitted");if(Td.C(b))try{return b.querySelectorAll("."+a.replace(/\./g,"\\."))}catch(c){throw new r(32,"An invalid or illegal class name was specified");}return wb(kb(b),"*",a,b)}};var Ud={w:function(a,b){if(!fa(b.querySelector)&&x&&dd(8)&&!ga(b.querySelector))throw Error("CSS selection is not supported");if(!a)throw new r(32,"No selector specified");a=ra(a);var c;try{c=b.querySelector(a)}catch(d){throw new r(32,"An invalid or illegal selector was specified");}return c&&1==c.nodeType?c:null},s:function(a,b){if(!fa(b.querySelectorAll)&&x&&dd(8)&&!ga(b.querySelector))throw Error("CSS selection is not supported");if(!a)throw new r(32,"No selector specified");a=ra(a);try{return b.querySelectorAll(a)}catch(c){throw new r(32,
"An invalid or illegal selector was specified");}}};var Vd={C:function(a,b){return!(!a.querySelectorAll||!a.querySelector)&&!/^\d.*/.test(b)},w:function(a,b){var c=kb(b),d=m(a)?c.a.getElementById(a):a;if(!d)return null;if(vd(d,"id")==a&&ob(b,d))return d;c=wb(c,"*");return Aa(c,function(c){return vd(c,"id")==a&&ob(b,c)})},s:function(a,b){if(!a)return[];if(Vd.C(b,a))try{return b.querySelectorAll("#"+Vd.P(a))}catch(d){return[]}var c=wb(kb(b),"*",null,b);return va(c,function(b){return vd(b,"id")==a})},P:function(a){return a.replace(/(['"\\#.:;,!?+<>=~*^$|%&@`{}\-\/\[\]\(\)])/g,
"\\$1")}};var Wd={},Xd={};Wd.O=function(a,b,c){var d;try{d=Ud.s("a",b)}catch(e){d=wb(kb(b),"A",null,b)}return Aa(d,function(b){b=Nd(b);return c&&-1!=b.indexOf(a)||b==a})};Wd.K=function(a,b,c){var d;try{d=Ud.s("a",b)}catch(e){d=wb(kb(b),"A",null,b)}return va(d,function(b){b=Nd(b);return c&&-1!=b.indexOf(a)||b==a})};Wd.w=function(a,b){return Wd.O(a,b,!1)};Wd.s=function(a,b){return Wd.K(a,b,!1)};Xd.w=function(a,b){return Wd.O(a,b,!0)};Xd.s=function(a,b){return Wd.K(a,b,!0)};var Yd={w:function(a,b){if(""===a)throw new r(32,'Unable to locate an element with the tagName ""');return b.getElementsByTagName(a)[0]||null},s:function(a,b){if(""===a)throw new r(32,'Unable to locate an element with the tagName ""');return b.getElementsByTagName(a)}};var Zd={className:Td,"class name":Td,css:Ud,"css selector":Ud,id:Vd,linkText:Wd,"link text":Wd,name:{w:function(a,b){var c=wb(kb(b),"*",null,b);return Aa(c,function(b){return vd(b,"name")==a})},s:function(a,b){var c=wb(kb(b),"*",null,b);return va(c,function(b){return vd(b,"name")==a})}},partialLinkText:Xd,"partial link text":Xd,tagName:Yd,"tag name":Yd,xpath:S};
function $d(a,b){var c;a:{for(c in a)if(a.hasOwnProperty(c))break a;c=null}if(c){var d=Zd[c];if(d&&fa(d.s))return d.s(a[c],b||oa.document)}throw Error("Unsupported locator strategy: "+c);};function ae(a){this.a=oa.document.documentElement;this.i=null;var b=qd(this.a);b&&be(this,b);this.v=a||new ce}function be(a,b){a.a=b;U(b,"OPTION")?a.i=vb(b,function(a){return U(a,"SELECT")}):a.i=null}Ya||ed&&fd(3.6);function de(a){return U(a,"FORM")}
function ee(a){if(!de(a))throw new r(12,"Element is not a form, so could not submit.");if(fe(a,ge))if(U(a.submit))if(!x||dd(8))a.constructor.prototype.submit.call(a);else{var b=$d({id:"submit"},a),c=$d({name:"submit"},a);q(b,function(a){a.removeAttribute("id")});q(c,function(a){a.removeAttribute("name")});a=a.submit;q(b,function(a){a.setAttribute("id","submit")});q(c,function(a){a.setAttribute("name","submit")});a()}else a.submit()}function ce(){this.a=0};var he=!(x&&!dd(10)),ie=Ab?!fd(4):!hd;function je(a,b,c){this.a=a;this.b=b;this.f=c}je.prototype.c=function(a){a=A(a);ld&&a.createEventObject?a=a.createEventObject():(a=a.createEvent("HTMLEvents"),a.initEvent(this.a,this.b,this.f));return a};je.prototype.toString=function(){return this.a};function ke(a,b,c){je.call(this,a,b,c)}p(ke,je);
ke.prototype.c=function(a,b){var c=A(a);if(z){var d=mb(c),e=b.charCode?0:b.keyCode,c=c.createEvent("KeyboardEvent");c.initKeyEvent(this.a,this.b,this.f,d,b.ctrlKey,b.altKey,b.shiftKey,b.metaKey,e,b.charCode);this.a==le&&b.preventDefault&&c.preventDefault()}else if(ld?c=c.createEventObject():(c=c.createEvent("Events"),c.initEvent(this.a,this.b,this.f)),c.altKey=b.altKey,c.ctrlKey=b.ctrlKey,c.metaKey=b.metaKey,c.shiftKey=b.shiftKey,c.keyCode=b.charCode||b.keyCode,Ya||Xa)c.charCode=this==le?c.keyCode:
0;return c};function me(a,b,c){je.call(this,a,b,c)}p(me,je);
me.prototype.c=function(a,b){function c(b){b=wa(b,function(b){return f.createTouch(g,a,b.identifier,b.pageX,b.pageY,b.screenX,b.screenY)});return f.createTouchList.apply(f,b)}function d(b){var c=wa(b,function(b){return{identifier:b.identifier,screenX:b.screenX,screenY:b.screenY,clientX:b.clientX,clientY:b.clientY,pageX:b.pageX,pageY:b.pageY,target:a}});c.item=function(a){return c[a]};return c}function e(a){return ie?d(a):c(a)}if(!he)throw new r(9,"Browser does not support firing touch events.");var f=
A(a),g=mb(f),k=e(b.changedTouches),n=b.touches==b.changedTouches?k:e(b.touches),v=b.targetTouches==b.changedTouches?k:e(b.targetTouches),u;ie?(u=f.createEvent("MouseEvents"),u.initMouseEvent(this.a,this.b,this.f,g,1,0,0,b.clientX,b.clientY,b.ctrlKey,b.altKey,b.shiftKey,b.metaKey,0,b.relatedTarget),u.touches=n,u.targetTouches=v,u.changedTouches=k,u.scale=b.scale,u.rotation=b.rotation):(u=f.createEvent("TouchEvent"),0==u.initTouchEvent.length?u.initTouchEvent(n,v,k,this.a,g,0,0,b.clientX,b.clientY,
b.ctrlKey,b.altKey,b.shiftKey,b.metaKey):u.initTouchEvent(this.a,this.b,this.f,g,1,0,0,b.clientX,b.clientY,b.ctrlKey,b.altKey,b.shiftKey,b.metaKey,n,v,k,b.scale,b.rotation),u.relatedTarget=b.relatedTarget);return u};
var ne=new je("blur",!1,!1),oe=new je("change",!0,!1),pe=new je("focus",!1,!1),qe=new je("input",!0,!1),ge=new je("submit",!0,!0),re=new je("textInput",!0,!0),se=new ke("keydown",!0,!0),le=new ke("keypress",!0,!0),te=new ke("keyup",!0,!0),ue=new me("touchend",!0,!0),ve=new me("touchstart",!0,!0);function fe(a,b,c){c=b.c(a,c);"isTrusted"in c||(c.isTrusted=!1);return ld&&a.fireEvent?a.fireEvent("on"+b.a,c):a.dispatchEvent(c)};function we(a,b){if(xe(a))a.selectionStart=b;else if(x){var c=ye(a),d=c[0];d.inRange(c[1])&&(b=ze(a,b),d.collapse(!0),d.move("character",b),d.select())}}
function Ae(a,b){var c=0,d=0;if(xe(a))c=a.selectionStart,d=b?-1:a.selectionEnd;else if(x){var e=ye(a),f=e[0],e=e[1];if(f.inRange(e)){f.setEndPoint("EndToStart",e);if("textarea"==a.type){for(var c=e.duplicate(),g=f.text,d=g,k=e=c.text,n=!1;!n;)0==f.compareEndPoints("StartToEnd",f)?n=!0:(f.moveEnd("character",-1),f.text==g?d+="\r\n":n=!0);if(b)f=[d.length,-1];else{for(f=!1;!f;)0==c.compareEndPoints("StartToEnd",c)?f=!0:(c.moveEnd("character",-1),c.text==e?k+="\r\n":f=!0);f=[d.length,d.length+k.length]}return f}c=
f.text.length;b?d=-1:d=f.text.length+e.text.length}}return[c,d]}function Be(a,b){if(xe(a))a.selectionEnd=b;else if(x){var c=ye(a),d=c[1];c[0].inRange(d)&&(b=ze(a,b),c=ze(a,Ae(a,!0)[0]),d.collapse(!0),d.moveEnd("character",b-c),d.select())}}function Ce(a,b){if(xe(a))a.selectionStart=b,a.selectionEnd=b;else if(x){b=ze(a,b);var c=a.createTextRange();c.collapse(!0);c.move("character",b);c.select()}}
function De(a,b){if(xe(a)){var c=a.value,d=a.selectionStart;a.value=c.substr(0,d)+b+c.substr(a.selectionEnd);a.selectionStart=d;a.selectionEnd=d+b.length}else if(x)d=ye(a),c=d[1],d[0].inRange(c)&&(d=c.duplicate(),c.text=b,c.setEndPoint("StartToStart",d),c.select());else throw Error("Cannot set the selection end");}function ye(a){var b=a.ownerDocument||a.document,c=b.selection.createRange();"textarea"==a.type?(b=b.body.createTextRange(),b.moveToElementText(a)):b=a.createTextRange();return[b,c]}
function ze(a,b){"textarea"==a.type&&(b=a.value.substring(0,b).replace(/(\r\n|\r|\n)/g,"\n").length);return b}function xe(a){try{return"number"==typeof a.selectionStart}catch(b){return!1}};function Ee(a,b){this.b={};this.a=[];this.c=this.f=0;var c=arguments.length;if(1<c){if(c%2)throw Error("Uneven number of arguments");for(var d=0;d<c;d+=2)Fe(this,arguments[d],arguments[d+1])}else if(a){if(a instanceof Ee)d=Ge(a),c=a.A();else{var c=[],e=0;for(d in a)c[e++]=d;d=c;c=Qa(a)}for(e=0;e<d.length;e++)Fe(this,d[e],c[e])}}h=Ee.prototype;h.A=function(){He(this);for(var a=[],b=0;b<this.a.length;b++)a.push(this.b[this.a[b]]);return a};function Ge(a){He(a);return a.a.concat()}
h.clear=function(){this.b={};this.c=this.f=this.a.length=0};function He(a){if(a.f!=a.a.length){for(var b=0,c=0;b<a.a.length;){var d=a.a[b];Ie(a.b,d)&&(a.a[c++]=d);b++}a.a.length=c}if(a.f!=a.a.length){for(var e={},c=b=0;b<a.a.length;)d=a.a[b],Ie(e,d)||(a.a[c++]=d,e[d]=1),b++;a.a.length=c}}h.get=function(a,b){return Ie(this.b,a)?this.b[a]:b};function Fe(a,b,c){Ie(a.b,b)||(a.f++,a.a.push(b),a.c++);a.b[b]=c}
h.forEach=function(a,b){for(var c=Ge(this),d=0;d<c.length;d++){var e=c[d],f=this.get(e);a.call(b,f,e,this)}};h.clone=function(){return new Ee(this)};function Ie(a,b){return Object.prototype.hasOwnProperty.call(a,b)};function Je(a){if(a.A&&"function"==typeof a.A)return a.A();if(m(a))return a.split("");if(da(a)){for(var b=[],c=a.length,d=0;d<c;d++)b.push(a[d]);return b}return Qa(a)};function Ke(a){this.a=new Ee;if(a){a=Je(a);for(var b=a.length,c=0;c<b;c++){var d=a[c];Fe(this.a,Le(d),d)}}}function Le(a){var b=typeof a;return"object"==b&&a||"function"==b?"o"+(a[ha]||(a[ha]=++ia)):b.substr(0,1)+a}Ke.prototype.clear=function(){this.a.clear()};Ke.prototype.contains=function(a){a=Le(a);return Ie(this.a.b,a)};Ke.prototype.A=function(){return this.a.A()};Ke.prototype.clone=function(){return new Ke(this)};function Me(a){ae.call(this);this.f=Cd(this.a);this.b=0;this.c=new Ke;a&&(q(a.pressed,function(a){Ne(this,a,!0)},this),this.b=a.currentPos||0)}p(Me,ae);var Oe={};function W(a,b,c){ga(a)&&(a=z?a.g:a.h);a=new Pe(a,b,c);!b||b in Oe&&!c||(Oe[b]={key:a,shift:!1},c&&(Oe[c]={key:a,shift:!0}));return a}function Pe(a,b,c){this.code=a;this.a=b||null;this.b=c||this.a}var Qe=W(8),Re=W(9),Se=W(13),X=W(16),Te=W(17),Ue=W(18),Ve=W(19);W(20);
var We=W(27),Xe=W(32," "),Ye=W(33),Ze=W(34),$e=W(35),af=W(36),bf=W(37),cf=W(38),df=W(39),ef=W(40);W(44);var ff=W(45),gf=W(46);W(48,"0",")");W(49,"1","!");W(50,"2","@");W(51,"3","#");W(52,"4","$");W(53,"5","%");W(54,"6","^");W(55,"7","&");W(56,"8","*");W(57,"9","(");W(65,"a","A");W(66,"b","B");W(67,"c","C");W(68,"d","D");W(69,"e","E");W(70,"f","F");W(71,"g","G");W(72,"h","H");W(73,"i","I");W(74,"j","J");W(75,"k","K");W(76,"l","L");W(77,"m","M");W(78,"n","N");W(79,"o","O");W(80,"p","P");W(81,"q","Q");
W(82,"r","R");W(83,"s","S");W(84,"t","T");W(85,"u","U");W(86,"v","V");W(87,"w","W");W(88,"x","X");W(89,"y","Y");W(90,"z","Z");
var hf=W(ab?{g:91,h:91}:$a?{g:224,h:91}:{g:0,h:91}),jf=W(ab?{g:92,h:92}:$a?{g:224,h:93}:{g:0,h:92}),kf=W(ab?{g:93,h:93}:$a?{g:0,h:0}:{g:93,h:null}),lf=W({g:96,h:96},"0"),mf=W({g:97,h:97},"1"),nf=W({g:98,h:98},"2"),of=W({g:99,h:99},"3"),pf=W({g:100,h:100},"4"),qf=W({g:101,h:101},"5"),rf=W({g:102,h:102},"6"),sf=W({g:103,h:103},"7"),tf=W({g:104,h:104},"8"),uf=W({g:105,h:105},"9"),vf=W({g:106,h:106},"*"),wf=W({g:107,h:107},"+"),xf=W({g:109,h:109},"-"),yf=W({g:110,h:110},"."),zf=W({g:111,h:111},"/");W(144);
var Af=W(112),Bf=W(113),Cf=W(114),Df=W(115),Ef=W(116),Ff=W(117),Gf=W(118),Hf=W(119),If=W(120),Jf=W(121),Kf=W(122),Lf=W(123),Mf=W({g:107,h:187},"=","+"),Nf=W(108,",");W({g:109,h:189},"-","_");W(188,",","<");W(190,".",">");W(191,"/","?");W(192,"`","~");W(219,"[","{");W(220,"\\","|");W(221,"]","}");var Of=W({g:59,h:186},";",":");W(222,"'",'"');var Pf=[Ue,Te,hf,X],Qf=new Ee;Fe(Qf,1,X);Fe(Qf,2,Te);Fe(Qf,4,Ue);Fe(Qf,8,hf);var Rf=function(a){var b=new Ee;q(Ge(a),function(c){Fe(b,a.get(c).code,c)});return b}(Qf);
function Ne(a,b,c){if(Ba(Pf,b)){var d=Rf.get(b.code),e=a.v;e.a=c?e.a|d:e.a&~d}c?Fe(a.c.a,Le(b),b):(a=a.c.a,b=Le(b),Ie(a.b,b)&&(delete a.b[b],a.f--,a.c++,a.a.length>2*a.f&&He(a)))}var Sf=x?"\r\n":"\n";function Y(a,b){return a.c.contains(b)}
function Tf(a,b){if(Ba(Pf,b)&&Y(a,b))throw new r(13,"Cannot press a modifier key that is already pressed.");var c=null!==b.code&&Uf(a,se,b);if((c||z)&&(!Vf(b)||Uf(a,le,b,!c))&&c&&(Wf(a,b),a.f))if(b.a){if(!Xf){var c=Yf(a,b),d=Ae(a.a,!0)[0]+1;Zf(a.a)?(De(a.a,c),we(a.a,d)):a.a.value+=c;Ya&&fe(a.a,re);ld||fe(a.a,qe);a.b=d}}else switch(b){case Se:Xf||(Ya&&fe(a.a,re),U(a.a,"TEXTAREA")&&(c=Ae(a.a,!0)[0]+Sf.length,Zf(a.a)?(De(a.a,Sf),we(a.a,c)):a.a.value+=Sf,x||fe(a.a,qe),a.b=c));break;case Qe:case gf:Xf||
($f(a.a),c=Ae(a.a,!1),c[0]==c[1]&&(b==Qe?(we(a.a,c[1]-1),Be(a.a,c[1])):Be(a.a,c[1]+1)),c=Ae(a.a,!1),c=!(c[0]==a.a.value.length||0==c[1]),De(a.a,""),(!x&&c||z&&b==Qe)&&fe(a.a,qe),c=Ae(a.a,!1),a.b=c[1]);break;case bf:case df:$f(a.a);var c=a.a,e=Ae(c,!0)[0],f=Ae(c,!1)[1],g=d=0;b==bf?Y(a,X)?a.b==e?(d=Math.max(e-1,0),g=f,e=d):(d=e,e=g=f-1):e=e==f?Math.max(e-1,0):e:Y(a,X)?a.b==f?(d=e,e=g=Math.min(f+1,c.value.length)):(d=e+1,g=f,e=d):e=e==f?Math.min(f+1,c.value.length):f;Y(a,X)?(we(c,d),Be(c,g)):Ce(c,e);
a.b=e;break;case af:case $e:$f(a.a),c=a.a,d=Ae(c,!0)[0],g=Ae(c,!1)[1],b==af?(Y(a,X)?(we(c,0),Be(c,a.b==d?g:d)):Ce(c,0),a.b=0):(Y(a,X)?(a.b==d&&we(c,g),Be(c,c.value.length)):Ce(c,c.value.length),a.b=c.value.length)}Ne(a,b,!0)}function Vf(a){if(a.a||a==Se)return!0;if(Ya||Xa)return!1;if(x)return a==We;switch(a){case X:case Te:case Ue:return!1;case hf:case jf:case kf:return z;default:return!0}}
function Wf(a,b){if(b==Se&&!z&&U(a.a,"INPUT")){var c=vb(a.a,de,!0);if(c){var d=c.getElementsByTagName("input");(ya(d,function(a){a:{if(U(a,"INPUT")){var b=a.type.toLowerCase();if("submit"==b||"image"==b){a=!0;break a}}if(U(a,"BUTTON")&&(b=a.type.toLowerCase(),"submit"==b)){a=!0;break a}a=!1}return a})||1==d.length||Ya&&!dd(534))&&ee(c)}}}function ag(a,b){if(!Y(a,b))throw new r(13,"Cannot release a key that is not pressed. ("+b.code+")");null===b.code||Uf(a,te,b);Ne(a,b,!1)}
function Yf(a,b){if(!b.a)throw new r(13,"not a character key");return Y(a,X)?b.b:b.a}var Xf=z&&!dd(12);function $f(a){try{a.selectionStart}catch(b){if(-1!=b.message.indexOf("does not support selection."))throw Error(b.message+" (For more information, see https://code.google.com/p/chromium/issues/detail?id=330456)");throw b;}}function Zf(a){try{$f(a)}catch(b){return!1}return!0}
function Uf(a,b,c,d){if(null===c.code)throw new r(13,"Key must have a keycode to be fired.");c={altKey:Y(a,Ue),ctrlKey:Y(a,Te),metaKey:Y(a,hf),shiftKey:Y(a,X),keyCode:c.code,charCode:c.a&&b==le?Yf(a,c).charCodeAt(0):0,preventDefault:!!d};return fe(a.a,b,c)}
function bg(a,b){be(a,b);a.f=Cd(b);var c;c=a.i||a.a;var d=qd(c);if(c==d)c=!1;else{if(d&&(fa(d.blur)||x&&ga(d.blur))){if(!U(d,"BODY"))try{d.blur()}catch(e){if(!x||"Unspecified error."!=e.message)throw e;}x&&!dd(8)&&mb(A(c)).focus()}fa(c.focus)||x&&ga(c.focus)?(c.focus(),c=!0):c=!1}a.f&&c&&(Ce(b,b.value.length),a.b=b.value.length)};function cg(a,b,c,d){function e(a){m(a)?q(a.split(""),function(a){if(1!=a.length)throw new r(13,"Argument not a single character: "+a);var b=Oe[a];b||(b=a.toUpperCase(),b=W(b.charCodeAt(0),a.toLowerCase(),b),b={key:b,shift:a!=b.a});a=b;b=Y(f,X);a.shift&&!b&&Tf(f,X);Tf(f,a.key);ag(f,a.key);a.shift&&!b&&ag(f,X)}):Ba(Pf,a)?Y(f,a)?ag(f,a):Tf(f,a):(Tf(f,a),ag(f,a))}if(a!=qd(a)){if(!rd(a))throw new r(12,"Element is not currently interactable and may not be manipulated");dg(a)}var f=c||new Me;bg(f,a);if((!Cb||
Za)&&Ya&&"date"==a.type){c="array"==ca(b)?b=b.join(""):b;var g=/\d{4}-\d{2}-\d{2}/;if(c.match(g)){Za&&Cb&&(fe(a,ve),fe(a,ue));fe(a,pe);a.value=c.match(g)[0];fe(a,oe);fe(a,ne);return}}"array"==ca(b)?q(b,e):e(b);d||q(Pf,function(a){Y(f,a)&&ag(f,a)})}
function dg(a){if("scroll"==Gd(a,void 0)){if(a.scrollIntoView&&(a.scrollIntoView(),"none"==Gd(a,void 0)))return;for(var b=Kd(a,void 0),c=Bd(a);c;c=Bd(c)){var d=c,e=Fd(d),f;var g=d;if(!x||9<=Number(hb))k=nd(g,"borderLeftWidth"),f=nd(g,"borderRightWidth"),n=nd(g,"borderTopWidth"),g=nd(g,"borderBottomWidth"),f=new md(parseFloat(n),parseFloat(f),parseFloat(g),parseFloat(k));else{var k=pd(g,"borderLeft");f=pd(g,"borderRight");var n=pd(g,"borderTop"),g=pd(g,"borderBottom");f=new md(n,f,g,k)}k=b.left-e.left-
f.left;e=b.top-e.top-f.top;f=d.clientHeight+b.top-b.bottom;d.scrollLeft+=Math.min(k,Math.max(k-(d.clientWidth+b.left-b.right),0));d.scrollTop+=Math.min(e,Math.max(e-f,0))}Gd(a,void 0)}};function Z(a,b,c,d){function e(){return{L:f,keys:[]}}var f=!!d,g=[],k=e();g.push(k);q(b,function(a){q(a.split(""),function(a){if("\ue000"<=a&&"\ue03d">=a){var b=Z.a[a];if(null===b)g.push(k=e()),f&&(k.L=!1,g.push(k=e()));else if(l(b))k.keys.push(b);else throw Error("Unsupported WebDriver key: \\u"+a.charCodeAt(0).toString(16));}else switch(a){case "\n":k.keys.push(Se);break;case "\t":k.keys.push(Re);break;case "\b":k.keys.push(Qe);break;default:k.keys.push(a)}})});q(g,function(b){cg(a,b.keys,c,b.L)})}
Z.a={};Z.a["\ue000"]=null;Z.a["\ue003"]=Qe;Z.a["\ue004"]=Re;Z.a["\ue006"]=Se;Z.a["\ue007"]=Se;Z.a["\ue008"]=X;Z.a["\ue009"]=Te;Z.a["\ue00a"]=Ue;Z.a["\ue00b"]=Ve;Z.a["\ue00c"]=We;Z.a["\ue00d"]=Xe;Z.a["\ue00e"]=Ye;Z.a["\ue00f"]=Ze;Z.a["\ue010"]=$e;Z.a["\ue011"]=af;Z.a["\ue012"]=bf;Z.a["\ue013"]=cf;Z.a["\ue014"]=df;Z.a["\ue015"]=ef;Z.a["\ue016"]=ff;Z.a["\ue017"]=gf;Z.a["\ue018"]=Of;Z.a["\ue019"]=Mf;Z.a["\ue01a"]=lf;Z.a["\ue01b"]=mf;Z.a["\ue01c"]=nf;Z.a["\ue01d"]=of;Z.a["\ue01e"]=pf;Z.a["\ue01f"]=qf;
Z.a["\ue020"]=rf;Z.a["\ue021"]=sf;Z.a["\ue022"]=tf;Z.a["\ue023"]=uf;Z.a["\ue024"]=vf;Z.a["\ue025"]=wf;Z.a["\ue027"]=xf;Z.a["\ue028"]=yf;Z.a["\ue029"]=zf;Z.a["\ue026"]=Nf;Z.a["\ue031"]=Af;Z.a["\ue032"]=Bf;Z.a["\ue033"]=Cf;Z.a["\ue034"]=Df;Z.a["\ue035"]=Ef;Z.a["\ue036"]=Ff;Z.a["\ue037"]=Gf;Z.a["\ue038"]=Hf;Z.a["\ue039"]=If;Z.a["\ue03a"]=Jf;Z.a["\ue03b"]=Kf;Z.a["\ue03c"]=Lf;Z.a["\ue03d"]=hf;function eg(){}
function fg(a,b,c){if(null==b)c.push("null");else{if("object"==typeof b){if("array"==ca(b)){var d=b;b=d.length;c.push("[");for(var e="",f=0;f<b;f++)c.push(e),fg(a,d[f],c),e=",";c.push("]");return}if(b instanceof String||b instanceof Number||b instanceof Boolean)b=b.valueOf();else{c.push("{");e="";for(d in b)Object.prototype.hasOwnProperty.call(b,d)&&(f=b[d],"function"!=typeof f&&(c.push(e),gg(d,c),c.push(":"),fg(a,f,c),e=","));c.push("}");return}}switch(typeof b){case "string":gg(b,c);break;case "number":c.push(isFinite(b)&&
!isNaN(b)?String(b):"null");break;case "boolean":c.push(String(b));break;case "function":c.push("null");break;default:throw Error("Unknown type: "+typeof b);}}}var hg={'"':'\\"',"\\":"\\\\","/":"\\/","\b":"\\b","\f":"\\f","\n":"\\n","\r":"\\r","\t":"\\t","\x0B":"\\u000b"},ig=/\uffff/.test("\uffff")?/[\\\"\x00-\x1f\x7f-\uffff]/g:/[\\\"\x00-\x1f\x7f-\xff]/g;
function gg(a,b){b.push('"',a.replace(ig,function(a){var b=hg[a];b||(b="\\u"+(a.charCodeAt(0)|65536).toString(16).substr(1),hg[a]=b);return b}),'"')};Ya||z&&dd(3.5)||x&&dd(8);function jg(a){switch(ca(a)){case "string":case "number":case "boolean":return a;case "function":return a.toString();case "array":return wa(a,jg);case "object":if(Ra(a,"nodeType")&&(1==a.nodeType||9==a.nodeType)){var b={};b.ELEMENT=kg(a);return b}if(Ra(a,"document"))return b={},b.WINDOW=kg(a),b;if(da(a))return wa(a,jg);a=Oa(a,function(a,b){return ea(b)||m(b)});return Pa(a,jg);default:return null}}
function lg(a,b){return"array"==ca(a)?wa(a,function(a){return lg(a,b)}):ga(a)?"function"==typeof a?a:Ra(a,"ELEMENT")?mg(a.ELEMENT,b):Ra(a,"WINDOW")?mg(a.WINDOW,b):Pa(a,function(a){return lg(a,b)}):a}function ng(a){a=a||document;var b=a.$wdc_;b||(b=a.$wdc_={},b.F=na());b.F||(b.F=na());return b}function kg(a){var b=ng(a.ownerDocument),c=Sa(b,function(b){return b==a});c||(c=":wdc:"+b.F++,b[c]=a);return c}
function mg(a,b){a=decodeURIComponent(a);var c=b||document,d=ng(c);if(!Ra(d,a))throw new r(10,"Element does not exist in cache");var e=d[a];if(Ra(e,"setInterval")){if(e.closed)throw delete d[a],new r(23,"Window has been closed.");return e}for(var f=e;f;){if(f==c.documentElement)return e;f=f.parentNode}delete d[a];throw new r(10,"Element is no longer attached to the DOM");};ba("_",function(a,b,c){a=[a,b];b=Z;var d;try{var e;c?e=mg(c.WINDOW):e=window;var f=lg(a,e.document),g=b.apply(null,f);d={status:0,value:jg(g)}}catch(k){d={status:Ra(k,"code")?k.code:13,value:{message:k.message}}}c=[];fg(new eg,d,c);return c.join("")});; return this._.apply(null,arguments);}.apply({navigator:typeof window!=undefined?window.navigator:null,document:typeof window!=undefined?window.document:null}, arguments);}
