function(){return function(){var h,l=this;function aa(a,b){var c=a.split("."),d=l;c[0]in d||!d.execScript||d.execScript("var "+c[0]);for(var e;c.length&&(e=c.shift());)c.length||void 0===b?d[e]?d=d[e]:d=d[e]={}:d[e]=b}
function ba(a){var b=typeof a;if("object"==b)if(a){if(a instanceof Array)return"array";if(a instanceof Object)return b;var c=Object.prototype.toString.call(a);if("[object Window]"==c)return"object";if("[object Array]"==c||"number"==typeof a.length&&"undefined"!=typeof a.splice&&"undefined"!=typeof a.propertyIsEnumerable&&!a.propertyIsEnumerable("splice"))return"array";if("[object Function]"==c||"undefined"!=typeof a.call&&"undefined"!=typeof a.propertyIsEnumerable&&!a.propertyIsEnumerable("call"))return"function"}else return"null";
else if("function"==b&&"undefined"==typeof a.call)return"object";return b}function ca(a){var b=ba(a);return"array"==b||"object"==b&&"number"==typeof a.length}function m(a){return"string"==typeof a}function da(a){return"number"==typeof a}function ea(a){var b=typeof a;return"object"==b&&null!=a||"function"==b}function fa(a,b,c){return a.call.apply(a.bind,arguments)}
function ga(a,b,c){if(!a)throw Error();if(2<arguments.length){var d=Array.prototype.slice.call(arguments,2);return function(){var c=Array.prototype.slice.call(arguments);Array.prototype.unshift.apply(c,d);return a.apply(b,c)}}return function(){return a.apply(b,arguments)}}function ha(a,b,c){ha=Function.prototype.bind&&-1!=Function.prototype.bind.toString().indexOf("native code")?fa:ga;return ha.apply(null,arguments)}
function ia(a,b){var c=Array.prototype.slice.call(arguments,1);return function(){var b=c.slice();b.push.apply(b,arguments);return a.apply(this,b)}}var ja=Date.now||function(){return+new Date};function n(a,b){function c(){}c.prototype=b.prototype;a.L=b.prototype;a.prototype=new c;a.prototype.constructor=a;a.K=function(a,c,f){for(var g=Array(arguments.length-2),k=2;k<arguments.length;k++)g[k-2]=arguments[k];return b.prototype[c].apply(a,g)}};var p=window;var ma;var na=String.prototype.trim?function(a){return a.trim()}:function(a){return a.replace(/^[\s\xa0]+|[\s\xa0]+$/g,"")};
function oa(a,b){for(var c=0,d=na(String(a)).split("."),e=na(String(b)).split("."),f=Math.max(d.length,e.length),g=0;0==c&&g<f;g++){var k=d[g]||"",x=e[g]||"",D=RegExp("(\\d*)(\\D*)","g"),Q=RegExp("(\\d*)(\\D*)","g");do{var ka=D.exec(k)||["","",""],la=Q.exec(x)||["","",""];if(0==ka[0].length&&0==la[0].length)break;c=pa(0==ka[1].length?0:parseInt(ka[1],10),0==la[1].length?0:parseInt(la[1],10))||pa(0==ka[2].length,0==la[2].length)||pa(ka[2],la[2])}while(0==c)}return c}
function pa(a,b){return a<b?-1:a>b?1:0};function q(a,b){for(var c=a.length,d=m(a)?a.split(""):a,e=0;e<c;e++)e in d&&b.call(void 0,d[e],e,a)}function qa(a,b){for(var c=a.length,d=[],e=0,f=m(a)?a.split(""):a,g=0;g<c;g++)if(g in f){var k=f[g];b.call(void 0,k,g,a)&&(d[e++]=k)}return d}function ra(a,b){for(var c=a.length,d=Array(c),e=m(a)?a.split(""):a,f=0;f<c;f++)f in e&&(d[f]=b.call(void 0,e[f],f,a));return d}function sa(a,b,c){var d=c;q(a,function(c,f){d=b.call(void 0,d,c,f,a)});return d}
function ta(a,b){for(var c=a.length,d=m(a)?a.split(""):a,e=0;e<c;e++)if(e in d&&b.call(void 0,d[e],e,a))return!0;return!1}function ua(a,b){var c;a:{c=a.length;for(var d=m(a)?a.split(""):a,e=0;e<c;e++)if(e in d&&b.call(void 0,d[e],e,a)){c=e;break a}c=-1}return 0>c?null:m(a)?a.charAt(c):a[c]}function va(a){return Array.prototype.concat.apply(Array.prototype,arguments)}function wa(a,b,c){return 2>=arguments.length?Array.prototype.slice.call(a,b):Array.prototype.slice.call(a,b,c)};function xa(a,b){this.code=a;this.a=r[a]||ya;this.message=b||"";var c=this.a.replace(/((?:^|\s+)[a-z])/g,function(a){return a.toUpperCase().replace(/^[\s\xa0]+/g,"")}),d=c.length-5;if(0>d||c.indexOf("Error",d)!=d)c+="Error";this.name=c;c=Error(this.message);c.name=this.name;this.stack=c.stack||""}n(xa,Error);var ya="unknown error",r={15:"element not selectable",11:"element not visible"};r[31]=ya;r[30]=ya;r[24]="invalid cookie domain";r[29]="invalid element coordinates";r[12]="invalid element state";
r[32]="invalid selector";r[51]="invalid selector";r[52]="invalid selector";r[17]="javascript error";r[405]="unsupported operation";r[34]="move target out of bounds";r[27]="no such alert";r[7]="no such element";r[8]="no such frame";r[23]="no such window";r[28]="script timeout";r[33]="session not created";r[10]="stale element reference";r[21]="timeout";r[25]="unable to set cookie";r[26]="unexpected alert open";r[13]=ya;r[9]="unknown command";xa.prototype.toString=function(){return this.name+": "+this.message};var t;a:{var za=l.navigator;if(za){var Aa=za.userAgent;if(Aa){t=Aa;break a}}t=""}function u(a){return-1!=t.indexOf(a)};function Ba(a,b){var c={},d;for(d in a)b.call(void 0,a[d],d,a)&&(c[d]=a[d]);return c}function Ca(a,b){var c={},d;for(d in a)c[d]=b.call(void 0,a[d],d,a);return c}function v(a,b){return null!==a&&b in a}function Da(a,b){for(var c in a)if(b.call(void 0,a[c],c,a))return c};function Ea(){return u("Opera")||u("OPR")}function Fa(){return(u("Chrome")||u("CriOS"))&&!Ea()&&!u("Edge")};function Ga(){return u("iPhone")&&!u("iPod")&&!u("iPad")};var Ha=Ea(),w=u("Trident")||u("MSIE"),Ia=u("Edge"),y=u("Gecko")&&!(-1!=t.toLowerCase().indexOf("webkit")&&!u("Edge"))&&!(u("Trident")||u("MSIE"))&&!u("Edge"),Ja=-1!=t.toLowerCase().indexOf("webkit")&&!u("Edge"),Ka=u("Macintosh"),La=u("Windows");function Ma(){var a=t;if(y)return/rv\:([^\);]+)(\)|;)/.exec(a);if(Ia)return/Edge\/([\d\.]+)/.exec(a);if(w)return/\b(?:MSIE|rv)[: ]([^\);]+)(\)|;)/.exec(a);if(Ja)return/WebKit\/(\S+)/.exec(a)}function Na(){var a=l.document;return a?a.documentMode:void 0}
var Oa=function(){if(Ha&&l.opera){var a;var b=l.opera.version;try{a=b()}catch(c){a=b}return a}a="";(b=Ma())&&(a=b?b[1]:"");return w&&(b=Na(),null!=b&&b>parseFloat(a))?String(b):a}(),Pa={};function Qa(a){return Pa[a]||(Pa[a]=0<=oa(Oa,a))}var Ra=l.document,z=Ra&&w?Na()||("CSS1Compat"==Ra.compatMode?parseInt(Oa,10):5):void 0;!y&&!w||w&&9<=Number(z)||y&&Qa("1.9.1");w&&Qa("9");function A(a,b){this.x=void 0!==a?a:0;this.y=void 0!==b?b:0}h=A.prototype;h.clone=function(){return new A(this.x,this.y)};h.toString=function(){return"("+this.x+", "+this.y+")"};h.ceil=function(){this.x=Math.ceil(this.x);this.y=Math.ceil(this.y);return this};h.floor=function(){this.x=Math.floor(this.x);this.y=Math.floor(this.y);return this};h.round=function(){this.x=Math.round(this.x);this.y=Math.round(this.y);return this};h.scale=function(a,b){var c=da(b)?b:a;this.x*=a;this.y*=c;return this};function Sa(a,b){this.width=a;this.height=b}h=Sa.prototype;h.clone=function(){return new Sa(this.width,this.height)};h.toString=function(){return"("+this.width+" x "+this.height+")"};h.ceil=function(){this.width=Math.ceil(this.width);this.height=Math.ceil(this.height);return this};h.floor=function(){this.width=Math.floor(this.width);this.height=Math.floor(this.height);return this};h.round=function(){this.width=Math.round(this.width);this.height=Math.round(this.height);return this};
h.scale=function(a,b){var c=da(b)?b:a;this.width*=a;this.height*=c;return this};function Ta(a){return a?new Ua(Va(a)):ma||(ma=new Ua)}function Wa(a,b){if(!a||!b)return!1;if(a.contains&&1==b.nodeType)return a==b||a.contains(b);if("undefined"!=typeof a.compareDocumentPosition)return a==b||!!(a.compareDocumentPosition(b)&16);for(;b&&a!=b;)b=b.parentNode;return b==a}
function Xa(a,b){if(a==b)return 0;if(a.compareDocumentPosition)return a.compareDocumentPosition(b)&2?1:-1;if(w&&!(9<=Number(z))){if(9==a.nodeType)return-1;if(9==b.nodeType)return 1}if("sourceIndex"in a||a.parentNode&&"sourceIndex"in a.parentNode){var c=1==a.nodeType,d=1==b.nodeType;if(c&&d)return a.sourceIndex-b.sourceIndex;var e=a.parentNode,f=b.parentNode;return e==f?Ya(a,b):!c&&Wa(e,b)?-1*Za(a,b):!d&&Wa(f,a)?Za(b,a):(c?a.sourceIndex:e.sourceIndex)-(d?b.sourceIndex:f.sourceIndex)}d=Va(a);c=d.createRange();
c.selectNode(a);c.collapse(!0);d=d.createRange();d.selectNode(b);d.collapse(!0);return c.compareBoundaryPoints(l.Range.START_TO_END,d)}function Za(a,b){var c=a.parentNode;if(c==b)return-1;for(var d=b;d.parentNode!=c;)d=d.parentNode;return Ya(d,a)}function Ya(a,b){for(var c=b;c=c.previousSibling;)if(c==a)return-1;return 1}function Va(a){return 9==a.nodeType?a:a.ownerDocument||a.document}function Ua(a){this.a=a||l.document||document}
function $a(a){a=a.a;a=(a.parentWindow||a.defaultView||window).document;a="CSS1Compat"==a.compatMode?a.documentElement:a.body;return new Sa(a.clientWidth,a.clientHeight)}Ua.prototype.contains=Wa;var ab=u("Firefox"),bb=Ga()||u("iPod"),cb=u("iPad"),db=u("Android")&&!(Fa()||u("Firefox")||Ea()||u("Silk")),eb=Fa(),fb=u("Safari")&&!(Fa()||u("Coast")||Ea()||u("Edge")||u("Silk")||u("Android"))&&!(Ga()||u("iPad")||u("iPod"));/*

 The MIT License

 Copyright (c) 2007 Cybozu Labs, Inc.
 Copyright (c) 2012 Google Inc.

 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to
 deal in the Software without restriction, including without limitation the
 rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
 sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in
 all copies or substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 IN THE SOFTWARE.
*/
function gb(a,b,c){this.a=a;this.b=b||1;this.h=c||1};var B=w&&!(9<=Number(z)),hb=w&&!(8<=Number(z));function ib(a,b,c,d){this.a=a;this.nodeName=c;this.nodeValue=d;this.nodeType=2;this.parentNode=this.ownerElement=b}function jb(a,b){var c=hb&&"href"==b.nodeName?a.getAttribute(b.nodeName,2):b.nodeValue;return new ib(b,a,b.nodeName,c)};function kb(a){this.b=a;this.a=0}function lb(a){a=a.match(mb);for(var b=0;b<a.length;b++)nb.test(a[b])&&a.splice(b,1);return new kb(a)}var mb=RegExp("\\$?(?:(?![0-9-\\.])(?:\\*|[\\w-\\.]+):)?(?![0-9-\\.])(?:\\*|[\\w-\\.]+)|\\/\\/|\\.\\.|::|\\d+(?:\\.\\d*)?|\\.\\d+|\"[^\"]*\"|'[^']*'|[!<>]=|\\s+|.","g"),nb=/^\s/;function C(a,b){return a.b[a.a+(b||0)]}function E(a){return a.b[a.a++]}function ob(a){return a.b.length<=a.a};function F(a){var b=null,c=a.nodeType;1==c&&(b=a.textContent,b=void 0==b||null==b?a.innerText:b,b=void 0==b||null==b?"":b);if("string"!=typeof b)if(B&&"title"==a.nodeName.toLowerCase()&&1==c)b=a.text;else if(9==c||1==c){a=9==c?a.documentElement:a.firstChild;for(var c=0,d=[],b="";a;){do 1!=a.nodeType&&(b+=a.nodeValue),B&&"title"==a.nodeName.toLowerCase()&&(b+=a.text),d[c++]=a;while(a=a.firstChild);for(;c&&!(a=d[--c].nextSibling););}}else b=a.nodeValue;return""+b}
function G(a,b,c){if(null===b)return!0;try{if(!a.getAttribute)return!1}catch(d){return!1}hb&&"class"==b&&(b="className");return null==c?!!a.getAttribute(b):a.getAttribute(b,2)==c}function pb(a,b,c,d,e){return(B?qb:rb).call(null,a,b,m(c)?c:null,m(d)?d:null,e||new H)}
function qb(a,b,c,d,e){if(a instanceof I||8==a.b||c&&null===a.b){var f=b.all;if(!f)return e;a=sb(a);if("*"!=a&&(f=b.getElementsByTagName(a),!f))return e;if(c){for(var g=[],k=0;b=f[k++];)G(b,c,d)&&g.push(b);f=g}for(k=0;b=f[k++];)"*"==a&&"!"==b.tagName||J(e,b);return e}tb(a,b,c,d,e);return e}
function rb(a,b,c,d,e){b.getElementsByName&&d&&"name"==c&&!w?(b=b.getElementsByName(d),q(b,function(b){a.a(b)&&J(e,b)})):b.getElementsByClassName&&d&&"class"==c?(b=b.getElementsByClassName(d),q(b,function(b){b.className==d&&a.a(b)&&J(e,b)})):a instanceof K?tb(a,b,c,d,e):b.getElementsByTagName&&(b=b.getElementsByTagName(a.h()),q(b,function(a){G(a,c,d)&&J(e,a)}));return e}
function ub(a,b,c,d,e){var f;if((a instanceof I||8==a.b||c&&null===a.b)&&(f=b.childNodes)){var g=sb(a);if("*"!=g&&(f=qa(f,function(a){return a.tagName&&a.tagName.toLowerCase()==g}),!f))return e;c&&(f=qa(f,function(a){return G(a,c,d)}));q(f,function(a){"*"==g&&("!"==a.tagName||"*"==g&&1!=a.nodeType)||J(e,a)});return e}return vb(a,b,c,d,e)}function vb(a,b,c,d,e){for(b=b.firstChild;b;b=b.nextSibling)G(b,c,d)&&a.a(b)&&J(e,b);return e}
function tb(a,b,c,d,e){for(b=b.firstChild;b;b=b.nextSibling)G(b,c,d)&&a.a(b)&&J(e,b),tb(a,b,c,d,e)}function sb(a){if(a instanceof K){if(8==a.b)return"!";if(null===a.b)return"*"}return a.h()};function H(){this.b=this.a=null;this.s=0}function wb(a){this.node=a;this.a=this.b=null}function xb(a,b){if(!a.a)return b;if(!b.a)return a;for(var c=a.a,d=b.a,e=null,f=null,g=0;c&&d;){var f=c.node,k=d.node;f==k||f instanceof ib&&k instanceof ib&&f.a==k.a?(f=c,c=c.a,d=d.a):0<Xa(c.node,d.node)?(f=d,d=d.a):(f=c,c=c.a);(f.b=e)?e.a=f:a.a=f;e=f;g++}for(f=c||d;f;)f.b=e,e=e.a=f,g++,f=f.a;a.b=e;a.s=g;return a}
H.prototype.unshift=function(a){a=new wb(a);a.a=this.a;this.b?this.a.b=a:this.a=this.b=a;this.a=a;this.s++};function J(a,b){var c=new wb(b);c.b=a.b;a.a?a.b.a=c:a.a=a.b=c;a.b=c;a.s++}function yb(a){return(a=a.a)?a.node:null}function zb(a){return(a=yb(a))?F(a):""}function L(a,b){return new Ab(a,!!b)}function Ab(a,b){this.h=a;this.b=(this.c=b)?a.b:a.a;this.a=null}function M(a){var b=a.b;if(null==b)return null;var c=a.a=b;a.b=a.c?b.b:b.a;return c.node};function N(a){this.m=a;this.b=this.i=!1;this.h=null}function O(a){return"\n  "+a.toString().split("\n").join("\n  ")}function Bb(a,b){a.i=b}function Cb(a,b){a.b=b}function P(a,b){var c=a.a(b);return c instanceof H?+zb(c):+c}function R(a,b){var c=a.a(b);return c instanceof H?zb(c):""+c}function Db(a,b){var c=a.a(b);return c instanceof H?!!c.s:!!c};function Eb(a,b,c){N.call(this,a.m);this.c=a;this.j=b;this.w=c;this.i=b.i||c.i;this.b=b.b||c.b;this.c==Fb&&(c.b||c.i||4==c.m||0==c.m||!b.h?b.b||b.i||4==b.m||0==b.m||!c.h||(this.h={name:c.h.name,A:b}):this.h={name:b.h.name,A:c})}n(Eb,N);
function Gb(a,b,c,d,e){b=b.a(d);c=c.a(d);var f;if(b instanceof H&&c instanceof H){b=L(b);for(d=M(b);d;d=M(b))for(e=L(c),f=M(e);f;f=M(e))if(a(F(d),F(f)))return!0;return!1}if(b instanceof H||c instanceof H){b instanceof H?(e=b,d=c):(e=c,d=b);f=L(e);for(var g=typeof d,k=M(f);k;k=M(f)){switch(g){case "number":k=+F(k);break;case "boolean":k=!!F(k);break;case "string":k=F(k);break;default:throw Error("Illegal primitive type for comparison.");}if(e==b&&a(k,d)||e==c&&a(d,k))return!0}return!1}return e?"boolean"==
typeof b||"boolean"==typeof c?a(!!b,!!c):"number"==typeof b||"number"==typeof c?a(+b,+c):a(b,c):a(+b,+c)}Eb.prototype.a=function(a){return this.c.v(this.j,this.w,a)};Eb.prototype.toString=function(){var a="Binary Expression: "+this.c,a=a+O(this.j);return a+=O(this.w)};function Hb(a,b,c,d){this.a=a;this.F=b;this.m=c;this.v=d}Hb.prototype.toString=function(){return this.a};var Ib={};
function S(a,b,c,d){if(Ib.hasOwnProperty(a))throw Error("Binary operator already created: "+a);a=new Hb(a,b,c,d);return Ib[a.toString()]=a}S("div",6,1,function(a,b,c){return P(a,c)/P(b,c)});S("mod",6,1,function(a,b,c){return P(a,c)%P(b,c)});S("*",6,1,function(a,b,c){return P(a,c)*P(b,c)});S("+",5,1,function(a,b,c){return P(a,c)+P(b,c)});S("-",5,1,function(a,b,c){return P(a,c)-P(b,c)});S("<",4,2,function(a,b,c){return Gb(function(a,b){return a<b},a,b,c)});
S(">",4,2,function(a,b,c){return Gb(function(a,b){return a>b},a,b,c)});S("<=",4,2,function(a,b,c){return Gb(function(a,b){return a<=b},a,b,c)});S(">=",4,2,function(a,b,c){return Gb(function(a,b){return a>=b},a,b,c)});var Fb=S("=",3,2,function(a,b,c){return Gb(function(a,b){return a==b},a,b,c,!0)});S("!=",3,2,function(a,b,c){return Gb(function(a,b){return a!=b},a,b,c,!0)});S("and",2,2,function(a,b,c){return Db(a,c)&&Db(b,c)});S("or",1,2,function(a,b,c){return Db(a,c)||Db(b,c)});function Jb(a,b){if(b.a.length&&4!=a.m)throw Error("Primary expression must evaluate to nodeset if filter has predicate(s).");N.call(this,a.m);this.c=a;this.j=b;this.i=a.i;this.b=a.b}n(Jb,N);Jb.prototype.a=function(a){a=this.c.a(a);return Kb(this.j,a)};Jb.prototype.toString=function(){var a;a="Filter:"+O(this.c);return a+=O(this.j)};function Lb(a,b){if(b.length<a.G)throw Error("Function "+a.o+" expects at least"+a.G+" arguments, "+b.length+" given");if(null!==a.D&&b.length>a.D)throw Error("Function "+a.o+" expects at most "+a.D+" arguments, "+b.length+" given");a.H&&q(b,function(b,d){if(4!=b.m)throw Error("Argument "+d+" to function "+a.o+" is not of type Nodeset: "+b);});N.call(this,a.m);this.j=a;this.c=b;Bb(this,a.i||ta(b,function(a){return a.i}));Cb(this,a.J&&!b.length||a.I&&!!b.length||ta(b,function(a){return a.b}))}
n(Lb,N);Lb.prototype.a=function(a){return this.j.v.apply(null,va(a,this.c))};Lb.prototype.toString=function(){var a="Function: "+this.j;if(this.c.length)var b=sa(this.c,function(a,b){return a+O(b)},"Arguments:"),a=a+O(b);return a};function Mb(a,b,c,d,e,f,g,k,x){this.o=a;this.m=b;this.i=c;this.J=d;this.I=e;this.v=f;this.G=g;this.D=void 0!==k?k:g;this.H=!!x}Mb.prototype.toString=function(){return this.o};var Nb={};
function T(a,b,c,d,e,f,g,k){if(Nb.hasOwnProperty(a))throw Error("Function already created: "+a+".");Nb[a]=new Mb(a,b,c,d,!1,e,f,g,k)}T("boolean",2,!1,!1,function(a,b){return Db(b,a)},1);T("ceiling",1,!1,!1,function(a,b){return Math.ceil(P(b,a))},1);T("concat",3,!1,!1,function(a,b){return sa(wa(arguments,1),function(b,d){return b+R(d,a)},"")},2,null);T("contains",2,!1,!1,function(a,b,c){b=R(b,a);a=R(c,a);return-1!=b.indexOf(a)},2);T("count",1,!1,!1,function(a,b){return b.a(a).s},1,1,!0);
T("false",2,!1,!1,function(){return!1},0);T("floor",1,!1,!1,function(a,b){return Math.floor(P(b,a))},1);
T("id",4,!1,!1,function(a,b){function c(a){if(B){var b=e.all[a];if(b){if(b.nodeType&&a==b.id)return b;if(b.length)return ua(b,function(b){return a==b.id})}return null}return e.getElementById(a)}var d=a.a,e=9==d.nodeType?d:d.ownerDocument,d=R(b,a).split(/\s+/),f=[];q(d,function(a){a=c(a);var b;if(!(b=!a)){a:if(m(f))b=m(a)&&1==a.length?f.indexOf(a,0):-1;else{for(b=0;b<f.length;b++)if(b in f&&f[b]===a)break a;b=-1}b=0<=b}b||f.push(a)});f.sort(Xa);var g=new H;q(f,function(a){J(g,a)});return g},1);
T("lang",2,!1,!1,function(){return!1},1);T("last",1,!0,!1,function(a){if(1!=arguments.length)throw Error("Function last expects ()");return a.h},0);T("local-name",3,!1,!0,function(a,b){var c=b?yb(b.a(a)):a.a;return c?c.localName||c.nodeName.toLowerCase():""},0,1,!0);T("name",3,!1,!0,function(a,b){var c=b?yb(b.a(a)):a.a;return c?c.nodeName.toLowerCase():""},0,1,!0);T("namespace-uri",3,!0,!1,function(){return""},0,1,!0);
T("normalize-space",3,!1,!0,function(a,b){return(b?R(b,a):F(a.a)).replace(/[\s\xa0]+/g," ").replace(/^\s+|\s+$/g,"")},0,1);T("not",2,!1,!1,function(a,b){return!Db(b,a)},1);T("number",1,!1,!0,function(a,b){return b?P(b,a):+F(a.a)},0,1);T("position",1,!0,!1,function(a){return a.b},0);T("round",1,!1,!1,function(a,b){return Math.round(P(b,a))},1);T("starts-with",2,!1,!1,function(a,b,c){b=R(b,a);a=R(c,a);return 0==b.lastIndexOf(a,0)},2);T("string",3,!1,!0,function(a,b){return b?R(b,a):F(a.a)},0,1);
T("string-length",1,!1,!0,function(a,b){return(b?R(b,a):F(a.a)).length},0,1);T("substring",3,!1,!1,function(a,b,c,d){c=P(c,a);if(isNaN(c)||Infinity==c||-Infinity==c)return"";d=d?P(d,a):Infinity;if(isNaN(d)||-Infinity===d)return"";c=Math.round(c)-1;var e=Math.max(c,0);a=R(b,a);return Infinity==d?a.substring(e):a.substring(e,c+Math.round(d))},2,3);T("substring-after",3,!1,!1,function(a,b,c){b=R(b,a);a=R(c,a);c=b.indexOf(a);return-1==c?"":b.substring(c+a.length)},2);
T("substring-before",3,!1,!1,function(a,b,c){b=R(b,a);a=R(c,a);a=b.indexOf(a);return-1==a?"":b.substring(0,a)},2);T("sum",1,!1,!1,function(a,b){for(var c=L(b.a(a)),d=0,e=M(c);e;e=M(c))d+=+F(e);return d},1,1,!0);T("translate",3,!1,!1,function(a,b,c,d){b=R(b,a);c=R(c,a);var e=R(d,a);a={};for(d=0;d<c.length;d++){var f=c.charAt(d);f in a||(a[f]=e.charAt(d))}c="";for(d=0;d<b.length;d++)f=b.charAt(d),c+=f in a?a[f]:f;return c},3);T("true",2,!1,!1,function(){return!0},0);function K(a,b){this.j=a;this.c=void 0!==b?b:null;this.b=null;switch(a){case "comment":this.b=8;break;case "text":this.b=3;break;case "processing-instruction":this.b=7;break;case "node":break;default:throw Error("Unexpected argument");}}function Ob(a){return"comment"==a||"text"==a||"processing-instruction"==a||"node"==a}K.prototype.a=function(a){return null===this.b||this.b==a.nodeType};K.prototype.h=function(){return this.j};
K.prototype.toString=function(){var a="Kind Test: "+this.j;null===this.c||(a+=O(this.c));return a};function Pb(a){N.call(this,3);this.c=a.substring(1,a.length-1)}n(Pb,N);Pb.prototype.a=function(){return this.c};Pb.prototype.toString=function(){return"Literal: "+this.c};function I(a,b){this.o=a.toLowerCase();var c;c="*"==this.o?"*":"http://www.w3.org/1999/xhtml";this.c=b?b.toLowerCase():c}I.prototype.a=function(a){var b=a.nodeType;return 1!=b&&2!=b?!1:"*"!=this.o&&this.o!=a.localName.toLowerCase()?!1:"*"==this.c?!0:this.c==(a.namespaceURI?a.namespaceURI.toLowerCase():"http://www.w3.org/1999/xhtml")};I.prototype.h=function(){return this.o};I.prototype.toString=function(){return"Name Test: "+("http://www.w3.org/1999/xhtml"==this.c?"":this.c+":")+this.o};function Qb(a){N.call(this,1);this.c=a}n(Qb,N);Qb.prototype.a=function(){return this.c};Qb.prototype.toString=function(){return"Number: "+this.c};function Rb(a,b){N.call(this,a.m);this.j=a;this.c=b;this.i=a.i;this.b=a.b;if(1==this.c.length){var c=this.c[0];c.C||c.c!=Sb||(c=c.w,"*"!=c.h()&&(this.h={name:c.h(),A:null}))}}n(Rb,N);function Tb(){N.call(this,4)}n(Tb,N);Tb.prototype.a=function(a){var b=new H;a=a.a;9==a.nodeType?J(b,a):J(b,a.ownerDocument);return b};Tb.prototype.toString=function(){return"Root Helper Expression"};function Ub(){N.call(this,4)}n(Ub,N);Ub.prototype.a=function(a){var b=new H;J(b,a.a);return b};Ub.prototype.toString=function(){return"Context Helper Expression"};
function Vb(a){return"/"==a||"//"==a}Rb.prototype.a=function(a){var b=this.j.a(a);if(!(b instanceof H))throw Error("Filter expression must evaluate to nodeset.");a=this.c;for(var c=0,d=a.length;c<d&&b.s;c++){var e=a[c],f=L(b,e.c.a),g;if(e.i||e.c!=Wb)if(e.i||e.c!=Xb)for(g=M(f),b=e.a(new gb(g));null!=(g=M(f));)g=e.a(new gb(g)),b=xb(b,g);else g=M(f),b=e.a(new gb(g));else{for(g=M(f);(b=M(f))&&(!g.contains||g.contains(b))&&b.compareDocumentPosition(g)&8;g=b);b=e.a(new gb(g))}}return b};
Rb.prototype.toString=function(){var a;a="Path Expression:"+O(this.j);if(this.c.length){var b=sa(this.c,function(a,b){return a+O(b)},"Steps:");a+=O(b)}return a};function Yb(a,b){this.a=a;this.b=!!b}
function Kb(a,b,c){for(c=c||0;c<a.a.length;c++)for(var d=a.a[c],e=L(b),f=b.s,g,k=0;g=M(e);k++){var x=a.b?f-k:k+1;g=d.a(new gb(g,x,f));if("number"==typeof g)x=x==g;else if("string"==typeof g||"boolean"==typeof g)x=!!g;else if(g instanceof H)x=0<g.s;else throw Error("Predicate.evaluate returned an unexpected type.");if(!x){x=e;g=x.h;var D=x.a;if(!D)throw Error("Next must be called at least once before remove.");var Q=D.b,D=D.a;Q?Q.a=D:g.a=D;D?D.b=Q:g.b=Q;g.s--;x.a=null}}return b}
Yb.prototype.toString=function(){return sa(this.a,function(a,b){return a+O(b)},"Predicates:")};function U(a,b,c,d){N.call(this,4);this.c=a;this.w=b;this.j=c||new Yb([]);this.C=!!d;b=this.j;b=0<b.a.length?b.a[0].h:null;a.b&&b&&(a=b.name,a=B?a.toLowerCase():a,this.h={name:a,A:b.A});a:{a=this.j;for(b=0;b<a.a.length;b++)if(c=a.a[b],c.i||1==c.m||0==c.m){a=!0;break a}a=!1}this.i=a}n(U,N);
U.prototype.a=function(a){var b=a.a,c=null,c=this.h,d=null,e=null,f=0;c&&(d=c.name,e=c.A?R(c.A,a):null,f=1);if(this.C)if(this.i||this.c!=Zb)if(a=L((new U($b,new K("node"))).a(a)),b=M(a))for(c=this.v(b,d,e,f);null!=(b=M(a));)c=xb(c,this.v(b,d,e,f));else c=new H;else c=pb(this.w,b,d,e),c=Kb(this.j,c,f);else c=this.v(a.a,d,e,f);return c};U.prototype.v=function(a,b,c,d){a=this.c.h(this.w,a,b,c);return a=Kb(this.j,a,d)};
U.prototype.toString=function(){var a;a="Step:"+O("Operator: "+(this.C?"//":"/"));this.c.o&&(a+=O("Axis: "+this.c));a+=O(this.w);if(this.j.a.length){var b=sa(this.j.a,function(a,b){return a+O(b)},"Predicates:");a+=O(b)}return a};function ac(a,b,c,d){this.o=a;this.h=b;this.a=c;this.b=d}ac.prototype.toString=function(){return this.o};var bc={};function V(a,b,c,d){if(bc.hasOwnProperty(a))throw Error("Axis already created: "+a);b=new ac(a,b,c,!!d);return bc[a]=b}
V("ancestor",function(a,b){for(var c=new H,d=b;d=d.parentNode;)a.a(d)&&c.unshift(d);return c},!0);V("ancestor-or-self",function(a,b){var c=new H,d=b;do a.a(d)&&c.unshift(d);while(d=d.parentNode);return c},!0);
var Sb=V("attribute",function(a,b){var c=new H,d=a.h();if("style"==d&&b.style&&B)return J(c,new ib(b.style,b,"style",b.style.cssText)),c;var e=b.attributes;if(e)if(a instanceof K&&null===a.b||"*"==d)for(var d=0,f;f=e[d];d++)B?f.nodeValue&&J(c,jb(b,f)):J(c,f);else(f=e.getNamedItem(d))&&(B?f.nodeValue&&J(c,jb(b,f)):J(c,f));return c},!1),Zb=V("child",function(a,b,c,d,e){return(B?ub:vb).call(null,a,b,m(c)?c:null,m(d)?d:null,e||new H)},!1,!0);V("descendant",pb,!1,!0);
var $b=V("descendant-or-self",function(a,b,c,d){var e=new H;G(b,c,d)&&a.a(b)&&J(e,b);return pb(a,b,c,d,e)},!1,!0),Wb=V("following",function(a,b,c,d){var e=new H;do for(var f=b;f=f.nextSibling;)G(f,c,d)&&a.a(f)&&J(e,f),e=pb(a,f,c,d,e);while(b=b.parentNode);return e},!1,!0);V("following-sibling",function(a,b){for(var c=new H,d=b;d=d.nextSibling;)a.a(d)&&J(c,d);return c},!1);V("namespace",function(){return new H},!1);
var cc=V("parent",function(a,b){var c=new H;if(9==b.nodeType)return c;if(2==b.nodeType)return J(c,b.ownerElement),c;var d=b.parentNode;a.a(d)&&J(c,d);return c},!1),Xb=V("preceding",function(a,b,c,d){var e=new H,f=[];do f.unshift(b);while(b=b.parentNode);for(var g=1,k=f.length;g<k;g++){var x=[];for(b=f[g];b=b.previousSibling;)x.unshift(b);for(var D=0,Q=x.length;D<Q;D++)b=x[D],G(b,c,d)&&a.a(b)&&J(e,b),e=pb(a,b,c,d,e)}return e},!0,!0);
V("preceding-sibling",function(a,b){for(var c=new H,d=b;d=d.previousSibling;)a.a(d)&&c.unshift(d);return c},!0);var dc=V("self",function(a,b){var c=new H;a.a(b)&&J(c,b);return c},!1);function ec(a){N.call(this,1);this.c=a;this.i=a.i;this.b=a.b}n(ec,N);ec.prototype.a=function(a){return-P(this.c,a)};ec.prototype.toString=function(){return"Unary Expression: -"+O(this.c)};function fc(a){N.call(this,4);this.c=a;Bb(this,ta(this.c,function(a){return a.i}));Cb(this,ta(this.c,function(a){return a.b}))}n(fc,N);fc.prototype.a=function(a){var b=new H;q(this.c,function(c){c=c.a(a);if(!(c instanceof H))throw Error("Path expression must evaluate to NodeSet.");b=xb(b,c)});return b};fc.prototype.toString=function(){return sa(this.c,function(a,b){return a+O(b)},"Union Expression:")};function gc(a,b){this.a=a;this.b=b}function hc(a){for(var b,c=[];;){W(a,"Missing right hand side of binary expression.");b=ic(a);var d=E(a.a);if(!d)break;var e=(d=Ib[d]||null)&&d.F;if(!e){a.a.a--;break}for(;c.length&&e<=c[c.length-1].F;)b=new Eb(c.pop(),c.pop(),b);c.push(b,d)}for(;c.length;)b=new Eb(c.pop(),c.pop(),b);return b}function W(a,b){if(ob(a.a))throw Error(b);}function jc(a,b){var c=E(a.a);if(c!=b)throw Error("Bad token, expected: "+b+" got: "+c);}
function kc(a){a=E(a.a);if(")"!=a)throw Error("Bad token: "+a);}function lc(a){a=E(a.a);if(2>a.length)throw Error("Unclosed literal string");return new Pb(a)}
function mc(a){var b,c=[],d;if(Vb(C(a.a))){b=E(a.a);d=C(a.a);if("/"==b&&(ob(a.a)||"."!=d&&".."!=d&&"@"!=d&&"*"!=d&&!/(?![0-9])[\w]/.test(d)))return new Tb;d=new Tb;W(a,"Missing next location step.");b=nc(a,b);c.push(b)}else{a:{b=C(a.a);d=b.charAt(0);switch(d){case "$":throw Error("Variable reference not allowed in HTML XPath");case "(":E(a.a);b=hc(a);W(a,'unclosed "("');jc(a,")");break;case '"':case "'":b=lc(a);break;default:if(isNaN(+b))if(!Ob(b)&&/(?![0-9])[\w]/.test(d)&&"("==C(a.a,1)){b=E(a.a);
b=Nb[b]||null;E(a.a);for(d=[];")"!=C(a.a);){W(a,"Missing function argument list.");d.push(hc(a));if(","!=C(a.a))break;E(a.a)}W(a,"Unclosed function argument list.");kc(a);b=new Lb(b,d)}else{b=null;break a}else b=new Qb(+E(a.a))}"["==C(a.a)&&(d=new Yb(oc(a)),b=new Jb(b,d))}if(b)if(Vb(C(a.a)))d=b;else return b;else b=nc(a,"/"),d=new Ub,c.push(b)}for(;Vb(C(a.a));)b=E(a.a),W(a,"Missing next location step."),b=nc(a,b),c.push(b);return new Rb(d,c)}
function nc(a,b){var c,d,e;if("/"!=b&&"//"!=b)throw Error('Step op should be "/" or "//"');if("."==C(a.a))return d=new U(dc,new K("node")),E(a.a),d;if(".."==C(a.a))return d=new U(cc,new K("node")),E(a.a),d;var f;if("@"==C(a.a))f=Sb,E(a.a),W(a,"Missing attribute name");else if("::"==C(a.a,1)){if(!/(?![0-9])[\w]/.test(C(a.a).charAt(0)))throw Error("Bad token: "+E(a.a));c=E(a.a);f=bc[c]||null;if(!f)throw Error("No axis with name: "+c);E(a.a);W(a,"Missing node name")}else f=Zb;c=C(a.a);if(/(?![0-9])[\w\*]/.test(c.charAt(0)))if("("==
C(a.a,1)){if(!Ob(c))throw Error("Invalid node type: "+c);c=E(a.a);if(!Ob(c))throw Error("Invalid type name: "+c);jc(a,"(");W(a,"Bad nodetype");e=C(a.a).charAt(0);var g=null;if('"'==e||"'"==e)g=lc(a);W(a,"Bad nodetype");kc(a);c=new K(c,g)}else if(c=E(a.a),e=c.indexOf(":"),-1==e)c=new I(c);else{var g=c.substring(0,e),k;if("*"==g)k="*";else if(k=a.b(g),!k)throw Error("Namespace prefix not declared: "+g);c=c.substr(e+1);c=new I(c,k)}else throw Error("Bad token: "+E(a.a));e=new Yb(oc(a),f.a);return d||
new U(f,c,e,"//"==b)}function oc(a){for(var b=[];"["==C(a.a);){E(a.a);W(a,"Missing predicate expression.");var c=hc(a);b.push(c);W(a,"Unclosed predicate expression.");jc(a,"]")}return b}function ic(a){if("-"==C(a.a))return E(a.a),new ec(ic(a));var b=mc(a);if("|"!=C(a.a))a=b;else{for(b=[b];"|"==E(a.a);)W(a,"Missing next union location path."),b.push(mc(a));a.a.a--;a=new fc(b)}return a};function pc(a){switch(a.nodeType){case 1:return ia(qc,a);case 9:return pc(a.documentElement);case 11:case 10:case 6:case 12:return rc;default:return a.parentNode?pc(a.parentNode):rc}}function rc(){return null}function qc(a,b){if(a.prefix==b)return a.namespaceURI||"http://www.w3.org/1999/xhtml";var c=a.getAttributeNode("xmlns:"+b);return c&&c.specified?c.value||null:a.parentNode&&9!=a.parentNode.nodeType?qc(a.parentNode,b):null};function sc(a,b){if(!a.length)throw Error("Empty XPath expression.");var c=lb(a);if(ob(c))throw Error("Invalid XPath expression.");b?"function"==ba(b)||(b=ha(b.lookupNamespaceURI,b)):b=function(){return null};var d=hc(new gc(c,b));if(!ob(c))throw Error("Bad token: "+E(c));this.evaluate=function(a,b){var c=d.a(new gb(a));return new X(c,b)}}
function X(a,b){if(0==b)if(a instanceof H)b=4;else if("string"==typeof a)b=2;else if("number"==typeof a)b=1;else if("boolean"==typeof a)b=3;else throw Error("Unexpected evaluation result.");if(2!=b&&1!=b&&3!=b&&!(a instanceof H))throw Error("value could not be converted to the specified type");this.resultType=b;var c;switch(b){case 2:this.stringValue=a instanceof H?zb(a):""+a;break;case 1:this.numberValue=a instanceof H?+zb(a):+a;break;case 3:this.booleanValue=a instanceof H?0<a.s:!!a;break;case 4:case 5:case 6:case 7:var d=
L(a);c=[];for(var e=M(d);e;e=M(d))c.push(e instanceof ib?e.a:e);this.snapshotLength=a.s;this.invalidIteratorState=!1;break;case 8:case 9:d=yb(a);this.singleNodeValue=d instanceof ib?d.a:d;break;default:throw Error("Unknown XPathResult type.");}var f=0;this.iterateNext=function(){if(4!=b&&5!=b)throw Error("iterateNext called with wrong result type");return f>=c.length?null:c[f++]};this.snapshotItem=function(a){if(6!=b&&7!=b)throw Error("snapshotItem called with wrong result type");return a>=c.length||
0>a?null:c[a]}}X.ANY_TYPE=0;X.NUMBER_TYPE=1;X.STRING_TYPE=2;X.BOOLEAN_TYPE=3;X.UNORDERED_NODE_ITERATOR_TYPE=4;X.ORDERED_NODE_ITERATOR_TYPE=5;X.UNORDERED_NODE_SNAPSHOT_TYPE=6;X.ORDERED_NODE_SNAPSHOT_TYPE=7;X.ANY_UNORDERED_NODE_TYPE=8;X.FIRST_ORDERED_NODE_TYPE=9;function tc(a){this.lookupNamespaceURI=pc(a)}
aa("wgxpath.install",function(a,b){var c=a||l,d=c.document;if(!d.evaluate||b)c.XPathResult=X,d.evaluate=function(a,b,c,d){return(new sc(a,c)).evaluate(b,d)},d.createExpression=function(a,b){return new sc(a,b)},d.createNSResolver=function(a){return new tc(a)}});function uc(a){return(a=a.exec(t))?a[1]:""}var vc=function(){if(ab)return uc(/Firefox\/([0-9.]+)/);if(w||Ia||Ha)return Oa;if(eb)return uc(/Chrome\/([0-9.]+)/);if(fb&&!(Ga()||u("iPad")||u("iPod")))return uc(/Version\/([0-9.]+)/);if(bb||cb){var a;if(a=/Version\/(\S+).*Mobile\/(\S+)/.exec(t))return a[1]+"."+a[2]}else if(db)return(a=uc(/Android\s+([0-9.]+)/))?a:uc(/Version\/([0-9.]+)/);return""}();var wc,xc;function yc(a){return zc?wc(a):w?0<=oa(z,a):Qa(a)}function Ac(a){zc?xc(a):db?oa(Bc,a):oa(vc,a)}
var zc=function(){if(!y)return!1;var a=l.Components;if(!a)return!1;try{if(!a.classes)return!1}catch(f){return!1}var b=a.classes,a=a.interfaces,c=b["@mozilla.org/xpcom/version-comparator;1"].getService(a.nsIVersionComparator),b=b["@mozilla.org/xre/app-info;1"].getService(a.nsIXULAppInfo),d=b.platformVersion,e=b.version;wc=function(a){return 0<=c.compare(d,""+a)};xc=function(a){c.compare(e,""+a)};return!0}(),Cc;if(db){var Dc=/Android\s+([0-9\.]+)/.exec(t);Cc=Dc?Dc[1]:"0"}else Cc="0";var Bc=Cc;db&&Ac(2.3);
db&&Ac(4);fb&&Ac(6);function Ec(a,b,c,d){this.top=a;this.right=b;this.bottom=c;this.left=d}h=Ec.prototype;h.clone=function(){return new Ec(this.top,this.right,this.bottom,this.left)};h.toString=function(){return"("+this.top+"t, "+this.right+"r, "+this.bottom+"b, "+this.left+"l)"};h.contains=function(a){return this&&a?a instanceof Ec?a.left>=this.left&&a.right<=this.right&&a.top>=this.top&&a.bottom<=this.bottom:a.x>=this.left&&a.x<=this.right&&a.y>=this.top&&a.y<=this.bottom:!1};
h.ceil=function(){this.top=Math.ceil(this.top);this.right=Math.ceil(this.right);this.bottom=Math.ceil(this.bottom);this.left=Math.ceil(this.left);return this};h.floor=function(){this.top=Math.floor(this.top);this.right=Math.floor(this.right);this.bottom=Math.floor(this.bottom);this.left=Math.floor(this.left);return this};h.round=function(){this.top=Math.round(this.top);this.right=Math.round(this.right);this.bottom=Math.round(this.bottom);this.left=Math.round(this.left);return this};
h.scale=function(a,b){var c=da(b)?b:a;this.left*=a;this.right*=a;this.top*=c;this.bottom*=c;return this};function Fc(a,b,c,d){this.left=a;this.top=b;this.width=c;this.height=d}h=Fc.prototype;h.clone=function(){return new Fc(this.left,this.top,this.width,this.height)};h.toString=function(){return"("+this.left+", "+this.top+" - "+this.width+"w x "+this.height+"h)"};h.contains=function(a){return a instanceof Fc?this.left<=a.left&&this.left+this.width>=a.left+a.width&&this.top<=a.top&&this.top+this.height>=a.top+a.height:a.x>=this.left&&a.x<=this.left+this.width&&a.y>=this.top&&a.y<=this.top+this.height};
h.ceil=function(){this.left=Math.ceil(this.left);this.top=Math.ceil(this.top);this.width=Math.ceil(this.width);this.height=Math.ceil(this.height);return this};h.floor=function(){this.left=Math.floor(this.left);this.top=Math.floor(this.top);this.width=Math.floor(this.width);this.height=Math.floor(this.height);return this};h.round=function(){this.left=Math.round(this.left);this.top=Math.round(this.top);this.width=Math.round(this.width);this.height=Math.round(this.height);return this};
h.scale=function(a,b){var c=da(b)?b:a;this.left*=a;this.width*=a;this.top*=c;this.height*=c;return this};function Gc(a,b){var c=Va(a);return c.defaultView&&c.defaultView.getComputedStyle&&(c=c.defaultView.getComputedStyle(a,null))?c[b]||c.getPropertyValue(b)||"":""}function Hc(a){var b;try{b=a.getBoundingClientRect()}catch(c){return{left:0,top:0,right:0,bottom:0}}w&&a.ownerDocument.body&&(a=a.ownerDocument,b.left-=a.documentElement.clientLeft+a.body.clientLeft,b.top-=a.documentElement.clientTop+a.body.clientTop);return b}
function Ic(a){var b=Va(a),c=new A(0,0),d;d=b?Va(b):document;var e;(e=!w||9<=Number(z))||(e="CSS1Compat"==Ta(d).a.compatMode);if(a==(e?d.documentElement:d.body))return c;a=Hc(a);d=Ta(b).a;b=d.scrollingElement?d.scrollingElement:Ja||"CSS1Compat"!=d.compatMode?d.body||d.documentElement:d.documentElement;d=d.parentWindow||d.defaultView;b=w&&Qa("10")&&d.pageYOffset!=b.scrollTop?new A(b.scrollLeft,b.scrollTop):new A(d.pageXOffset||b.scrollLeft,d.pageYOffset||b.scrollTop);c.x=a.left+b.x;c.y=a.top+b.y;return c}
function Jc(a){if(1==a.nodeType)return a=Hc(a),new A(a.left,a.top);a=a.changedTouches?a.changedTouches[0]:a;return new A(a.clientX,a.clientY)}var Kc={thin:2,medium:4,thick:6};
function Lc(a,b){if("none"==(a.currentStyle?a.currentStyle[b+"Style"]:null))return 0;var c=a.currentStyle?a.currentStyle[b+"Width"]:null,d;if(c in Kc)d=Kc[c];else if(/^\d+px?$/.test(c))d=parseInt(c,10);else{d=a.style.left;var e=a.runtimeStyle.left;a.runtimeStyle.left=a.currentStyle.left;a.style.left=c;c=a.style.pixelLeft;a.style.left=d;a.runtimeStyle.left=e;d=c}return d};Ja||zc&&Ac(3.6);w&&yc(10);db&&Ac(4);function Y(a,b){this.u={};this.l=[];this.b=this.a=0;var c=arguments.length;if(1<c){if(c%2)throw Error("Uneven number of arguments");for(var d=0;d<c;d+=2)Mc(this,arguments[d],arguments[d+1])}else if(a){var e;if(a instanceof Y)for(d=Nc(a),Oc(a),e=[],c=0;c<a.l.length;c++)e.push(a.u[a.l[c]]);else{var c=[],f=0;for(d in a)c[f++]=d;d=c;c=[];f=0;for(e in a)c[f++]=a[e];e=c}for(c=0;c<d.length;c++)Mc(this,d[c],e[c])}}function Nc(a){Oc(a);return a.l.concat()}
Y.prototype.clear=function(){this.u={};this.b=this.a=this.l.length=0};function Oc(a){if(a.a!=a.l.length){for(var b=0,c=0;b<a.l.length;){var d=a.l[b];Object.prototype.hasOwnProperty.call(a.u,d)&&(a.l[c++]=d);b++}a.l.length=c}if(a.a!=a.l.length){for(var e={},c=b=0;b<a.l.length;)d=a.l[b],Object.prototype.hasOwnProperty.call(e,d)||(a.l[c++]=d,e[d]=1),b++;a.l.length=c}}Y.prototype.get=function(a,b){return Object.prototype.hasOwnProperty.call(this.u,a)?this.u[a]:b};
function Mc(a,b,c){Object.prototype.hasOwnProperty.call(a.u,b)||(a.a++,a.l.push(b),a.b++);a.u[b]=c}Y.prototype.forEach=function(a,b){for(var c=Nc(this),d=0;d<c.length;d++){var e=c[d],f=this.get(e);a.call(b,f,e,this)}};Y.prototype.clone=function(){return new Y(this)};var Pc={};function Z(a,b,c){ea(a)&&(a=y?a.f:a.g);a=new Qc(a);!b||b in Pc&&!c||(Pc[b]={key:a,shift:!1},c&&(Pc[c]={key:a,shift:!0}));return a}function Qc(a){this.code=a}Z(8);Z(9);Z(13);var Rc=Z(16),Sc=Z(17),Tc=Z(18);Z(19);Z(20);Z(27);Z(32," ");Z(33);Z(34);Z(35);Z(36);Z(37);Z(38);Z(39);Z(40);Z(44);Z(45);Z(46);Z(48,"0",")");Z(49,"1","!");Z(50,"2","@");Z(51,"3","#");Z(52,"4","$");Z(53,"5","%");Z(54,"6","^");Z(55,"7","&");Z(56,"8","*");Z(57,"9","(");Z(65,"a","A");Z(66,"b","B");Z(67,"c","C");Z(68,"d","D");
Z(69,"e","E");Z(70,"f","F");Z(71,"g","G");Z(72,"h","H");Z(73,"i","I");Z(74,"j","J");Z(75,"k","K");Z(76,"l","L");Z(77,"m","M");Z(78,"n","N");Z(79,"o","O");Z(80,"p","P");Z(81,"q","Q");Z(82,"r","R");Z(83,"s","S");Z(84,"t","T");Z(85,"u","U");Z(86,"v","V");Z(87,"w","W");Z(88,"x","X");Z(89,"y","Y");Z(90,"z","Z");var Uc=Z(La?{f:91,g:91}:Ka?{f:224,g:91}:{f:0,g:91});Z(La?{f:92,g:92}:Ka?{f:224,g:93}:{f:0,g:92});Z(La?{f:93,g:93}:Ka?{f:0,g:0}:{f:93,g:null});Z({f:96,g:96},"0");Z({f:97,g:97},"1");
Z({f:98,g:98},"2");Z({f:99,g:99},"3");Z({f:100,g:100},"4");Z({f:101,g:101},"5");Z({f:102,g:102},"6");Z({f:103,g:103},"7");Z({f:104,g:104},"8");Z({f:105,g:105},"9");Z({f:106,g:106},"*");Z({f:107,g:107},"+");Z({f:109,g:109},"-");Z({f:110,g:110},".");Z({f:111,g:111},"/");Z(144);Z(112);Z(113);Z(114);Z(115);Z(116);Z(117);Z(118);Z(119);Z(120);Z(121);Z(122);Z(123);Z({f:107,g:187},"=","+");Z(108,",");Z({f:109,g:189},"-","_");Z(188,",","<");Z(190,".",">");Z(191,"/","?");Z(192,"`","~");Z(219,"[","{");
Z(220,"\\","|");Z(221,"]","}");Z({f:59,g:186},";",":");Z(222,"'",'"');var Vc=new Y;Mc(Vc,1,Rc);Mc(Vc,2,Sc);Mc(Vc,4,Tc);Mc(Vc,8,Uc);(function(a){var b=new Y;q(Nc(a),function(c){Mc(b,a.get(c).code,c)});return b})(Vc);y&&yc(12);function Wc(){}
function Xc(a,b,c){if(null==b)c.push("null");else{if("object"==typeof b){if("array"==ba(b)){var d=b;b=d.length;c.push("[");for(var e="",f=0;f<b;f++)c.push(e),Xc(a,d[f],c),e=",";c.push("]");return}if(b instanceof String||b instanceof Number||b instanceof Boolean)b=b.valueOf();else{c.push("{");e="";for(d in b)Object.prototype.hasOwnProperty.call(b,d)&&(f=b[d],"function"!=typeof f&&(c.push(e),Yc(d,c),c.push(":"),Xc(a,f,c),e=","));c.push("}");return}}switch(typeof b){case "string":Yc(b,c);break;case "number":c.push(isFinite(b)&&
!isNaN(b)?String(b):"null");break;case "boolean":c.push(String(b));break;case "function":c.push("null");break;default:throw Error("Unknown type: "+typeof b);}}}var Zc={'"':'\\"',"\\":"\\\\","/":"\\/","\b":"\\b","\f":"\\f","\n":"\\n","\r":"\\r","\t":"\\t","\x0B":"\\u000b"},$c=/\uffff/.test("\uffff")?/[\\\"\x00-\x1f\x7f-\uffff]/g:/[\\\"\x00-\x1f\x7f-\xff]/g;
function Yc(a,b){b.push('"',a.replace($c,function(a){var b=Zc[a];b||(b="\\u"+(a.charCodeAt(0)|65536).toString(16).substr(1),Zc[a]=b);return b}),'"')};Ja||y&&yc(3.5)||w&&yc(8);function ad(a){switch(ba(a)){case "string":case "number":case "boolean":return a;case "function":return a.toString();case "array":return ra(a,ad);case "object":if(v(a,"nodeType")&&(1==a.nodeType||9==a.nodeType)){var b={};b.ELEMENT=bd(a);return b}if(v(a,"document"))return b={},b.WINDOW=bd(a),b;if(ca(a))return ra(a,ad);a=Ba(a,function(a,b){return da(b)||m(b)});return Ca(a,ad);default:return null}}
function cd(a,b){return"array"==ba(a)?ra(a,function(a){return cd(a,b)}):ea(a)?"function"==typeof a?a:v(a,"ELEMENT")?dd(a.ELEMENT,b):v(a,"WINDOW")?dd(a.WINDOW,b):Ca(a,function(a){return cd(a,b)}):a}function ed(a){a=a||document;var b=a.$wdc_;b||(b=a.$wdc_={},b.B=ja());b.B||(b.B=ja());return b}function bd(a){var b=ed(a.ownerDocument),c=Da(b,function(b){return b==a});c||(c=":wdc:"+b.B++,b[c]=a);return c}
function dd(a,b){a=decodeURIComponent(a);var c=b||document,d=ed(c);if(!v(d,a))throw new xa(10,"Element does not exist in cache");var e=d[a];if(v(e,"setInterval")){if(e.closed)throw delete d[a],new xa(23,"Window has been closed.");return e}for(var f=e;f;){if(f==c.documentElement)return e;f=f.parentNode}delete d[a];throw new xa(10,"Element is no longer attached to the DOM");};var fd="function"===typeof ShadowRoot;function gd(a,b){var c;c=Ic(b);var d=Ic(a);c=new A(c.x-d.x,c.y-d.y);if(!w||9<=Number(z))d=Gc(a,"borderLeftWidth"),e=Gc(a,"borderRightWidth"),f=Gc(a,"borderTopWidth"),g=Gc(a,"borderBottomWidth"),d=new Ec(parseFloat(f),parseFloat(e),parseFloat(g),parseFloat(d));else var d=Lc(a,"borderLeft"),e=Lc(a,"borderRight"),f=Lc(a,"borderTop"),g=Lc(a,"borderBottom"),d=new Ec(f,e,g,d);c.x-=d.left;c.y-=d.top;return c}
function hd(a,b,c){function d(a,b,c,d,e){d=new Fc(c.x+d.left,c.y+d.top,d.width,d.height);c=[0,0];b=[b.width,b.height];var f=[d.left,d.top];d=[d.width,d.height];for(var g=0;2>g;g++)if(d[g]>b[g])c[g]=e?f[g]+d[g]/2-b[g]/2:f[g];else{var k=f[g]-b[g]+d[g];0<k?c[g]=k:0>f[g]&&(c[g]=f[g])}e=new A(c[0],c[1]);a.scrollLeft+=e.x;a.scrollTop+=e.y}function e(a){var b=a.parentNode;fd&&b instanceof ShadowRoot&&(b=a.host);return b}for(var f=Va(a),g=e(a),k;g&&g!=f.documentElement&&g!=f.body;)k=gd(g,a),d(g,new Sa(g.clientWidth,
g.clientHeight),k,b,c),g=e(g);k=Jc(a);a=$a(Ta(a));d(f.body,a,k,b,c)}function id(a,b,c){c||(c=new Fc(0,0,a.offsetWidth,a.offsetHeight));hd(a,c,b);a=Jc(a);return new A(a.x+c.left,a.y+c.top)};aa("_",function(a){a=[a];var b=id,c;try{a:{var d=b;if(m(d))try{b=new p.Function(d);break a}catch(g){if(w&&p.execScript){p.execScript(";");b=new p.Function(d);break a}throw g;}b=p==window?d:new p.Function("return ("+d+").apply(null,arguments);")}var e=cd(a,p.document),f=b.apply(null,e);c={status:0,value:ad(f)}}catch(g){c={status:v(g,"code")?g.code:13,value:{message:g.message}}}e=[];Xc(new Wc,c,e);return e.join("")});; return this._.apply(null,arguments);}.apply({navigator:typeof window!=undefined?window.navigator:null,document:typeof window!=undefined?window.document:null}, arguments);}
