function(){return function(){var k,aa=this;function l(a){return void 0!==a}function ba(a,b){var c=a.split("."),d=aa;c[0]in d||!d.execScript||d.execScript("var "+c[0]);for(var e;c.length&&(e=c.shift());)!c.length&&l(b)?d[e]=b:d[e]?d=d[e]:d=d[e]={}}
function ca(a){var b=typeof a;if("object"==b)if(a){if(a instanceof Array)return"array";if(a instanceof Object)return b;var c=Object.prototype.toString.call(a);if("[object Window]"==c)return"object";if("[object Array]"==c||"number"==typeof a.length&&"undefined"!=typeof a.splice&&"undefined"!=typeof a.propertyIsEnumerable&&!a.propertyIsEnumerable("splice"))return"array";if("[object Function]"==c||"undefined"!=typeof a.call&&"undefined"!=typeof a.propertyIsEnumerable&&!a.propertyIsEnumerable("call"))return"function"}else return"null";
else if("function"==b&&"undefined"==typeof a.call)return"object";return b}function da(a){var b=ca(a);return"array"==b||"object"==b&&"number"==typeof a.length}function m(a){return"string"==typeof a}function ea(a){return"number"==typeof a}function fa(a){return"function"==ca(a)}function ga(a){var b=typeof a;return"object"==b&&null!=a||"function"==b}var ha="closure_uid_"+(1E9*Math.random()>>>0),ia=0;function ja(a,b,c){return a.call.apply(a.bind,arguments)}
function ka(a,b,c){if(!a)throw Error();if(2<arguments.length){var d=Array.prototype.slice.call(arguments,2);return function(){var c=Array.prototype.slice.call(arguments);Array.prototype.unshift.apply(c,d);return a.apply(b,c)}}return function(){return a.apply(b,arguments)}}function la(a,b,c){la=Function.prototype.bind&&-1!=Function.prototype.bind.toString().indexOf("native code")?ja:ka;return la.apply(null,arguments)}
function ma(a,b){var c=Array.prototype.slice.call(arguments,1);return function(){var b=c.slice();b.push.apply(b,arguments);return a.apply(this,b)}}var na=Date.now||function(){return+new Date};function p(a,b){function c(){}c.prototype=b.prototype;a.W=b.prototype;a.prototype=new c;a.prototype.constructor=a;a.V=function(a,c,f){for(var g=Array(arguments.length-2),h=2;h<arguments.length;h++)g[h-2]=arguments[h];return b.prototype[c].apply(a,g)}};var oa=window;var pa;function qa(a){var b=a.length-1;return 0<=b&&a.indexOf(" ",b)==b}var ra=String.prototype.trim?function(a){return a.trim()}:function(a){return a.replace(/^[\s\xa0]+|[\s\xa0]+$/g,"")};
function sa(a,b){for(var c=0,d=ra(String(a)).split("."),e=ra(String(b)).split("."),f=Math.max(d.length,e.length),g=0;0==c&&g<f;g++){var h=d[g]||"",n=e[g]||"",q=RegExp("(\\d*)(\\D*)","g"),u=RegExp("(\\d*)(\\D*)","g");do{var A=q.exec(h)||["","",""],y=u.exec(n)||["","",""];if(0==A[0].length&&0==y[0].length)break;c=ta(0==A[1].length?0:parseInt(A[1],10),0==y[1].length?0:parseInt(y[1],10))||ta(0==A[2].length,0==y[2].length)||ta(A[2],y[2])}while(0==c)}return c}function ta(a,b){return a<b?-1:a>b?1:0}
function ua(a){return String(a).replace(/\-([a-z])/g,function(a,c){return c.toUpperCase()})};function r(a,b,c){for(var d=a.length,e=m(a)?a.split(""):a,f=0;f<d;f++)f in e&&b.call(c,e[f],f,a)}function va(a,b){for(var c=a.length,d=[],e=0,f=m(a)?a.split(""):a,g=0;g<c;g++)if(g in f){var h=f[g];b.call(void 0,h,g,a)&&(d[e++]=h)}return d}function wa(a,b){for(var c=a.length,d=Array(c),e=m(a)?a.split(""):a,f=0;f<c;f++)f in e&&(d[f]=b.call(void 0,e[f],f,a));return d}function xa(a,b,c){var d=c;r(a,function(c,f){d=b.call(void 0,d,c,f,a)});return d}
function ya(a,b){for(var c=a.length,d=m(a)?a.split(""):a,e=0;e<c;e++)if(e in d&&b.call(void 0,d[e],e,a))return!0;return!1}function za(a,b){for(var c=a.length,d=m(a)?a.split(""):a,e=0;e<c;e++)if(e in d&&!b.call(void 0,d[e],e,a))return!1;return!0}function Aa(a,b){var c;a:{c=a.length;for(var d=m(a)?a.split(""):a,e=0;e<c;e++)if(e in d&&b.call(void 0,d[e],e,a)){c=e;break a}c=-1}return 0>c?null:m(a)?a.charAt(c):a[c]}
function Ba(a,b){var c;a:if(m(a))c=m(b)&&1==b.length?a.indexOf(b,0):-1;else{for(c=0;c<a.length;c++)if(c in a&&a[c]===b)break a;c=-1}return 0<=c}function Ca(a){return Array.prototype.concat.apply(Array.prototype,arguments)}function Da(a,b,c){return 2>=arguments.length?Array.prototype.slice.call(a,b):Array.prototype.slice.call(a,b,c)};var Ea={aliceblue:"#f0f8ff",antiquewhite:"#faebd7",aqua:"#00ffff",aquamarine:"#7fffd4",azure:"#f0ffff",beige:"#f5f5dc",bisque:"#ffe4c4",black:"#000000",blanchedalmond:"#ffebcd",blue:"#0000ff",blueviolet:"#8a2be2",brown:"#a52a2a",burlywood:"#deb887",cadetblue:"#5f9ea0",chartreuse:"#7fff00",chocolate:"#d2691e",coral:"#ff7f50",cornflowerblue:"#6495ed",cornsilk:"#fff8dc",crimson:"#dc143c",cyan:"#00ffff",darkblue:"#00008b",darkcyan:"#008b8b",darkgoldenrod:"#b8860b",darkgray:"#a9a9a9",darkgreen:"#006400",
darkgrey:"#a9a9a9",darkkhaki:"#bdb76b",darkmagenta:"#8b008b",darkolivegreen:"#556b2f",darkorange:"#ff8c00",darkorchid:"#9932cc",darkred:"#8b0000",darksalmon:"#e9967a",darkseagreen:"#8fbc8f",darkslateblue:"#483d8b",darkslategray:"#2f4f4f",darkslategrey:"#2f4f4f",darkturquoise:"#00ced1",darkviolet:"#9400d3",deeppink:"#ff1493",deepskyblue:"#00bfff",dimgray:"#696969",dimgrey:"#696969",dodgerblue:"#1e90ff",firebrick:"#b22222",floralwhite:"#fffaf0",forestgreen:"#228b22",fuchsia:"#ff00ff",gainsboro:"#dcdcdc",
ghostwhite:"#f8f8ff",gold:"#ffd700",goldenrod:"#daa520",gray:"#808080",green:"#008000",greenyellow:"#adff2f",grey:"#808080",honeydew:"#f0fff0",hotpink:"#ff69b4",indianred:"#cd5c5c",indigo:"#4b0082",ivory:"#fffff0",khaki:"#f0e68c",lavender:"#e6e6fa",lavenderblush:"#fff0f5",lawngreen:"#7cfc00",lemonchiffon:"#fffacd",lightblue:"#add8e6",lightcoral:"#f08080",lightcyan:"#e0ffff",lightgoldenrodyellow:"#fafad2",lightgray:"#d3d3d3",lightgreen:"#90ee90",lightgrey:"#d3d3d3",lightpink:"#ffb6c1",lightsalmon:"#ffa07a",
lightseagreen:"#20b2aa",lightskyblue:"#87cefa",lightslategray:"#778899",lightslategrey:"#778899",lightsteelblue:"#b0c4de",lightyellow:"#ffffe0",lime:"#00ff00",limegreen:"#32cd32",linen:"#faf0e6",magenta:"#ff00ff",maroon:"#800000",mediumaquamarine:"#66cdaa",mediumblue:"#0000cd",mediumorchid:"#ba55d3",mediumpurple:"#9370db",mediumseagreen:"#3cb371",mediumslateblue:"#7b68ee",mediumspringgreen:"#00fa9a",mediumturquoise:"#48d1cc",mediumvioletred:"#c71585",midnightblue:"#191970",mintcream:"#f5fffa",mistyrose:"#ffe4e1",
moccasin:"#ffe4b5",navajowhite:"#ffdead",navy:"#000080",oldlace:"#fdf5e6",olive:"#808000",olivedrab:"#6b8e23",orange:"#ffa500",orangered:"#ff4500",orchid:"#da70d6",palegoldenrod:"#eee8aa",palegreen:"#98fb98",paleturquoise:"#afeeee",palevioletred:"#db7093",papayawhip:"#ffefd5",peachpuff:"#ffdab9",peru:"#cd853f",pink:"#ffc0cb",plum:"#dda0dd",powderblue:"#b0e0e6",purple:"#800080",red:"#ff0000",rosybrown:"#bc8f8f",royalblue:"#4169e1",saddlebrown:"#8b4513",salmon:"#fa8072",sandybrown:"#f4a460",seagreen:"#2e8b57",
seashell:"#fff5ee",sienna:"#a0522d",silver:"#c0c0c0",skyblue:"#87ceeb",slateblue:"#6a5acd",slategray:"#708090",slategrey:"#708090",snow:"#fffafa",springgreen:"#00ff7f",steelblue:"#4682b4",tan:"#d2b48c",teal:"#008080",thistle:"#d8bfd8",tomato:"#ff6347",turquoise:"#40e0d0",violet:"#ee82ee",wheat:"#f5deb3",white:"#ffffff",whitesmoke:"#f5f5f5",yellow:"#ffff00",yellowgreen:"#9acd32"};var Fa="backgroundColor borderTopColor borderRightColor borderBottomColor borderLeftColor color outlineColor".split(" "),Ga=/#([0-9a-fA-F])([0-9a-fA-F])([0-9a-fA-F])/,Ha=/^#(?:[0-9a-f]{3}){1,2}$/i,Ia=/^(?:rgba)?\((\d{1,3}),\s?(\d{1,3}),\s?(\d{1,3}),\s?(0|1|0\.\d*)\)$/i,Ja=/^(?:rgb)?\((0|[1-9]\d{0,2}),\s?(0|[1-9]\d{0,2}),\s?(0|[1-9]\d{0,2})\)$/i;function t(a,b){this.code=a;this.a=v[a]||Ka;this.message=b||"";var c=this.a.replace(/((?:^|\s+)[a-z])/g,function(a){return a.toUpperCase().replace(/^[\s\xa0]+/g,"")}),d=c.length-5;if(0>d||c.indexOf("Error",d)!=d)c+="Error";this.name=c;c=Error(this.message);c.name=this.name;this.stack=c.stack||""}p(t,Error);var Ka="unknown error",v={15:"element not selectable",11:"element not visible"};v[31]=Ka;v[30]=Ka;v[24]="invalid cookie domain";v[29]="invalid element coordinates";v[12]="invalid element state";
v[32]="invalid selector";v[51]="invalid selector";v[52]="invalid selector";v[17]="javascript error";v[405]="unsupported operation";v[34]="move target out of bounds";v[27]="no such alert";v[7]="no such element";v[8]="no such frame";v[23]="no such window";v[28]="script timeout";v[33]="session not created";v[10]="stale element reference";v[21]="timeout";v[25]="unable to set cookie";v[26]="unexpected alert open";v[13]=Ka;v[9]="unknown command";t.prototype.toString=function(){return this.name+": "+this.message};var La;a:{var Ma=aa.navigator;if(Ma){var Na=Ma.userAgent;if(Na){La=Na;break a}}La=""}function w(a){return-1!=La.indexOf(a)};function Oa(a,b){var c={},d;for(d in a)b.call(void 0,a[d],d,a)&&(c[d]=a[d]);return c}function Pa(a,b){var c={},d;for(d in a)c[d]=b.call(void 0,a[d],d,a);return c}function Qa(a){var b=[],c=0,d;for(d in a)b[c++]=a[d];return b}function Ra(a,b){return null!==a&&b in a}function Sa(a,b){for(var c in a)if(b.call(void 0,a[c],c,a))return c};function Ta(){return w("Opera")||w("OPR")}function Ua(){return(w("Chrome")||w("CriOS"))&&!Ta()&&!w("Edge")};function Va(){return w("iPhone")&&!w("iPod")&&!w("iPad")};var Wa=Ta(),x=w("Trident")||w("MSIE"),Xa=w("Edge"),z=w("Gecko")&&!(-1!=La.toLowerCase().indexOf("webkit")&&!w("Edge"))&&!(w("Trident")||w("MSIE"))&&!w("Edge"),B=-1!=La.toLowerCase().indexOf("webkit")&&!w("Edge"),Ya=B&&w("Mobile"),Za=w("Macintosh"),$a=w("Windows");function ab(){var a=La;if(z)return/rv\:([^\);]+)(\)|;)/.exec(a);if(Xa)return/Edge\/([\d\.]+)/.exec(a);if(x)return/\b(?:MSIE|rv)[: ]([^\);]+)(\)|;)/.exec(a);if(B)return/WebKit\/(\S+)/.exec(a)}
function bb(){var a=aa.document;return a?a.documentMode:void 0}var cb=function(){if(Wa&&aa.opera){var a;var b=aa.opera.version;try{a=b()}catch(c){a=b}return a}a="";(b=ab())&&(a=b?b[1]:"");return x&&(b=bb(),null!=b&&b>parseFloat(a))?String(b):a}(),db={};function eb(a){return db[a]||(db[a]=0<=sa(cb,a))}function fb(a){return Number(gb)>=a}var hb=aa.document,gb=hb&&x?bb()||("CSS1Compat"==hb.compatMode?parseInt(cb,10):5):void 0;!z&&!x||x&&fb(9)||z&&eb("1.9.1");x&&eb("9");function ib(a,b){this.x=l(a)?a:0;this.y=l(b)?b:0}k=ib.prototype;k.clone=function(){return new ib(this.x,this.y)};k.toString=function(){return"("+this.x+", "+this.y+")"};k.ceil=function(){this.x=Math.ceil(this.x);this.y=Math.ceil(this.y);return this};k.floor=function(){this.x=Math.floor(this.x);this.y=Math.floor(this.y);return this};k.round=function(){this.x=Math.round(this.x);this.y=Math.round(this.y);return this};k.scale=function(a,b){var c=ea(b)?b:a;this.x*=a;this.y*=c;return this};function jb(a,b){this.width=a;this.height=b}k=jb.prototype;k.clone=function(){return new jb(this.width,this.height)};k.toString=function(){return"("+this.width+" x "+this.height+")"};k.ceil=function(){this.width=Math.ceil(this.width);this.height=Math.ceil(this.height);return this};k.floor=function(){this.width=Math.floor(this.width);this.height=Math.floor(this.height);return this};k.round=function(){this.width=Math.round(this.width);this.height=Math.round(this.height);return this};
k.scale=function(a,b){var c=ea(b)?b:a;this.width*=a;this.height*=c;return this};function kb(a){return a?new lb(C(a)):pa||(pa=new lb)}function mb(a){return a.scrollingElement?a.scrollingElement:B||"CSS1Compat"!=a.compatMode?a.body||a.documentElement:a.documentElement}function nb(a){return a?a.parentWindow||a.defaultView:window}function ob(a){for(;a&&1!=a.nodeType;)a=a.previousSibling;return a}
function pb(a,b){if(!a||!b)return!1;if(a.contains&&1==b.nodeType)return a==b||a.contains(b);if("undefined"!=typeof a.compareDocumentPosition)return a==b||!!(a.compareDocumentPosition(b)&16);for(;b&&a!=b;)b=b.parentNode;return b==a}
function qb(a,b){if(a==b)return 0;if(a.compareDocumentPosition)return a.compareDocumentPosition(b)&2?1:-1;if(x&&!fb(9)){if(9==a.nodeType)return-1;if(9==b.nodeType)return 1}if("sourceIndex"in a||a.parentNode&&"sourceIndex"in a.parentNode){var c=1==a.nodeType,d=1==b.nodeType;if(c&&d)return a.sourceIndex-b.sourceIndex;var e=a.parentNode,f=b.parentNode;return e==f?rb(a,b):!c&&pb(e,b)?-1*sb(a,b):!d&&pb(f,a)?sb(b,a):(c?a.sourceIndex:e.sourceIndex)-(d?b.sourceIndex:f.sourceIndex)}d=C(a);c=d.createRange();
c.selectNode(a);c.collapse(!0);d=d.createRange();d.selectNode(b);d.collapse(!0);return c.compareBoundaryPoints(aa.Range.START_TO_END,d)}function sb(a,b){var c=a.parentNode;if(c==b)return-1;for(var d=b;d.parentNode!=c;)d=d.parentNode;return rb(d,a)}function rb(a,b){for(var c=b;c=c.previousSibling;)if(c==a)return-1;return 1}function C(a){return 9==a.nodeType?a:a.ownerDocument||a.document}var tb={SCRIPT:1,STYLE:1,HEAD:1,IFRAME:1,OBJECT:1},ub={IMG:" ",BR:"\n"};
function vb(a,b,c){if(!(a.nodeName in tb))if(3==a.nodeType)c?b.push(String(a.nodeValue).replace(/(\r\n|\r|\n)/g,"")):b.push(a.nodeValue);else if(a.nodeName in ub)b.push(ub[a.nodeName]);else for(a=a.firstChild;a;)vb(a,b,c),a=a.nextSibling}function wb(a,b,c){c||(a=a.parentNode);for(c=0;a;){if(b(a))return a;a=a.parentNode;c++}return null}function lb(a){this.a=a||aa.document||document}
function xb(a,b,c,d){a=d||a.a;b=b&&"*"!=b?b.toUpperCase():"";if(a.querySelectorAll&&a.querySelector&&(b||c))c=a.querySelectorAll(b+(c?"."+c:""));else if(c&&a.getElementsByClassName)if(a=a.getElementsByClassName(c),b){d={};for(var e=0,f=0,g;g=a[f];f++)b==g.nodeName&&(d[e++]=g);d.length=e;c=d}else c=a;else if(a=a.getElementsByTagName(b||"*"),c){d={};for(f=e=0;g=a[f];f++)b=g.className,"function"==typeof b.split&&Ba(b.split(/\s+/),c)&&(d[e++]=g);d.length=e;c=d}else c=a;return c}
function yb(a){return mb(a.a)}lb.prototype.contains=pb;var zb=w("Firefox"),Ab=Va()||w("iPod"),Bb=w("iPad"),Cb=w("Android")&&!(Ua()||w("Firefox")||Ta()||w("Silk")),Db=Ua(),Eb=w("Safari")&&!(Ua()||w("Coast")||Ta()||w("Edge")||w("Silk")||w("Android"))&&!(Va()||w("iPad")||w("iPod"));/*

 The MIT License

 Copyright (c) 2007 Cybozu Labs, Inc.
 Copyright (c) 2012 Google Inc.

 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to
 deal in the Software without restriction, including without limitation the
 rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
 sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in
 all copies or substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 IN THE SOFTWARE.
*/
function Fb(a,b,c){this.a=a;this.b=b||1;this.f=c||1};var Gb=x&&!fb(9),Hb=x&&!fb(8);function Ib(a,b,c,d){this.a=a;this.nodeName=c;this.nodeValue=d;this.nodeType=2;this.parentNode=this.ownerElement=b}function Jb(a,b){var c=Hb&&"href"==b.nodeName?a.getAttribute(b.nodeName,2):b.nodeValue;return new Ib(b,a,b.nodeName,c)};function Kb(a){this.b=a;this.a=0}function Lb(a){a=a.match(Mb);for(var b=0;b<a.length;b++)Nb.test(a[b])&&a.splice(b,1);return new Kb(a)}var Mb=RegExp("\\$?(?:(?![0-9-\\.])(?:\\*|[\\w-\\.]+):)?(?![0-9-\\.])(?:\\*|[\\w-\\.]+)|\\/\\/|\\.\\.|::|\\d+(?:\\.\\d*)?|\\.\\d+|\"[^\"]*\"|'[^']*'|[!<>]=|\\s+|.","g"),Nb=/^\s/;function D(a,b){return a.b[a.a+(b||0)]}function E(a){return a.b[a.a++]}function Ob(a){return a.b.length<=a.a};function Pb(a){var b=null,c=a.nodeType;1==c&&(b=a.textContent,b=void 0==b||null==b?a.innerText:b,b=void 0==b||null==b?"":b);if("string"!=typeof b)if(Gb&&"title"==a.nodeName.toLowerCase()&&1==c)b=a.text;else if(9==c||1==c){a=9==c?a.documentElement:a.firstChild;for(var c=0,d=[],b="";a;){do 1!=a.nodeType&&(b+=a.nodeValue),Gb&&"title"==a.nodeName.toLowerCase()&&(b+=a.text),d[c++]=a;while(a=a.firstChild);for(;c&&!(a=d[--c].nextSibling););}}else b=a.nodeValue;return""+b}
function Qb(a,b,c){if(null===b)return!0;try{if(!a.getAttribute)return!1}catch(d){return!1}Hb&&"class"==b&&(b="className");return null==c?!!a.getAttribute(b):a.getAttribute(b,2)==c}function Rb(a,b,c,d,e){return(Gb?Sb:Tb).call(null,a,b,m(c)?c:null,m(d)?d:null,e||new F)}
function Sb(a,b,c,d,e){if(a instanceof Ub||8==a.b||c&&null===a.b){var f=b.all;if(!f)return e;a=Vb(a);if("*"!=a&&(f=b.getElementsByTagName(a),!f))return e;if(c){for(var g=[],h=0;b=f[h++];)Qb(b,c,d)&&g.push(b);f=g}for(h=0;b=f[h++];)"*"==a&&"!"==b.tagName||G(e,b);return e}Wb(a,b,c,d,e);return e}
function Tb(a,b,c,d,e){b.getElementsByName&&d&&"name"==c&&!x?(b=b.getElementsByName(d),r(b,function(b){a.a(b)&&G(e,b)})):b.getElementsByClassName&&d&&"class"==c?(b=b.getElementsByClassName(d),r(b,function(b){b.className==d&&a.a(b)&&G(e,b)})):a instanceof Xb?Wb(a,b,c,d,e):b.getElementsByTagName&&(b=b.getElementsByTagName(a.f()),r(b,function(a){Qb(a,c,d)&&G(e,a)}));return e}
function Yb(a,b,c,d,e){var f;if((a instanceof Ub||8==a.b||c&&null===a.b)&&(f=b.childNodes)){var g=Vb(a);if("*"!=g&&(f=va(f,function(a){return a.tagName&&a.tagName.toLowerCase()==g}),!f))return e;c&&(f=va(f,function(a){return Qb(a,c,d)}));r(f,function(a){"*"==g&&("!"==a.tagName||"*"==g&&1!=a.nodeType)||G(e,a)});return e}return Zb(a,b,c,d,e)}function Zb(a,b,c,d,e){for(b=b.firstChild;b;b=b.nextSibling)Qb(b,c,d)&&a.a(b)&&G(e,b);return e}
function Wb(a,b,c,d,e){for(b=b.firstChild;b;b=b.nextSibling)Qb(b,c,d)&&a.a(b)&&G(e,b),Wb(a,b,c,d,e)}function Vb(a){if(a instanceof Xb){if(8==a.b)return"!";if(null===a.b)return"*"}return a.f()};function F(){this.b=this.a=null;this.s=0}function $b(a){this.node=a;this.a=this.b=null}function ac(a,b){if(!a.a)return b;if(!b.a)return a;for(var c=a.a,d=b.a,e=null,f=null,g=0;c&&d;){var f=c.node,h=d.node;f==h||f instanceof Ib&&h instanceof Ib&&f.a==h.a?(f=c,c=c.a,d=d.a):0<qb(c.node,d.node)?(f=d,d=d.a):(f=c,c=c.a);(f.b=e)?e.a=f:a.a=f;e=f;g++}for(f=c||d;f;)f.b=e,e=e.a=f,g++,f=f.a;a.b=e;a.s=g;return a}
F.prototype.unshift=function(a){a=new $b(a);a.a=this.a;this.b?this.a.b=a:this.a=this.b=a;this.a=a;this.s++};function G(a,b){var c=new $b(b);c.b=a.b;a.a?a.b.a=c:a.a=a.b=c;a.b=c;a.s++}function bc(a){return(a=a.a)?a.node:null}function cc(a){return(a=bc(a))?Pb(a):""}function ec(a,b){return new fc(a,!!b)}function fc(a,b){this.f=a;this.b=(this.c=b)?a.b:a.a;this.a=null}function H(a){var b=a.b;if(null==b)return null;var c=a.a=b;a.b=a.c?b.b:b.a;return c.node};function J(a){this.l=a;this.b=this.j=!1;this.f=null}function K(a){return"\n  "+a.toString().split("\n").join("\n  ")}function gc(a,b){a.j=b}function hc(a,b){a.b=b}function L(a,b){var c=a.a(b);return c instanceof F?+cc(c):+c}function M(a,b){var c=a.a(b);return c instanceof F?cc(c):""+c}function ic(a,b){var c=a.a(b);return c instanceof F?!!c.s:!!c};function jc(a,b,c){J.call(this,a.l);this.c=a;this.g=b;this.o=c;this.j=b.j||c.j;this.b=b.b||c.b;this.c==kc&&(c.b||c.j||4==c.l||0==c.l||!b.f?b.b||b.j||4==b.l||0==b.l||!c.f||(this.f={name:c.f.name,C:b}):this.f={name:b.f.name,C:c})}p(jc,J);
function lc(a,b,c,d,e){b=b.a(d);c=c.a(d);var f;if(b instanceof F&&c instanceof F){b=ec(b);for(d=H(b);d;d=H(b))for(e=ec(c),f=H(e);f;f=H(e))if(a(Pb(d),Pb(f)))return!0;return!1}if(b instanceof F||c instanceof F){b instanceof F?(e=b,d=c):(e=c,d=b);f=ec(e);for(var g=typeof d,h=H(f);h;h=H(f)){switch(g){case "number":h=+Pb(h);break;case "boolean":h=!!Pb(h);break;case "string":h=Pb(h);break;default:throw Error("Illegal primitive type for comparison.");}if(e==b&&a(h,d)||e==c&&a(d,h))return!0}return!1}return e?
"boolean"==typeof b||"boolean"==typeof c?a(!!b,!!c):"number"==typeof b||"number"==typeof c?a(+b,+c):a(b,c):a(+b,+c)}jc.prototype.a=function(a){return this.c.v(this.g,this.o,a)};jc.prototype.toString=function(){var a="Binary Expression: "+this.c,a=a+K(this.g);return a+=K(this.o)};function mc(a,b,c,d){this.a=a;this.N=b;this.l=c;this.v=d}mc.prototype.toString=function(){return this.a};var nc={};
function N(a,b,c,d){if(nc.hasOwnProperty(a))throw Error("Binary operator already created: "+a);a=new mc(a,b,c,d);return nc[a.toString()]=a}N("div",6,1,function(a,b,c){return L(a,c)/L(b,c)});N("mod",6,1,function(a,b,c){return L(a,c)%L(b,c)});N("*",6,1,function(a,b,c){return L(a,c)*L(b,c)});N("+",5,1,function(a,b,c){return L(a,c)+L(b,c)});N("-",5,1,function(a,b,c){return L(a,c)-L(b,c)});N("<",4,2,function(a,b,c){return lc(function(a,b){return a<b},a,b,c)});
N(">",4,2,function(a,b,c){return lc(function(a,b){return a>b},a,b,c)});N("<=",4,2,function(a,b,c){return lc(function(a,b){return a<=b},a,b,c)});N(">=",4,2,function(a,b,c){return lc(function(a,b){return a>=b},a,b,c)});var kc=N("=",3,2,function(a,b,c){return lc(function(a,b){return a==b},a,b,c,!0)});N("!=",3,2,function(a,b,c){return lc(function(a,b){return a!=b},a,b,c,!0)});N("and",2,2,function(a,b,c){return ic(a,c)&&ic(b,c)});N("or",1,2,function(a,b,c){return ic(a,c)||ic(b,c)});function oc(a,b){if(b.a.length&&4!=a.l)throw Error("Primary expression must evaluate to nodeset if filter has predicate(s).");J.call(this,a.l);this.c=a;this.g=b;this.j=a.j;this.b=a.b}p(oc,J);oc.prototype.a=function(a){a=this.c.a(a);return pc(this.g,a)};oc.prototype.toString=function(){var a;a="Filter:"+K(this.c);return a+=K(this.g)};function qc(a,b){if(b.length<a.P)throw Error("Function "+a.m+" expects at least"+a.P+" arguments, "+b.length+" given");if(null!==a.H&&b.length>a.H)throw Error("Function "+a.m+" expects at most "+a.H+" arguments, "+b.length+" given");a.R&&r(b,function(b,d){if(4!=b.l)throw Error("Argument "+d+" to function "+a.m+" is not of type Nodeset: "+b);});J.call(this,a.l);this.g=a;this.c=b;gc(this,a.j||ya(b,function(a){return a.j}));hc(this,a.U&&!b.length||a.T&&!!b.length||ya(b,function(a){return a.b}))}
p(qc,J);qc.prototype.a=function(a){return this.g.v.apply(null,Ca(a,this.c))};qc.prototype.toString=function(){var a="Function: "+this.g;if(this.c.length)var b=xa(this.c,function(a,b){return a+K(b)},"Arguments:"),a=a+K(b);return a};function rc(a,b,c,d,e,f,g,h,n){this.m=a;this.l=b;this.j=c;this.U=d;this.T=e;this.v=f;this.P=g;this.H=l(h)?h:g;this.R=!!n}rc.prototype.toString=function(){return this.m};var sc={};
function O(a,b,c,d,e,f,g,h){if(sc.hasOwnProperty(a))throw Error("Function already created: "+a+".");sc[a]=new rc(a,b,c,d,!1,e,f,g,h)}O("boolean",2,!1,!1,function(a,b){return ic(b,a)},1);O("ceiling",1,!1,!1,function(a,b){return Math.ceil(L(b,a))},1);O("concat",3,!1,!1,function(a,b){return xa(Da(arguments,1),function(b,d){return b+M(d,a)},"")},2,null);O("contains",2,!1,!1,function(a,b,c){b=M(b,a);a=M(c,a);return-1!=b.indexOf(a)},2);O("count",1,!1,!1,function(a,b){return b.a(a).s},1,1,!0);
O("false",2,!1,!1,function(){return!1},0);O("floor",1,!1,!1,function(a,b){return Math.floor(L(b,a))},1);O("id",4,!1,!1,function(a,b){function c(a){if(Gb){var b=e.all[a];if(b){if(b.nodeType&&a==b.id)return b;if(b.length)return Aa(b,function(b){return a==b.id})}return null}return e.getElementById(a)}var d=a.a,e=9==d.nodeType?d:d.ownerDocument,d=M(b,a).split(/\s+/),f=[];r(d,function(a){(a=c(a))&&!Ba(f,a)&&f.push(a)});f.sort(qb);var g=new F;r(f,function(a){G(g,a)});return g},1);
O("lang",2,!1,!1,function(){return!1},1);O("last",1,!0,!1,function(a){if(1!=arguments.length)throw Error("Function last expects ()");return a.f},0);O("local-name",3,!1,!0,function(a,b){var c=b?bc(b.a(a)):a.a;return c?c.localName||c.nodeName.toLowerCase():""},0,1,!0);O("name",3,!1,!0,function(a,b){var c=b?bc(b.a(a)):a.a;return c?c.nodeName.toLowerCase():""},0,1,!0);O("namespace-uri",3,!0,!1,function(){return""},0,1,!0);
O("normalize-space",3,!1,!0,function(a,b){return(b?M(b,a):Pb(a.a)).replace(/[\s\xa0]+/g," ").replace(/^\s+|\s+$/g,"")},0,1);O("not",2,!1,!1,function(a,b){return!ic(b,a)},1);O("number",1,!1,!0,function(a,b){return b?L(b,a):+Pb(a.a)},0,1);O("position",1,!0,!1,function(a){return a.b},0);O("round",1,!1,!1,function(a,b){return Math.round(L(b,a))},1);O("starts-with",2,!1,!1,function(a,b,c){b=M(b,a);a=M(c,a);return 0==b.lastIndexOf(a,0)},2);O("string",3,!1,!0,function(a,b){return b?M(b,a):Pb(a.a)},0,1);
O("string-length",1,!1,!0,function(a,b){return(b?M(b,a):Pb(a.a)).length},0,1);O("substring",3,!1,!1,function(a,b,c,d){c=L(c,a);if(isNaN(c)||Infinity==c||-Infinity==c)return"";d=d?L(d,a):Infinity;if(isNaN(d)||-Infinity===d)return"";c=Math.round(c)-1;var e=Math.max(c,0);a=M(b,a);return Infinity==d?a.substring(e):a.substring(e,c+Math.round(d))},2,3);O("substring-after",3,!1,!1,function(a,b,c){b=M(b,a);a=M(c,a);c=b.indexOf(a);return-1==c?"":b.substring(c+a.length)},2);
O("substring-before",3,!1,!1,function(a,b,c){b=M(b,a);a=M(c,a);a=b.indexOf(a);return-1==a?"":b.substring(0,a)},2);O("sum",1,!1,!1,function(a,b){for(var c=ec(b.a(a)),d=0,e=H(c);e;e=H(c))d+=+Pb(e);return d},1,1,!0);O("translate",3,!1,!1,function(a,b,c,d){b=M(b,a);c=M(c,a);var e=M(d,a);a={};for(d=0;d<c.length;d++){var f=c.charAt(d);f in a||(a[f]=e.charAt(d))}c="";for(d=0;d<b.length;d++)f=b.charAt(d),c+=f in a?a[f]:f;return c},3);O("true",2,!1,!1,function(){return!0},0);function Xb(a,b){this.g=a;this.c=l(b)?b:null;this.b=null;switch(a){case "comment":this.b=8;break;case "text":this.b=3;break;case "processing-instruction":this.b=7;break;case "node":break;default:throw Error("Unexpected argument");}}function tc(a){return"comment"==a||"text"==a||"processing-instruction"==a||"node"==a}Xb.prototype.a=function(a){return null===this.b||this.b==a.nodeType};Xb.prototype.f=function(){return this.g};
Xb.prototype.toString=function(){var a="Kind Test: "+this.g;null===this.c||(a+=K(this.c));return a};function uc(a){J.call(this,3);this.c=a.substring(1,a.length-1)}p(uc,J);uc.prototype.a=function(){return this.c};uc.prototype.toString=function(){return"Literal: "+this.c};function Ub(a,b){this.m=a.toLowerCase();var c;c="*"==this.m?"*":"http://www.w3.org/1999/xhtml";this.c=b?b.toLowerCase():c}Ub.prototype.a=function(a){var b=a.nodeType;return 1!=b&&2!=b?!1:"*"!=this.m&&this.m!=a.localName.toLowerCase()?!1:"*"==this.c?!0:this.c==(a.namespaceURI?a.namespaceURI.toLowerCase():"http://www.w3.org/1999/xhtml")};Ub.prototype.f=function(){return this.m};Ub.prototype.toString=function(){return"Name Test: "+("http://www.w3.org/1999/xhtml"==this.c?"":this.c+":")+this.m};function vc(a){J.call(this,1);this.c=a}p(vc,J);vc.prototype.a=function(){return this.c};vc.prototype.toString=function(){return"Number: "+this.c};function wc(a,b){J.call(this,a.l);this.g=a;this.c=b;this.j=a.j;this.b=a.b;if(1==this.c.length){var c=this.c[0];c.w||c.c!=xc||(c=c.o,"*"!=c.f()&&(this.f={name:c.f(),C:null}))}}p(wc,J);function yc(){J.call(this,4)}p(yc,J);yc.prototype.a=function(a){var b=new F;a=a.a;9==a.nodeType?G(b,a):G(b,a.ownerDocument);return b};yc.prototype.toString=function(){return"Root Helper Expression"};function zc(){J.call(this,4)}p(zc,J);zc.prototype.a=function(a){var b=new F;G(b,a.a);return b};zc.prototype.toString=function(){return"Context Helper Expression"};
function Ac(a){return"/"==a||"//"==a}wc.prototype.a=function(a){var b=this.g.a(a);if(!(b instanceof F))throw Error("Filter expression must evaluate to nodeset.");a=this.c;for(var c=0,d=a.length;c<d&&b.s;c++){var e=a[c],f=ec(b,e.c.a),g;if(e.j||e.c!=Bc)if(e.j||e.c!=Cc)for(g=H(f),b=e.a(new Fb(g));null!=(g=H(f));)g=e.a(new Fb(g)),b=ac(b,g);else g=H(f),b=e.a(new Fb(g));else{for(g=H(f);(b=H(f))&&(!g.contains||g.contains(b))&&b.compareDocumentPosition(g)&8;g=b);b=e.a(new Fb(g))}}return b};
wc.prototype.toString=function(){var a;a="Path Expression:"+K(this.g);if(this.c.length){var b=xa(this.c,function(a,b){return a+K(b)},"Steps:");a+=K(b)}return a};function Dc(a,b){this.a=a;this.b=!!b}
function pc(a,b,c){for(c=c||0;c<a.a.length;c++)for(var d=a.a[c],e=ec(b),f=b.s,g,h=0;g=H(e);h++){var n=a.b?f-h:h+1;g=d.a(new Fb(g,n,f));if("number"==typeof g)n=n==g;else if("string"==typeof g||"boolean"==typeof g)n=!!g;else if(g instanceof F)n=0<g.s;else throw Error("Predicate.evaluate returned an unexpected type.");if(!n){n=e;g=n.f;var q=n.a;if(!q)throw Error("Next must be called at least once before remove.");var u=q.b,q=q.a;u?u.a=q:g.a=q;q?q.b=u:g.b=u;g.s--;n.a=null}}return b}
Dc.prototype.toString=function(){return xa(this.a,function(a,b){return a+K(b)},"Predicates:")};function Ec(a,b,c,d){J.call(this,4);this.c=a;this.o=b;this.g=c||new Dc([]);this.w=!!d;b=this.g;b=0<b.a.length?b.a[0].f:null;a.b&&b&&(a=b.name,a=Gb?a.toLowerCase():a,this.f={name:a,C:b.C});a:{a=this.g;for(b=0;b<a.a.length;b++)if(c=a.a[b],c.j||1==c.l||0==c.l){a=!0;break a}a=!1}this.j=a}p(Ec,J);
Ec.prototype.a=function(a){var b=a.a,c=null,c=this.f,d=null,e=null,f=0;c&&(d=c.name,e=c.C?M(c.C,a):null,f=1);if(this.w)if(this.j||this.c!=Fc)if(a=ec((new Ec(Gc,new Xb("node"))).a(a)),b=H(a))for(c=this.v(b,d,e,f);null!=(b=H(a));)c=ac(c,this.v(b,d,e,f));else c=new F;else c=Rb(this.o,b,d,e),c=pc(this.g,c,f);else c=this.v(a.a,d,e,f);return c};Ec.prototype.v=function(a,b,c,d){a=this.c.f(this.o,a,b,c);return a=pc(this.g,a,d)};
Ec.prototype.toString=function(){var a;a="Step:"+K("Operator: "+(this.w?"//":"/"));this.c.m&&(a+=K("Axis: "+this.c));a+=K(this.o);if(this.g.a.length){var b=xa(this.g.a,function(a,b){return a+K(b)},"Predicates:");a+=K(b)}return a};function Hc(a,b,c,d){this.m=a;this.f=b;this.a=c;this.b=d}Hc.prototype.toString=function(){return this.m};var Ic={};function Jc(a,b,c,d){if(Ic.hasOwnProperty(a))throw Error("Axis already created: "+a);b=new Hc(a,b,c,!!d);return Ic[a]=b}
Jc("ancestor",function(a,b){for(var c=new F,d=b;d=d.parentNode;)a.a(d)&&c.unshift(d);return c},!0);Jc("ancestor-or-self",function(a,b){var c=new F,d=b;do a.a(d)&&c.unshift(d);while(d=d.parentNode);return c},!0);
var xc=Jc("attribute",function(a,b){var c=new F,d=a.f();if("style"==d&&b.style&&Gb)return G(c,new Ib(b.style,b,"style",b.style.cssText)),c;var e=b.attributes;if(e)if(a instanceof Xb&&null===a.b||"*"==d)for(var d=0,f;f=e[d];d++)Gb?f.nodeValue&&G(c,Jb(b,f)):G(c,f);else(f=e.getNamedItem(d))&&(Gb?f.nodeValue&&G(c,Jb(b,f)):G(c,f));return c},!1),Fc=Jc("child",function(a,b,c,d,e){return(Gb?Yb:Zb).call(null,a,b,m(c)?c:null,m(d)?d:null,e||new F)},!1,!0);Jc("descendant",Rb,!1,!0);
var Gc=Jc("descendant-or-self",function(a,b,c,d){var e=new F;Qb(b,c,d)&&a.a(b)&&G(e,b);return Rb(a,b,c,d,e)},!1,!0),Bc=Jc("following",function(a,b,c,d){var e=new F;do for(var f=b;f=f.nextSibling;)Qb(f,c,d)&&a.a(f)&&G(e,f),e=Rb(a,f,c,d,e);while(b=b.parentNode);return e},!1,!0);Jc("following-sibling",function(a,b){for(var c=new F,d=b;d=d.nextSibling;)a.a(d)&&G(c,d);return c},!1);Jc("namespace",function(){return new F},!1);
var Kc=Jc("parent",function(a,b){var c=new F;if(9==b.nodeType)return c;if(2==b.nodeType)return G(c,b.ownerElement),c;var d=b.parentNode;a.a(d)&&G(c,d);return c},!1),Cc=Jc("preceding",function(a,b,c,d){var e=new F,f=[];do f.unshift(b);while(b=b.parentNode);for(var g=1,h=f.length;g<h;g++){var n=[];for(b=f[g];b=b.previousSibling;)n.unshift(b);for(var q=0,u=n.length;q<u;q++)b=n[q],Qb(b,c,d)&&a.a(b)&&G(e,b),e=Rb(a,b,c,d,e)}return e},!0,!0);
Jc("preceding-sibling",function(a,b){for(var c=new F,d=b;d=d.previousSibling;)a.a(d)&&c.unshift(d);return c},!0);var Lc=Jc("self",function(a,b){var c=new F;a.a(b)&&G(c,b);return c},!1);function Mc(a){J.call(this,1);this.c=a;this.j=a.j;this.b=a.b}p(Mc,J);Mc.prototype.a=function(a){return-L(this.c,a)};Mc.prototype.toString=function(){return"Unary Expression: -"+K(this.c)};function Nc(a){J.call(this,4);this.c=a;gc(this,ya(this.c,function(a){return a.j}));hc(this,ya(this.c,function(a){return a.b}))}p(Nc,J);Nc.prototype.a=function(a){var b=new F;r(this.c,function(c){c=c.a(a);if(!(c instanceof F))throw Error("Path expression must evaluate to NodeSet.");b=ac(b,c)});return b};Nc.prototype.toString=function(){return xa(this.c,function(a,b){return a+K(b)},"Union Expression:")};function Oc(a,b){this.a=a;this.b=b}function Pc(a){for(var b,c=[];;){Qc(a,"Missing right hand side of binary expression.");b=Rc(a);var d=E(a.a);if(!d)break;var e=(d=nc[d]||null)&&d.N;if(!e){a.a.a--;break}for(;c.length&&e<=c[c.length-1].N;)b=new jc(c.pop(),c.pop(),b);c.push(b,d)}for(;c.length;)b=new jc(c.pop(),c.pop(),b);return b}function Qc(a,b){if(Ob(a.a))throw Error(b);}function Sc(a,b){var c=E(a.a);if(c!=b)throw Error("Bad token, expected: "+b+" got: "+c);}
function Tc(a){a=E(a.a);if(")"!=a)throw Error("Bad token: "+a);}function Uc(a){a=E(a.a);if(2>a.length)throw Error("Unclosed literal string");return new uc(a)}
function Vc(a){var b,c=[],d;if(Ac(D(a.a))){b=E(a.a);d=D(a.a);if("/"==b&&(Ob(a.a)||"."!=d&&".."!=d&&"@"!=d&&"*"!=d&&!/(?![0-9])[\w]/.test(d)))return new yc;d=new yc;Qc(a,"Missing next location step.");b=Wc(a,b);c.push(b)}else{a:{b=D(a.a);d=b.charAt(0);switch(d){case "$":throw Error("Variable reference not allowed in HTML XPath");case "(":E(a.a);b=Pc(a);Qc(a,'unclosed "("');Sc(a,")");break;case '"':case "'":b=Uc(a);break;default:if(isNaN(+b))if(!tc(b)&&/(?![0-9])[\w]/.test(d)&&"("==D(a.a,1)){b=E(a.a);
b=sc[b]||null;E(a.a);for(d=[];")"!=D(a.a);){Qc(a,"Missing function argument list.");d.push(Pc(a));if(","!=D(a.a))break;E(a.a)}Qc(a,"Unclosed function argument list.");Tc(a);b=new qc(b,d)}else{b=null;break a}else b=new vc(+E(a.a))}"["==D(a.a)&&(d=new Dc(Xc(a)),b=new oc(b,d))}if(b)if(Ac(D(a.a)))d=b;else return b;else b=Wc(a,"/"),d=new zc,c.push(b)}for(;Ac(D(a.a));)b=E(a.a),Qc(a,"Missing next location step."),b=Wc(a,b),c.push(b);return new wc(d,c)}
function Wc(a,b){var c,d,e;if("/"!=b&&"//"!=b)throw Error('Step op should be "/" or "//"');if("."==D(a.a))return d=new Ec(Lc,new Xb("node")),E(a.a),d;if(".."==D(a.a))return d=new Ec(Kc,new Xb("node")),E(a.a),d;var f;if("@"==D(a.a))f=xc,E(a.a),Qc(a,"Missing attribute name");else if("::"==D(a.a,1)){if(!/(?![0-9])[\w]/.test(D(a.a).charAt(0)))throw Error("Bad token: "+E(a.a));c=E(a.a);f=Ic[c]||null;if(!f)throw Error("No axis with name: "+c);E(a.a);Qc(a,"Missing node name")}else f=Fc;c=D(a.a);if(/(?![0-9])[\w\*]/.test(c.charAt(0)))if("("==
D(a.a,1)){if(!tc(c))throw Error("Invalid node type: "+c);c=E(a.a);if(!tc(c))throw Error("Invalid type name: "+c);Sc(a,"(");Qc(a,"Bad nodetype");e=D(a.a).charAt(0);var g=null;if('"'==e||"'"==e)g=Uc(a);Qc(a,"Bad nodetype");Tc(a);c=new Xb(c,g)}else if(c=E(a.a),e=c.indexOf(":"),-1==e)c=new Ub(c);else{var g=c.substring(0,e),h;if("*"==g)h="*";else if(h=a.b(g),!h)throw Error("Namespace prefix not declared: "+g);c=c.substr(e+1);c=new Ub(c,h)}else throw Error("Bad token: "+E(a.a));e=new Dc(Xc(a),f.a);return d||
new Ec(f,c,e,"//"==b)}function Xc(a){for(var b=[];"["==D(a.a);){E(a.a);Qc(a,"Missing predicate expression.");var c=Pc(a);b.push(c);Qc(a,"Unclosed predicate expression.");Sc(a,"]")}return b}function Rc(a){if("-"==D(a.a))return E(a.a),new Mc(Rc(a));var b=Vc(a);if("|"!=D(a.a))a=b;else{for(b=[b];"|"==E(a.a);)Qc(a,"Missing next union location path."),b.push(Vc(a));a.a.a--;a=new Nc(b)}return a};function Yc(a){switch(a.nodeType){case 1:return ma(Zc,a);case 9:return Yc(a.documentElement);case 11:case 10:case 6:case 12:return $c;default:return a.parentNode?Yc(a.parentNode):$c}}function $c(){return null}function Zc(a,b){if(a.prefix==b)return a.namespaceURI||"http://www.w3.org/1999/xhtml";var c=a.getAttributeNode("xmlns:"+b);return c&&c.specified?c.value||null:a.parentNode&&9!=a.parentNode.nodeType?Zc(a.parentNode,b):null};function ad(a,b){if(!a.length)throw Error("Empty XPath expression.");var c=Lb(a);if(Ob(c))throw Error("Invalid XPath expression.");b?fa(b)||(b=la(b.lookupNamespaceURI,b)):b=function(){return null};var d=Pc(new Oc(c,b));if(!Ob(c))throw Error("Bad token: "+E(c));this.evaluate=function(a,b){var c=d.a(new Fb(a));return new bd(c,b)}}
function bd(a,b){if(0==b)if(a instanceof F)b=4;else if("string"==typeof a)b=2;else if("number"==typeof a)b=1;else if("boolean"==typeof a)b=3;else throw Error("Unexpected evaluation result.");if(2!=b&&1!=b&&3!=b&&!(a instanceof F))throw Error("value could not be converted to the specified type");this.resultType=b;var c;switch(b){case 2:this.stringValue=a instanceof F?cc(a):""+a;break;case 1:this.numberValue=a instanceof F?+cc(a):+a;break;case 3:this.booleanValue=a instanceof F?0<a.s:!!a;break;case 4:case 5:case 6:case 7:var d=
ec(a);c=[];for(var e=H(d);e;e=H(d))c.push(e instanceof Ib?e.a:e);this.snapshotLength=a.s;this.invalidIteratorState=!1;break;case 8:case 9:d=bc(a);this.singleNodeValue=d instanceof Ib?d.a:d;break;default:throw Error("Unknown XPathResult type.");}var f=0;this.iterateNext=function(){if(4!=b&&5!=b)throw Error("iterateNext called with wrong result type");return f>=c.length?null:c[f++]};this.snapshotItem=function(a){if(6!=b&&7!=b)throw Error("snapshotItem called with wrong result type");return a>=c.length||
0>a?null:c[a]}}bd.ANY_TYPE=0;bd.NUMBER_TYPE=1;bd.STRING_TYPE=2;bd.BOOLEAN_TYPE=3;bd.UNORDERED_NODE_ITERATOR_TYPE=4;bd.ORDERED_NODE_ITERATOR_TYPE=5;bd.UNORDERED_NODE_SNAPSHOT_TYPE=6;bd.ORDERED_NODE_SNAPSHOT_TYPE=7;bd.ANY_UNORDERED_NODE_TYPE=8;bd.FIRST_ORDERED_NODE_TYPE=9;function cd(a){this.lookupNamespaceURI=Yc(a)}
function dd(a,b){var c=a||aa,d=c.document;if(!d.evaluate||b)c.XPathResult=bd,d.evaluate=function(a,b,c,d){return(new ad(a,c)).evaluate(b,d)},d.createExpression=function(a,b){return new ad(a,b)},d.createNSResolver=function(a){return new cd(a)}}ba("wgxpath.install",dd);var ed={};ed.I=function(){var a={X:"http://www.w3.org/2000/svg"};return function(b){return a[b]||null}}();
ed.v=function(a,b,c){var d=C(a);if(!d.documentElement)return null;(x||Cb)&&dd(nb(d));try{var e=d.createNSResolver?d.createNSResolver(d.documentElement):ed.I;if(x&&!eb(7))return d.evaluate.call(d,b,a,e,c,null);if(!x||fb(9)){for(var f={},g=d.getElementsByTagName("*"),h=0;h<g.length;++h){var n=g[h],q=n.namespaceURI;if(q&&!f[q]){var u=n.lookupPrefix(q);if(!u)var A=q.match(".*/(\\w+)/?$"),u=A?A[1]:"xhtml";f[q]=u}}var y={},I;for(I in f)y[f[I]]=I;e=function(a){return y[a]||null}}try{return d.evaluate(b,
a,e,c,null)}catch(S){if("TypeError"===S.name)return e=d.createNSResolver?d.createNSResolver(d.documentElement):ed.I,d.evaluate(b,a,e,c,null);throw S;}}catch(S){if(!z||"NS_ERROR_ILLEGAL_VALUE"!=S.name)throw new t(32,"Unable to locate an element with the xpath expression "+b+" because of the following error:\n"+S);}};ed.J=function(a,b){if(!a||1!=a.nodeType)throw new t(32,'The result of the xpath expression "'+b+'" is: '+a+". It should be an element.");};
ed.A=function(a,b){var c=function(){var c=ed.v(b,a,9);return c?c.singleNodeValue||null:b.selectSingleNode?(c=C(b),c.setProperty&&c.setProperty("SelectionLanguage","XPath"),b.selectSingleNode(a)):null}();null===c||ed.J(c,a);return c};
ed.u=function(a,b){var c=function(){var c=ed.v(b,a,7);if(c){for(var e=c.snapshotLength,f=[],g=0;g<e;++g)f.push(c.snapshotItem(g));return f}return b.selectNodes?(c=C(b),c.setProperty&&c.setProperty("SelectionLanguage","XPath"),b.selectNodes(a)):[]}();r(c,function(b){ed.J(b,a)});return c};function fd(a){return(a=a.exec(La))?a[1]:""}var gd=function(){if(zb)return fd(/Firefox\/([0-9.]+)/);if(x||Xa||Wa)return cb;if(Db)return fd(/Chrome\/([0-9.]+)/);if(Eb&&!(Va()||w("iPad")||w("iPod")))return fd(/Version\/([0-9.]+)/);if(Ab||Bb){var a;if(a=/Version\/(\S+).*Mobile\/(\S+)/.exec(La))return a[1]+"."+a[2]}else if(Cb)return(a=fd(/Android\s+([0-9.]+)/))?a:fd(/Version\/([0-9.]+)/);return""}();var hd,id;function jd(a){return kd?hd(a):x?0<=sa(gb,a):eb(a)}function ld(a){return kd?id(a):Cb?0<=sa(md,a):0<=sa(gd,a)}
var kd=function(){if(!z)return!1;var a=aa.Components;if(!a)return!1;try{if(!a.classes)return!1}catch(f){return!1}var b=a.classes,a=a.interfaces,c=b["@mozilla.org/xpcom/version-comparator;1"].getService(a.nsIVersionComparator),b=b["@mozilla.org/xre/app-info;1"].getService(a.nsIXULAppInfo),d=b.platformVersion,e=b.version;hd=function(a){return 0<=c.compare(d,""+a)};id=function(a){return 0<=c.compare(e,""+a)};return!0}(),nd=Bb||Ab,od;
if(Cb){var pd=/Android\s+([0-9\.]+)/.exec(La);od=pd?pd[1]:"0"}else od="0";var md=od,qd=x&&!fb(8),rd=fb(9),sd=x&&!fb(9),td=fb(10);Cb&&ld(2.3);Cb&&ld(4);Eb&&ld(6);var ud=x&&-1!=La.indexOf("IEMobile");function vd(a,b,c,d){this.top=a;this.right=b;this.bottom=c;this.left=d}k=vd.prototype;k.clone=function(){return new vd(this.top,this.right,this.bottom,this.left)};k.toString=function(){return"("+this.top+"t, "+this.right+"r, "+this.bottom+"b, "+this.left+"l)"};k.contains=function(a){return this&&a?a instanceof vd?a.left>=this.left&&a.right<=this.right&&a.top>=this.top&&a.bottom<=this.bottom:a.x>=this.left&&a.x<=this.right&&a.y>=this.top&&a.y<=this.bottom:!1};
k.ceil=function(){this.top=Math.ceil(this.top);this.right=Math.ceil(this.right);this.bottom=Math.ceil(this.bottom);this.left=Math.ceil(this.left);return this};k.floor=function(){this.top=Math.floor(this.top);this.right=Math.floor(this.right);this.bottom=Math.floor(this.bottom);this.left=Math.floor(this.left);return this};k.round=function(){this.top=Math.round(this.top);this.right=Math.round(this.right);this.bottom=Math.round(this.bottom);this.left=Math.round(this.left);return this};
k.scale=function(a,b){var c=ea(b)?b:a;this.left*=a;this.right*=a;this.top*=c;this.bottom*=c;return this};function P(a,b,c,d){this.left=a;this.top=b;this.width=c;this.height=d}k=P.prototype;k.clone=function(){return new P(this.left,this.top,this.width,this.height)};k.toString=function(){return"("+this.left+", "+this.top+" - "+this.width+"w x "+this.height+"h)"};k.contains=function(a){return a instanceof P?this.left<=a.left&&this.left+this.width>=a.left+a.width&&this.top<=a.top&&this.top+this.height>=a.top+a.height:a.x>=this.left&&a.x<=this.left+this.width&&a.y>=this.top&&a.y<=this.top+this.height};
k.ceil=function(){this.left=Math.ceil(this.left);this.top=Math.ceil(this.top);this.width=Math.ceil(this.width);this.height=Math.ceil(this.height);return this};k.floor=function(){this.left=Math.floor(this.left);this.top=Math.floor(this.top);this.width=Math.floor(this.width);this.height=Math.floor(this.height);return this};k.round=function(){this.left=Math.round(this.left);this.top=Math.round(this.top);this.width=Math.round(this.width);this.height=Math.round(this.height);return this};
k.scale=function(a,b){var c=ea(b)?b:a;this.left*=a;this.width*=a;this.top*=c;this.height*=c;return this};function wd(a,b){var c=C(a);return c.defaultView&&c.defaultView.getComputedStyle&&(c=c.defaultView.getComputedStyle(a,null))?c[b]||c.getPropertyValue(b)||"":""}function xd(a){a=a?C(a):document;var b;(b=!x||fb(9))||(b="CSS1Compat"==kb(a).a.compatMode);return b?a.documentElement:a.body}
function yd(a){var b=a.offsetWidth,c=a.offsetHeight,d=B&&!b&&!c;if((!l(b)||d)&&a.getBoundingClientRect){var e;a:{try{e=a.getBoundingClientRect()}catch(f){e={left:0,top:0,right:0,bottom:0};break a}x&&a.ownerDocument.body&&(a=a.ownerDocument,e.left-=a.documentElement.clientLeft+a.body.clientLeft,e.top-=a.documentElement.clientTop+a.body.clientTop)}return new jb(e.right-e.left,e.bottom-e.top)}return new jb(b,c)}var zd={thin:2,medium:4,thick:6};
function Ad(a,b){if("none"==(a.currentStyle?a.currentStyle[b+"Style"]:null))return 0;var c=a.currentStyle?a.currentStyle[b+"Width"]:null,d;if(c in zd)d=zd[c];else if(/^\d+px?$/.test(c))d=parseInt(c,10);else{d=a.style.left;var e=a.runtimeStyle.left;a.runtimeStyle.left=a.currentStyle.left;a.style.left=c;c=a.style.pixelLeft;a.style.left=d;a.runtimeStyle.left=e;d=c}return d};function Bd(a){var b;a:{a=C(a);try{b=a&&a.activeElement;break a}catch(c){}b=null}return x&&b&&"undefined"===typeof b.nodeType?null:b}function Q(a,b){return!!a&&1==a.nodeType&&(!b||a.tagName.toUpperCase()==b)}function Cd(a){var b;if(b=Dd(a,!0)&&Ed(a))b=!(x||z&&!jd("1.9.2")?0:"none"==R(a,"pointer-events"));return b}function Fd(a){return Q(a,"OPTION")?!0:Q(a,"INPUT")?(a=a.type.toLowerCase(),"checkbox"==a||"radio"==a):!1}
function Gd(a){if(!Fd(a))throw new t(15,"Element is not selectable");var b="selected",c=a.type&&a.type.toLowerCase();if("checkbox"==c||"radio"==c)b="checked";return!!Hd(a,b)}function Hd(a,b){var c;if(c=qd&&"value"==b&&Q(a,"OPTION"))c=null===Id(a,"value");c?(c=[],vb(a,c,!1),c=c.join("")):c=a[b];return c}var Jd=/[;]+(?=(?:(?:[^"]*"){2})*[^"]*$)(?=(?:(?:[^']*'){2})*[^']*$)(?=(?:[^()]*\([^()]*\))*[^()]*$)/;
function Kd(a){var b=[];r(a.split(Jd),function(a){var d=a.indexOf(":");0<d&&(a=[a.slice(0,d),a.slice(d+1)],2==a.length&&b.push(a[0].toLowerCase(),":",a[1],";"))});b=b.join("");return b=";"==b.charAt(b.length-1)?b:b+";"}function Id(a,b){b=b.toLowerCase();if("style"==b)return Kd(a.style.cssText);if(qd&&"value"==b&&Q(a,"INPUT"))return a.value;if(sd&&!0===a[b])return String(a.getAttribute(b));var c=a.getAttributeNode(b);return c&&c.specified?c.value:null}var Ld="BUTTON INPUT OPTGROUP OPTION SELECT TEXTAREA".split(" ");
function Ed(a){var b=a.tagName.toUpperCase();return Ba(Ld,b)?Hd(a,"disabled")?!1:a.parentNode&&1==a.parentNode.nodeType&&"OPTGROUP"==b||"OPTION"==b?Ed(a.parentNode):!wb(a,function(a){var b=a.parentNode;if(b&&Q(b,"FIELDSET")&&Hd(b,"disabled")){if(!Q(a,"LEGEND"))return!0;for(;a=l(a.previousElementSibling)?a.previousElementSibling:ob(a.previousSibling);)if(Q(a,"LEGEND"))return!0}return!1},!0):!0}var Md="text search tel url email password number".split(" ");
function Nd(a){function b(a){return"inherit"==a.contentEditable?(a=Od(a))?b(a):!1:"true"==a.contentEditable}return l(a.contentEditable)?!x&&l(a.isContentEditable)?a.isContentEditable:b(a):!1}function Pd(a){return((Q(a,"TEXTAREA")?!0:Q(a,"INPUT")?Ba(Md,a.type.toLowerCase()):Nd(a)?!0:!1)||(Q(a,"INPUT")?"file"==a.type.toLowerCase():!1))&&!Hd(a,"readOnly")}function Od(a){for(a=a.parentNode;a&&1!=a.nodeType&&9!=a.nodeType&&11!=a.nodeType;)a=a.parentNode;return Q(a)?a:null}
function R(a,b){var c=ua(b);if("float"==c||"cssFloat"==c||"styleFloat"==c)c=sd?"styleFloat":"cssFloat";var d=wd(a,c)||Qd(a,c);if(null===d)d=null;else if(Ba(Fa,c)){b:{var e=d.match(Ia);if(e){var c=Number(e[1]),f=Number(e[2]),g=Number(e[3]),e=Number(e[4]);if(0<=c&&255>=c&&0<=f&&255>=f&&0<=g&&255>=g&&0<=e&&1>=e){c=[c,f,g,e];break b}}c=null}if(!c)b:{if(g=d.match(Ja))if(c=Number(g[1]),f=Number(g[2]),g=Number(g[3]),0<=c&&255>=c&&0<=f&&255>=f&&0<=g&&255>=g){c=[c,f,g,1];break b}c=null}if(!c)b:{c=d.toLowerCase();
f=Ea[c.toLowerCase()];if(!f&&(f="#"==c.charAt(0)?c:"#"+c,4==f.length&&(f=f.replace(Ga,"#$1$1$2$2$3$3")),!Ha.test(f))){c=null;break b}c=[parseInt(f.substr(1,2),16),parseInt(f.substr(3,2),16),parseInt(f.substr(5,2),16),1]}d=c?"rgba("+c.join(", ")+")":d}return d}function Qd(a,b){var c=a.currentStyle||a.style,d=c[b];!l(d)&&fa(c.getPropertyValue)&&(d=c.getPropertyValue(b));return"inherit"!=d?l(d)?d:null:(c=Od(a))?Qd(c,b):null}
function Rd(a,b,c){function d(a){var b=Sd(a);return 0<b.height&&0<b.width?!0:Q(a,"PATH")&&(0<b.height||0<b.width)?(a=R(a,"stroke-width"),!!a&&0<parseInt(a,10)):"hidden"!=R(a,"overflow")&&ya(a.childNodes,function(a){return 3==a.nodeType||Q(a)&&d(a)})}function e(a){return Td(a)==Ud&&za(a.childNodes,function(a){return!Q(a)||e(a)||!d(a)})}if(!Q(a))throw Error("Argument to isShown must be of type Element");if(Q(a,"BODY"))return!0;if(Q(a,"OPTION")||Q(a,"OPTGROUP"))return a=wb(a,function(a){return Q(a,"SELECT")}),
!!a&&Rd(a,!0,c);var f=Vd(a);if(f)return!!f.K&&0<f.rect.width&&0<f.rect.height&&Rd(f.K,b,c);if(Q(a,"INPUT")&&"hidden"==a.type.toLowerCase()||Q(a,"NOSCRIPT"))return!1;f=R(a,"visibility");return"collapse"!=f&&"hidden"!=f&&c(a)&&(b||0!=Wd(a))&&d(a)?!e(a):!1}function Dd(a,b){function c(a){if("none"==R(a,"display"))return!1;a=Od(a);return!a||c(a)}return Rd(a,!!b,c)}var Ud="hidden";
function Td(a,b){function c(a){function b(a){return a==h?!0:0==R(a,"display").lastIndexOf("inline",0)||"absolute"==c&&"static"==R(a,"position")?!1:!0}var c=R(a,"position");if("fixed"==c)return u=!0,a==h?null:h;for(a=Od(a);a&&!b(a);)a=Od(a);return a}function d(a){var b=a;if("visible"==q)if(a==h&&n)b=n;else if(a==n)return{x:"visible",y:"visible"};b={x:R(b,"overflow-x"),y:R(b,"overflow-y")};a==h&&(b.x="visible"==b.x?"auto":b.x,b.y="visible"==b.y?"auto":b.y);return b}function e(a){if(a==h){var b=(new lb(g)).a;
a=mb(b);b=b.parentWindow||b.defaultView;a=x&&eb("10")&&b.pageYOffset!=a.scrollTop?new ib(a.scrollLeft,a.scrollTop):new ib(b.pageXOffset||a.scrollLeft,b.pageYOffset||a.scrollTop)}else a=new ib(a.scrollLeft,a.scrollTop);return a}for(var f=Xd(a,b),g=C(a),h=g.documentElement,n=g.body,q=R(h,"overflow"),u,A=c(a);A;A=c(A)){var y=d(A);if("visible"!=y.x||"visible"!=y.y){var I=Sd(A);if(0==I.width||0==I.height)return Ud;var S=f.right<I.left,dc=f.bottom<I.top;if(S&&"hidden"==y.x||dc&&"hidden"==y.y)return Ud;
if(S&&"visible"!=y.x||dc&&"visible"!=y.y){S=e(A);dc=f.bottom<I.top-S.y;if(f.right<I.left-S.x&&"visible"!=y.x||dc&&"visible"!=y.x)return Ud;f=Td(A);return f==Ud?Ud:"scroll"}S=f.left>=I.left+I.width;I=f.top>=I.top+I.height;if(S&&"hidden"==y.x||I&&"hidden"==y.y)return Ud;if(S&&"visible"!=y.x||I&&"visible"!=y.y){if(u&&(y=e(A),f.left>=h.scrollWidth-y.x||f.right>=h.scrollHeight-y.y))return Ud;f=Td(A);return f==Ud?Ud:"scroll"}}}return"none"}
function Sd(a){var b=Vd(a);if(b)return b.rect;if(Q(a,"HTML"))return a=C(a),a=(nb(a)||window).document,a="CSS1Compat"==a.compatMode?a.documentElement:a.body,a=new jb(a.clientWidth,a.clientHeight),new P(0,0,a.width,a.height);var c;try{c=a.getBoundingClientRect()}catch(d){return new P(0,0,0,0)}b=new P(c.left,c.top,c.right-c.left,c.bottom-c.top);x&&a.ownerDocument.body&&(a=C(a),b.left-=a.documentElement.clientLeft+a.body.clientLeft,b.top-=a.documentElement.clientTop+a.body.clientTop);return b}
function Vd(a){var b=Q(a,"MAP");if(!b&&!Q(a,"AREA"))return null;var c=b?a:Q(a.parentNode,"MAP")?a.parentNode:null,d=null,e=null;c&&c.name&&(d=ed.A('/descendant::*[@usemap = "#'+c.name+'"]',C(c)))&&(e=Sd(d),b||"default"==a.shape.toLowerCase()||(a=Yd(a),b=Math.min(Math.max(a.left,0),e.width),c=Math.min(Math.max(a.top,0),e.height),e=new P(b+e.left,c+e.top,Math.min(a.width,e.width-b),Math.min(a.height,e.height-c))));return{K:d,rect:e||new P(0,0,0,0)}}
function Yd(a){var b=a.shape.toLowerCase();a=a.coords.split(",");if("rect"==b&&4==a.length){var b=a[0],c=a[1];return new P(b,c,a[2]-b,a[3]-c)}if("circle"==b&&3==a.length)return b=a[2],new P(a[0]-b,a[1]-b,2*b,2*b);if("poly"==b&&2<a.length){for(var b=a[0],c=a[1],d=b,e=c,f=2;f+1<a.length;f+=2)b=Math.min(b,a[f]),d=Math.max(d,a[f]),c=Math.min(c,a[f+1]),e=Math.max(e,a[f+1]);return new P(b,c,d-b,e-c)}return new P(0,0,0,0)}
function Xd(a,b){var c;c=Sd(a);c=new vd(c.top,c.left+c.width,c.top+c.height,c.left);if(b){var d=b instanceof P?b:new P(b.x,b.y,1,1);c.left=Math.min(Math.max(c.left+d.left,c.left),c.right);c.top=Math.min(Math.max(c.top+d.top,c.top),c.bottom);c.right=Math.min(Math.max(c.left+d.width,c.left),c.right);c.bottom=Math.min(Math.max(c.top+d.height,c.top),c.bottom)}return c}function Zd(a){return a.replace(/^[^\S\xa0]+|[^\S\xa0]+$/g,"")}
function $d(a){var b=[];ae(a,b);a=wa(b,Zd);return Zd(a.join("\n")).replace(/\xa0/g," ")}
function be(a,b,c){var d=Dd;if(Q(a,"BR"))b.push("");else{var e=Q(a,"TD"),f=R(a,"display"),g=!e&&!Ba(ce,f),h=l(a.previousElementSibling)?a.previousElementSibling:ob(a.previousSibling),h=h?R(h,"display"):"",n=R(a,"float")||R(a,"cssFloat")||R(a,"styleFloat");!g||"run-in"==h&&"none"==n||/^[\s\xa0]*$/.test(b[b.length-1]||"")||b.push("");var q=d(a),u=null,A=null;q&&(u=R(a,"white-space"),A=R(a,"text-transform"));r(a.childNodes,function(a){c(a,b,q,u,A)});a=b[b.length-1]||"";!e&&"table-cell"!=f||!a||qa(a)||
(b[b.length-1]+=" ");g&&"run-in"!=f&&!/^[\s\xa0]*$/.test(a)&&b.push("")}}function ae(a,b){be(a,b,function(a,b,e,f,g){3==a.nodeType&&e?de(a,b,f,g):Q(a)&&ae(a,b)})}var ce="inline inline-block inline-table none table-cell table-column table-column-group".split(" ");
function de(a,b,c,d){a=a.nodeValue.replace(/[\u200b\u200e\u200f]/g,"");a=a.replace(/(\r\n|\r|\n)/g,"\n");if("normal"==c||"nowrap"==c)a=a.replace(/\n/g," ");a="pre"==c||"pre-wrap"==c?a.replace(/[ \f\t\v\u2028\u2029]/g,"\u00a0"):a.replace(/[\ \f\t\v\u2028\u2029]+/g," ");"capitalize"==d?a=a.replace(/(^|\s)(\S)/g,function(a,b,c){return b+c.toUpperCase()}):"uppercase"==d?a=a.toUpperCase():"lowercase"==d&&(a=a.toLowerCase());c=b.pop()||"";qa(c)&&0==a.lastIndexOf(" ",0)&&(a=a.substr(1));b.push(c+a)}
function Wd(a){if(sd){if("relative"==R(a,"position"))return 1;a=R(a,"filter");return(a=a.match(/^alpha\(opacity=(\d*)\)/)||a.match(/^progid:DXImageTransform.Microsoft.Alpha\(Opacity=(\d*)\)/))?Number(a[1])/100:1}return ee(a)}function ee(a){var b=1,c=R(a,"opacity");c&&(b=Number(c));(a=Od(a))&&(b*=ee(a));return b};var fe={D:function(a){return!(!a.querySelectorAll||!a.querySelector)},A:function(a,b){if(!a)throw new t(32,"No class name specified");a=ra(a);if(-1!==a.indexOf(" "))throw new t(32,"Compound class names not permitted");if(fe.D(b))try{return b.querySelector("."+a.replace(/\./g,"\\."))||null}catch(d){throw new t(32,"An invalid or illegal class name was specified");}var c=xb(kb(b),"*",a,b);return c.length?c[0]:null},u:function(a,b){if(!a)throw new t(32,"No class name specified");a=ra(a);if(-1!==a.indexOf(" "))throw new t(32,
"Compound class names not permitted");if(fe.D(b))try{return b.querySelectorAll("."+a.replace(/\./g,"\\."))}catch(c){throw new t(32,"An invalid or illegal class name was specified");}return xb(kb(b),"*",a,b)}};var ge={A:function(a,b){if(!fa(b.querySelector)&&x&&jd(8)&&!ga(b.querySelector))throw Error("CSS selection is not supported");if(!a)throw new t(32,"No selector specified");a=ra(a);var c;try{c=b.querySelector(a)}catch(d){throw new t(32,"An invalid or illegal selector was specified");}return c&&1==c.nodeType?c:null},u:function(a,b){if(!fa(b.querySelectorAll)&&x&&jd(8)&&!ga(b.querySelector))throw Error("CSS selection is not supported");if(!a)throw new t(32,"No selector specified");a=ra(a);try{return b.querySelectorAll(a)}catch(c){throw new t(32,
"An invalid or illegal selector was specified");}}};var he={D:function(a,b){return!(!a.querySelectorAll||!a.querySelector)&&!/^\d.*/.test(b)},A:function(a,b){var c=kb(b),d=m(a)?c.a.getElementById(a):a;if(!d)return null;if(Id(d,"id")==a&&pb(b,d))return d;c=xb(c,"*");return Aa(c,function(c){return Id(c,"id")==a&&pb(b,c)})},u:function(a,b){if(!a)return[];if(he.D(b,a))try{return b.querySelectorAll("#"+he.S(a))}catch(d){return[]}var c=xb(kb(b),"*",null,b);return va(c,function(b){return Id(b,"id")==a})},S:function(a){return a.replace(/(['"\\#.:;,!?+<>=~*^$|%&@`{}\-\/\[\]\(\)])/g,
"\\$1")}};var ie={},je={};ie.O=function(a,b,c){var d;try{d=ge.u("a",b)}catch(e){d=xb(kb(b),"A",null,b)}return Aa(d,function(b){b=$d(b);return c&&-1!=b.indexOf(a)||b==a})};ie.L=function(a,b,c){var d;try{d=ge.u("a",b)}catch(e){d=xb(kb(b),"A",null,b)}return va(d,function(b){b=$d(b);return c&&-1!=b.indexOf(a)||b==a})};ie.A=function(a,b){return ie.O(a,b,!1)};ie.u=function(a,b){return ie.L(a,b,!1)};je.A=function(a,b){return ie.O(a,b,!0)};je.u=function(a,b){return ie.L(a,b,!0)};var ke={A:function(a,b){if(""===a)throw new t(32,'Unable to locate an element with the tagName ""');return b.getElementsByTagName(a)[0]||null},u:function(a,b){if(""===a)throw new t(32,'Unable to locate an element with the tagName ""');return b.getElementsByTagName(a)}};var le={className:fe,"class name":fe,css:ge,"css selector":ge,id:he,linkText:ie,"link text":ie,name:{A:function(a,b){var c=xb(kb(b),"*",null,b);return Aa(c,function(b){return Id(b,"name")==a})},u:function(a,b){var c=xb(kb(b),"*",null,b);return va(c,function(b){return Id(b,"name")==a})}},partialLinkText:je,"partial link text":je,tagName:ke,"tag name":ke,xpath:ed};
function me(a,b){var c;a:{for(c in a)if(a.hasOwnProperty(c))break a;c=null}if(c){var d=le[c];if(d&&fa(d.u))return d.u(a[c],b||oa.document)}throw Error("Unsupported locator strategy: "+c);};function ne(a){this.a=oa.document.documentElement;this.b=null;var b=Bd(this.a);b&&oe(this,b);this.o=a||new pe}function oe(a,b){a.a=b;Q(b,"OPTION")?a.b=wb(b,function(a){return Q(a,"SELECT")}):a.b=null}
function qe(a,b,c,d,e,f,g,h,n){if(!g&&!Cd(a.a))return!1;if(e&&re!=b&&se!=b)throw new t(12,"Event type does not allow related target: "+b);c={clientX:c.x,clientY:c.y,button:d,altKey:0!=(a.o.a&4),ctrlKey:0!=(a.o.a&2),shiftKey:0!=(a.o.a&1),metaKey:0!=(a.o.a&8),wheelDelta:f||0,relatedTarget:e||null,count:n||1};h=h||1;d=a.a;b!=te&&b!=ue&&h in ve?d=ve[h]:a.b&&(d=we(a,b));return d?T(d,b,c):!0}
function xe(a,b,c,d,e,f,g){var h=MSPointerEvent.MSPOINTER_TYPE_MOUSE;if(!g&&!Cd(a.a))return!1;if(f&&ye!=b&&ze!=b)throw new t(12,"Event type does not allow related target: "+b);c={clientX:c.x,clientY:c.y,button:d,altKey:!1,ctrlKey:!1,shiftKey:!1,metaKey:!1,relatedTarget:f||null,width:0,height:0,pressure:0,rotation:0,pointerId:1,tiltX:0,tiltY:0,pointerType:h,isPrimary:e};d=a.b?we(a,b):a.a;ve[1]&&(d=ve[1]);a=nb(C(a.a));var n;a&&b==Ae&&(n=a.Element.prototype.msSetPointerCapture,a.Element.prototype.msSetPointerCapture=
function(a){ve[a]=this});b=d?T(d,b,c):!0;n&&(a.Element.prototype.msSetPointerCapture=n);return b}function we(a,b){if(x)switch(b){case re:case ye:return null;case Be:case Ce:case De:return a.b.multiple?a.b:null;default:return a.b}if(B)switch(b){case te:case Ee:return a.b.multiple?a.a:a.b;default:return a.b.multiple?a.a:null}return a.a}
function Fe(a){a=a.b||a.a;var b=Bd(a);if(a==b)return!1;if(b&&(fa(b.blur)||x&&ga(b.blur))){if(!Q(b,"BODY"))try{b.blur()}catch(c){if(!x||"Unspecified error."!=c.message)throw c;}x&&!jd(8)&&nb(C(a)).focus()}return fa(a.focus)||x&&ga(a.focus)?(a.focus(),!0):!1}var Ge=B||kd&&ld(3.6);function He(a){if(Q(a,"INPUT")){var b=a.type.toLowerCase();if("submit"==b||"image"==b)return!0}return Q(a,"BUTTON")&&(b=a.type.toLowerCase(),"submit"==b)?!0:!1}
function Ie(a){if(Ge||!a.href)return!1;if(!kd)return!0;if(a.target||0==a.href.toLowerCase().indexOf("javascript"))return!1;var b=nb(C(a)),c=b.location.href;a=Je(b.location,a.href);return c.split("#")[0]!==a.split("#")[0]}function Ke(a){return Q(a,"FORM")}
function Le(a){if(!Ke(a))throw new t(12,"Element is not a form, so could not submit.");if(T(a,Me))if(Q(a.submit))if(!x||jd(8))a.constructor.prototype.submit.call(a);else{var b=me({id:"submit"},a),c=me({name:"submit"},a);r(b,function(a){a.removeAttribute("id")});r(c,function(a){a.removeAttribute("name")});a=a.submit;r(b,function(a){a.setAttribute("id","submit")});r(c,function(a){a.setAttribute("name","submit")});a()}else a.submit()}var Ne=/^([^:/?#.]+:)?(?:\/\/([^/]*))?([^?#]+)?(\?[^#]*)?(#.*)?$/;
function Je(a,b){var c=b.match(Ne);if(!c)return"";var d=c[1]||"",e=c[2]||"",f=c[3]||"",g=c[4]||"",c=c[5]||"";if(!d&&(d=a.protocol,!e))if(e=a.host,!f)f=a.pathname,g=g||a.search;else if("/"!=f.charAt(0)){var h=a.pathname.lastIndexOf("/");-1!=h&&(f=a.pathname.substr(0,h+1)+f)}return d+"//"+e+f+g+c}function pe(){this.a=0}var ve={};var Oe=!(x&&!jd(10)),Pe=Cb?!ld(4):!nd,Qe=x&&oa.navigator.msPointerEnabled;function U(a,b,c){this.a=a;this.b=b;this.f=c}U.prototype.c=function(a){a=C(a);sd&&a.createEventObject?a=a.createEventObject():(a=a.createEvent("HTMLEvents"),a.initEvent(this.a,this.b,this.f));return a};U.prototype.toString=function(){return this.a};function Re(a,b,c){U.call(this,a,b,c)}p(Re,U);
Re.prototype.c=function(a,b){if(!z&&this==Se)throw new t(9,"Browser does not support a mouse pixel scroll event.");var c=C(a),d;if(sd){d=c.createEventObject();d.altKey=b.altKey;d.ctrlKey=b.ctrlKey;d.metaKey=b.metaKey;d.shiftKey=b.shiftKey;d.button=b.button;d.clientX=b.clientX;d.clientY=b.clientY;c=function(a,b){Object.defineProperty(d,a,{get:function(){return b}})};if(this==se||this==re)if(Object.defineProperty){var e=this==se;c("fromElement",e?a:b.relatedTarget);c("toElement",e?b.relatedTarget:a)}else d.relatedTarget=
b.relatedTarget;this==Te&&(Object.defineProperty?c("wheelDelta",b.wheelDelta):d.detail=b.wheelDelta)}else{e=nb(c);d=c.createEvent("MouseEvents");var f=1;this==Te&&(z||(d.wheelDelta=b.wheelDelta),z&&(f=b.wheelDelta/-40));z&&this==Se&&(f=b.wheelDelta);d.initMouseEvent(this.a,this.b,this.f,e,f,b.clientX,b.clientY,b.clientX,b.clientY,b.ctrlKey,b.altKey,b.shiftKey,b.metaKey,b.button,b.relatedTarget);if(x&&0===d.pageX&&0===d.pageY&&Object.defineProperty){var e=yb(kb(a)),c=xd(c),g=b.clientX+e.scrollLeft-
c.clientLeft,h=b.clientY+e.scrollTop-c.clientTop;Object.defineProperty(d,"pageX",{get:function(){return g}});Object.defineProperty(d,"pageY",{get:function(){return h}})}}return d};function Ue(a,b,c){U.call(this,a,b,c)}p(Ue,U);
Ue.prototype.c=function(a,b){var c=C(a);if(z){var d=nb(c),e=b.charCode?0:b.keyCode,c=c.createEvent("KeyboardEvent");c.initKeyEvent(this.a,this.b,this.f,d,b.ctrlKey,b.altKey,b.shiftKey,b.metaKey,e,b.charCode);this.a==Ve&&b.preventDefault&&c.preventDefault()}else if(sd?c=c.createEventObject():(c=c.createEvent("Events"),c.initEvent(this.a,this.b,this.f)),c.altKey=b.altKey,c.ctrlKey=b.ctrlKey,c.metaKey=b.metaKey,c.shiftKey=b.shiftKey,c.keyCode=b.charCode||b.keyCode,B||Xa)c.charCode=this==Ve?c.keyCode:
0;return c};function We(a,b,c){U.call(this,a,b,c)}p(We,U);
We.prototype.c=function(a,b){function c(b){b=wa(b,function(b){return f.createTouch(g,a,b.identifier,b.pageX,b.pageY,b.screenX,b.screenY)});return f.createTouchList.apply(f,b)}function d(b){var c=wa(b,function(b){return{identifier:b.identifier,screenX:b.screenX,screenY:b.screenY,clientX:b.clientX,clientY:b.clientY,pageX:b.pageX,pageY:b.pageY,target:a}});c.item=function(a){return c[a]};return c}function e(a){return Pe?d(a):c(a)}if(!Oe)throw new t(9,"Browser does not support firing touch events.");var f=
C(a),g=nb(f),h=e(b.changedTouches),n=b.touches==b.changedTouches?h:e(b.touches),q=b.targetTouches==b.changedTouches?h:e(b.targetTouches),u;Pe?(u=f.createEvent("MouseEvents"),u.initMouseEvent(this.a,this.b,this.f,g,1,0,0,b.clientX,b.clientY,b.ctrlKey,b.altKey,b.shiftKey,b.metaKey,0,b.relatedTarget),u.touches=n,u.targetTouches=q,u.changedTouches=h,u.scale=b.scale,u.rotation=b.rotation):(u=f.createEvent("TouchEvent"),0==u.initTouchEvent.length?u.initTouchEvent(n,q,h,this.a,g,0,0,b.clientX,b.clientY,
b.ctrlKey,b.altKey,b.shiftKey,b.metaKey):u.initTouchEvent(this.a,this.b,this.f,g,1,0,0,b.clientX,b.clientY,b.ctrlKey,b.altKey,b.shiftKey,b.metaKey,n,q,h,b.scale,b.rotation),u.relatedTarget=b.relatedTarget);return u};function Xe(a,b,c){U.call(this,a,b,c)}p(Xe,U);
Xe.prototype.c=function(a,b){if(!Qe)throw new t(9,"Browser does not support MSPointer events.");var c=C(a),d=nb(c),c=c.createEvent("MSPointerEvent");c.initPointerEvent(this.a,this.b,this.f,d,0,0,0,b.clientX,b.clientY,b.ctrlKey,b.altKey,b.shiftKey,b.metaKey,b.button,b.relatedTarget,0,0,b.width,b.height,b.pressure,b.rotation,b.tiltX,b.tiltY,b.pointerId,b.pointerType,0,b.isPrimary);return c};
var Ye=new U("blur",!1,!1),Ze=new U("change",!0,!1),$e=new U("focus",!1,!1),af=new U("input",!0,!1),Me=new U("submit",!0,!0),bf=new U("textInput",!0,!0),te=new Re("click",!0,!0),Be=new Re("contextmenu",!0,!0),cf=new Re("dblclick",!0,!0),ue=new Re("mousedown",!0,!0),Ce=new Re("mousemove",!0,!1),se=new Re("mouseout",!0,!0),re=new Re("mouseover",!0,!0),Ee=new Re("mouseup",!0,!0),Te=new Re(z?"DOMMouseScroll":"mousewheel",!0,!0),Se=new Re("MozMousePixelScroll",!0,!0),df=new Ue("keydown",!0,!0),Ve=new Ue("keypress",
!0,!0),ef=new Ue("keyup",!0,!0),ff=new We("touchend",!0,!0),gf=new We("touchstart",!0,!0),hf=new Xe("MSGotPointerCapture",!0,!1),jf=new Xe("MSLostPointerCapture",!0,!1),Ae=new Xe("MSPointerDown",!0,!0),De=new Xe("MSPointerMove",!0,!0),ye=new Xe("MSPointerOver",!0,!0),ze=new Xe("MSPointerOut",!0,!0),kf=new Xe("MSPointerUp",!0,!0);function T(a,b,c){c=b.c(a,c);"isTrusted"in c||(c.isTrusted=!1);return sd&&a.fireEvent?a.fireEvent("on"+b.a,c):a.dispatchEvent(c)};function lf(a,b){if(mf(a))a.selectionStart=b;else if(x){var c=nf(a),d=c[0];d.inRange(c[1])&&(b=of(a,b),d.collapse(!0),d.move("character",b),d.select())}}
function pf(a,b){var c=0,d=0;if(mf(a))c=a.selectionStart,d=b?-1:a.selectionEnd;else if(x){var e=nf(a),f=e[0],e=e[1];if(f.inRange(e)){f.setEndPoint("EndToStart",e);if("textarea"==a.type){for(var c=e.duplicate(),g=f.text,d=g,h=e=c.text,n=!1;!n;)0==f.compareEndPoints("StartToEnd",f)?n=!0:(f.moveEnd("character",-1),f.text==g?d+="\r\n":n=!0);if(b)f=[d.length,-1];else{for(f=!1;!f;)0==c.compareEndPoints("StartToEnd",c)?f=!0:(c.moveEnd("character",-1),c.text==e?h+="\r\n":f=!0);f=[d.length,d.length+h.length]}return f}c=
f.text.length;b?d=-1:d=f.text.length+e.text.length}}return[c,d]}function qf(a,b){if(mf(a))a.selectionEnd=b;else if(x){var c=nf(a),d=c[1];c[0].inRange(d)&&(b=of(a,b),c=of(a,pf(a,!0)[0]),d.collapse(!0),d.moveEnd("character",b-c),d.select())}}function rf(a,b){if(mf(a))a.selectionStart=b,a.selectionEnd=b;else if(x){b=of(a,b);var c=a.createTextRange();c.collapse(!0);c.move("character",b);c.select()}}
function sf(a,b){if(mf(a)){var c=a.value,d=a.selectionStart;a.value=c.substr(0,d)+b+c.substr(a.selectionEnd);a.selectionStart=d;a.selectionEnd=d+b.length}else if(x)d=nf(a),c=d[1],d[0].inRange(c)&&(d=c.duplicate(),c.text=b,c.setEndPoint("StartToStart",d),c.select());else throw Error("Cannot set the selection end");}function nf(a){var b=a.ownerDocument||a.document,c=b.selection.createRange();"textarea"==a.type?(b=b.body.createTextRange(),b.moveToElementText(a)):b=a.createTextRange();return[b,c]}
function of(a,b){"textarea"==a.type&&(b=a.value.substring(0,b).replace(/(\r\n|\r|\n)/g,"\n").length);return b}function mf(a){try{return"number"==typeof a.selectionStart}catch(b){return!1}};function tf(a,b){this.b={};this.a=[];this.c=this.f=0;var c=arguments.length;if(1<c){if(c%2)throw Error("Uneven number of arguments");for(var d=0;d<c;d+=2)uf(this,arguments[d],arguments[d+1])}else if(a){if(a instanceof tf)d=vf(a),c=a.B();else{var c=[],e=0;for(d in a)c[e++]=d;d=c;c=Qa(a)}for(e=0;e<d.length;e++)uf(this,d[e],c[e])}}k=tf.prototype;k.B=function(){wf(this);for(var a=[],b=0;b<this.a.length;b++)a.push(this.b[this.a[b]]);return a};function vf(a){wf(a);return a.a.concat()}
k.clear=function(){this.b={};this.c=this.f=this.a.length=0};function wf(a){if(a.f!=a.a.length){for(var b=0,c=0;b<a.a.length;){var d=a.a[b];xf(a.b,d)&&(a.a[c++]=d);b++}a.a.length=c}if(a.f!=a.a.length){for(var e={},c=b=0;b<a.a.length;)d=a.a[b],xf(e,d)||(a.a[c++]=d,e[d]=1),b++;a.a.length=c}}k.get=function(a,b){return xf(this.b,a)?this.b[a]:b};function uf(a,b,c){xf(a.b,b)||(a.f++,a.a.push(b),a.c++);a.b[b]=c}
k.forEach=function(a,b){for(var c=vf(this),d=0;d<c.length;d++){var e=c[d],f=this.get(e);a.call(b,f,e,this)}};k.clone=function(){return new tf(this)};function xf(a,b){return Object.prototype.hasOwnProperty.call(a,b)};function yf(a){if(a.B&&"function"==typeof a.B)return a.B();if(m(a))return a.split("");if(da(a)){for(var b=[],c=a.length,d=0;d<c;d++)b.push(a[d]);return b}return Qa(a)};function zf(a){this.a=new tf;if(a){a=yf(a);for(var b=a.length,c=0;c<b;c++){var d=a[c];uf(this.a,Af(d),d)}}}function Af(a){var b=typeof a;return"object"==b&&a||"function"==b?"o"+(a[ha]||(a[ha]=++ia)):b.substr(0,1)+a}zf.prototype.clear=function(){this.a.clear()};zf.prototype.contains=function(a){a=Af(a);return xf(this.a.b,a)};zf.prototype.B=function(){return this.a.B()};zf.prototype.clone=function(){return new zf(this)};function Bf(a){ne.call(this);this.c=Pd(this.a);this.f=0;this.g=new zf;a&&(r(a.pressed,function(a){Cf(this,a,!0)},this),this.f=a.currentPos||0)}p(Bf,ne);var Df={};function V(a,b,c){ga(a)&&(a=z?a.h:a.i);a=new Ef(a,b,c);!b||b in Df&&!c||(Df[b]={key:a,shift:!1},c&&(Df[c]={key:a,shift:!0}));return a}function Ef(a,b,c){this.code=a;this.a=b||null;this.b=c||this.a}var Ff=V(8),Gf=V(9),Hf=V(13),W=V(16),If=V(17),Jf=V(18),Kf=V(19);V(20);
var Lf=V(27),Mf=V(32," "),Nf=V(33),Of=V(34),Pf=V(35),Qf=V(36),Rf=V(37),Sf=V(38),Tf=V(39),Uf=V(40);V(44);var Vf=V(45),Wf=V(46);V(48,"0",")");V(49,"1","!");V(50,"2","@");V(51,"3","#");V(52,"4","$");V(53,"5","%");V(54,"6","^");V(55,"7","&");V(56,"8","*");V(57,"9","(");V(65,"a","A");V(66,"b","B");V(67,"c","C");V(68,"d","D");V(69,"e","E");V(70,"f","F");V(71,"g","G");V(72,"h","H");V(73,"i","I");V(74,"j","J");V(75,"k","K");V(76,"l","L");V(77,"m","M");V(78,"n","N");V(79,"o","O");V(80,"p","P");V(81,"q","Q");
V(82,"r","R");V(83,"s","S");V(84,"t","T");V(85,"u","U");V(86,"v","V");V(87,"w","W");V(88,"x","X");V(89,"y","Y");V(90,"z","Z");
var Xf=V($a?{h:91,i:91}:Za?{h:224,i:91}:{h:0,i:91}),Yf=V($a?{h:92,i:92}:Za?{h:224,i:93}:{h:0,i:92}),Zf=V($a?{h:93,i:93}:Za?{h:0,i:0}:{h:93,i:null}),$f=V({h:96,i:96},"0"),ag=V({h:97,i:97},"1"),bg=V({h:98,i:98},"2"),cg=V({h:99,i:99},"3"),dg=V({h:100,i:100},"4"),eg=V({h:101,i:101},"5"),fg=V({h:102,i:102},"6"),gg=V({h:103,i:103},"7"),hg=V({h:104,i:104},"8"),ig=V({h:105,i:105},"9"),jg=V({h:106,i:106},"*"),kg=V({h:107,i:107},"+"),lg=V({h:109,i:109},"-"),mg=V({h:110,i:110},"."),ng=V({h:111,i:111},"/");V(144);
var og=V(112),pg=V(113),qg=V(114),rg=V(115),sg=V(116),tg=V(117),ug=V(118),vg=V(119),wg=V(120),xg=V(121),yg=V(122),zg=V(123),Ag=V({h:107,i:187},"=","+"),Bg=V(108,",");V({h:109,i:189},"-","_");V(188,",","<");V(190,".",">");V(191,"/","?");V(192,"`","~");V(219,"[","{");V(220,"\\","|");V(221,"]","}");var Cg=V({h:59,i:186},";",":");V(222,"'",'"');var Dg=[Jf,If,Xf,W],Eg=new tf;uf(Eg,1,W);uf(Eg,2,If);uf(Eg,4,Jf);uf(Eg,8,Xf);var Fg=function(a){var b=new tf;r(vf(a),function(c){uf(b,a.get(c).code,c)});return b}(Eg);
function Cf(a,b,c){if(Ba(Dg,b)){var d=Fg.get(b.code),e=a.o;e.a=c?e.a|d:e.a&~d}c?uf(a.g.a,Af(b),b):(a=a.g.a,b=Af(b),xf(a.b,b)&&(delete a.b[b],a.f--,a.c++,a.a.length>2*a.f&&wf(a)))}var Gg=x?"\r\n":"\n";function X(a,b){return a.g.contains(b)}
function Hg(a,b){if(Ba(Dg,b)&&X(a,b))throw new t(13,"Cannot press a modifier key that is already pressed.");var c=null!==b.code&&Ig(a,df,b);if((c||z)&&(!Jg(b)||Ig(a,Ve,b,!c))&&c&&(Kg(a,b),a.c))if(b.a){if(!Lg){var c=Mg(a,b),d=pf(a.a,!0)[0]+1;Ng(a.a)?(sf(a.a,c),lf(a.a,d)):a.a.value+=c;B&&T(a.a,bf);sd||T(a.a,af);a.f=d}}else switch(b){case Hf:Lg||(B&&T(a.a,bf),Q(a.a,"TEXTAREA")&&(c=pf(a.a,!0)[0]+Gg.length,Ng(a.a)?(sf(a.a,Gg),lf(a.a,c)):a.a.value+=Gg,x||T(a.a,af),a.f=c));break;case Ff:case Wf:Lg||(Og(a.a),
c=pf(a.a,!1),c[0]==c[1]&&(b==Ff?(lf(a.a,c[1]-1),qf(a.a,c[1])):qf(a.a,c[1]+1)),c=pf(a.a,!1),c=!(c[0]==a.a.value.length||0==c[1]),sf(a.a,""),(!x&&c||z&&b==Ff)&&T(a.a,af),c=pf(a.a,!1),a.f=c[1]);break;case Rf:case Tf:Og(a.a);var c=a.a,e=pf(c,!0)[0],f=pf(c,!1)[1],g=d=0;b==Rf?X(a,W)?a.f==e?(d=Math.max(e-1,0),g=f,e=d):(d=e,e=g=f-1):e=e==f?Math.max(e-1,0):e:X(a,W)?a.f==f?(d=e,e=g=Math.min(f+1,c.value.length)):(d=e+1,g=f,e=d):e=e==f?Math.min(f+1,c.value.length):f;X(a,W)?(lf(c,d),qf(c,g)):rf(c,e);a.f=e;break;
case Qf:case Pf:Og(a.a),c=a.a,d=pf(c,!0)[0],g=pf(c,!1)[1],b==Qf?(X(a,W)?(lf(c,0),qf(c,a.f==d?g:d)):rf(c,0),a.f=0):(X(a,W)?(a.f==d&&lf(c,g),qf(c,c.value.length)):rf(c,c.value.length),a.f=c.value.length)}Cf(a,b,!0)}function Jg(a){if(a.a||a==Hf)return!0;if(B||Xa)return!1;if(x)return a==Lf;switch(a){case W:case If:case Jf:return!1;case Xf:case Yf:case Zf:return z;default:return!0}}
function Kg(a,b){if(b==Hf&&!z&&Q(a.a,"INPUT")){var c=wb(a.a,Ke,!0);if(c){var d=c.getElementsByTagName("input");(ya(d,function(a){return He(a)})||1==d.length||B&&!jd(534))&&Le(c)}}}function Pg(a,b){if(!X(a,b))throw new t(13,"Cannot release a key that is not pressed. ("+b.code+")");null===b.code||Ig(a,ef,b);Cf(a,b,!1)}function Mg(a,b){if(!b.a)throw new t(13,"not a character key");return X(a,W)?b.b:b.a}var Lg=z&&!jd(12);
function Og(a){try{a.selectionStart}catch(b){if(-1!=b.message.indexOf("does not support selection."))throw Error(b.message+" (For more information, see https://code.google.com/p/chromium/issues/detail?id=330456)");throw b;}}function Ng(a){try{Og(a)}catch(b){return!1}return!0}
function Ig(a,b,c,d){if(null===c.code)throw new t(13,"Key must have a keycode to be fired.");c={altKey:X(a,Jf),ctrlKey:X(a,If),metaKey:X(a,Xf),shiftKey:X(a,W),keyCode:c.code,charCode:c.a&&b==Ve?Mg(a,c).charCodeAt(0):0,preventDefault:!!d};return T(a.a,b,c)}function Qg(a,b){oe(a,b);a.c=Pd(b);var c=Fe(a);a.c&&c&&(rf(b,b.value.length),a.f=b.value.length)};function Rg(a,b){ne.call(this,b);this.g=this.f=null;this.c=new ib(0,0);this.G=this.w=!1;if(a){ea(a.buttonPressed)&&(this.f=a.buttonPressed);try{Q(a.elementPressed)&&(this.g=a.elementPressed)}catch(c){this.f=null}this.c=new ib(a.clientXY.x,a.clientXY.y);this.w=!!a.nextClickIsDoubleClick;this.G=!!a.hasEverInteracted;try{a.element&&Q(a.element)&&oe(this,a.element)}catch(c){this.f=null}}}p(Rg,ne);var Y={};
sd?(Y[te]=[0,0,0,null],Y[Be]=[null,null,0,null],Y[Ee]=[1,4,2,null],Y[se]=[0,0,0,0],Y[Ce]=[1,4,2,0]):B||rd?(Y[te]=[0,1,2,null],Y[Be]=[null,null,2,null],Y[Ee]=[0,1,2,null],Y[se]=[0,1,2,0],Y[Ce]=[0,1,2,0]):(Y[te]=[0,1,2,null],Y[Be]=[null,null,2,null],Y[Ee]=[0,1,2,null],Y[se]=[0,0,0,0],Y[Ce]=[0,0,0,0]);td&&(Y[Ae]=Y[Ee],Y[kf]=Y[Ee],Y[De]=[-1,-1,-1,-1],Y[ze]=Y[De],Y[ye]=Y[De]);Y[cf]=Y[te];Y[ue]=Y[Ee];Y[re]=Y[se];var Sg={};Sg[ue]=Ae;Sg[Ce]=De;Sg[se]=ze;Sg[re]=ye;Sg[Ee]=kf;
function Tg(a,b,c,d,e,f){a.G=!0;if(td){var g=Sg[b];if(g&&!xe(a,g,a.c,Ug(a,g),!0,c,e))return!1}return qe(a,b,a.c,Ug(a,b),c,d,e,null,f)}function Ug(a,b){if(!(b in Y))return 0;var c=Y[b][null===a.f?3:a.f];if(null===c)throw new t(13,"Event does not permit the specified mouse button.");return c};function Vg(a,b){this.x=a;this.y=b}p(Vg,ib);Vg.prototype.clone=function(){return new Vg(this.x,this.y)};Vg.prototype.scale=ib.prototype.scale;Vg.prototype.rotate=function(a){var b=Math.cos(a);a=Math.sin(a);var c=this.y*b+this.x*a;this.x=this.x*b-this.y*a;this.y=c;return this};function Wg(a,b,c,d){function e(a){m(a)?r(a.split(""),function(a){if(1!=a.length)throw new t(13,"Argument not a single character: "+a);var b=Df[a];b||(b=a.toUpperCase(),b=V(b.charCodeAt(0),a.toLowerCase(),b),b={key:b,shift:a!=b.a});a=b;b=X(f,W);a.shift&&!b&&Hg(f,W);Hg(f,a.key);Pg(f,a.key);a.shift&&!b&&Pg(f,W)}):Ba(Dg,a)?X(f,a)?Pg(f,a):Hg(f,a):(Hg(f,a),Pg(f,a))}if(a!=Bd(a)){if(!Cd(a))throw new t(12,"Element is not currently interactable and may not be manipulated");Xg(a)}var f=c||new Bf;Qg(f,a);if((!Eb||
Ya)&&B&&"date"==a.type){c="array"==ca(b)?b=b.join(""):b;var g=/\d{4}-\d{2}-\d{2}/;if(c.match(g)){Ya&&Eb&&(T(a,gf),T(a,ff));T(a,$e);a.value=c.match(g)[0];T(a,Ze);T(a,Ye);return}}"array"==ca(b)?r(b,e):e(b);d||r(Dg,function(a){X(f,a)&&Pg(f,a)})}
function Yg(a,b,c,d){if(!Dd(a,!0))throw new t(11,"Element is not currently visible and may not be manipulated");Xg(a,b||void 0);b?b=new Vg(b.x,b.y):(b=Zg(a),b=new Vg(b.width/2,b.height/2));c=c||new Rg;var e=b;b=Cd(a);var f=Sd(a);c.c.x=e.x+f.left;c.c.y=e.y+f.top;e=c.a;if(a!=e){try{nb(C(e)).closed&&(e=null)}catch(S){e=null}e&&(f=e===oa.document.documentElement||e===oa.document.body,e=!c.G&&f?null:e,Tg(c,se,a));oe(c,a);x||Tg(c,re,e,null,b)}Tg(c,Ce,null,null,b);x&&a!=e&&Tg(c,re,e,null,b);c.w=!1;if(null!==
c.f)throw new t(13,"Cannot press more then one button or an already pressed button.");c.f=0;c.g=c.a;var g;a=z&&!ld(4);(B||a)&&(Q(c.a,"OPTION")||Q(c.a,"SELECT"))?g=!0:((a=z||x)&&(g=Bd(c.a)),g=(b=Tg(c,ue,null,null,!1,void 0))&&a&&g!=Bd(c.a)?!1:b);g&&(td&&0==c.f&&Q(c.g,"OPTION")&&xe(c,hf,c.c,0,!0),Fe(c));if(null===c.f)throw new t(13,"Cannot release a button when no button is pressed.");c.b&&Cd(c.a)&&(g=c.b,a=Gd(c.a),!a||g.multiple)&&(c.a.selected=!a,(!B||!g.multiple||Db&&ld(28)||Cb&&ld(4))&&T(g,Ze));
g=Cd(c.a);Tg(c,Ee,null,null,d,void 0);try{if(0==c.f&&c.a==c.g){if(!ud||!Q(c.g,"OPTION")){var h=c.c,n=Ug(c,te);if(g||Cd(c.a)){a=d=null;if(!Ge)for(var q=c.a;q;q=q.parentNode)if(Q(q,"A")){d=q;break}else if(He(q)){a=q;break}var u=!c.b&&Fd(c.a),A=u&&Gd(c.a);if(x&&a)a.click();else if(qe(c,te,h,n,null,0,g,void 0))if(d&&Ie(d)){var h=d,y=h.href,I=nb(C(h));x&&!jd(8)&&(y=Je(I.location,y));h.target?I.open(y,h.target):I.location.href=y}else!u||z||B||A&&"radio"==c.a.type.toLowerCase()||(c.a.checked=!A)}}c.w&&Tg(c,
cf);c.w=!c.w;td&&0==c.f&&Q(c.g,"OPTION")&&xe(c,jf,new ib(0,0),0,!1)}else 2==c.f&&Tg(c,Be)}catch(S){}ve={};c.f=null;c.g=null}function Zg(a){var b;if("none"!=(wd(a,"display")||(a.currentStyle?a.currentStyle.display:null)||a.style&&a.style.display))b=yd(a);else{b=a.style;var c=b.display,d=b.visibility,e=b.position;b.visibility="hidden";b.position="absolute";b.display="inline";var f=yd(a);b.display=c;b.position=e;b.visibility=d;b=f}return 0<b.width&&0<b.height||!a.offsetParent?b:Zg(a.offsetParent)}
function Xg(a,b){if("scroll"==Td(a,b)){if(a.scrollIntoView&&(a.scrollIntoView(),"none"==Td(a,b)))return;for(var c=Xd(a,b),d=Od(a);d;d=Od(d)){var e=d,f=Sd(e),g;var h=e;if(x&&!fb(9)){var n=Ad(h,"borderLeft");g=Ad(h,"borderRight");var q=Ad(h,"borderTop"),h=Ad(h,"borderBottom");g=new vd(q,g,h,n)}else n=wd(h,"borderLeftWidth"),g=wd(h,"borderRightWidth"),q=wd(h,"borderTopWidth"),h=wd(h,"borderBottomWidth"),g=new vd(parseFloat(q),parseFloat(g),parseFloat(h),parseFloat(n));n=c.left-f.left-g.left;f=c.top-
f.top-g.top;g=e.clientHeight+c.top-c.bottom;e.scrollLeft+=Math.min(n,Math.max(n-(e.clientWidth+c.left-c.right),0));e.scrollTop+=Math.min(f,Math.max(f-g,0))}Td(a,b)}};function Z(a,b,c,d){function e(){return{M:f,keys:[]}}var f=!!d,g=[],h=e();g.push(h);r(b,function(a){r(a.split(""),function(a){if("\ue000"<=a&&"\ue03d">=a){var b=Z.a[a];if(null===b)g.push(h=e()),f&&(h.M=!1,g.push(h=e()));else if(l(b))h.keys.push(b);else throw Error("Unsupported WebDriver key: \\u"+a.charCodeAt(0).toString(16));}else switch(a){case "\n":h.keys.push(Hf);break;case "\t":h.keys.push(Gf);break;case "\b":h.keys.push(Ff);break;default:h.keys.push(a)}})});r(g,function(b){Wg(a,b.keys,c,b.M)})}
Z.a={};Z.a["\ue000"]=null;Z.a["\ue003"]=Ff;Z.a["\ue004"]=Gf;Z.a["\ue006"]=Hf;Z.a["\ue007"]=Hf;Z.a["\ue008"]=W;Z.a["\ue009"]=If;Z.a["\ue00a"]=Jf;Z.a["\ue00b"]=Kf;Z.a["\ue00c"]=Lf;Z.a["\ue00d"]=Mf;Z.a["\ue00e"]=Nf;Z.a["\ue00f"]=Of;Z.a["\ue010"]=Pf;Z.a["\ue011"]=Qf;Z.a["\ue012"]=Rf;Z.a["\ue013"]=Sf;Z.a["\ue014"]=Tf;Z.a["\ue015"]=Uf;Z.a["\ue016"]=Vf;Z.a["\ue017"]=Wf;Z.a["\ue018"]=Cg;Z.a["\ue019"]=Ag;Z.a["\ue01a"]=$f;Z.a["\ue01b"]=ag;Z.a["\ue01c"]=bg;Z.a["\ue01d"]=cg;Z.a["\ue01e"]=dg;Z.a["\ue01f"]=eg;
Z.a["\ue020"]=fg;Z.a["\ue021"]=gg;Z.a["\ue022"]=hg;Z.a["\ue023"]=ig;Z.a["\ue024"]=jg;Z.a["\ue025"]=kg;Z.a["\ue027"]=lg;Z.a["\ue028"]=mg;Z.a["\ue029"]=ng;Z.a["\ue026"]=Bg;Z.a["\ue031"]=og;Z.a["\ue032"]=pg;Z.a["\ue033"]=qg;Z.a["\ue034"]=rg;Z.a["\ue035"]=sg;Z.a["\ue036"]=tg;Z.a["\ue037"]=ug;Z.a["\ue038"]=vg;Z.a["\ue039"]=wg;Z.a["\ue03a"]=xg;Z.a["\ue03b"]=yg;Z.a["\ue03c"]=zg;Z.a["\ue03d"]=Xf;function $g(){}
function ah(a,b,c){if(null==b)c.push("null");else{if("object"==typeof b){if("array"==ca(b)){var d=b;b=d.length;c.push("[");for(var e="",f=0;f<b;f++)c.push(e),ah(a,d[f],c),e=",";c.push("]");return}if(b instanceof String||b instanceof Number||b instanceof Boolean)b=b.valueOf();else{c.push("{");e="";for(d in b)Object.prototype.hasOwnProperty.call(b,d)&&(f=b[d],"function"!=typeof f&&(c.push(e),bh(d,c),c.push(":"),ah(a,f,c),e=","));c.push("}");return}}switch(typeof b){case "string":bh(b,c);break;case "number":c.push(isFinite(b)&&
!isNaN(b)?String(b):"null");break;case "boolean":c.push(String(b));break;case "function":c.push("null");break;default:throw Error("Unknown type: "+typeof b);}}}var ch={'"':'\\"',"\\":"\\\\","/":"\\/","\b":"\\b","\f":"\\f","\n":"\\n","\r":"\\r","\t":"\\t","\x0B":"\\u000b"},dh=/\uffff/.test("\uffff")?/[\\\"\x00-\x1f\x7f-\uffff]/g:/[\\\"\x00-\x1f\x7f-\xff]/g;
function bh(a,b){b.push('"',a.replace(dh,function(a){var b=ch[a];b||(b="\\u"+(a.charCodeAt(0)|65536).toString(16).substr(1),ch[a]=b);return b}),'"')};B||z&&jd(3.5)||x&&jd(8);function eh(a){switch(ca(a)){case "string":case "number":case "boolean":return a;case "function":return a.toString();case "array":return wa(a,eh);case "object":if(Ra(a,"nodeType")&&(1==a.nodeType||9==a.nodeType)){var b={};b.ELEMENT=fh(a);return b}if(Ra(a,"document"))return b={},b.WINDOW=fh(a),b;if(da(a))return wa(a,eh);a=Oa(a,function(a,b){return ea(b)||m(b)});return Pa(a,eh);default:return null}}
function gh(a,b){return"array"==ca(a)?wa(a,function(a){return gh(a,b)}):ga(a)?"function"==typeof a?a:Ra(a,"ELEMENT")?hh(a.ELEMENT,b):Ra(a,"WINDOW")?hh(a.WINDOW,b):Pa(a,function(a){return gh(a,b)}):a}function ih(a){a=a||document;var b=a.$wdc_;b||(b=a.$wdc_={},b.F=na());b.F||(b.F=na());return b}function fh(a){var b=ih(a.ownerDocument),c=Sa(b,function(b){return b==a});c||(c=":wdc:"+b.F++,b[c]=a);return c}
function hh(a,b){a=decodeURIComponent(a);var c=b||document,d=ih(c);if(!Ra(d,a))throw new t(10,"Element does not exist in cache");var e=d[a];if(Ra(e,"setInterval")){if(e.closed)throw delete d[a],new t(23,"Window has been closed.");return e}for(var f=e;f;){if(f==c.documentElement)return e;f=f.parentNode}delete d[a];throw new t(10,"Element is no longer attached to the DOM");};ba("_",function(a,b){var c=[a],d;try{var e;b?e=hh(b.WINDOW):e=window;var f=gh(c,e.document),g=Yg.apply(null,f);d={status:0,value:eh(g)}}catch(h){d={status:Ra(h,"code")?h.code:13,value:{message:h.message}}}c=[];ah(new $g,d,c);return c.join("")});; return this._.apply(null,arguments);}.apply({navigator:typeof window!=undefined?window.navigator:null,document:typeof window!=undefined?window.document:null}, arguments);}
